(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    526929,       9433]
NotebookOptionsPosition[    522025,       9269]
NotebookOutlinePosition[    522543,       9288]
CellTagsIndexPosition[    522500,       9285]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Learning financial shocks and the Great Recession", "Title",
 CellChangeTimes->{{3.735877706306584*^9, 3.735877714853073*^9}, {
  3.7359687455687876`*^9, 3.735968753027214*^9}}],

Cell["Code to generate figure 10", "Subtitle",
 CellChangeTimes->{{3.7359687609266663`*^9, 3.7359688239212694`*^9}, {
   3.7362490393518615`*^9, 3.7362490454732113`*^9}, 3.736426297138093*^9, {
   3.7364278640057125`*^9, 3.736427865605804*^9}}],

Cell[TextData[{
 StyleBox["(PintusSuda_RED_ReplicationCode_Figures510.nb)\n\n",
  FontFamily->"Arial",
  FontSize->14],
 StyleBox["Model-generated recessions with endogenous labor",
  FontFamily->"Arial",
  FontSize->18,
  FontVariations->{"Underline"->True}],
 StyleBox["\n",
  FontFamily->"Arial",
  FontSize->14],
 "\nThis code generates Figure 10 in the paper \
\[OpenCurlyDoubleQuote]Learning financial shocks and the Great Recession\
\[CloseCurlyDoubleQuote] by Patrick Pintus and Jacek Suda\n\nDate: 27 May \
2018\nVersion: 1.0\n\nLeverage is defined as net borrowing (from Flow of \
Funds) over land market value\nGoal is to generate Great Recession: NBER \
2007Q4(peak) - 2009Q2(trough) with output falling by -5.1% from peak to \
trough\n\[LineSeparator]Borrowing constraint is ",
 Cell[BoxData[
  FormBox[
   RowBox[{"R", " ", 
    SubscriptBox["B", 
     RowBox[{"t", "+", "1"}]]}], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[CapitalTheta]", "t"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["E", "t"], "[", 
     SubscriptBox["Q", 
      RowBox[{"t", "+", "1"}]], "]"}], " "}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", 
    RowBox[{"t", "+", "1"}]], TraditionalForm]]],
 "\n\nDescription:\nThe code works along following steps:\n1. Load data on \
prices and leverage\n2. Estimate aurocorrelation paramter for leverage \
process under\n\ta. Adaptive (constant-gain) learning\n\tb. OLS / Rational \
Expectations\n\tc. and recover financial shocks / innovations\n3. Solve model \
under learning given the estimated coefficients\n\ta. Set paramters\n\tb. \
Find steady state\n\tc. Compute matrices corresponding to equations (31)-(33) \
in the appendix 2\n\td. Compute RE equilibrium (matrices mRE and hRE) by \
iterating over T-map\n4. Compute/generate model-generated recession under \
adaptive (constant-gain) learning\n5. Compute/generate model-generated \
recession under RE\n6. Generate figures 10\n\n\n"
}], "Text",
 CellChangeTimes->{{3.5055626546149397`*^9, 3.505562664396002*^9}, {
   3.515478244328125*^9, 3.515478278640625*^9}, {3.51550536321875*^9, 
   3.515505384265625*^9}, {3.523609599796875*^9, 3.52360973715625*^9}, {
   3.523611940359375*^9, 3.523611944390625*^9}, 3.52361496034375*^9, {
   3.527071119828125*^9, 3.527071232265625*^9}, {3.527071605140625*^9, 
   3.527071616359375*^9}, {3.527071884609375*^9, 3.52707191346875*^9}, {
   3.527093073484375*^9, 3.52709315315625*^9}, {3.5270950084375*^9, 
   3.52709501553125*^9}, {3.52709800828125*^9, 3.527098040625*^9}, {
   3.527098074*^9, 3.527098098953125*^9}, {3.5270984013125*^9, 
   3.52709841534375*^9}, {3.527154324921875*^9, 3.527154331421875*^9}, {
   3.5298220865561604`*^9, 3.5298221059469604`*^9}, {3.53058694690625*^9, 
   3.53058695396875*^9}, {3.5309832200625*^9, 3.530983223171875*^9}, {
   3.531032839920763*^9, 3.531032849093563*^9}, {3.5310329260743628`*^9, 
   3.531033064773963*^9}, {3.5310331115727625`*^9, 3.531033155344963*^9}, {
   3.5310353735915627`*^9, 3.531035402747963*^9}, {3.53122373412294*^9, 
   3.5312237392397404`*^9}, {3.53234105834375*^9, 3.532341072078125*^9}, {
   3.54513382946875*^9, 3.54513389765625*^9}, {3.545135217609375*^9, 
   3.545135252359375*^9}, 3.545137326078125*^9, {3.549085961875*^9, 
   3.549085975453125*^9}, {3.5498138241875*^9, 3.549813851546875*^9}, {
   3.550583674984375*^9, 3.550583690328125*^9}, {3.57217444778125*^9, 
   3.572174585*^9}, {3.57217481996875*^9, 3.5721748575625*^9}, {
   3.57219414078125*^9, 3.572194145828125*^9}, {3.5723346516414833`*^9, 
   3.572334655697483*^9}, {3.5727059755422745`*^9, 3.5727059896810904`*^9}, {
   3.572962743697*^9, 3.5729627493442*^9}, {3.578723180359397*^9, 
   3.578723203713597*^9}, {3.578918294483407*^9, 3.578918300161807*^9}, {
   3.590749723182*^9, 3.590749735974*^9}, {3.590810231818366*^9, 
   3.5908102370793657`*^9}, {3.593323126695361*^9, 3.593323167849161*^9}, {
   3.5933363247523613`*^9, 3.5933363705539613`*^9}, {3.59585022922041*^9, 
   3.59585024145741*^9}, {3.663396682186617*^9, 3.663396757886138*^9}, {
   3.663396824951483*^9, 3.663396837053726*^9}, {3.663397004323135*^9, 
   3.663397020837468*^9}, {3.6634781161219425`*^9, 3.663478235148855*^9}, {
   3.6639431176256847`*^9, 3.663943121325833*^9}, {3.664092176865198*^9, 
   3.664092181131417*^9}, {3.664093168512162*^9, 3.6640931807562823`*^9}, {
   3.669371802516779*^9, 3.669371816434698*^9}, {3.6693773236657906`*^9, 
   3.6693773258858576`*^9}, {3.731929192528675*^9, 3.731929249043907*^9}, {
   3.73192928161977*^9, 3.7319293037490363`*^9}, {3.735627257554847*^9, 
   3.7356274836327777`*^9}, {3.735638232098153*^9, 3.735638251639271*^9}, {
   3.735638306722421*^9, 3.73563833799221*^9}, {3.735640169638974*^9, 
   3.735640248746499*^9}, {3.7356402788092184`*^9, 3.735640311159068*^9}, {
   3.7356403676583*^9, 3.735640415269023*^9}, {3.7356446062677345`*^9, 
   3.735644645254965*^9}, {3.7357280045509167`*^9, 3.735728006851048*^9}, 
   3.735814294960184*^9, {3.7358340186463146`*^9, 3.735834084468079*^9}, {
   3.7358776700015078`*^9, 3.7358776708225546`*^9}, {3.735877720339387*^9, 
   3.735877722718523*^9}, {3.735909128422919*^9, 3.7359091704983253`*^9}, {
   3.7362490491634226`*^9, 3.736249078908124*^9}, {3.736249117465329*^9, 
   3.736249117758346*^9}, {3.7364266028955812`*^9, 3.7364269687485065`*^9}, {
   3.736427192859325*^9, 3.7364272021228547`*^9}},
 FontSize->12],

Cell[CellGroupData[{

Cell["0. Setting figure", "Section",
 CellChangeTimes->{{3.73572801929976*^9, 3.7357280276672387`*^9}, 
   3.735877766624034*^9, {3.7364269514215155`*^9, 3.736426952108555*^9}}],

Cell["\<\
Choose figure/table/data to generate
Set outputToProduce to
           - \[OpenCurlyDoubleQuote]Figure10\[CloseCurlyDoubleQuote]   to \
generate Figure 10

\
\>", "Text",
 CellChangeTimes->{{3.7357280482114134`*^9, 3.735728099186329*^9}, {
  3.7357285277278404`*^9, 3.735728586799219*^9}, {3.735728769085645*^9, 
  3.7357287827654276`*^9}, {3.7357289053734407`*^9, 3.735728957132401*^9}, {
  3.7357290399801397`*^9, 3.73572904522744*^9}, {3.7357355186706996`*^9, 
  3.7357355256781006`*^9}, {3.7358039746808977`*^9, 3.7358039773210487`*^9}, {
  3.735877758715582*^9, 3.735877760536686*^9}, {3.736418560552585*^9, 
  3.736418600935895*^9}, {3.736426316865221*^9, 3.7364263268807936`*^9}, {
  3.7364272093872705`*^9, 3.7364272142825503`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"outputToProduce", "=", "\"\<Figure10\>\""}], ";"}]], "Input",
 CellChangeTimes->{{3.735729024529256*^9, 3.735729055149007*^9}, {
   3.7357341625211325`*^9, 3.7357341630001593`*^9}, 3.7357355021587553`*^9, {
   3.735735761309578*^9, 3.735735762349637*^9}, 3.7357359279481087`*^9, 
   3.73573702316295*^9, {3.7357371618338814`*^9, 3.7357371624099145`*^9}, {
   3.735737480984136*^9, 3.735737483271267*^9}, {3.735737879876951*^9, 
   3.7357378800529613`*^9}, 3.7358042418961816`*^9, 3.735805098273164*^9, 
   3.735832364001674*^9, {3.735834134900964*^9, 3.7358341351569786`*^9}, 
   3.7359072796011724`*^9, {3.7359075070531816`*^9, 3.7359075074342036`*^9}, 
   3.735907548238538*^9, 3.735907763429846*^9, 3.7359092133477764`*^9, {
   3.736418564024784*^9, 3.7364185640887876`*^9}, 3.7364185972406836`*^9, {
   3.736426329665953*^9, 3.7364263313610497`*^9}, {3.736427205771064*^9, 
   3.7364272074351587`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SeedRandom", "[", "1234", "]"}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1. Data", "Section",
 CellChangeTimes->{{3.7362491315621357`*^9, 3.736249132442186*^9}}],

Cell["\<\
The data were kindly proviced by Emilie Boz and Enqrique Mednoza and \
originally used in their paper \[OpenCurlyDoubleQuote]Financial innovation, \
the discovery of risk, and the U.S. credit crisis.\[CloseCurlyDoubleQuote] \
(2015, Journal of Monetary Economics 65: 1-22)

\[OpenCurlyDoubleQuote]p\[CloseCurlyDoubleQuote] is  price index for \
residential land for 1975q1 - 2010 q1

\[OpenCurlyDoubleQuote]leverage\[CloseCurlyDoubleQuote] is net borrowing over \
land value for 1975q1 - 2010 q1 computed as the ratio of Net credit market \
assets/GDP and  Aggregate market value of residential land/GDP

\[OpenCurlyDoubleQuote]Net credit market assets\[CloseCurlyDoubleQuote] equal \
of households and nonprofit organizations credit market instruments, \
excluding corporate equities asset minus households and nonprofit \
organizations credit and equity market instruments liability\
\>", "Text",
 CellChangeTimes->{{3.7362491394225855`*^9, 3.736249143087795*^9}, {
   3.7362496696209106`*^9, 3.736249780770268*^9}, 3.7362504687206163`*^9, {
   3.7362505330972986`*^9, 3.736250541151759*^9}, {3.7362507338767824`*^9, 
   3.7362507694368167`*^9}, {3.736252766571046*^9, 3.7362527739574685`*^9}, {
   3.736253228190449*^9, 3.7362532781303053`*^9}, {3.7362533199256964`*^9, 
   3.7362533490123596`*^9}, {3.7364119533506746`*^9, 3.736411971285701*^9}, {
   3.736412589092037*^9, 3.7364126678895445`*^9}},
 FontSize->12],

Cell[CellGroupData[{

Cell["a. Data on land prices", "Subsection",
 CellChangeTimes->{{3.736253377667999*^9, 3.736253381635226*^9}, {
  3.736253508273469*^9, 3.736253514513826*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "p", " ", "is", " ", "LAND", " ", "price", " ", "index", " ", "1975", 
     "q1"}], " ", "-", " ", 
    RowBox[{"2010", "q1"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"p", " ", "=", " ", 
     RowBox[{"{", 
      RowBox[{
      "0.185733201", ",", "0.192412353", ",", "0.186620969", ",", 
       "0.189045805", ",", "0.195385886", ",", "0.204149135", ",", 
       "0.203945961", ",", "0.206161947", ",", "0.216595331", ",", 
       "0.233813564", ",", "0.234330938", ",", "0.245057176", ",", 
       "0.25282471", ",", "0.2683388", ",", "0.278218769", ",", "0.288378955",
        ",", "0.317133261", ",", "0.324002058", ",", "0.324231715", ",", 
       "0.328562771", ",", "0.328154954", ",", "0.327765202", ",", 
       "0.343024559", ",", "0.326450198", ",", "0.319331066", ",", 
       "0.332110463", ",", "0.336065788", ",", "0.33020155", ",", 
       "0.330676907", ",", "0.325245184", ",", "0.311386718", ",", 
       "0.315644532", ",", "0.332548006", ",", "0.344001318", ",", 
       "0.348396525", ",", "0.345430069", ",", "0.357110028", ",", 
       "0.370018941", ",", "0.373115859", ",", "0.380631979", ",", 
       "0.392648746", ",", "0.410205022", ",", "0.426252414", ",", 
       "0.432733079", ",", "0.448252681", ",", "0.468158498", ",", 
       "0.47919974", ",", "0.489247252", ",", "0.510344001", ",", 
       "0.528858994", ",", "0.540823207", ",", "0.543753807", ",", 
       "0.557797449", ",", "0.5807496", ",", "0.591603174", ",", "0.59852908",
        ",", "0.610436116", ",", "0.620539007", ",", "0.654547045", ",", 
       "0.665061792", ",", "0.661358135", ",", "0.659403904", ",", 
       "0.659856205", ",", "0.650687864", ",", "0.663178767", ",", 
       "0.657858422", ",", "0.651672438", ",", "0.670770908", ",", 
       "0.692703489", ",", "0.680841542", ",", "0.689344452", ",", 
       "0.689232807", ",", "0.672342261", ",", "0.683863646", ",", 
       "0.688461562", ",", "0.699176294", ",", "0.7056163", ",", 
       "0.716454323", ",", "0.71535913", ",", "0.706033391", ",", 
       "0.698343089", ",", "0.707283338", ",", "0.720218456", ",", 
       "0.725975265", ",", "0.743411558", ",", "0.752475555", ",", 
       "0.74865203", ",", "0.75395015", ",", "0.760781296", ",", 
       "0.773903461", ",", "0.776488439", ",", "0.788081097", ",", 
       "0.812584264", ",", "0.83312446", ",", "0.849141018", ",", 
       "0.870017737", ",", "0.887588191", ",", "0.906307618", ",", 
       "0.929408176", ",", "0.955143848", ",", "0.970554386", ",", "1.0", ",",
        " ", "1.031864789", ",", "1.065069827", ",", "1.093999366", ",", 
       "1.123260306", ",", "1.135450645", ",", "1.164197583", ",", 
       "1.220668557", ",", "1.268852106", ",", "1.325243235", ",", 
       "1.354112619", ",", "1.360509083", ",", "1.417848824", ",", 
       "1.474769618", ",", "1.506010072", ",", "1.526536859", ",", 
       "1.549753766", ",", "1.590038106", ",", "1.652132002", ",", 
       "1.708503626", ",", "1.763643095", ",", "1.795621486", ",", 
       "1.843919939", ",", "1.861688053", ",", "1.861012489", ",", 
       "1.870015176", ",", "1.881466586", ",", "1.906764405", ",", 
       "1.921743465", ",", "1.87551625", ",", "1.807488189", ",", 
       "1.741527345", ",", "1.666399658", ",", "1.583641487", ",", 
       "1.527787202", ",", "1.546870196", ",", "1.566583146", ",", 
       "1.583569469", ",", "1.539171213", ",", "1.446931686"}], "}"}]}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pmean", "=", 
     RowBox[{"Mean", "[", "p", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p", "=", 
     RowBox[{"Log", " ", "[", "p", "]"}]}], ";"}], "      ", 
   RowBox[{"(*", " ", 
    RowBox[{"Taking", " ", "the", " ", "log", " ", "of", " ", "prices"}], " ",
     "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Plot", " ", "of", " ", "price", " ", "data"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"DateListPlot", "[", 
    RowBox[{
     RowBox[{"Exp", "[", "p", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1975", ",", "1", ",", "1"}], "}"}], ",", "Automatic", ",", 
       "\"\<Quarter\>\""}], "}"}], ",", 
     RowBox[{"Joined", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"True", ",", "False"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Price\>\""}]}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.736253852632165*^9, 3.7362538578164616`*^9}, {
  3.736411935687665*^9, 3.736411944471167*^9}, {3.736412673602871*^9, 
  3.736412683410432*^9}},
 FontSize->10],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwl1QtQk1caBuBocbkpYEu3JogEKxIY1AisYXVVvi2ToGhBLlHQFWpBi0WC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     "]]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  AxesOrigin->{2.3667552*^9, 0.185733201},
  Frame->True,
  FrameLabel->{None, None},
  FrameTicks->{{Automatic, Automatic}, {{{2208988800, 
       FormBox["\"1970\"", TraditionalForm]}, {2524521600, 
       FormBox["\"1980\"", TraditionalForm]}, {2840140800, 
       FormBox["\"1990\"", TraditionalForm]}, {3155673600, 
       FormBox["\"2000\"", TraditionalForm]}, {3471292800, 
       FormBox["\"2010\"", TraditionalForm]}, {2272060800, 
       FormBox["\"\"", TraditionalForm]}, {2335219200, 
       FormBox["\"\"", TraditionalForm]}, {2398291200, 
       FormBox["\"\"", TraditionalForm]}, {2461449600, 
       FormBox["\"\"", TraditionalForm]}, {2587680000, 
       FormBox["\"\"", TraditionalForm]}, {2650752000, 
       FormBox["\"\"", TraditionalForm]}, {2713910400, 
       FormBox["\"\"", TraditionalForm]}, {2776982400, 
       FormBox["\"\"", TraditionalForm]}, {2903212800, 
       FormBox["\"\"", TraditionalForm]}, {2966371200, 
       FormBox["\"\"", TraditionalForm]}, {3029443200, 
       FormBox["\"\"", TraditionalForm]}, {3092601600, 
       FormBox["\"\"", TraditionalForm]}, {3218832000, 
       FormBox["\"\"", TraditionalForm]}, {3281904000, 
       FormBox["\"\"", TraditionalForm]}, {3345062400, 
       FormBox["\"\"", TraditionalForm]}, {3408134400, 
       FormBox["\"\"", TraditionalForm]}}, {{2208988800, 
       FormBox["\"\"", TraditionalForm]}, {2524521600, 
       FormBox["\"\"", TraditionalForm]}, {2840140800, 
       FormBox["\"\"", TraditionalForm]}, {3155673600, 
       FormBox["\"\"", TraditionalForm]}, {3471292800, 
       FormBox["\"\"", TraditionalForm]}, {2272060800, 
       FormBox["\"\"", TraditionalForm]}, {2335219200, 
       FormBox["\"\"", TraditionalForm]}, {2398291200, 
       FormBox["\"\"", TraditionalForm]}, {2461449600, 
       FormBox["\"\"", TraditionalForm]}, {2587680000, 
       FormBox["\"\"", TraditionalForm]}, {2650752000, 
       FormBox["\"\"", TraditionalForm]}, {2713910400, 
       FormBox["\"\"", TraditionalForm]}, {2776982400, 
       FormBox["\"\"", TraditionalForm]}, {2903212800, 
       FormBox["\"\"", TraditionalForm]}, {2966371200, 
       FormBox["\"\"", TraditionalForm]}, {3029443200, 
       FormBox["\"\"", TraditionalForm]}, {3092601600, 
       FormBox["\"\"", TraditionalForm]}, {3218832000, 
       FormBox["\"\"", TraditionalForm]}, {3281904000, 
       FormBox["\"\"", TraditionalForm]}, {3345062400, 
       FormBox["\"\"", TraditionalForm]}, {3408134400, 
       FormBox["\"\"", TraditionalForm]}}}},
  GridLines->{{{2208988800, 
      GrayLevel[0.8]}, {2524521600, 
      GrayLevel[0.8]}, {2840140800, 
      GrayLevel[0.8]}, {3155673600, 
      GrayLevel[0.8]}, {3471292800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"Price\"", TraditionalForm],
  PlotRangeClipping->True,
  Ticks->None]], "Output",
 CellChangeTimes->{3.736414619282158*^9, 3.736414997340781*^9, 
  3.7364261871508017`*^9, 3.7364262872215257`*^9, 3.7364264588993444`*^9, 
  3.7364265307644553`*^9, 3.736426969929574*^9, 3.7364277216805716`*^9, 
  3.736427773940561*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["b. Data on leverage", "Subsection",
 CellChangeTimes->{{3.736253377667999*^9, 3.736253381635226*^9}, {
  3.7362534413696423`*^9, 3.7362534439387894`*^9}, {3.736253516747954*^9, 
  3.7362535186450624`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Leverage", " ", "is", " ", "NET", " ", "borrowing", " ", "over", " ", 
     "LAND", " ", "value", " ", "1975", "q1"}], " ", "-", " ", 
    RowBox[{"2010", " ", "q1"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"leverage", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.487374449"}], ",", 
       RowBox[{"-", "0.481462724"}], ",", 
       RowBox[{"-", "0.503472298"}], ",", 
       RowBox[{"-", "0.507668317"}], ",", 
       RowBox[{"-", "0.513707855"}], ",", 
       RowBox[{"-", "0.503532455"}], ",", 
       RowBox[{"-", "0.525717607"}], ",", 
       RowBox[{"-", "0.545430709"}], ",", 
       RowBox[{"-", "0.536833891"}], ",", 
       RowBox[{"-", "0.523672256"}], ",", 
       RowBox[{"-", "0.550388874"}], ",", 
       RowBox[{"-", "0.548808217"}], ",", 
       RowBox[{"-", "0.552596807"}], ",", 
       RowBox[{"-", "0.543616116"}], ",", 
       RowBox[{"-", "0.549233219"}], ",", 
       RowBox[{"-", "0.548975294"}], ",", 
       RowBox[{"-", "0.515491696"}], ",", 
       RowBox[{"-", "0.517976717"}], ",", 
       RowBox[{"-", "0.538630428"}], ",", 
       RowBox[{"-", "0.539839212"}], ",", 
       RowBox[{"-", "0.557484666"}], ",", 
       RowBox[{"-", "0.571488044"}], ",", 
       RowBox[{"-", "0.561861504"}], ",", 
       RowBox[{"-", "0.597937858"}], ",", 
       RowBox[{"-", "0.629022319"}], ",", 
       RowBox[{"-", "0.62215739"}], ",", 
       RowBox[{"-", "0.62579605"}], ",", 
       RowBox[{"-", "0.643698876"}], ",", 
       RowBox[{"-", "0.641861012"}], ",", 
       RowBox[{"-", "0.647013723"}], ",", 
       RowBox[{"-", "0.669127577"}], ",", 
       RowBox[{"-", "0.672660528"}], ",", 
       RowBox[{"-", "0.636052654"}], ",", 
       RowBox[{"-", "0.625135987"}], ",", 
       RowBox[{"-", "0.628434906"}], ",", 
       RowBox[{"-", "0.6499382"}], ",", 
       RowBox[{"-", "0.652872307"}], ",", 
       RowBox[{"-", "0.62672708"}], ",", 
       RowBox[{"-", "0.630824192"}], ",", 
       RowBox[{"-", "0.645720073"}], ",", "\n", 
       RowBox[{"-", "0.628340885"}], ",", 
       RowBox[{"-", "0.628829351"}], ",", 
       RowBox[{"-", "0.633288553"}], ",", 
       RowBox[{"-", "0.652369711"}], ",", 
       RowBox[{"-", "0.659236302"}], ",", 
       RowBox[{"-", "0.654478018"}], ",", 
       RowBox[{"-", "0.669403316"}], ",", 
       RowBox[{"-", "0.673074539"}], ",", 
       RowBox[{"-", "0.641684907"}], ",", 
       RowBox[{"-", "0.631979617"}], ",", 
       RowBox[{"-", "0.620337378"}], ",", 
       RowBox[{"-", "0.618699071"}], ",", 
       RowBox[{"-", "0.625460628"}], ",", 
       RowBox[{"-", "0.607057475"}], ",", 
       RowBox[{"-", "0.594974824"}], ",", 
       RowBox[{"-", "0.588528572"}], ",", 
       RowBox[{"-", "0.578008103"}], ",", 
       RowBox[{"-", "0.58887114"}], ",", 
       RowBox[{"-", "0.571024246"}], ",", 
       RowBox[{"-", "0.582955808"}], ",", 
       RowBox[{"-", "0.600126383"}], ",", 
       RowBox[{"-", "0.605618422"}], ",", 
       RowBox[{"-", "0.601449548"}], ",", 
       RowBox[{"-", "0.592584524"}], ",", 
       RowBox[{"-", "0.597831609"}], ",", 
       RowBox[{"-", "0.604986345"}], ",", 
       RowBox[{"-", "0.612404757"}], ",", 
       RowBox[{"-", "0.604582819"}], ",", 
       RowBox[{"-", "0.598582396"}], ",", 
       RowBox[{"-", "0.615391576"}], ",", 
       RowBox[{"-", "0.61525654"}], ",", 
       RowBox[{"-", "0.627447447"}], ",", 
       RowBox[{"-", "0.645526675"}], ",", 
       RowBox[{"-", "0.658129285"}], ",", 
       RowBox[{"-", "0.685438548"}], ",", 
       RowBox[{"-", "0.686003474"}], ",", 
       RowBox[{"-", "0.677153524"}], ",", 
       RowBox[{"-", "0.669159022"}], ",", 
       RowBox[{"-", "0.670135908"}], ",", 
       RowBox[{"-", "0.677791227"}], ",", 
       RowBox[{"-", "0.704579925"}], ",", 
       RowBox[{"-", "0.72746818"}], ",", 
       RowBox[{"-", "0.711410115"}], ",", 
       RowBox[{"-", "0.734888264"}], ",", 
       RowBox[{"-", "0.734704988"}], ",", 
       RowBox[{"-", "0.72468342"}], ",", 
       RowBox[{"-", "0.733275394"}], ",", 
       RowBox[{"-", "0.74525154"}], ",", 
       RowBox[{"-", "0.76012619"}], ",", 
       RowBox[{"-", "0.774835942"}], ",", 
       RowBox[{"-", "0.790264406"}], ",", 
       RowBox[{"-", "0.790423888"}], ",", 
       RowBox[{"-", "0.78164857"}], ",", 
       RowBox[{"-", "0.771800801"}], ",", 
       RowBox[{"-", "0.772118663"}], ",", 
       RowBox[{"-", "0.797077364"}], ",", 
       RowBox[{"-", "0.789869748"}], ",", 
       RowBox[{"-", "0.796251025"}], ",", 
       RowBox[{"-", "0.798006681"}], ",", 
       RowBox[{"-", "0.796986657"}], ",", 
       RowBox[{"-", "0.819400233"}], ",", 
       RowBox[{"-", "0.828117648"}], ",", 
       RowBox[{"-", "0.829669535"}], ",", 
       RowBox[{"-", "0.841809895"}], ",", 
       RowBox[{"-", "0.836939556"}], ",", 
       RowBox[{"-", "0.845124375"}], ",", 
       RowBox[{"-", "0.861157767"}], ",", 
       RowBox[{"-", "0.898097624"}], ",", 
       RowBox[{"-", "0.870536729"}], ",", 
       RowBox[{"-", "0.865104569"}], ",", 
       RowBox[{"-", "0.863390534"}], ",", 
       RowBox[{"-", "0.868916829"}], ",", 
       RowBox[{"-", "0.900354405"}], ",", 
       RowBox[{"-", "0.896101908"}], ",", 
       RowBox[{"-", "0.881340349"}], ",", 
       RowBox[{"-", "0.878799025"}], ",", 
       RowBox[{"-", "0.903607881"}], ",", 
       RowBox[{"-", "0.909177577"}], ",", 
       RowBox[{"-", "0.905030024"}], ",", 
       RowBox[{"-", "0.888723642"}], ",", 
       RowBox[{"-", "0.883172724"}], ",", 
       RowBox[{"-", "0.875352037"}], ",", 
       RowBox[{"-", "0.889908788"}], ",", 
       RowBox[{"-", "0.877548694"}], ",", 
       RowBox[{"-", "0.885492374"}], ",", 
       RowBox[{"-", "0.910713593"}], ",", 
       RowBox[{"-", "0.935530842"}], ",", 
       RowBox[{"-", "0.95907905"}], ",", 
       RowBox[{"-", "0.954016162"}], ",", 
       RowBox[{"-", "0.965804178"}], ",", 
       RowBox[{"-", "0.97728864"}], ",", 
       RowBox[{"-", "1.021448597"}], ",", 
       RowBox[{"-", "1.083176159"}], ",", 
       RowBox[{"-", "1.124117207"}], ",", 
       RowBox[{"-", "1.178305763"}], ",", 
       RowBox[{"-", "1.261431097"}], ",", 
       RowBox[{"-", "1.200543588"}], ",", 
       RowBox[{"-", "1.201963532"}], ",", 
       RowBox[{"-", "1.177181608"}], ",", 
       RowBox[{"-", "1.214710928"}], ",", 
       RowBox[{"-", "1.276826542"}]}], "\[IndentingNewLine]", "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"leverage", " ", "=", " ", 
     RowBox[{"Log", "[", 
      RowBox[{"-", "leverage"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Mean", "[", 
     RowBox[{"Exp", "[", "leverage", "]"}], "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.5715472737926807`*^9, 3.571547337986681*^9}, 
   3.571547575033681*^9, {3.571547641770481*^9, 3.5715476945296807`*^9}, {
   3.571548133346481*^9, 3.571548150475281*^9}, {3.57198841313037*^9, 
   3.571988413358383*^9}, {3.571988520682522*^9, 3.5719886102266436`*^9}, {
   3.571988767476638*^9, 3.571988769660763*^9}, 3.571988845331091*^9, {
   3.5719892566286154`*^9, 3.57198928572128*^9}, 3.5719893625026712`*^9, 
   3.571989393827463*^9, {3.5719899460400476`*^9, 3.5719899685183334`*^9}, {
   3.571998100302228*^9, 3.571998110442808*^9}, {3.571999087667702*^9, 
   3.5719991280640125`*^9}, {3.57200498796918*^9, 3.5720049881841927`*^9}, {
   3.5720057115235653`*^9, 3.5720057146417437`*^9}, {3.5720057475806274`*^9, 
   3.572005770893961*^9}, 3.572005861137122*^9, {3.5720060663458595`*^9, 
   3.572006066821887*^9}, {3.5720066460580177`*^9, 3.5720066520433598`*^9}, {
   3.5720068600492573`*^9, 3.572006921925796*^9}, {3.5720072296503973`*^9, 
   3.572007243987217*^9}, {3.572008451360275*^9, 3.5720084517392964`*^9}, {
   3.5720085340800056`*^9, 3.5720085345660343`*^9}, {3.5720085915012903`*^9, 
   3.572008594245447*^9}, {3.572009654914114*^9, 3.5720096570332355`*^9}, {
   3.5720098021185336`*^9, 3.5720098350734186`*^9}, 3.5728634958268485`*^9, {
   3.5728663338434486`*^9, 3.5728664171328487`*^9}, {3.5728664924496484`*^9, 
   3.572866502730048*^9}, {3.5728665364728484`*^9, 3.5728665984516487`*^9}, {
   3.5728667390076485`*^9, 3.5728667395380487`*^9}, 3.5728667752308483`*^9, 
   3.5728669402164483`*^9, {3.573043425625*^9, 3.57304342565625*^9}, {
   3.573043572484375*^9, 3.57304357403125*^9}, {3.573043936359375*^9, 
   3.5730439368125*^9}, {3.57304402296875*^9, 3.573044023453125*^9}, {
   3.57304412515625*^9, 3.573044125703125*^9}, 3.573044728375*^9, {
   3.573044891234375*^9, 3.57304489203125*^9}, {3.573044980875*^9, 
   3.57304498134375*^9}, {3.573045276953125*^9, 3.573045314375*^9}, {
   3.573045386984375*^9, 3.573045389296875*^9}, {3.573046243296875*^9, 
   3.57304624471875*^9}, {3.57304635959375*^9, 3.573046363125*^9}, 
   3.573046510234375*^9, {3.573046992546875*^9, 3.57304699265625*^9}, {
   3.5730476458125*^9, 3.573047646171875*^9}, 3.57304789215625*^9, {
   3.573048009890625*^9, 3.57304801090625*^9}, {3.57304809521875*^9, 
   3.573048095265625*^9}, 3.57304827784375*^9, {3.57304849571875*^9, 
   3.57304849778125*^9}, 3.57304860090625*^9, 3.573048706921875*^9, {
   3.57304887340625*^9, 3.573048874453125*^9}, 3.57304901746875*^9, {
   3.573049108953125*^9, 3.573049110171875*^9}, 3.57304920725*^9, 
   3.573049324703125*^9, {3.573049679234375*^9, 3.57304967959375*^9}, {
   3.573049772140625*^9, 3.573049773953125*^9}, {3.573049893609375*^9, 
   3.573049895*^9}, 3.573050059171875*^9, {3.573050278796875*^9, 
   3.57305028521875*^9}, 3.57305059425*^9, {3.5730507170625*^9, 
   3.5730507209375*^9}, 3.573050920328125*^9, 3.573051021140625*^9, {
   3.573051129390625*^9, 3.573051129453125*^9}, {3.5730551025625*^9, 
   3.5730551093125*^9}, {3.573055257609375*^9, 3.573055259140625*^9}, {
   3.573055377140625*^9, 3.573055379125*^9}, 3.573056173234375*^9, {
   3.57305626421875*^9, 3.573056269453125*^9}, 3.573056382953125*^9, 
   3.573056883453125*^9, {3.57305754640625*^9, 3.57305754678125*^9}, {
   3.5730576731875*^9, 3.57305767321875*^9}, {3.5730577636875*^9, 
   3.573057764140625*^9}, {3.573057865984375*^9, 3.5730578670625*^9}, 
   3.573057963671875*^9, 3.57305805021875*^9, {3.57305813915625*^9, 
   3.573058141015625*^9}, {3.573058233734375*^9, 3.573058235484375*^9}, {
   3.57305837325*^9, 3.57305837328125*^9}, 3.57305848609375*^9, 
   3.57305861859375*^9, {3.573058718125*^9, 3.573058719875*^9}, {
   3.573058813296875*^9, 3.573058819609375*^9}, {3.573059228609375*^9, 
   3.5730592301875*^9}, {3.57306083553125*^9, 3.57306083821875*^9}, {
   3.573060927359375*^9, 3.57306092853125*^9}, {3.5730609975625*^9, 
   3.57306099803125*^9}, 3.57306108621875*^9, 3.573061155859375*^9, {
   3.57306203934375*^9, 3.5730620423125*^9}, {3.573062279640625*^9, 
   3.57306227971875*^9}, {3.57306234890625*^9, 3.573062348984375*^9}, 
   3.573062437609375*^9, 3.57306251284375*^9, {3.573062613875*^9, 
   3.57306261590625*^9}, {3.57306269125*^9, 3.5730627*^9}, {
   3.573062770046875*^9, 3.57306277509375*^9}, 3.573063027765625*^9, {
   3.57306310303125*^9, 3.57306310309375*^9}, 3.573063180703125*^9, {
   3.573063251984375*^9, 3.57306326121875*^9}, {3.57306333728125*^9, 
   3.5730633430625*^9}, {3.573063508015625*^9, 3.57306350890625*^9}, {
   3.573063582390625*^9, 3.5730635838125*^9}, {3.573063660703125*^9, 
   3.573063663125*^9}, 3.57306374840625*^9, {3.573063813140625*^9, 
   3.573063819578125*^9}, {3.5730644336875*^9, 3.573064435890625*^9}, {
   3.573065101453125*^9, 3.57306510284375*^9}, {3.573065464953125*^9, 
   3.573065465328125*^9}, 3.573065554546875*^9, 3.57306564259375*^9, {
   3.57306706615625*^9, 3.573067067125*^9}, {3.57306726103125*^9, 
   3.5730672610625*^9}, {3.57306734809375*^9, 3.573067348171875*^9}, {
   3.573067447921875*^9, 3.5730674520625*^9}, {3.573067616*^9, 
   3.57306761740625*^9}, 3.573067725015625*^9, {3.573105081453125*^9, 
   3.573105084078125*^9}, {3.573105173265625*^9, 3.573105173640625*^9}, {
   3.573105282078125*^9, 3.573105282390625*^9}, {3.573105528203125*^9, 
   3.5731055411875*^9}, {3.573105720453125*^9, 3.57310572334375*^9}, {
   3.573105814265625*^9, 3.573105820296875*^9}, {3.57310591440625*^9, 
   3.573105923171875*^9}, {3.57310602525*^9, 3.57310602775*^9}, {
   3.57310611509375*^9, 3.57310611559375*^9}, {3.5731063356875*^9, 
   3.57310633575*^9}, 3.573106437578125*^9, 3.5731065405625*^9, {
   3.5731066643125*^9, 3.573106665234375*^9}, {3.5731067633125*^9, 
   3.573106764234375*^9}, {3.57310687759375*^9, 3.573106878046875*^9}, {
   3.573107046015625*^9, 3.57310704659375*^9}, {3.573107348171875*^9, 
   3.573107376984375*^9}, {3.573107531359375*^9, 3.573107532296875*^9}, {
   3.573107616328125*^9, 3.573107623671875*^9}, {3.57310771153125*^9, 
   3.573107722234375*^9}, {3.573107780359375*^9, 3.573107780734375*^9}, {
   3.57310807953125*^9, 3.573108091375*^9}, 3.573108125015625*^9, 
   3.573108219796875*^9, 3.573108281234375*^9, {3.57310869725*^9, 
   3.573108698*^9}, {3.573108790859375*^9, 3.573108791578125*^9}, {
   3.5731088273125*^9, 3.57310883853125*^9}, {3.573108869140625*^9, 
   3.573108922140625*^9}, {3.573109097328125*^9, 3.57310917421875*^9}, {
   3.573109251328125*^9, 3.57310925315625*^9}, {3.573109375203125*^9, 
   3.5731093824375*^9}, {3.573109505390625*^9, 3.573109506*^9}, {
   3.573109601546875*^9, 3.57310960425*^9}, {3.573109688328125*^9, 
   3.57310968871875*^9}, {3.57310989978125*^9, 3.57310990015625*^9}, 
   3.573109979828125*^9, {3.573110064859375*^9, 3.573110066375*^9}, 
   3.57311014909375*^9, {3.57311023571875*^9, 3.573110236359375*^9}, {
   3.57311033515625*^9, 3.573110336015625*^9}, {3.573110416875*^9, 
   3.573110417390625*^9}, {3.5731105285625*^9, 3.57311053165625*^9}, {
   3.57311056728125*^9, 3.573110568125*^9}, {3.57311295853125*^9, 
   3.573112960453125*^9}, {3.573113053953125*^9, 3.573113054859375*^9}, {
   3.573113217*^9, 3.573113217984375*^9}, {3.573113304890625*^9, 
   3.5731133053125*^9}, {3.57311349903125*^9, 3.573113501921875*^9}, {
   3.573113862984375*^9, 3.573113863609375*^9}, 3.5731141493125*^9, {
   3.573114571375*^9, 3.573114574640625*^9}, {3.573115201109375*^9, 
   3.57311520153125*^9}, 3.573115518359375*^9, {3.573115832546875*^9, 
   3.57311583584375*^9}, {3.573116106328125*^9, 3.573116114625*^9}, 
   3.57311733771875*^9, {3.573117479359375*^9, 3.57311751259375*^9}, 
   3.573117584671875*^9, {3.573198375856311*^9, 3.573198376152711*^9}, {
   3.5731984388647113`*^9, 3.573198439722711*^9}, {3.573198504713311*^9, 
   3.573198506460511*^9}, {3.5731985990153112`*^9, 3.573198599717311*^9}, {
   3.573198667873711*^9, 3.573198668279311*^9}, {3.5731987360457115`*^9, 
   3.573198736966111*^9}, {3.5731988173989115`*^9, 3.573198817866911*^9}, {
   3.573199362567911*^9, 3.5731993678875113`*^9}, {3.57322736971875*^9, 
   3.573227369984375*^9}, 3.57322745134375*^9, {3.57322831453125*^9, 
   3.57322832828125*^9}, {3.57323254934375*^9, 3.573232550546875*^9}, {
   3.57323266234375*^9, 3.573232662453125*^9}, {3.573232785234375*^9, 
   3.5732327873125*^9}, {3.57323285525*^9, 3.573232856609375*^9}, 
   3.573232970125*^9, {3.5732330624375*^9, 3.57323306725*^9}, {
   3.57323315678125*^9, 3.573233156890625*^9}, 3.573233270203125*^9, 
   3.573538168305842*^9, {3.573538243263842*^9, 3.573538243763042*^9}, {
   3.573538307006442*^9, 3.573538334291842*^9}, {3.573538485736642*^9, 
   3.573538486173442*^9}, {3.5735386820792418`*^9, 3.573538683296042*^9}, {
   3.573538725431642*^9, 3.573538735197242*^9}, {3.573538820279642*^9, 
   3.5735388206852417`*^9}, {3.5735388701372423`*^9, 3.573538870511642*^9}, {
   3.5735389710174417`*^9, 3.573538971469842*^9}, {3.5735391615880423`*^9, 
   3.573539161993642*^9}, {3.573539533253042*^9, 3.573539592018242*^9}, {
   3.573540112921842*^9, 3.5735401132650423`*^9}, {3.5735402528724422`*^9, 
   3.573540253418442*^9}, {3.573540355411242*^9, 3.5735403558636417`*^9}, {
   3.573540780324842*^9, 3.573540780761642*^9}, {3.573543526786242*^9, 
   3.573543549546442*^9}, {3.573544192780642*^9, 3.573544193139442*^9}, {
   3.573544384848242*^9, 3.573544386377042*^9}, {3.573544423785842*^9, 
   3.5735444239106417`*^9}, {3.573544455906242*^9, 3.573544456124642*^9}, {
   3.573544690329442*^9, 3.573544691047042*^9}, {3.5735447289560423`*^9, 
   3.5735447497196417`*^9}, {3.573544856423642*^9, 3.573544862070842*^9}, {
   3.573544898652842*^9, 3.5735449075136423`*^9}, {3.573544951006442*^9, 
   3.573544951084442*^9}, {3.5735452216206417`*^9, 3.573545230013442*^9}, {
   3.573545422455042*^9, 3.573545422845042*^9}, {3.573545492408442*^9, 
   3.573545492892042*^9}, {3.573545580158442*^9, 3.5735455805328417`*^9}, {
   3.5735458766302423`*^9, 3.573545894102242*^9}, {3.573545964365642*^9, 
   3.5735459729612417`*^9}, {3.573546009449642*^9, 3.573546066405242*^9}, {
   3.573552988019842*^9, 3.573552988534642*^9}, {3.573553026297242*^9, 
   3.573553026780842*^9}, 3.573553088526642*^9, 3.573553141476042*^9, {
   3.5735532175592422`*^9, 3.573553245921042*^9}, 3.573553283081242*^9, {
   3.5735533172306423`*^9, 3.573553346605442*^9}, {3.573553871219842*^9, 
   3.573553871719042*^9}, {3.5735539028818417`*^9, 3.573553907140642*^9}, {
   3.573553984364642*^9, 3.5735539847390423`*^9}, {3.573554030323242*^9, 
   3.573554060587242*^9}, 3.573554252391242*^9, {3.573555047904842*^9, 
   3.573555072227242*^9}, 3.573555244779842*^9, {3.5735553627158422`*^9, 
   3.573555363277442*^9}, {3.5735553945866423`*^9, 3.573555395288642*^9}, {
   3.573555445349042*^9, 3.573555446004242*^9}, {3.5735554954104424`*^9, 
   3.573555525549642*^9}, {3.573555578433642*^9, 3.573555579681642*^9}, {
   3.573556655146242*^9, 3.5735566559886417`*^9}, 3.57373708575*^9, {
   3.573737415359375*^9, 3.573737438921875*^9}, {3.573738176078125*^9, 
   3.573738176171875*^9}, {3.573738212265625*^9, 3.573738212328125*^9}, {
   3.573738262*^9, 3.573738262546875*^9}, {3.5737383306875*^9, 
   3.57373833125*^9}, {3.57373857384375*^9, 3.5737385745*^9}, {
   3.573738622015625*^9, 3.5737386238125*^9}, {3.573738704703125*^9, 
   3.573738705390625*^9}, 3.590898932858988*^9, 3.590898975353388*^9, {
   3.590899021232988*^9, 3.590899021669788*^9}, {3.590899064819388*^9, 
   3.5908990715273876`*^9}, {3.590899338124788*^9, 3.590899338764388*^9}, 
   3.5908993815863876`*^9, 3.5908994463887877`*^9, {3.590899698424388*^9, 
   3.590899698876788*^9}, {3.590901473992788*^9, 3.590901478828788*^9}, {
   3.5909015094515877`*^9, 3.590901509841588*^9}, {3.590901665234388*^9, 
   3.5909016659051876`*^9}, {3.590901704920788*^9, 3.590901708773988*^9}, {
   3.590902143906188*^9, 3.5909021444677877`*^9}, {3.590902187508188*^9, 
   3.5909022176629877`*^9}, {3.5909022562105875`*^9, 3.590902256600588*^9}, 
   3.5909025904113874`*^9, {3.590902620581788*^9, 3.5909026485681877`*^9}, {
   3.590903106455588*^9, 3.5909031069079876`*^9}, {3.590903293203188*^9, 
   3.590903294669588*^9}, {3.5909033281003876`*^9, 3.5909033353075876`*^9}, {
   3.590903727959388*^9, 3.590903728056388*^9}, {3.5909056166783876`*^9, 
   3.590905618314388*^9}, {3.5909137839473877`*^9, 3.590913784919388*^9}, {
   3.5909138267693877`*^9, 3.590913827365388*^9}, {3.590915134962388*^9, 
   3.590915135610388*^9}, {3.590916988347388*^9, 3.590916989537388*^9}, {
   3.5909171229603877`*^9, 3.590917152077388*^9}, 3.5909800661669607`*^9, {
   3.590980102078161*^9, 3.5909801027645607`*^9}, {3.590980522823161*^9, 
   3.5909805232911606`*^9}, {3.5909805569871607`*^9, 3.590980557657961*^9}, 
   3.590981036355561*^9, {3.590982990585761*^9, 3.590982990928961*^9}, {
   3.590983023548561*^9, 3.590983023907361*^9}, {3.590983065762161*^9, 
   3.590983068133361*^9}, {3.590983263763561*^9, 3.590983266883561*^9}, {
   3.590983489574561*^9, 3.5909834899801607`*^9}, {3.590983592596961*^9, 
   3.5909838470797606`*^9}, {3.590984247338561*^9, 3.590984256885761*^9}, {
   3.5909843441209607`*^9, 3.590984539167761*^9}, 3.590985548417361*^9, {
   3.590985585966561*^9, 3.590985586824561*^9}, 3.5909884390879607`*^9, 
   3.590988739451761*^9, {3.5909902637701607`*^9, 3.5909903053597608`*^9}, 
   3.5909904511275606`*^9, {3.5909909065383606`*^9, 3.5909909087691607`*^9}, 
   3.5915316446197634`*^9, 3.59153169211831*^9, 3.5915440925038824`*^9, 
   3.5915441389738398`*^9, {3.593346490347722*^9, 3.5933465024886584`*^9}, 
   3.593348428931161*^9, 3.5934131910165434`*^9, {3.593413237020943*^9, 
   3.593413266926143*^9}, {3.593413391547943*^9, 3.5934134220459433`*^9}, {
   3.593414513827943*^9, 3.593414533717943*^9}, 3.593414644165943*^9, 
   3.593414720319743*^9, {3.5934147671197433`*^9, 3.5934147688045435`*^9}, 
   3.593414807757743*^9, {3.5934994535514007`*^9, 3.593499453973273*^9}, 
   3.593501128075509*^9, {3.5935012446528873`*^9, 3.5935012459966288`*^9}, {
   3.5935014511828156`*^9, 3.5935014923388023`*^9}, 3.5935030447150445`*^9, 
   3.5943199894932146`*^9, 3.5943200387544556`*^9, 3.5943222963582296`*^9, {
   3.5943224022028847`*^9, 3.594322442618867*^9}, 3.594322482315363*^9, 
   3.594322522347082*^9, {3.594451352308937*^9, 3.594451378017737*^9}, {
   3.594453090053537*^9, 3.5944531184143367`*^9}, {3.5963676960333652`*^9, 
   3.596367778421119*^9}, {3.5963680984658623`*^9, 3.5963681082413626`*^9}, {
   3.5963682167774835`*^9, 3.5963682198375196`*^9}, {3.6694561795799866`*^9, 
   3.669456305037073*^9}, {3.6694590154292703`*^9, 3.66945902091949*^9}, {
   3.6694590601255603`*^9, 3.6694590896012735`*^9}, {3.669459258655574*^9, 
   3.669459283376562*^9}, {3.6694593864597197`*^9, 3.6694593868497353`*^9}, {
   3.6694595589861755`*^9, 3.669459559433693*^9}, {3.6694597048370843`*^9, 
   3.6694597077667027`*^9}, {3.6694598043651295`*^9, 3.669459856653329*^9}, {
   3.7362533624871306`*^9, 3.7362533635301905`*^9}, 3.7362534079097285`*^9, {
   3.7362534467169485`*^9, 3.736253472722436*^9}, {3.73625366598549*^9, 
   3.7362536693966846`*^9}, 3.736253714105242*^9, {3.736253863972814*^9, 
   3.736253888222201*^9}},
 FontFamily->"Courier New",
 FontSize->10],

Cell[CellGroupData[{

Cell["Figure 1a.", "Subsubsection",
 CellChangeTimes->{{3.7362537238157973`*^9, 3.7362537297951393`*^9}, {
  3.736426343617751*^9, 3.736426345200842*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Figure", " ", "1", "a"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"DateListPlot", "[", 
   RowBox[{
    RowBox[{"Exp", "[", "leverage", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1975", ",", "1", ",", "1"}], "}"}], ",", "Automatic", ",", 
      "\"\<Quarter\>\""}], "}"}], ",", 
    RowBox[{"Joined", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "False"}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<\[CapitalTheta] (level)\>\""}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{
  3.736253847781888*^9, {3.7362538920434194`*^9, 3.7362539002768908`*^9}, {
   3.7362539517218328`*^9, 3.73625395272189*^9}},
 FontSize->10],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwl0gtQU2cWB/AgO5UC5bF1rSCPiDjCtkJEFFELHJAgIgoqb1cCkrql0oSC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     "]]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  AxesOrigin->{2.3667552*^9, 0.481462724},
  Frame->True,
  FrameLabel->{None, None},
  FrameTicks->{{Automatic, Automatic}, {{{2208988800, 
       FormBox["\"1970\"", TraditionalForm]}, {2524521600, 
       FormBox["\"1980\"", TraditionalForm]}, {2840140800, 
       FormBox["\"1990\"", TraditionalForm]}, {3155673600, 
       FormBox["\"2000\"", TraditionalForm]}, {3471292800, 
       FormBox["\"2010\"", TraditionalForm]}, {2272060800, 
       FormBox["\"\"", TraditionalForm]}, {2335219200, 
       FormBox["\"\"", TraditionalForm]}, {2398291200, 
       FormBox["\"\"", TraditionalForm]}, {2461449600, 
       FormBox["\"\"", TraditionalForm]}, {2587680000, 
       FormBox["\"\"", TraditionalForm]}, {2650752000, 
       FormBox["\"\"", TraditionalForm]}, {2713910400, 
       FormBox["\"\"", TraditionalForm]}, {2776982400, 
       FormBox["\"\"", TraditionalForm]}, {2903212800, 
       FormBox["\"\"", TraditionalForm]}, {2966371200, 
       FormBox["\"\"", TraditionalForm]}, {3029443200, 
       FormBox["\"\"", TraditionalForm]}, {3092601600, 
       FormBox["\"\"", TraditionalForm]}, {3218832000, 
       FormBox["\"\"", TraditionalForm]}, {3281904000, 
       FormBox["\"\"", TraditionalForm]}, {3345062400, 
       FormBox["\"\"", TraditionalForm]}, {3408134400, 
       FormBox["\"\"", TraditionalForm]}}, {{2208988800, 
       FormBox["\"\"", TraditionalForm]}, {2524521600, 
       FormBox["\"\"", TraditionalForm]}, {2840140800, 
       FormBox["\"\"", TraditionalForm]}, {3155673600, 
       FormBox["\"\"", TraditionalForm]}, {3471292800, 
       FormBox["\"\"", TraditionalForm]}, {2272060800, 
       FormBox["\"\"", TraditionalForm]}, {2335219200, 
       FormBox["\"\"", TraditionalForm]}, {2398291200, 
       FormBox["\"\"", TraditionalForm]}, {2461449600, 
       FormBox["\"\"", TraditionalForm]}, {2587680000, 
       FormBox["\"\"", TraditionalForm]}, {2650752000, 
       FormBox["\"\"", TraditionalForm]}, {2713910400, 
       FormBox["\"\"", TraditionalForm]}, {2776982400, 
       FormBox["\"\"", TraditionalForm]}, {2903212800, 
       FormBox["\"\"", TraditionalForm]}, {2966371200, 
       FormBox["\"\"", TraditionalForm]}, {3029443200, 
       FormBox["\"\"", TraditionalForm]}, {3092601600, 
       FormBox["\"\"", TraditionalForm]}, {3218832000, 
       FormBox["\"\"", TraditionalForm]}, {3281904000, 
       FormBox["\"\"", TraditionalForm]}, {3345062400, 
       FormBox["\"\"", TraditionalForm]}, {3408134400, 
       FormBox["\"\"", TraditionalForm]}}}},
  GridLines->{{{2208988800, 
      GrayLevel[0.8]}, {2524521600, 
      GrayLevel[0.8]}, {2840140800, 
      GrayLevel[0.8]}, {3155673600, 
      GrayLevel[0.8]}, {3471292800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"\[CapitalTheta] (level)\"", TraditionalForm],
  PlotRangeClipping->True,
  Ticks->None]], "Output",
 CellChangeTimes->{3.736414619358162*^9, 3.736414997410785*^9, 
  3.736426187204805*^9, 3.7364262872605276`*^9, 3.736426458941347*^9, 
  3.736426530809458*^9, 3.7364269699585757`*^9, 3.7364277217445755`*^9, 
  3.7364277740265656`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
c. The measure of leverage used in the paper\
\>", "Subsection",
 CellChangeTimes->{{3.736253377667999*^9, 3.736253381635226*^9}, {
  3.7362534413696423`*^9, 3.7362534439387894`*^9}, {3.736253505377303*^9, 
  3.7362535322008376`*^9}}],

Cell["\<\
Extracting exognous component of leverage (see equation 9)\
\>", "Text",
 CellChangeTimes->{{3.7362535511319203`*^9, 3.7362535768103895`*^9}, {
  3.7364127329772673`*^9, 3.7364127630249853`*^9}},
 FontSize->10],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   StyleBox[
    RowBox[{"epsilon", "=", "0.5"}],
    FontVariations->{"Underline"->True}], ";", "       ", 
   RowBox[{"(*", " ", 
    RowBox[{
    "land", " ", "price", " ", "elasticity", " ", "of", " ", "leverage"}], 
    " ", "*)"}], "\n", "  ", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Correcting", " ", "leverage", " ", "data", " ", "for", " ", "land", " ", 
     "price", " ", "elasticity"}], "  ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"yepsilon", "=", 
    RowBox[{"leverage", "-", 
     RowBox[{"epsilon", "*", "p"}], "+", 
     RowBox[{"epsilon", "*", 
      RowBox[{"Log", "[", "pmean", "]"}]}]}]}], ";", " ", 
   RowBox[{"(*", " ", 
    RowBox[{"Data", " ", "in", " ", "log", " ", "levels"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ylevel", "=", 
    RowBox[{"Exp", "[", "yepsilon", "]"}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Plotting", " ", "the", " ", "data"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"{", "ylevel", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1975", ",", "1", ",", "1"}], "}"}], ",", "Automatic", ",", 
     "\"\<Quarter\>\""}], "}"}], ",", 
   RowBox[{"Joined", "\[Rule]", 
    RowBox[{"{", "True", "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{
   "PlotLabel", "\[Rule]", 
    "\"\<\[Theta] (\[CapitalTheta] net of land price)\>\""}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"{", "yepsilon", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1975", ",", "1", ",", "1"}], "}"}], ",", "Automatic", ",", 
     "\"\<Quarter\>\""}], "}"}], ",", 
   RowBox[{"Joined", "\[Rule]", 
    RowBox[{"{", "True", "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{
   "PlotLabel", "\[Rule]", 
    "\"\<Log[\[Theta]] (log of \[CapitalTheta] net of land price)\>\""}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.7362536006987553`*^9, 3.7362536403860254`*^9}, {
   3.7364134322702646`*^9, 3.7364134654381614`*^9}, 3.7364272271492863`*^9, 
   3.7364277655930834`*^9},
 FontSize->10],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwl1QtQU2cWB/CYxQJBHrWwPEQN4JaHixMLArIqOcUSUWGBChYRGpHsSouS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     "]]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  AxesOrigin->{2.3667552*^9, 0.5809361617525278},
  Frame->True,
  FrameLabel->{None, None},
  FrameTicks->{{Automatic, Automatic}, {{{2208988800, 
       FormBox["\"1970\"", TraditionalForm]}, {2524521600, 
       FormBox["\"1980\"", TraditionalForm]}, {2840140800, 
       FormBox["\"1990\"", TraditionalForm]}, {3155673600, 
       FormBox["\"2000\"", TraditionalForm]}, {3471292800, 
       FormBox["\"2010\"", TraditionalForm]}, {2272060800, 
       FormBox["\"\"", TraditionalForm]}, {2335219200, 
       FormBox["\"\"", TraditionalForm]}, {2398291200, 
       FormBox["\"\"", TraditionalForm]}, {2461449600, 
       FormBox["\"\"", TraditionalForm]}, {2587680000, 
       FormBox["\"\"", TraditionalForm]}, {2650752000, 
       FormBox["\"\"", TraditionalForm]}, {2713910400, 
       FormBox["\"\"", TraditionalForm]}, {2776982400, 
       FormBox["\"\"", TraditionalForm]}, {2903212800, 
       FormBox["\"\"", TraditionalForm]}, {2966371200, 
       FormBox["\"\"", TraditionalForm]}, {3029443200, 
       FormBox["\"\"", TraditionalForm]}, {3092601600, 
       FormBox["\"\"", TraditionalForm]}, {3218832000, 
       FormBox["\"\"", TraditionalForm]}, {3281904000, 
       FormBox["\"\"", TraditionalForm]}, {3345062400, 
       FormBox["\"\"", TraditionalForm]}, {3408134400, 
       FormBox["\"\"", TraditionalForm]}}, {{2208988800, 
       FormBox["\"\"", TraditionalForm]}, {2524521600, 
       FormBox["\"\"", TraditionalForm]}, {2840140800, 
       FormBox["\"\"", TraditionalForm]}, {3155673600, 
       FormBox["\"\"", TraditionalForm]}, {3471292800, 
       FormBox["\"\"", TraditionalForm]}, {2272060800, 
       FormBox["\"\"", TraditionalForm]}, {2335219200, 
       FormBox["\"\"", TraditionalForm]}, {2398291200, 
       FormBox["\"\"", TraditionalForm]}, {2461449600, 
       FormBox["\"\"", TraditionalForm]}, {2587680000, 
       FormBox["\"\"", TraditionalForm]}, {2650752000, 
       FormBox["\"\"", TraditionalForm]}, {2713910400, 
       FormBox["\"\"", TraditionalForm]}, {2776982400, 
       FormBox["\"\"", TraditionalForm]}, {2903212800, 
       FormBox["\"\"", TraditionalForm]}, {2966371200, 
       FormBox["\"\"", TraditionalForm]}, {3029443200, 
       FormBox["\"\"", TraditionalForm]}, {3092601600, 
       FormBox["\"\"", TraditionalForm]}, {3218832000, 
       FormBox["\"\"", TraditionalForm]}, {3281904000, 
       FormBox["\"\"", TraditionalForm]}, {3345062400, 
       FormBox["\"\"", TraditionalForm]}, {3408134400, 
       FormBox["\"\"", TraditionalForm]}}}},
  GridLines->{{{2208988800, 
      GrayLevel[0.8]}, {2524521600, 
      GrayLevel[0.8]}, {2840140800, 
      GrayLevel[0.8]}, {3155673600, 
      GrayLevel[0.8]}, {3471292800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox[
   "\"\[Theta] (\[CapitalTheta] net of land price)\"", TraditionalForm],
  PlotRangeClipping->True,
  Ticks->None]], "Output",
 CellChangeTimes->{
  3.571999128804055*^9, 3.5720028149978933`*^9, 3.572004988868232*^9, 
   3.572005059401266*^9, 3.5720053290596895`*^9, {3.572005724794324*^9, 
   3.5720057727870693`*^9}, 3.5720058210158277`*^9, 3.572005863208241*^9, 
   3.5720059799639187`*^9, {3.57200601197375*^9, 3.5720061154826703`*^9}, 
   3.5720061617953196`*^9, 3.5720062127492332`*^9, {3.57200633384816*^9, 
   3.572006378395708*^9}, 3.5720069008275895`*^9, {3.57200694734625*^9, 
   3.5720069708095922`*^9}, 3.572007025695731*^9, 3.572007261281206*^9, {
   3.57200733495942*^9, 3.5720074373672776`*^9}, 3.5720081691191316`*^9, 
   3.5720084553035*^9, 3.572008536410139*^9, {3.572008596201559*^9, 
   3.5720086809044037`*^9}, {3.572008730748255*^9, 3.5720088014482985`*^9}, 
   3.5727665400051255`*^9, 3.5727666519340286`*^9, 3.5727667608815613`*^9, 
   3.572767264301044*^9, {3.5728636605794487`*^9, 3.5728636875372486`*^9}, 
   3.5728637214516487`*^9, 3.572863817157648*^9, 3.5728639318020487`*^9, 
   3.5728640531834483`*^9, 3.5728642787780485`*^9, 3.572864681845248*^9, 
   3.5728647350100484`*^9, 3.572864925268648*^9, {3.5728650257014484`*^9, 
   3.5728650541090484`*^9}, 3.5728651013926487`*^9, {3.5728652082380486`*^9, 
   3.5728652307020483`*^9}, {3.572866019191448*^9, 3.5728660318586483`*^9}, 
   3.5728660623722486`*^9, 3.5728662478094482`*^9, {3.5728663944494486`*^9, 
   3.5728664180220485`*^9}, {3.5728665766272483`*^9, 3.572866599793248*^9}, 
   3.572866691474448*^9, 3.5728667406144485`*^9, 3.5728667766348486`*^9, {
   3.5728669471896486`*^9, 3.5728669751292486`*^9}, 3.5729253170450916`*^9, 
   3.5729276899940915`*^9, {3.5729277376052914`*^9, 3.572927760069291*^9}, 
   3.572928368829091*^9, {3.572928474706291*^9, 3.5729284889178915`*^9}, 
   3.5729292104178915`*^9, 3.572929463309491*^9, 3.572929716909891*^9, 
   3.572929887386691*^9, 3.5729299816606913`*^9, 3.5729301833394914`*^9, 
   3.572930333832691*^9, 3.572930567039091*^9, 3.5729306240570917`*^9, 
   3.5729308103844914`*^9, 3.572930963234291*^9, 3.5729310034728913`*^9, 
   3.5729310983520913`*^9, 3.5729311302228913`*^9, 3.5729311834812913`*^9, 
   3.5729312504832916`*^9, 3.5729314334712915`*^9, 3.5729315635284915`*^9, 
   3.572956857644767*^9, 3.572958014264564*^9, 3.5729589091203184`*^9, 
   3.572959395458024*^9, 3.5729594526549253`*^9, 3.5729596013887415`*^9, 
   3.572959748497734*^9, 3.5729597816972466`*^9, 3.5729599067461395`*^9, 
   3.572960253911489*^9, 3.572960335246389*^9, 3.572961118962*^9, 
   3.5729612239032*^9, 3.572961284082*^9, 3.5729613774948*^9, 
   3.5729616301056004`*^9, 3.5729617253747997`*^9, 3.5729618210964003`*^9, 
   3.5729618978796*^9, 3.5729619536496*^9, 3.5729621807076*^9, 
   3.5729630853682003`*^9, 3.57304291903125*^9, 3.573043426890625*^9, 
   3.573043576046875*^9, 3.573043643734375*^9, 3.573043766421875*^9, 
   3.573043876421875*^9, 3.5730439388125*^9, 3.573044024953125*^9, 
   3.57304412965625*^9, 3.573044229171875*^9, 3.573044380546875*^9, 
   3.573044752671875*^9, 3.573044894*^9, 3.573044983671875*^9, {
   3.5730452866875*^9, 3.57304530571875*^9}, 3.573045405671875*^9, 
   3.573046040125*^9, 3.573046149796875*^9, 3.5730462531875*^9, 
   3.57304636525*^9, 3.573046515734375*^9, 3.573046745796875*^9, 
   3.5730469990625*^9, 3.57304718565625*^9, 3.5730473615*^9, 
   3.573047654109375*^9, 3.573047802234375*^9, 3.573047897265625*^9, 
   3.57304801246875*^9, 3.57304809675*^9, 3.573048187296875*^9, 
   3.573048279453125*^9, 3.573048499578125*^9, 3.57304861478125*^9, {
   3.5730487089375*^9, 3.5730487273125*^9}, 3.573048875828125*^9, 
   3.573049019140625*^9, 3.5730491150625*^9, 3.57304920915625*^9, 
   3.573049326609375*^9, 3.573049682453125*^9, 3.573049779890625*^9, 
   3.5730498973125*^9, 3.573050061796875*^9, 3.573050286640625*^9, 
   3.573050595765625*^9, 3.573050722625*^9, 3.573050922609375*^9, 
   3.573051038578125*^9, 3.573053234375*^9, 3.573053748265625*^9, 
   3.57305410665625*^9, 3.573055105015625*^9, 3.57305514640625*^9, 
   3.5730552774375*^9, 3.57305538534375*^9, 3.573056174859375*^9, {
   3.573056266203125*^9, 3.573056287890625*^9}, 3.573056384609375*^9, 
   3.57305688528125*^9, 3.573057242375*^9, 3.57305735578125*^9, 
   3.573057423375*^9, 3.573057568234375*^9, 3.5730576748125*^9, 
   3.573057765546875*^9, 3.573057869125*^9, 3.573057965796875*^9, 
   3.573058052796875*^9, 3.57305814265625*^9, 3.57305823740625*^9, 
   3.573058374828125*^9, 3.57305848825*^9, 3.57305862*^9, 
   3.573058727609375*^9, 3.57305882684375*^9, 3.573058920421875*^9, 
   3.573059021921875*^9, 3.573059132484375*^9, 3.573059252671875*^9, 
   3.573060604078125*^9, 3.573060639390625*^9, 3.573060675265625*^9, 
   3.573060736578125*^9, 3.57306084528125*^9, 3.5730609298125*^9, 
   3.5730610033125*^9, 3.573061090953125*^9, 3.573061157359375*^9, 
   3.573061222515625*^9, 3.57306192090625*^9, 3.5730620441875*^9, 
   3.573062123015625*^9, 3.573062198578125*^9, 3.573062283625*^9, 
   3.573062364125*^9, 3.573062439875*^9, 3.57306253084375*^9, 
   3.57306261778125*^9, 3.573062702328125*^9, 3.573062777015625*^9, 
   3.573062853125*^9, 3.573063029125*^9, 3.5730631046875*^9, 
   3.573063182390625*^9, 3.573063262875*^9, 3.573063344625*^9, 
   3.573063419671875*^9, 3.573063513609375*^9, 3.573063585046875*^9, 
   3.57306366490625*^9, 3.573063750109375*^9, 3.57306382190625*^9, 
   3.573063924546875*^9, 3.573064004984375*^9, 3.573064114734375*^9, 
   3.57306419765625*^9, 3.573064272578125*^9, 3.573064347015625*^9, 
   3.5730644459375*^9, 3.573064524796875*^9, 3.573064628453125*^9, 
   3.57306470371875*^9, 3.573064783234375*^9, 3.573064868765625*^9, 
   3.57306494759375*^9, 3.57306502578125*^9, 3.573065119203125*^9, 
   3.573065217609375*^9, 3.573065386984375*^9, 3.573065466875*^9, 
   3.573065556359375*^9, 3.573065667125*^9, 3.57306707496875*^9, 
   3.57306717959375*^9, 3.573067269578125*^9, 3.57306735009375*^9, 
   3.57306745375*^9, 3.573067626921875*^9, 3.573067733*^9, 
   3.573105093578125*^9, 3.57310517540625*^9, 3.57310528396875*^9, 
   3.573105549625*^9, 3.573105725265625*^9, 3.573105821765625*^9, 
   3.57310592903125*^9, 3.57310602925*^9, 3.573106116921875*^9, 
   3.573106217203125*^9, 3.573106337546875*^9, 3.573106439078125*^9, 
   3.573106542265625*^9, 3.573106666671875*^9, 3.57310676615625*^9, 
   3.573106879890625*^9, 3.57310709171875*^9, 3.57310723734375*^9, 
   3.573107378984375*^9, 3.573107647375*^9, 3.573108105578125*^9, 
   3.573108221703125*^9, 3.57310834515625*^9, 3.573108703046875*^9, 
   3.573108871125*^9, 3.57310898234375*^9, 3.573109159203125*^9, 
   3.573109274015625*^9, 3.573109395921875*^9, 3.5731095075625*^9, 
   3.57310960571875*^9, 3.573109690421875*^9, 3.573109902375*^9, 
   3.573109981890625*^9, 3.5731100694375*^9, 3.5731101508125*^9, 
   3.573110237859375*^9, 3.5731103378125*^9, 3.573110419203125*^9, 
   3.573110544328125*^9, 3.5731114234375*^9, 3.57311296615625*^9, 
   3.573113056375*^9, 3.573113222234375*^9, 3.57311330765625*^9, 
   3.573113503421875*^9, 3.5731138653125*^9, 3.57311415053125*^9, 
   3.573114576921875*^9, 3.573115203171875*^9, 3.573115520421875*^9, 
   3.573115837953125*^9, 3.57311611596875*^9, 3.57311659075*^9, 
   3.573117516828125*^9, 3.5731962401727114`*^9, 3.5731963285311112`*^9, 
   3.573196540310111*^9, 3.573197593598111*^9, 3.5731977110983114`*^9, 
   3.573197791018111*^9, 3.5731979115281115`*^9, 3.573198014584111*^9, 
   3.5731980989177113`*^9, 3.573198201208911*^9, 3.5731983790231113`*^9, 
   3.573198441547911*^9, 3.573198511109311*^9, 3.573198601807711*^9, 
   3.5731986692309113`*^9, 3.5731987427225113`*^9, 3.573198818943311*^9, 
   3.5731989125463114`*^9, 3.5731989941719112`*^9, 3.5731990687555113`*^9, 
   3.5731991409845114`*^9, 3.5731992915401115`*^9, 3.573199426371911*^9, 
   3.5732067985597115`*^9, 3.5732070905969114`*^9, {3.5732092064981112`*^9, 
   3.5732092299137115`*^9}, 3.5732093651189113`*^9, 3.5732238681875*^9, 
   3.573223986171875*^9, 3.573224160234375*^9, 3.573224300421875*^9, 
   3.573224421671875*^9, 3.5732245039375*^9, 3.57322682221875*^9, 
   3.573227040875*^9, 3.5732271845*^9, 3.573227271609375*^9, 
   3.57322737196875*^9, 3.573227453078125*^9, 3.573227615546875*^9, 
   3.573227696390625*^9, 3.573227792921875*^9, 3.57322791596875*^9, 
   3.573228192375*^9, 3.573228300609375*^9, 3.573232455578125*^9, 
   3.573232553078125*^9, 3.57323266428125*^9, 3.573232789046875*^9, 
   3.573232858265625*^9, 3.573232971859375*^9, 3.57323316903125*^9, 
   3.57323327290625*^9, 3.57323436834375*^9, 3.57323459471875*^9, 
   3.57323587753125*^9, 3.573235909375*^9, 3.573236051046875*^9, 
   3.573236218984375*^9, 3.573236355734375*^9, 3.573272250953125*^9, 
   3.57327265015625*^9, 3.573283877109375*^9, 3.573284727578125*^9, 
   3.57328529365625*^9, 3.5732853784375*^9, 3.57328677740625*^9, 
   3.573293545546875*^9, 3.5732946510625*^9, 3.5732950864375*^9, 
   3.573295192203125*^9, 3.573295290953125*^9, 3.573295391640625*^9, 
   3.573295482515625*^9, 3.573295576640625*^9, 3.57329576703125*^9, 
   3.573295859859375*^9, 3.57329605821875*^9, 3.5732961728125*^9, 
   3.573296275515625*^9, 3.573296404875*^9, 3.573298054609375*^9, 
   3.57329816965625*^9, 3.573298252421875*^9, 3.573535598693242*^9, 
   3.5735367907966423`*^9, 3.5735368472540417`*^9, 3.573536939528042*^9, 
   3.5735370470286417`*^9, 3.573537080789042*^9, 3.5735371719710417`*^9, 
   3.5735372188802423`*^9, 3.573537276491042*^9, 3.5735373448502417`*^9, 
   3.573537502435442*^9, 3.573537898784642*^9, 3.5735381190410423`*^9, 
   3.5735381709890423`*^9, 3.573538206167042*^9, 3.573538244995442*^9, {
   3.573538307864442*^9, 3.573538335259042*^9}, 3.573538380592642*^9, {
   3.573538465846642*^9, 3.573538493521042*^9}, 3.573538692375242*^9, 
   3.5735387416400423`*^9, 3.5735388267692423`*^9, 3.573538871385242*^9, 
   3.573538983825042*^9, 3.573539027459242*^9, 3.573539078876842*^9, 
   3.573539122556842*^9, 3.5735392331140423`*^9, 3.5735392924408417`*^9, 
   3.5735393306452417`*^9, 3.573539422471842*^9, 3.5735394921002417`*^9, 
   3.5735395393214417`*^9, 3.573539633982242*^9, 3.5735398294356422`*^9, 
   3.573539880603642*^9, 3.573539913615242*^9, 3.573539985391842*^9, 
   3.573540118366242*^9, 3.573540259533642*^9, 3.573540289813242*^9, 
   3.573540329764842*^9, {3.573540361698042*^9, 3.5735403709956417`*^9}, 
   3.573540450555642*^9, 3.573540484594842*^9, 3.573540538258842*^9, 
   3.573540726302042*^9, 3.5735407905272417`*^9, 3.573541292207642*^9, 
   3.573541621133642*^9, 3.5735416721456423`*^9, 3.573542150506042*^9, 
   3.5735421821126423`*^9, 3.573542270575242*^9, 3.5735423495122423`*^9, 
   3.573542412427042*^9, {3.573542472365242*^9, 3.573542494688842*^9}, {
   3.573543528127842*^9, 3.5735435554588423`*^9}, 3.573543644456842*^9, 
   3.573543684194042*^9, 3.573543847323242*^9, 3.5735439159008417`*^9, 
   3.573544009183242*^9, 3.573544093376442*^9, 3.573544128055242*^9, 
   3.573544194371842*^9, 3.573544229239842*^9, 3.573544282828842*^9, 
   3.573544341798842*^9, 3.573544387250642*^9, 3.5735444259542418`*^9, 
   3.573544465687442*^9, 3.573544550224842*^9, {3.573544621190242*^9, 
   3.573544640565442*^9}, 3.573544692451042*^9, {3.573544731124442*^9, 
   3.573544755382442*^9}, 3.573544799327642*^9, 3.573544909120442*^9, 
   3.573544957215242*^9, 3.573545016387042*^9, 3.573545095432242*^9, 
   3.573545144431842*^9, 3.573545181559842*^9, 3.5735452313706417`*^9, 
   3.573545380225842*^9, 3.573545423656242*^9, 3.573545524996842*^9, 
   3.573545586710442*^9, 3.5735456374104424`*^9, 3.573545686862442*^9, 
   3.573545748981642*^9, 3.573545896333042*^9, 3.573545935317442*^9, 
   3.573545974786442*^9, {3.5735460108692417`*^9, 3.573546068183642*^9}, 
   3.5735461363088417`*^9, 3.573552989767042*^9, 3.573553027888442*^9, 
   3.573553062490242*^9, 3.573553093425042*^9, 3.5735531503544416`*^9, 
   3.573553218838442*^9, 3.573553252145442*^9, 3.5735532847660418`*^9, {
   3.5735533184162416`*^9, 3.5735533474478416`*^9}, 3.573553390956242*^9, 
   3.573553425853442*^9, {3.573553465274642*^9, 3.573553491654242*^9}, 
   3.5735535295164423`*^9, {3.573553677388842*^9, 3.573553705656042*^9}, 
   3.5735537485248423`*^9, 3.573553806525642*^9, {3.573553845464242*^9, 
   3.573553872764242*^9}, {3.573553912117042*^9, 3.573553990698242*^9}, {
   3.573554034691242*^9, 3.573554061523242*^9}, 3.573554172736642*^9, 
   3.573554223656042*^9, 3.573554282452442*^9, {3.573554332076042*^9, 
   3.5735543618408422`*^9}, 3.573554411449842*^9, 3.573554453857842*^9, 
   3.573554489223042*^9, 3.573554525274642*^9, 3.573554739323242*^9, 
   3.573554825899242*^9, 3.573554917426442*^9, 3.5735549623544416`*^9, 
   3.573555123036442*^9, 3.573555164236042*^9, 3.573555196763042*^9, 
   3.573555230505842*^9, {3.573555264623042*^9, 3.573555321531842*^9}, 
   3.5735553642758417`*^9, 3.573555396521042*^9, 3.573555447205442*^9, {
   3.5735554977660418`*^9, 3.573555526594842*^9}, 3.573555580882842*^9, 
   3.573555623236842*^9, 3.573555663968442*^9, 3.5735557360410423`*^9, 
   3.5735558152236423`*^9, 3.573555900557642*^9, 3.5735559316494417`*^9, 
   3.573555970743042*^9, 3.5735561456824417`*^9, 3.573556181703842*^9, 
   3.573556935245242*^9, {3.5735588789766417`*^9, 3.573558893047842*^9}, 
   3.573735604890625*^9, 3.573735651328125*^9, 3.573735689296875*^9, 
   3.573737087296875*^9, 3.573737228375*^9, 3.573737278953125*^9, 
   3.57373737696875*^9, {3.573737417921875*^9, 3.573737446203125*^9}, 
   3.573737485484375*^9, 3.573737562578125*^9, 3.573737744671875*^9, 
   3.573737851984375*^9, 3.573738044703125*^9, 3.57373810365625*^9, 
   3.573738177484375*^9, 3.57373821790625*^9, 3.5737382636875*^9, 
   3.5737383339375*^9, 3.573738487203125*^9, 3.573738531140625*^9, 
   3.573738575875*^9, 3.573738625984375*^9, 3.57373866690625*^9, 
   3.573738707421875*^9, 3.573738803671875*^9, 3.573738853328125*^9, 
   3.57373891746875*^9, 3.57373899303125*^9, 3.57373903628125*^9, 
   3.57373908190625*^9, 3.57373916609375*^9, {3.573739451921875*^9, 
   3.57373668853125*^9}, 3.573736784765625*^9, 3.573736924390625*^9, 
   3.5737370803125*^9, 3.5738957474022527`*^9, 3.5738958788478527`*^9, 
   3.5738960485184526`*^9, 3.5738962742132525`*^9, 3.5738963583596525`*^9, 
   3.573896952176653*^9, 3.5738970142802525`*^9, 3.5738970759782524`*^9, 
   3.5739591684258404`*^9, 3.57395976391864*^9, 3.5786340216478567`*^9, 
   3.5786340907402573`*^9, 3.5786529842022*^9, 3.5786532292566*^9, 
   3.578653557225*^9, 3.5786545451694*^9, 3.5786548056582003`*^9, 
   3.578717255011397*^9, 3.5787177898437967`*^9, 3.5787180957909966`*^9, 
   3.578721407849197*^9, 3.5787352073071966`*^9, 3.578746851094197*^9, 
   3.578747097373397*^9, 3.5787471299617968`*^9, 3.578747326537397*^9, 
   3.578747437969197*^9, 3.5787480062791967`*^9, 3.578748054623597*^9, 
   3.5788220997485976`*^9, 3.5788222844369974`*^9, 3.5788228520213976`*^9, 
   3.578822936807398*^9, 3.5788231974989977`*^9, 3.578823253253398*^9, 
   3.578823302284198*^9, 3.5788233402545977`*^9, 3.5788233885225973`*^9, 
   3.578823451813798*^9, {3.5789067170974073`*^9, 3.5789067450370073`*^9}, 
   3.578907782987007*^9, 3.578907888708207*^9, 3.578908102694407*^9, 
   3.578908159151807*^9, 3.578908223377007*^9, 3.578908271628807*^9, 
   3.578910245493207*^9, 3.5789188580190067`*^9, 3.578918952820207*^9, 
   3.578918989339807*^9, 3.578919069869007*^9, 3.578919121754607*^9, 
   3.5789191654190073`*^9, 3.578919206057007*^9, 3.578919254370207*^9, 
   3.578919318049407*^9, 3.5789196561756067`*^9, 3.5789886209447994`*^9, 
   3.578988657152399*^9, 3.5789887196459994`*^9, 3.5789887507523994`*^9, 
   3.5789888010155993`*^9, 3.5789888415443993`*^9, 3.5789889845963993`*^9, 
   3.5790000287119994`*^9, 3.5790001222495995`*^9, 3.5790001723723993`*^9, 
   3.5790002665651994`*^9, 3.5790003149875994`*^9, 3.5790003667503996`*^9, 
   3.5790028795279994`*^9, 3.5868503836756*^9, 3.5868505525612*^9, 
   3.5868508343752003`*^9, 3.586862025894*^9, 3.5868620883876*^9, 
   3.586862244216*^9, 3.5868623405092*^9, 3.5868624369337997`*^9, 
   3.5868629335794*^9, 3.5868630347454*^9, 3.5868632944034*^9, 
   3.5868633916548*^9, 3.5868636371772003`*^9, 3.5868637522372*^9, 
   3.5868638352302*^9, 3.5868638836057997`*^9, 3.5868639310142*^9, 
   3.5868639789842*^9, 3.5868640215108*^9, 3.5868640617060003`*^9, 
   3.5868642003588*^9, 3.5868643155648003`*^9, 3.5868643563472*^9, 
   3.5868644096836*^9, 3.5868644665144*^9, 3.5868645252016*^9, 
   3.5868645703792*^9, 3.5868646763752003`*^9, 3.586864735156*^9, 
   3.5868647912536*^9, 3.5868649140724*^9, 3.5868649699924*^9, 
   3.586865043094*^9, 3.5868653116334*^9, 3.5868653603536*^9, 
   3.5868654074208*^9, 3.586865552722*^9, {3.586865618398*^9, 
   3.5868656479132*^9}, 3.5868657079264*^9, 3.5868657709854*^9, 
   3.5868658060386*^9, {3.5868658532130003`*^9, 3.5868658784226*^9}, 
   3.5868664109598*^9, 3.5868665438406*^9, 3.5868666340086*^9, 
   3.5868666760671997`*^9, 3.5868667460488*^9, 3.5908978931847878`*^9, 
   3.590897966411188*^9, 3.590898192845188*^9, 3.5908982327967877`*^9, 
   3.5908983431199875`*^9, 3.5908987839403877`*^9, 3.5908989342005877`*^9, 
   3.590898976991388*^9, 3.5908990228241878`*^9, 3.590899060045788*^9, 
   3.5908990951613874`*^9, 3.590899147234188*^9, 3.590899215546588*^9, 
   3.590899252955388*^9, {3.5908993104971876`*^9, 3.5908993397939878`*^9}, 
   3.5908993826003876`*^9, 3.590899447855188*^9, 3.5908995280235877`*^9, 
   3.5908995606587877`*^9, 3.590899631545188*^9, 3.590899699984388*^9, 
   3.590899769092388*^9, 3.5908999948399878`*^9, 3.5909000823715878`*^9, 
   3.590900142041588*^9, 3.5909001859711876`*^9, 3.5909002575595875`*^9, 
   3.590900305249788*^9, 3.590900344015788*^9, 3.5909003916269875`*^9, 
   3.590900427491388*^9, 3.590900471420988*^9, 3.590900504010388*^9, 
   3.590900542277188*^9, 3.590900584677988*^9, 3.590900621415988*^9, 
   3.590900663551588*^9, 3.590900703768388*^9, 3.5909007352491875`*^9, 
   3.590900767605588*^9, 3.590900807042388*^9, 3.590900841051388*^9, 
   3.5909008818453875`*^9, 3.590900930345788*^9, 3.590900990791788*^9, 
   3.5909010274361877`*^9, 3.5909010590885878`*^9, 3.5909011328307877`*^9, 
   3.590901216853388*^9, 3.590901253825388*^9, 3.590901287365388*^9, 
   3.5909013257735877`*^9, 3.5909014294703875`*^9, 3.5909014798271875`*^9, 
   3.5909015218847876`*^9, 3.5909015784659877`*^9, 3.5909016180899878`*^9, 
   3.590901672550788*^9, 3.5909017157159877`*^9, 3.590901768974388*^9, 
   3.590901818098788*^9, 3.590901855320388*^9, 3.590901923024388*^9, 
   3.590901957704188*^9, 3.5909020387133875`*^9, 3.5909020743145876`*^9, 
   3.5909021532505875`*^9, {3.5909021891773877`*^9, 3.590902218630188*^9}, 
   3.590902257505388*^9, 3.5909023516045876`*^9, 3.5909023850509877`*^9, 
   3.5909024592777877`*^9, 3.5909025146109877`*^9, 3.590902592408188*^9, {
   3.5909026225005875`*^9, 3.590902649628988*^9}, 3.5909027005785875`*^9, 
   3.590902732026988*^9, 3.5909027710737877`*^9, 3.5909028943293877`*^9, 
   3.590902924484188*^9, 3.590902956198988*^9, 3.590903017896988*^9, 
   3.590903115378788*^9, 3.590903193082388*^9, 3.5909032268095875`*^9, 
   3.5909032957147875`*^9, 3.5909033457127876`*^9, 3.590903473781388*^9, 
   3.590903517300388*^9, 3.5909035528763876`*^9, 3.5909035875223875`*^9, 
   3.590903638356388*^9, 3.5909036897183876`*^9, 3.5909037370933876`*^9, 
   3.590904092071388*^9, 3.5909042008313875`*^9, 3.590904277859388*^9, 
   3.5909043296403875`*^9, 3.590904396745388*^9, 3.590904518650388*^9, 
   3.590904831806388*^9, 3.5909049822113876`*^9, 3.5909050561783876`*^9, 
   3.5909051460063877`*^9, 3.590905562172388*^9, 3.5909056259943876`*^9, 
   3.5909056901903877`*^9, 3.590905744709388*^9, 3.5909058088173876`*^9, 
   3.590905868641388*^9, 3.5909059440743876`*^9, 3.590905995106388*^9, 
   3.5909060266473875`*^9, 3.590913247481388*^9, 3.5909132802773876`*^9, 
   3.590913312097388*^9, 3.5909133590083876`*^9, 3.5909134089753876`*^9, 
   3.5909134772723875`*^9, 3.590913509465388*^9, 3.590913546694388*^9, 
   3.5909136178713875`*^9, 3.590913651681388*^9, 3.590913732859388*^9, 
   3.590913786525388*^9, 3.590913837990388*^9, 3.590913888852388*^9, 
   3.590913926531388*^9, 3.5909139942033877`*^9, 3.590914078839388*^9, 
   3.590914117958388*^9, 3.590914188781388*^9, 3.590914230385388*^9, 
   3.590914268768388*^9, 3.590914300510388*^9, 3.5909143455263877`*^9, 
   3.590914390599388*^9, 3.590914543851388*^9, 3.590914606007388*^9, 
   3.590914642443388*^9, 3.5909146790783877`*^9, 3.590914726995388*^9, 
   3.5909147846903877`*^9, 3.590914867900388*^9, 3.590914935172388*^9, 
   3.590914999783388*^9, 3.590915055840388*^9, 3.590915091340388*^9, 
   3.590915152662388*^9, 3.590915217851388*^9, 3.590915273044388*^9, 
   3.590915320016388*^9, 3.590915393245388*^9, 3.5909154601333876`*^9, 
   3.590915509577388*^9, 3.590915568226388*^9, 3.590915616847388*^9, 
   3.590915666110388*^9, 3.590915714715388*^9, 3.590915778853388*^9, 
   3.5909158472033877`*^9, 3.5909159148613877`*^9, 3.5909159749823875`*^9, 
   3.590916024292388*^9, 3.590916078417388*^9, 3.5909161278243876`*^9, 
   3.590916171906388*^9, 3.5909162333763876`*^9, 3.5909162721513877`*^9, 
   3.590916308858388*^9, 3.590916364242388*^9, 3.5909164057433877`*^9, 
   3.5909164458383875`*^9, 3.590916505962388*^9, 3.5909165701663876`*^9, 
   3.590916617176388*^9, 3.590916651462388*^9, 3.590916759215388*^9, 
   3.590916811418388*^9, 3.590916843880388*^9, 3.590916937042388*^9, 
   3.5909169902983875`*^9, 3.590917125255388*^9, 3.590917157568388*^9, 
   3.5909800684133606`*^9, 3.590980105400961*^9, 3.590980176131361*^9, 
   3.590980246658961*^9, 3.590980293053361*^9, 3.5909803730033607`*^9, 
   3.5909804335881605`*^9, 3.5909805244455605`*^9, 3.5909805669399605`*^9, 
   3.590980616346161*^9, 3.590980677904761*^9, 3.590980989649161*^9, 
   3.590981045169561*^9, {3.590981107117161*^9, 3.5909811366801605`*^9}, 
   3.590981196663161*^9, 3.590981289202361*^9, 3.590981382037961*^9, 
   3.590981438572361*^9, 3.5909815337167606`*^9, 3.5909816458193607`*^9, 
   3.590981692900161*^9, 3.590981733617161*^9, 3.5909818994049606`*^9, 
   3.5909819449569607`*^9, 3.590982024610561*^9, 3.590982064593361*^9, 
   3.5909821324533606`*^9, 3.590982184214161*^9, 3.590982244242961*^9, {
   3.5909822963937607`*^9, 3.5909823173913608`*^9}, 3.5909824236897607`*^9, 
   3.590982467687361*^9, 3.590982571662361*^9, 3.5909826037203608`*^9, 
   3.590982712514761*^9, 3.590982850793161*^9, 3.590982947997761*^9, 
   3.590982992691761*^9, 3.5909830698493605`*^9, 3.590983334229761*^9, 
   3.590984529121361*^9, {3.5909846334229608`*^9, 3.5909846431885605`*^9}, 
   3.590985089469361*^9, 3.590985200462361*^9, 3.590985249212361*^9, 
   3.590985305243561*^9, 3.590985384054761*^9, 3.5909854454105606`*^9, 
   3.590985514768161*^9, 3.5909855536901608`*^9, 3.590985597463761*^9, 
   3.5909856495833607`*^9, 3.590985704058561*^9, 3.5909857397981606`*^9, 
   3.590985789967761*^9, 3.5909858273765607`*^9, 3.590986195614561*^9, 
   3.5909862655649605`*^9, 3.590986316857761*^9, 3.590986369648161*^9, 
   3.590986428865761*^9, 3.590986472312761*^9, 3.590986589655961*^9, 
   3.590986691523961*^9, 3.5909867374815607`*^9, 3.5909867757171607`*^9, 
   3.590986821908761*^9, 3.5909868658705606`*^9, 3.5909869211569605`*^9, 
   3.5909870026513605`*^9, 3.5909870906977606`*^9, 3.5909873420303607`*^9, 
   3.5909874449903607`*^9, 3.5909875001675606`*^9, 3.590987689970761*^9, 
   3.590988233221961*^9, 3.590988285717961*^9, 3.590988342397761*^9, 
   3.5909884442515607`*^9, 3.590988516729161*^9, 3.5909886524505606`*^9, 
   3.5909887484217606`*^9, 3.590988807015361*^9, 3.5909888766225605`*^9, 
   3.5909889538435607`*^9, 3.590989037225561*^9, 3.590989102404361*^9, 
   3.5909891660523605`*^9, 3.590989215847561*^9, 3.5909892800727606`*^9, 
   3.590989356559561*^9, 3.590989437570361*^9, 3.5909894846823606`*^9, 
   3.590989564773761*^9, 3.590989647594161*^9, 3.5909903111785607`*^9, 
   3.5909904726555605`*^9, 3.590990578329961*^9, 3.590990843186761*^9, 
   3.5909911185735607`*^9, 3.5909911508811607`*^9, 3.590991193547161*^9, 
   3.5909912281479607`*^9, 3.590991264497961*^9, 3.590991298973961*^9, 
   3.591530721308555*^9, 3.591530802018155*^9, 3.5915314320585294`*^9, 
   3.5915315679218254`*^9, 3.5915316458015456`*^9, 3.591531701120283*^9, 
   3.5915317594189997`*^9, 3.591531859242818*^9, 3.591531946732913*^9, 
   3.591532010743419*^9, 3.5915321957823086`*^9, 3.5915322599419127`*^9, 
   3.59153234659046*^9, 3.5915324258290815`*^9, 3.5915324970703907`*^9, 
   3.5915325454735346`*^9, 3.591532958385818*^9, 3.591533763335413*^9, 
   3.591533950767886*^9, 3.5915340015536127`*^9, 3.591534345677211*^9, 
   3.591535263278471*^9, 3.5915353460674515`*^9, 3.5915354124225206`*^9, 
   3.5915354920013657`*^9, 3.591535558598667*^9, 3.591535665617737*^9, 
   3.5915357385972033`*^9, 3.591535808198553*^9, 3.591535914083496*^9, 
   3.5915364253692203`*^9, 3.5915365260530024`*^9, 3.5915366197932577`*^9, 
   3.5915376045541396`*^9, 3.5915376685186195`*^9, 3.5915378250525737`*^9, 
   3.5915378790434294`*^9, 3.591537929011615*^9, 3.591538318773455*^9, 
   3.5915384108305902`*^9, 3.5915434713446174`*^9, 3.5915435318441067`*^9, 
   3.591543583689602*^9, 3.5915436649313064`*^9, 3.591543699307252*^9, 
   3.59154380512576*^9, 3.5915438527201433`*^9, 3.5915439253615627`*^9, 
   3.5915440942890673`*^9, 3.591544142672295*^9, 3.591544260479312*^9, 
   3.5915443491509066`*^9, 3.591544476850444*^9, 3.591544550315709*^9, 
   3.5915446034864044`*^9, 3.5915446507309246`*^9, 3.5915451510700006`*^9, 
   3.591545315189245*^9, 3.5915453731511307`*^9, 3.5919491699808164`*^9, 
   3.5919498931956997`*^9, 3.5919499385860343`*^9, {3.5919505340763893`*^9, 
   3.5919505625614333`*^9}, 3.5919505967799644`*^9, 3.591950668029508*^9, 
   3.591950714919833*^9, 3.5919510940565095`*^9, 3.5919511573369493`*^9, 
   3.591951192367751*^9, 3.5919512311797543`*^9, 3.5919512621168585`*^9, 
   3.5919513119096713`*^9, 3.5919516902562776`*^9, 3.5919517528784723`*^9, {
   3.591951995025509*^9, 3.5919520356804576`*^9}, 3.5919520951316805`*^9, 
   3.591952320515093*^9, 3.59195247418205*^9, 3.5919525530545263`*^9, 
   3.592137049173611*^9, 3.592137095110523*^9, 3.5921371437974*^9, 
   3.592137184796875*^9, {3.5921372839049816`*^9, 3.5921373097640257`*^9}, 
   3.592137372372599*^9, 3.5921379686505404`*^9, {3.592138011041436*^9, 
   3.5921380222133827`*^9}, 3.5921380553229694`*^9, 3.592547372820463*^9, 
   3.5925488573575897`*^9, {3.5925491062947817`*^9, 3.592549154932307*^9}, {
   3.5925493266891375`*^9, 3.5925493547502003`*^9}, 3.59254938521739*^9, 
   3.592549416825147*^9, 3.592549502821057*^9, 3.5933429450406675`*^9, 
   3.5933430834737377`*^9, 3.593343170005205*^9, 3.593345386944476*^9, 
   3.5933455543862624`*^9, 3.5933455894965363`*^9, 3.5933457644853907`*^9, 
   3.5933465110826283`*^9, 3.5933466381235485`*^9, 3.593346699941781*^9, 
   3.593346917550933*^9, 3.5933473985185614`*^9, 3.593347520277561*^9, 
   3.5933477008943615`*^9, 3.593347826489961*^9, 3.5933478886715612`*^9, {
   3.593347992021561*^9, 3.5933480372791615`*^9}, 3.593348142659161*^9, {
   3.593348174462961*^9, 3.5933482266761613`*^9}, 3.593348294785761*^9, 
   3.593348342443761*^9, 3.593348437152361*^9, 3.5933485672095613`*^9, 
   3.593348794679561*^9, 3.5934103531281433`*^9, 3.593410438350943*^9, 
   3.593410472202943*^9, 3.593410508348143*^9, 3.5934105522153435`*^9, 
   3.5934105921513433`*^9, 3.593410636377343*^9, 3.593410686025543*^9, 
   3.593410722888343*^9, 3.593410784415743*^9, 3.593411239920143*^9, {
   3.5934112921801434`*^9, 3.593411366373743*^9}, 3.5934114684133434`*^9, 
   3.593411502624143*^9, 3.593411561453743*^9, 3.5934116067027435`*^9, 
   3.593411641459543*^9, 3.5934117313311434`*^9, 3.593411770955143*^9, 
   3.593411835289543*^9, 3.5934119753307433`*^9, {3.5934120236127434`*^9, 
   3.5934120752799435`*^9}, 3.5934121327815433`*^9, 3.593412167244943*^9, 
   3.593412272622943*^9, 3.593412327831343*^9, 3.5934123997785435`*^9, 
   3.593412663578543*^9, 3.593412781483343*^9, 3.5934128991541433`*^9, 
   3.5934129873565435`*^9, 3.593413056963743*^9, {3.5934131011907434`*^9, 
   3.593413129209343*^9}, 3.5934131918433433`*^9, {3.593413238206543*^9, 
   3.593413268018143*^9}, {3.593413335784543*^9, 3.593413392421543*^9}, 
   3.593413450009743*^9, {3.593413503626943*^9, 3.5934135333605433`*^9}, 
   3.593413604699343*^9, 3.5934137066921434`*^9, 3.593413813981943*^9, {
   3.593414081893143*^9, 3.593414102158543*^9}, 3.593414187117143*^9, {
   3.5934142207039433`*^9, 3.5934142752883434`*^9}, 3.5934143263003435`*^9, 
   3.593414365690343*^9, 3.5934144457183433`*^9, 3.593414492206343*^9, 
   3.5934145354183435`*^9, {3.593414618004743*^9, 3.593414625945143*^9}, 
   3.593414659141943*^9, 3.5934147229561434`*^9, 3.5934148013305435`*^9, 
   3.5934148383493433`*^9, 3.5934150889381433`*^9, 3.593415479521343*^9, 
   3.5934155137321434`*^9, 3.5934155730277433`*^9, {3.5934156574237432`*^9, 
   3.593415681759743*^9}, 3.593415724473543*^9, 3.5934158703733435`*^9, 
   3.5934186795467997`*^9, 3.5934187914685717`*^9, 3.5934188308904467`*^9, 
   3.5934188688435717`*^9, 3.5934189497029467`*^9, 3.5934189962654467`*^9, 
   3.5934190836716967`*^9, 3.5934191294373217`*^9, {3.5934191867185717`*^9, 
   3.5934192109685717`*^9}, 3.5934192608279467`*^9, 3.5934193188591967`*^9, 
   3.5934194012029467`*^9, 3.5934194468435717`*^9, 3.593422165451536*^9, 
   3.593422238653256*^9, 3.593422417243915*^9, 3.5934229342563763`*^9, 
   3.5934230601157513`*^9, 3.5934231528188763`*^9, 3.5934255556491866`*^9, 
   3.5934258391960616`*^9, 3.593425958793578*^9, 3.593426033390193*^9, 
   3.5934261619732227`*^9, 3.5934262254896607`*^9, {3.5934262702089834`*^9, 
   3.5934262758496804`*^9}, 3.593426325194062*^9, 3.5934265713051715`*^9, 
   3.5934267801645465`*^9, 3.5934974066533537`*^9, 3.593497469292776*^9, 
   3.593497645697055*^9, 3.5934977169139814`*^9, 3.5934977516787167`*^9, {
   3.5934992261778555`*^9, 3.5934992560682898`*^9}, 3.5934995479414215`*^9, 
   3.5934997895858016`*^9, 3.5935009309978795`*^9, 3.5935010141856127`*^9, 
   3.5935011402941804`*^9, 3.593501252730961*^9, {3.5935014564952817`*^9, 
   3.5935014798076324`*^9}, 3.59350193844039*^9, 3.593503054777802*^9, 
   3.5935031408112545`*^9, {3.593503186421797*^9, 3.593503206922322*^9}, 
   3.5935046861410437`*^9, 3.5935047734847937`*^9, 3.5935048403706264`*^9, {
   3.5935049448768864`*^9, 3.593504969359068*^9}, 3.59350504114951*^9, 
   3.5935050826770387`*^9, 3.593505167283465*^9, 3.593505264717847*^9, 
   3.593505955221378*^9, 3.5935060162678623`*^9, 3.5935060676425333`*^9, 
   3.5935061389858265`*^9, 3.5935061751262207`*^9, {3.5935069198558292`*^9, 
   3.5935069460587864`*^9}, 3.5935070088708844`*^9, 3.5935132137417927`*^9, 
   3.593513256272771*^9, {3.593513305756829*^9, 3.593513355756509*^9}, 
   3.59351343216227*^9, 3.5935136255672817`*^9, 3.5935137020511675`*^9, 
   3.593513773503835*^9, 3.5935139600338917`*^9, 3.5935141107673016`*^9, 
   3.59351425482888*^9, 3.5935148344189205`*^9, 3.593514884902972*^9, 
   3.593514981011732*^9, 3.593515083276703*^9, 3.593515140370087*^9, 
   3.593515212682124*^9, 3.593517091170102*^9, 3.593517386215089*^9, 
   3.594313888580101*^9, 3.5943139478706784`*^9, 3.594314443438525*^9, 
   3.5943144936540446`*^9, 3.5943146065173836`*^9, 3.5943147075067964`*^9, 
   3.594315006710024*^9, 3.5943151488208857`*^9, 3.594315493190759*^9, 
   3.5943155240123367`*^9, {3.59431560824961*^9, 3.5943156195921817`*^9}, 
   3.594315687906783*^9, 3.5943157380792737`*^9, 3.59431577775776*^9, 
   3.5943158174082975`*^9, 3.5943159023960266`*^9, 3.5943159902706847`*^9, 
   3.5943161753962603`*^9, 3.594316229904647*^9, 3.5943162727742624`*^9, 
   3.594316311263955*^9, 3.594316377590229*^9, 3.594316502075327*^9, 
   3.5943165861034164`*^9, 3.594316636080778*^9, 3.594316761266344*^9, 
   3.594316882878521*^9, 3.5943169580707135`*^9, 3.5943170256388235`*^9, 
   3.594317066539119*^9, 3.594317167138938*^9, 3.5943172728104744`*^9, 
   3.5943173643203764`*^9, 3.594317446798027*^9, 3.594317566685054*^9, 
   3.594317641737677*^9, 3.5943177132594194`*^9, 3.5943177822250724`*^9, 
   3.594317853623734*^9, 3.5943179241808324`*^9, 3.594317981097824*^9, 
   3.5943180622019625`*^9, 3.5943180955542274`*^9, 3.5943181939769254`*^9, {
   3.5943182397224617`*^9, 3.594318293009033*^9}, 3.5943183507485757`*^9, 
   3.594318423961445*^9, 3.5943184808724365`*^9, 3.5943185395756216`*^9, 
   3.594318633999312*^9, 3.5943187547869864`*^9, 3.5943188273664336`*^9, 
   3.594318877960205*^9, 3.594318939651387*^9, 3.59431898363349*^9, 
   3.5943190172829523`*^9, 3.594319053059835*^9, 3.594319259130392*^9, 
   3.5943193386265025`*^9, 3.5943194085031457`*^9, 3.594319465401126*^9, 
   3.5943195101419926`*^9, 3.5943195788928857`*^9, 3.5943197160857067`*^9, 
   3.594319874574501*^9, 3.594319957346754*^9, 3.5943199904838743`*^9, 
   3.594320044488284*^9, {3.594320280771039*^9, 3.5943202999218225`*^9}, 
   3.594320377378528*^9, 3.5943204744243135`*^9, 3.5943205464003572`*^9, 
   3.5943206850755854`*^9, 3.594320725269416*^9, {3.5943207896944227`*^9, 
   3.5943208127328014`*^9}, 3.5943208495853977`*^9, 3.594320920196534*^9, 
   3.594320998024485*^9, 3.5943211922561398`*^9, 3.5943212661394567`*^9, {
   3.594321309340296*^9, 3.594321336004094*^9}, 3.594321369605524*^9, 
   3.594321467431825*^9, 3.5943215282794423`*^9, 3.594321594647744*^9, 
   3.59432163207873*^9, 3.594321750285635*^9, 3.5943217974291053`*^9, {
   3.594321839950489*^9, 3.594321865772725*^9}, 3.5943219354162583`*^9, 
   3.5943221374741716`*^9, 3.594322180120639*^9, 3.594322253487612*^9, 
   3.594322297434949*^9, 3.594322358654813*^9, {3.5943224041721983`*^9, 
   3.5943224445211315`*^9}, 3.594322483488145*^9, 3.594322536941825*^9, 
   3.5943226148168077`*^9, 3.5943226846304092`*^9, 3.5943227381961656`*^9, 
   3.594322774656504*^9, 3.594322834496456*^9, 3.594322884417771*^9, 
   3.594322919394698*^9, 3.594323002017851*^9, 3.594323080084962*^9, 
   3.594323129201747*^9, 3.5943232140613933`*^9, 3.594323287751584*^9, 
   3.5943233837236476`*^9, 3.5943234327333603`*^9, {3.594323493397331*^9, 
   3.594323504592806*^9}, 3.5943235457142553`*^9, 3.594323580523491*^9, 
   3.5943236499688463`*^9, 3.594323698823459*^9, 3.5943237507841434`*^9, 
   3.5943238165620537`*^9, 3.594323866043085*^9, 3.594323938524537*^9, 
   3.5943239731246343`*^9, 3.594324017274105*^9, 3.5943240597424517`*^9, 
   3.594324100019338*^9, 3.5943241786588306`*^9, 3.594324230187229*^9, 
   3.5943242841632595`*^9, 3.5943243620122232`*^9, 3.5943679695483255`*^9, 
   3.5943771710007253`*^9, 3.594377262479125*^9, 3.5943774373551254`*^9, 
   3.594377496604925*^9, 3.5943776402809253`*^9, 3.594377744832125*^9, 
   3.5943779361661253`*^9, 3.594377983512125*^9, 3.594378169839525*^9, 
   3.5943783258083253`*^9, 3.5943783717035255`*^9, 3.5943784386431255`*^9, 
   3.594378639259125*^9, 3.594378703422925*^9, 3.594378786524125*^9, 
   3.594378822887725*^9, 3.5943789265497255`*^9, 3.594379037824525*^9, 
   3.594379205540125*^9, 3.594379409808525*^9, 3.594379457872125*^9, 
   3.594379539039925*^9, 3.5943798041775255`*^9, 3.5943802720693254`*^9, 
   3.5943803025517254`*^9, 3.594380441578925*^9, 3.5943815272751255`*^9, 
   3.594381605165925*^9, 3.594381683665125*^9, 3.594381814003125*^9, 
   3.5943819323291254`*^9, 3.594381980096325*^9, 3.594382133272725*^9, 
   3.594382263814525*^9, 3.594383266965525*^9, 3.594383313524925*^9, 
   3.5943839631845255`*^9, 3.594384088889325*^9, 3.5943842016773252`*^9, 
   3.594384286732525*^9, 3.594384403155325*^9, 3.594384479362325*^9, 
   3.5943845299647255`*^9, 3.594384580851925*^9, 3.594384621177925*^9, 
   3.5943846689919252`*^9, 3.594384732516125*^9, {3.594384792560525*^9, 
   3.5943848203839254`*^9}, 3.594439210545537*^9, 3.5944393737839365`*^9, {
   3.5944414496399364`*^9, 3.594441471058737*^9}, 3.5944415423195367`*^9, 
   3.594441933785937*^9, 3.594442015701537*^9, 3.5944420646231365`*^9, 
   3.594442166241537*^9, 3.594442213540737*^9, 3.5944422683591366`*^9, 
   3.594445795223137*^9, 3.594445827343537*^9, 3.594445901677537*^9, 
   3.594445946199937*^9, 3.5944459814217367`*^9, 3.594446061208737*^9, 
   3.594446129458737*^9, 3.5944464180365367`*^9, 3.5944464954749365`*^9, 
   3.594446641764737*^9, 3.5944477762811365`*^9, 3.594447867231137*^9, 
   3.594447924249137*^9, 3.594447977959937*^9, 3.594448033839137*^9, 
   3.594448080639137*^9, 3.5944481130583367`*^9, 3.5944481661295366`*^9, 
   3.594448218857537*^9, 3.594448292115137*^9, 3.5944483335523367`*^9, 
   3.5944484021299367`*^9, {3.594448434063137*^9, 3.594448459990337*^9}, {
   3.5944484966659365`*^9, 3.594448520268737*^9}, 3.594448569549137*^9, 
   3.594448607675537*^9, 3.5944487596819367`*^9, 3.5944487961703367`*^9, 
   3.594448832362337*^9, 3.594448894497137*^9, 3.5944489282489367`*^9, 
   3.5944489597609367`*^9, 3.5944490594449368`*^9, 3.594449115511337*^9, 
   3.594449156664137*^9, 3.594449197336137*^9, 3.5944492308605366`*^9, 
   3.594449293541337*^9, {3.594449338937337*^9, 3.594449367173337*^9}, 
   3.594449424145537*^9, 3.594449460478937*^9, 3.594450078192537*^9, 
   3.594450335640337*^9, 3.594450373112537*^9, 3.5944505093493366`*^9, 
   3.594450553388137*^9, 3.5944505981601367`*^9, 3.594450738826337*^9, 
   3.5944507973585367`*^9, {3.5944508738317366`*^9, 3.5944509030193367`*^9}, 
   3.5944509456239367`*^9, 3.5944509788051367`*^9, 3.5944511871673365`*^9, 
   3.5944513585957365`*^9, 3.5944513936489367`*^9, 3.594452054795537*^9, 
   3.594452180719737*^9, {3.594452658251337*^9, 3.594452678094537*^9}, 
   3.5944528006793365`*^9, 3.594453037060337*^9, {3.5944530915979366`*^9, 
   3.5944531192411366`*^9}, 3.594453202023337*^9, 3.5947205762096305`*^9, 
   3.5947206285355587`*^9, 3.5947231749617996`*^9, 3.594723266577952*^9, 
   3.5947232975706453`*^9, 3.5947233288665314`*^9, 3.594723581930519*^9, 
   3.594723744061744*^9, 3.594723981774423*^9, 3.5947241399650173`*^9, 
   3.594732924940566*^9, 3.594732973999316*^9, 3.594733034594763*^9, 
   3.5947331208603497`*^9, 3.594733199309718*^9, 3.5947332824730687`*^9, 
   3.594733327848121*^9, 3.5947333659805746`*^9, 3.594733647489092*^9, 
   3.5947338462417665`*^9, 3.5947339260780554`*^9, 3.59473398810046*^9, 
   3.594734092952448*^9, 3.594734155785391*^9, 3.5947343085783825`*^9, 
   3.594734413232242*^9, 3.5947345033463955`*^9, 3.5947345901593485`*^9, 
   3.5947346622914987`*^9, 3.5947347430504065`*^9, 3.594734949296076*^9, 
   3.594735069656419*^9, 3.5947352181625495`*^9, 3.594735336077261*^9, 
   3.5947354976070848`*^9, 3.5947355499650354`*^9, 3.59473562413455*^9, 
   3.594735785364174*^9, 3.594735862481649*^9, 3.594736005371029*^9, 
   3.594736078338736*^9, 3.594736143847464*^9, 3.594736190121353*^9, 
   3.5947364608897266`*^9, 3.596107415320054*^9, 3.596362044596094*^9, 
   3.5963630418707495`*^9, 3.5963631095048776`*^9, 3.5963631768906603`*^9, 
   3.596364154031719*^9, {3.596367715721449*^9, 3.5963677427434053`*^9}, 
   3.596367785673934*^9, 3.5963681115035257`*^9, 3.5963682261667223`*^9, 
   3.663483666669719*^9, 3.663483932777591*^9, 3.6634840021531477`*^9, 
   3.6634840466951685`*^9, 3.6634841327320566`*^9, 3.66348422850611*^9, 
   3.6634843957816467`*^9, 3.663484465284234*^9, 3.6634845061980343`*^9, 
   3.6634846160593653`*^9, 3.6634846816371984`*^9, 3.6634847959144135`*^9, 
   3.6634848955309925`*^9, 3.66348495018029*^9, 3.663485018211651*^9, 
   3.663485223451418*^9, 3.663485387556134*^9, 3.6634854417769794`*^9, 
   3.6634855826350417`*^9, 3.663485656582077*^9, 3.6634857434470882`*^9, 
   3.663485809261339*^9, 3.6634858771316833`*^9, 3.6634859454410105`*^9, 
   3.663486012511589*^9, 3.663486343762823*^9, 3.6634863832832413`*^9, {
   3.663486504304864*^9, 3.663486551957162*^9}, 3.6634866060128775`*^9, 
   3.6634866694197865`*^9, 3.663486789028842*^9, 3.663486864833089*^9, 
   3.663486993070303*^9, 3.66348707283253*^9, 3.663487111311431*^9, 
   3.6634872617416406`*^9, 3.6634873438379946`*^9, 3.663488272015529*^9, 
   3.663488307775218*^9, 3.6634883572493114`*^9, 3.6634884057398663`*^9, 
   3.663488443467639*^9, 3.6634884920642157`*^9, 3.6634885790204535`*^9, 
   3.6634886192907877`*^9, 3.663488672312559*^9, 3.6634891148629255`*^9, {
   3.663489260531838*^9, 3.6634892866170754`*^9}, 3.663489346638405*^9, 
   3.6634900170159225`*^9, 3.6634900664673996`*^9, 3.663490148297989*^9, 
   3.6634902431158266`*^9, 3.6634905996389704`*^9, 3.6634906313503113`*^9, 
   3.663490706067917*^9, 3.6635698469651766`*^9, 3.663569915067607*^9, 
   3.663570013896763*^9, 3.6635700750150995`*^9, 3.6635701304804363`*^9, 
   3.6635701704619427`*^9, 3.6635702778258257`*^9, 3.6635704899488645`*^9, 
   3.6635705638320045`*^9, 3.6635706193757963`*^9, 3.6635706583257456`*^9, 
   3.6635707319313464`*^9, 3.663570984752812*^9, 3.663571157350419*^9, 
   3.6635720606518974`*^9, 3.6635723176872354`*^9, 3.6635900970958357`*^9, 
   3.663590224494483*^9, 3.663590312005367*^9, 3.663590374021759*^9, 
   3.663590472457841*^9, 3.663590550415539*^9, 3.6635907107989063`*^9, 
   3.663591152251875*^9, 3.6635916004550796`*^9, 3.663591635193919*^9, 
   3.663591782014969*^9, 3.6635919232919874`*^9, 3.663591967863017*^9, 
   3.6635925022098646`*^9, 3.6635926153262577`*^9, 3.663592833369777*^9, 
   3.6635929515293026`*^9, 3.663593044647302*^9, {3.663593113914835*^9, 
   3.6635931282652526`*^9}, 3.663593220403235*^9, 3.6635933288835382`*^9, 
   3.6635933724845476`*^9, 3.6635934547863245`*^9, 3.6635935739848194`*^9, 
   3.6635939319007015`*^9, 3.663594011902277*^9, 3.663594100126323*^9, 
   3.663594136679414*^9, 3.663594223715392*^9, 3.6635943637204*^9, 
   3.6635946349679146`*^9, 3.663594688108954*^9, 3.6635947462492795`*^9, 
   3.663594859941782*^9, 3.663594982741806*^9, 3.663928174953024*^9, 
   3.663933075026091*^9, 3.6639337019350767`*^9, 3.66393394099675*^9, 
   3.6639345032508926`*^9, 3.663935204879082*^9, 3.663935277725586*^9, 
   3.663935370438447*^9, 3.663935461629675*^9, 3.663935881024763*^9, 
   3.6639359849850245`*^9, 3.663936023323654*^9, 3.6639361103957305`*^9, 
   3.6639362290596085`*^9, 3.663936349024991*^9, 3.6639369056034193`*^9, 
   3.6639370390673804`*^9, 3.6639371109773674`*^9, 3.663937170025325*^9, 
   3.6639373007577133`*^9, 3.6639374479721966`*^9, 3.6639378444650545`*^9, 
   3.6639379034575663`*^9, 3.6639379466373854`*^9, 3.663938049151637*^9, 
   3.663938095587589*^9, 3.6639382214500113`*^9, 3.6639382901539707`*^9, 
   3.6639383379452114`*^9, 3.6639383825166545`*^9, 3.663938418796562*^9, 
   3.6639385217466354`*^9, 3.663938621797793*^9, 3.663938734657164*^9, 
   3.663938784615864*^9, 3.663938850296928*^9, 3.663939061723632*^9, 
   3.663939121882113*^9, 3.6639392077476234`*^9, 3.663939328348076*^9, 
   3.6639393603840017`*^9, 3.6639394274392424`*^9, 3.663939482834551*^9, 
   3.6639395494398184`*^9, 3.663939596342291*^9, 3.663939627559637*^9, 
   3.6639396578984685`*^9, 3.6639397263343105`*^9, 3.6639397795690455`*^9, 
   3.663939815139061*^9, 3.663939878812214*^9, 3.663939920963573*^9, 
   3.6639399740034256`*^9, 3.66394004537236*^9, 3.663940139788236*^9, 
   3.6639401974596367`*^9, 3.663940237909376*^9, 3.6639402837718334`*^9, 
   3.663940342427268*^9, 3.663940426551736*^9, 3.663940514024832*^9, {
   3.6639406125818915`*^9, 3.6639406407051105`*^9}, 3.663940711557547*^9, 
   3.6639407457585087`*^9, 3.6639407803444605`*^9, 3.6639408117982883`*^9, 
   3.6639408536495514`*^9, 3.663940909918397*^9, {3.6639409424937983`*^9, 
   3.6639409693429656`*^9}, 3.6639410054900026`*^9, 3.66394106301086*^9, 
   3.6639411125039053`*^9, 3.663941151019018*^9, 3.663941204849271*^9, 
   3.663941248516586*^9, 3.6639413157733545`*^9, 3.663941369344123*^9, 
   3.6639418241183386`*^9, 3.663941871696349*^9, {3.6639422617271185`*^9, 
   3.663942288079746*^9}, {3.6639423353764086`*^9, 3.6639423619575896`*^9}, 
   3.6639423921723223`*^9, 3.6639426266959133`*^9, 3.663942739320003*^9, 
   3.6639430160815043`*^9, 3.6639433660825176`*^9, 3.6639437348883905`*^9, 
   3.663943817283849*^9, 3.6639439647604837`*^9, 3.6639440608505397`*^9, 
   3.663944133294582*^9, 3.663944198566801*^9, 3.6639446534981885`*^9, 
   3.6639447114340925`*^9, 3.66394476583484*^9, 3.663944832862651*^9, 
   3.663944873446846*^9, 3.663945311874017*^9, 3.6639453816344337`*^9, 
   3.663945616042062*^9, 3.663945694978795*^9, 3.6639457773017254`*^9, 
   3.663994861550467*^9, 3.6639951303308496`*^9, 3.663995272584972*^9, 
   3.6639953225746*^9, 3.663995396144493*^9, 3.6639954406858253`*^9, 
   3.66399551577806*^9, {3.6639955480724945`*^9, 3.663995570284922*^9}, 
   3.663995612886856*^9, 3.6639956668998632`*^9, 3.663995719486862*^9, 
   3.6639978309250093`*^9, 3.6639978867786446`*^9, 3.663998445327569*^9, 
   3.6639986355033884`*^9, 3.663998728907248*^9, 3.664001117207658*^9, 
   3.664001304657214*^9, 3.664001392366681*^9, 3.6640015945888023`*^9, 
   3.6640016407510867`*^9, 3.664001680772029*^9, 3.6640023677029285`*^9, 
   3.664002538577778*^9, 3.664002573923973*^9, 3.6640026986215096`*^9, 
   3.6640027878197117`*^9, 3.664003349525326*^9, 3.6640043342634172`*^9, 
   3.6640044010871744`*^9, 3.6640044613931065`*^9, 3.6640045214187994`*^9, 
   3.6640056278065233`*^9, 3.6640058260309906`*^9, 3.664007529519247*^9, 
   3.664007595311241*^9, {3.6640077207068872`*^9, 3.664007747852565*^9}, 
   3.664007781110616*^9, 3.6640078125705566`*^9, 3.664007876104448*^9, {
   3.664007906144314*^9, 3.664007932621961*^9}, {3.6640079675688057`*^9, 
   3.6640079972376785`*^9}, {3.6640080407680206`*^9, 3.664008069232939*^9}, 
   3.6640083581799507`*^9, 3.6640084322982936`*^9, 3.6640084949183197`*^9, {
   3.6640085359216537`*^9, 3.6640085728253784`*^9}, 3.6640086059790936`*^9, 
   3.6640887837619762`*^9, 3.6640888867322817`*^9, 3.6640889965978985`*^9, 
   3.664089456083003*^9, 3.6640896599079237`*^9, 3.664089691266086*^9, 
   3.6640897696361217`*^9, {3.6640898344445667`*^9, 3.6640898622470284`*^9}, 
   3.6640899155553136`*^9, 3.6640900628911333`*^9, 3.6640916066799088`*^9, 
   3.6640916662289934`*^9, 3.664091708097246*^9, 3.664091771370489*^9, 
   3.664091810450487*^9, 3.6640920261473937`*^9, 3.6640921670926394`*^9, 
   3.6640924062067957`*^9, 3.664092469594091*^9, 3.6640925245300245`*^9, 
   3.664092584711136*^9, 3.6640926704375896`*^9, 3.664092723444339*^9, {
   3.6640927539589415`*^9, 3.66409277230892*^9}, 3.6640931999157734`*^9, 
   3.664093244356185*^9, 3.664093354295844*^9, 3.664093451256319*^9, 
   3.664093706421015*^9, 3.6640988598399997`*^9, 3.6640990400237293`*^9, 
   3.6640992926175203`*^9, 3.664099425599683*^9, 3.664099515708763*^9, 
   3.664099690140909*^9, 3.664099887227048*^9, 3.664100076175827*^9, 
   3.664100198860827*^9, 3.6641005750287037`*^9, 3.664100789220085*^9, 
   3.6641008365113926`*^9, 3.6641009138831377`*^9, 3.664101418149305*^9, 
   3.66410148616481*^9, 3.664101761951945*^9, 3.664101861369625*^9, 
   3.664102005543356*^9, 3.6641022526336174`*^9, 3.6641025584394636`*^9, 
   3.6641109106157827`*^9, 3.6641120884967623`*^9, 3.664176397715892*^9, 
   3.669369547504711*^9, 3.669370516962368*^9, 3.6693706322173986`*^9, 
   3.6693708523050747`*^9, 3.6693756570677004`*^9, 3.669375706771821*^9, 
   3.669375749067219*^9, 3.6693760531883216`*^9, 3.669376496134754*^9, 
   3.6693767271499414`*^9, 3.6693770686517563`*^9, 3.669377198264404*^9, 
   3.669456309532972*^9, 3.6694590616881227`*^9, 3.66945928383158*^9, 
   3.6694593884022975`*^9, 3.669459562426313*^9, 3.6694596629298773`*^9, 
   3.6694597120353737`*^9, {3.669459805897691*^9, 3.6694598579808817`*^9}, 
   3.6694644576592627`*^9, 3.6694655426173286`*^9, 3.6694655976331663`*^9, 
   3.669465826789917*^9, 3.669720113417411*^9, 3.6697204114674587`*^9, 
   3.670135060852167*^9, 3.6766309092826405`*^9, 3.6767897404089146`*^9, 
   3.6768821083539925`*^9, 3.676887713447097*^9, 3.681540836079119*^9, 
   3.6816219129722986`*^9, 3.6816397324794035`*^9, 3.6840379644715805`*^9, 
   3.6846610491338415`*^9, 3.684673432042624*^9, 3.6846735411438646`*^9, 
   3.684673678222705*^9, 3.6846737654136915`*^9, 3.6846738635003023`*^9, 
   3.7005594340656757`*^9, 3.7005595459010725`*^9, 3.7364146193971643`*^9, 
   3.736414997444787*^9, 3.736426187255808*^9, 3.73642628729453*^9, 
   3.73642645898335*^9, 3.73642653085046*^9, 3.7364269699835773`*^9, 
   3.736427721770577*^9, 3.7364277740675683`*^9},
 FontFamily->"Courier New",
 FontSize->10],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwllAtQU2cWxwOKIBG0PhhAwChuB0ZRCmhUdiBnobFq16Yq4AMh7cJWHttE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     "]]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  AxesOrigin->{2.3667552*^9, 0.},
  Frame->True,
  FrameLabel->{None, None},
  FrameTicks->{{Automatic, Automatic}, {{{2208988800, 
       FormBox["\"1970\"", TraditionalForm]}, {2524521600, 
       FormBox["\"1980\"", TraditionalForm]}, {2840140800, 
       FormBox["\"1990\"", TraditionalForm]}, {3155673600, 
       FormBox["\"2000\"", TraditionalForm]}, {3471292800, 
       FormBox["\"2010\"", TraditionalForm]}, {2272060800, 
       FormBox["\"\"", TraditionalForm]}, {2335219200, 
       FormBox["\"\"", TraditionalForm]}, {2398291200, 
       FormBox["\"\"", TraditionalForm]}, {2461449600, 
       FormBox["\"\"", TraditionalForm]}, {2587680000, 
       FormBox["\"\"", TraditionalForm]}, {2650752000, 
       FormBox["\"\"", TraditionalForm]}, {2713910400, 
       FormBox["\"\"", TraditionalForm]}, {2776982400, 
       FormBox["\"\"", TraditionalForm]}, {2903212800, 
       FormBox["\"\"", TraditionalForm]}, {2966371200, 
       FormBox["\"\"", TraditionalForm]}, {3029443200, 
       FormBox["\"\"", TraditionalForm]}, {3092601600, 
       FormBox["\"\"", TraditionalForm]}, {3218832000, 
       FormBox["\"\"", TraditionalForm]}, {3281904000, 
       FormBox["\"\"", TraditionalForm]}, {3345062400, 
       FormBox["\"\"", TraditionalForm]}, {3408134400, 
       FormBox["\"\"", TraditionalForm]}}, {{2208988800, 
       FormBox["\"\"", TraditionalForm]}, {2524521600, 
       FormBox["\"\"", TraditionalForm]}, {2840140800, 
       FormBox["\"\"", TraditionalForm]}, {3155673600, 
       FormBox["\"\"", TraditionalForm]}, {3471292800, 
       FormBox["\"\"", TraditionalForm]}, {2272060800, 
       FormBox["\"\"", TraditionalForm]}, {2335219200, 
       FormBox["\"\"", TraditionalForm]}, {2398291200, 
       FormBox["\"\"", TraditionalForm]}, {2461449600, 
       FormBox["\"\"", TraditionalForm]}, {2587680000, 
       FormBox["\"\"", TraditionalForm]}, {2650752000, 
       FormBox["\"\"", TraditionalForm]}, {2713910400, 
       FormBox["\"\"", TraditionalForm]}, {2776982400, 
       FormBox["\"\"", TraditionalForm]}, {2903212800, 
       FormBox["\"\"", TraditionalForm]}, {2966371200, 
       FormBox["\"\"", TraditionalForm]}, {3029443200, 
       FormBox["\"\"", TraditionalForm]}, {3092601600, 
       FormBox["\"\"", TraditionalForm]}, {3218832000, 
       FormBox["\"\"", TraditionalForm]}, {3281904000, 
       FormBox["\"\"", TraditionalForm]}, {3345062400, 
       FormBox["\"\"", TraditionalForm]}, {3408134400, 
       FormBox["\"\"", TraditionalForm]}}}},
  GridLines->{{{2208988800, 
      GrayLevel[0.8]}, {2524521600, 
      GrayLevel[0.8]}, {2840140800, 
      GrayLevel[0.8]}, {3155673600, 
      GrayLevel[0.8]}, {3471292800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox[
   "\"Log[\[Theta]] (log of \[CapitalTheta] net of land price)\"", 
    TraditionalForm],
  PlotRangeClipping->True,
  Ticks->None]], "Output",
 CellChangeTimes->{
  3.571999128804055*^9, 3.5720028149978933`*^9, 3.572004988868232*^9, 
   3.572005059401266*^9, 3.5720053290596895`*^9, {3.572005724794324*^9, 
   3.5720057727870693`*^9}, 3.5720058210158277`*^9, 3.572005863208241*^9, 
   3.5720059799639187`*^9, {3.57200601197375*^9, 3.5720061154826703`*^9}, 
   3.5720061617953196`*^9, 3.5720062127492332`*^9, {3.57200633384816*^9, 
   3.572006378395708*^9}, 3.5720069008275895`*^9, {3.57200694734625*^9, 
   3.5720069708095922`*^9}, 3.572007025695731*^9, 3.572007261281206*^9, {
   3.57200733495942*^9, 3.5720074373672776`*^9}, 3.5720081691191316`*^9, 
   3.5720084553035*^9, 3.572008536410139*^9, {3.572008596201559*^9, 
   3.5720086809044037`*^9}, {3.572008730748255*^9, 3.5720088014482985`*^9}, 
   3.5727665400051255`*^9, 3.5727666519340286`*^9, 3.5727667608815613`*^9, 
   3.572767264301044*^9, {3.5728636605794487`*^9, 3.5728636875372486`*^9}, 
   3.5728637214516487`*^9, 3.572863817157648*^9, 3.5728639318020487`*^9, 
   3.5728640531834483`*^9, 3.5728642787780485`*^9, 3.572864681845248*^9, 
   3.5728647350100484`*^9, 3.572864925268648*^9, {3.5728650257014484`*^9, 
   3.5728650541090484`*^9}, 3.5728651013926487`*^9, {3.5728652082380486`*^9, 
   3.5728652307020483`*^9}, {3.572866019191448*^9, 3.5728660318586483`*^9}, 
   3.5728660623722486`*^9, 3.5728662478094482`*^9, {3.5728663944494486`*^9, 
   3.5728664180220485`*^9}, {3.5728665766272483`*^9, 3.572866599793248*^9}, 
   3.572866691474448*^9, 3.5728667406144485`*^9, 3.5728667766348486`*^9, {
   3.5728669471896486`*^9, 3.5728669751292486`*^9}, 3.5729253170450916`*^9, 
   3.5729276899940915`*^9, {3.5729277376052914`*^9, 3.572927760069291*^9}, 
   3.572928368829091*^9, {3.572928474706291*^9, 3.5729284889178915`*^9}, 
   3.5729292104178915`*^9, 3.572929463309491*^9, 3.572929716909891*^9, 
   3.572929887386691*^9, 3.5729299816606913`*^9, 3.5729301833394914`*^9, 
   3.572930333832691*^9, 3.572930567039091*^9, 3.5729306240570917`*^9, 
   3.5729308103844914`*^9, 3.572930963234291*^9, 3.5729310034728913`*^9, 
   3.5729310983520913`*^9, 3.5729311302228913`*^9, 3.5729311834812913`*^9, 
   3.5729312504832916`*^9, 3.5729314334712915`*^9, 3.5729315635284915`*^9, 
   3.572956857644767*^9, 3.572958014264564*^9, 3.5729589091203184`*^9, 
   3.572959395458024*^9, 3.5729594526549253`*^9, 3.5729596013887415`*^9, 
   3.572959748497734*^9, 3.5729597816972466`*^9, 3.5729599067461395`*^9, 
   3.572960253911489*^9, 3.572960335246389*^9, 3.572961118962*^9, 
   3.5729612239032*^9, 3.572961284082*^9, 3.5729613774948*^9, 
   3.5729616301056004`*^9, 3.5729617253747997`*^9, 3.5729618210964003`*^9, 
   3.5729618978796*^9, 3.5729619536496*^9, 3.5729621807076*^9, 
   3.5729630853682003`*^9, 3.57304291903125*^9, 3.573043426890625*^9, 
   3.573043576046875*^9, 3.573043643734375*^9, 3.573043766421875*^9, 
   3.573043876421875*^9, 3.5730439388125*^9, 3.573044024953125*^9, 
   3.57304412965625*^9, 3.573044229171875*^9, 3.573044380546875*^9, 
   3.573044752671875*^9, 3.573044894*^9, 3.573044983671875*^9, {
   3.5730452866875*^9, 3.57304530571875*^9}, 3.573045405671875*^9, 
   3.573046040125*^9, 3.573046149796875*^9, 3.5730462531875*^9, 
   3.57304636525*^9, 3.573046515734375*^9, 3.573046745796875*^9, 
   3.5730469990625*^9, 3.57304718565625*^9, 3.5730473615*^9, 
   3.573047654109375*^9, 3.573047802234375*^9, 3.573047897265625*^9, 
   3.57304801246875*^9, 3.57304809675*^9, 3.573048187296875*^9, 
   3.573048279453125*^9, 3.573048499578125*^9, 3.57304861478125*^9, {
   3.5730487089375*^9, 3.5730487273125*^9}, 3.573048875828125*^9, 
   3.573049019140625*^9, 3.5730491150625*^9, 3.57304920915625*^9, 
   3.573049326609375*^9, 3.573049682453125*^9, 3.573049779890625*^9, 
   3.5730498973125*^9, 3.573050061796875*^9, 3.573050286640625*^9, 
   3.573050595765625*^9, 3.573050722625*^9, 3.573050922609375*^9, 
   3.573051038578125*^9, 3.573053234375*^9, 3.573053748265625*^9, 
   3.57305410665625*^9, 3.573055105015625*^9, 3.57305514640625*^9, 
   3.5730552774375*^9, 3.57305538534375*^9, 3.573056174859375*^9, {
   3.573056266203125*^9, 3.573056287890625*^9}, 3.573056384609375*^9, 
   3.57305688528125*^9, 3.573057242375*^9, 3.57305735578125*^9, 
   3.573057423375*^9, 3.573057568234375*^9, 3.5730576748125*^9, 
   3.573057765546875*^9, 3.573057869125*^9, 3.573057965796875*^9, 
   3.573058052796875*^9, 3.57305814265625*^9, 3.57305823740625*^9, 
   3.573058374828125*^9, 3.57305848825*^9, 3.57305862*^9, 
   3.573058727609375*^9, 3.57305882684375*^9, 3.573058920421875*^9, 
   3.573059021921875*^9, 3.573059132484375*^9, 3.573059252671875*^9, 
   3.573060604078125*^9, 3.573060639390625*^9, 3.573060675265625*^9, 
   3.573060736578125*^9, 3.57306084528125*^9, 3.5730609298125*^9, 
   3.5730610033125*^9, 3.573061090953125*^9, 3.573061157359375*^9, 
   3.573061222515625*^9, 3.57306192090625*^9, 3.5730620441875*^9, 
   3.573062123015625*^9, 3.573062198578125*^9, 3.573062283625*^9, 
   3.573062364125*^9, 3.573062439875*^9, 3.57306253084375*^9, 
   3.57306261778125*^9, 3.573062702328125*^9, 3.573062777015625*^9, 
   3.573062853125*^9, 3.573063029125*^9, 3.5730631046875*^9, 
   3.573063182390625*^9, 3.573063262875*^9, 3.573063344625*^9, 
   3.573063419671875*^9, 3.573063513609375*^9, 3.573063585046875*^9, 
   3.57306366490625*^9, 3.573063750109375*^9, 3.57306382190625*^9, 
   3.573063924546875*^9, 3.573064004984375*^9, 3.573064114734375*^9, 
   3.57306419765625*^9, 3.573064272578125*^9, 3.573064347015625*^9, 
   3.5730644459375*^9, 3.573064524796875*^9, 3.573064628453125*^9, 
   3.57306470371875*^9, 3.573064783234375*^9, 3.573064868765625*^9, 
   3.57306494759375*^9, 3.57306502578125*^9, 3.573065119203125*^9, 
   3.573065217609375*^9, 3.573065386984375*^9, 3.573065466875*^9, 
   3.573065556359375*^9, 3.573065667125*^9, 3.57306707496875*^9, 
   3.57306717959375*^9, 3.573067269578125*^9, 3.57306735009375*^9, 
   3.57306745375*^9, 3.573067626921875*^9, 3.573067733*^9, 
   3.573105093578125*^9, 3.57310517540625*^9, 3.57310528396875*^9, 
   3.573105549625*^9, 3.573105725265625*^9, 3.573105821765625*^9, 
   3.57310592903125*^9, 3.57310602925*^9, 3.573106116921875*^9, 
   3.573106217203125*^9, 3.573106337546875*^9, 3.573106439078125*^9, 
   3.573106542265625*^9, 3.573106666671875*^9, 3.57310676615625*^9, 
   3.573106879890625*^9, 3.57310709171875*^9, 3.57310723734375*^9, 
   3.573107378984375*^9, 3.573107647375*^9, 3.573108105578125*^9, 
   3.573108221703125*^9, 3.57310834515625*^9, 3.573108703046875*^9, 
   3.573108871125*^9, 3.57310898234375*^9, 3.573109159203125*^9, 
   3.573109274015625*^9, 3.573109395921875*^9, 3.5731095075625*^9, 
   3.57310960571875*^9, 3.573109690421875*^9, 3.573109902375*^9, 
   3.573109981890625*^9, 3.5731100694375*^9, 3.5731101508125*^9, 
   3.573110237859375*^9, 3.5731103378125*^9, 3.573110419203125*^9, 
   3.573110544328125*^9, 3.5731114234375*^9, 3.57311296615625*^9, 
   3.573113056375*^9, 3.573113222234375*^9, 3.57311330765625*^9, 
   3.573113503421875*^9, 3.5731138653125*^9, 3.57311415053125*^9, 
   3.573114576921875*^9, 3.573115203171875*^9, 3.573115520421875*^9, 
   3.573115837953125*^9, 3.57311611596875*^9, 3.57311659075*^9, 
   3.573117516828125*^9, 3.5731962401727114`*^9, 3.5731963285311112`*^9, 
   3.573196540310111*^9, 3.573197593598111*^9, 3.5731977110983114`*^9, 
   3.573197791018111*^9, 3.5731979115281115`*^9, 3.573198014584111*^9, 
   3.5731980989177113`*^9, 3.573198201208911*^9, 3.5731983790231113`*^9, 
   3.573198441547911*^9, 3.573198511109311*^9, 3.573198601807711*^9, 
   3.5731986692309113`*^9, 3.5731987427225113`*^9, 3.573198818943311*^9, 
   3.5731989125463114`*^9, 3.5731989941719112`*^9, 3.5731990687555113`*^9, 
   3.5731991409845114`*^9, 3.5731992915401115`*^9, 3.573199426371911*^9, 
   3.5732067985597115`*^9, 3.5732070905969114`*^9, {3.5732092064981112`*^9, 
   3.5732092299137115`*^9}, 3.5732093651189113`*^9, 3.5732238681875*^9, 
   3.573223986171875*^9, 3.573224160234375*^9, 3.573224300421875*^9, 
   3.573224421671875*^9, 3.5732245039375*^9, 3.57322682221875*^9, 
   3.573227040875*^9, 3.5732271845*^9, 3.573227271609375*^9, 
   3.57322737196875*^9, 3.573227453078125*^9, 3.573227615546875*^9, 
   3.573227696390625*^9, 3.573227792921875*^9, 3.57322791596875*^9, 
   3.573228192375*^9, 3.573228300609375*^9, 3.573232455578125*^9, 
   3.573232553078125*^9, 3.57323266428125*^9, 3.573232789046875*^9, 
   3.573232858265625*^9, 3.573232971859375*^9, 3.57323316903125*^9, 
   3.57323327290625*^9, 3.57323436834375*^9, 3.57323459471875*^9, 
   3.57323587753125*^9, 3.573235909375*^9, 3.573236051046875*^9, 
   3.573236218984375*^9, 3.573236355734375*^9, 3.573272250953125*^9, 
   3.57327265015625*^9, 3.573283877109375*^9, 3.573284727578125*^9, 
   3.57328529365625*^9, 3.5732853784375*^9, 3.57328677740625*^9, 
   3.573293545546875*^9, 3.5732946510625*^9, 3.5732950864375*^9, 
   3.573295192203125*^9, 3.573295290953125*^9, 3.573295391640625*^9, 
   3.573295482515625*^9, 3.573295576640625*^9, 3.57329576703125*^9, 
   3.573295859859375*^9, 3.57329605821875*^9, 3.5732961728125*^9, 
   3.573296275515625*^9, 3.573296404875*^9, 3.573298054609375*^9, 
   3.57329816965625*^9, 3.573298252421875*^9, 3.573535598693242*^9, 
   3.5735367907966423`*^9, 3.5735368472540417`*^9, 3.573536939528042*^9, 
   3.5735370470286417`*^9, 3.573537080789042*^9, 3.5735371719710417`*^9, 
   3.5735372188802423`*^9, 3.573537276491042*^9, 3.5735373448502417`*^9, 
   3.573537502435442*^9, 3.573537898784642*^9, 3.5735381190410423`*^9, 
   3.5735381709890423`*^9, 3.573538206167042*^9, 3.573538244995442*^9, {
   3.573538307864442*^9, 3.573538335259042*^9}, 3.573538380592642*^9, {
   3.573538465846642*^9, 3.573538493521042*^9}, 3.573538692375242*^9, 
   3.5735387416400423`*^9, 3.5735388267692423`*^9, 3.573538871385242*^9, 
   3.573538983825042*^9, 3.573539027459242*^9, 3.573539078876842*^9, 
   3.573539122556842*^9, 3.5735392331140423`*^9, 3.5735392924408417`*^9, 
   3.5735393306452417`*^9, 3.573539422471842*^9, 3.5735394921002417`*^9, 
   3.5735395393214417`*^9, 3.573539633982242*^9, 3.5735398294356422`*^9, 
   3.573539880603642*^9, 3.573539913615242*^9, 3.573539985391842*^9, 
   3.573540118366242*^9, 3.573540259533642*^9, 3.573540289813242*^9, 
   3.573540329764842*^9, {3.573540361698042*^9, 3.5735403709956417`*^9}, 
   3.573540450555642*^9, 3.573540484594842*^9, 3.573540538258842*^9, 
   3.573540726302042*^9, 3.5735407905272417`*^9, 3.573541292207642*^9, 
   3.573541621133642*^9, 3.5735416721456423`*^9, 3.573542150506042*^9, 
   3.5735421821126423`*^9, 3.573542270575242*^9, 3.5735423495122423`*^9, 
   3.573542412427042*^9, {3.573542472365242*^9, 3.573542494688842*^9}, {
   3.573543528127842*^9, 3.5735435554588423`*^9}, 3.573543644456842*^9, 
   3.573543684194042*^9, 3.573543847323242*^9, 3.5735439159008417`*^9, 
   3.573544009183242*^9, 3.573544093376442*^9, 3.573544128055242*^9, 
   3.573544194371842*^9, 3.573544229239842*^9, 3.573544282828842*^9, 
   3.573544341798842*^9, 3.573544387250642*^9, 3.5735444259542418`*^9, 
   3.573544465687442*^9, 3.573544550224842*^9, {3.573544621190242*^9, 
   3.573544640565442*^9}, 3.573544692451042*^9, {3.573544731124442*^9, 
   3.573544755382442*^9}, 3.573544799327642*^9, 3.573544909120442*^9, 
   3.573544957215242*^9, 3.573545016387042*^9, 3.573545095432242*^9, 
   3.573545144431842*^9, 3.573545181559842*^9, 3.5735452313706417`*^9, 
   3.573545380225842*^9, 3.573545423656242*^9, 3.573545524996842*^9, 
   3.573545586710442*^9, 3.5735456374104424`*^9, 3.573545686862442*^9, 
   3.573545748981642*^9, 3.573545896333042*^9, 3.573545935317442*^9, 
   3.573545974786442*^9, {3.5735460108692417`*^9, 3.573546068183642*^9}, 
   3.5735461363088417`*^9, 3.573552989767042*^9, 3.573553027888442*^9, 
   3.573553062490242*^9, 3.573553093425042*^9, 3.5735531503544416`*^9, 
   3.573553218838442*^9, 3.573553252145442*^9, 3.5735532847660418`*^9, {
   3.5735533184162416`*^9, 3.5735533474478416`*^9}, 3.573553390956242*^9, 
   3.573553425853442*^9, {3.573553465274642*^9, 3.573553491654242*^9}, 
   3.5735535295164423`*^9, {3.573553677388842*^9, 3.573553705656042*^9}, 
   3.5735537485248423`*^9, 3.573553806525642*^9, {3.573553845464242*^9, 
   3.573553872764242*^9}, {3.573553912117042*^9, 3.573553990698242*^9}, {
   3.573554034691242*^9, 3.573554061523242*^9}, 3.573554172736642*^9, 
   3.573554223656042*^9, 3.573554282452442*^9, {3.573554332076042*^9, 
   3.5735543618408422`*^9}, 3.573554411449842*^9, 3.573554453857842*^9, 
   3.573554489223042*^9, 3.573554525274642*^9, 3.573554739323242*^9, 
   3.573554825899242*^9, 3.573554917426442*^9, 3.5735549623544416`*^9, 
   3.573555123036442*^9, 3.573555164236042*^9, 3.573555196763042*^9, 
   3.573555230505842*^9, {3.573555264623042*^9, 3.573555321531842*^9}, 
   3.5735553642758417`*^9, 3.573555396521042*^9, 3.573555447205442*^9, {
   3.5735554977660418`*^9, 3.573555526594842*^9}, 3.573555580882842*^9, 
   3.573555623236842*^9, 3.573555663968442*^9, 3.5735557360410423`*^9, 
   3.5735558152236423`*^9, 3.573555900557642*^9, 3.5735559316494417`*^9, 
   3.573555970743042*^9, 3.5735561456824417`*^9, 3.573556181703842*^9, 
   3.573556935245242*^9, {3.5735588789766417`*^9, 3.573558893047842*^9}, 
   3.573735604890625*^9, 3.573735651328125*^9, 3.573735689296875*^9, 
   3.573737087296875*^9, 3.573737228375*^9, 3.573737278953125*^9, 
   3.57373737696875*^9, {3.573737417921875*^9, 3.573737446203125*^9}, 
   3.573737485484375*^9, 3.573737562578125*^9, 3.573737744671875*^9, 
   3.573737851984375*^9, 3.573738044703125*^9, 3.57373810365625*^9, 
   3.573738177484375*^9, 3.57373821790625*^9, 3.5737382636875*^9, 
   3.5737383339375*^9, 3.573738487203125*^9, 3.573738531140625*^9, 
   3.573738575875*^9, 3.573738625984375*^9, 3.57373866690625*^9, 
   3.573738707421875*^9, 3.573738803671875*^9, 3.573738853328125*^9, 
   3.57373891746875*^9, 3.57373899303125*^9, 3.57373903628125*^9, 
   3.57373908190625*^9, 3.57373916609375*^9, {3.573739451921875*^9, 
   3.57373668853125*^9}, 3.573736784765625*^9, 3.573736924390625*^9, 
   3.5737370803125*^9, 3.5738957474022527`*^9, 3.5738958788478527`*^9, 
   3.5738960485184526`*^9, 3.5738962742132525`*^9, 3.5738963583596525`*^9, 
   3.573896952176653*^9, 3.5738970142802525`*^9, 3.5738970759782524`*^9, 
   3.5739591684258404`*^9, 3.57395976391864*^9, 3.5786340216478567`*^9, 
   3.5786340907402573`*^9, 3.5786529842022*^9, 3.5786532292566*^9, 
   3.578653557225*^9, 3.5786545451694*^9, 3.5786548056582003`*^9, 
   3.578717255011397*^9, 3.5787177898437967`*^9, 3.5787180957909966`*^9, 
   3.578721407849197*^9, 3.5787352073071966`*^9, 3.578746851094197*^9, 
   3.578747097373397*^9, 3.5787471299617968`*^9, 3.578747326537397*^9, 
   3.578747437969197*^9, 3.5787480062791967`*^9, 3.578748054623597*^9, 
   3.5788220997485976`*^9, 3.5788222844369974`*^9, 3.5788228520213976`*^9, 
   3.578822936807398*^9, 3.5788231974989977`*^9, 3.578823253253398*^9, 
   3.578823302284198*^9, 3.5788233402545977`*^9, 3.5788233885225973`*^9, 
   3.578823451813798*^9, {3.5789067170974073`*^9, 3.5789067450370073`*^9}, 
   3.578907782987007*^9, 3.578907888708207*^9, 3.578908102694407*^9, 
   3.578908159151807*^9, 3.578908223377007*^9, 3.578908271628807*^9, 
   3.578910245493207*^9, 3.5789188580190067`*^9, 3.578918952820207*^9, 
   3.578918989339807*^9, 3.578919069869007*^9, 3.578919121754607*^9, 
   3.5789191654190073`*^9, 3.578919206057007*^9, 3.578919254370207*^9, 
   3.578919318049407*^9, 3.5789196561756067`*^9, 3.5789886209447994`*^9, 
   3.578988657152399*^9, 3.5789887196459994`*^9, 3.5789887507523994`*^9, 
   3.5789888010155993`*^9, 3.5789888415443993`*^9, 3.5789889845963993`*^9, 
   3.5790000287119994`*^9, 3.5790001222495995`*^9, 3.5790001723723993`*^9, 
   3.5790002665651994`*^9, 3.5790003149875994`*^9, 3.5790003667503996`*^9, 
   3.5790028795279994`*^9, 3.5868503836756*^9, 3.5868505525612*^9, 
   3.5868508343752003`*^9, 3.586862025894*^9, 3.5868620883876*^9, 
   3.586862244216*^9, 3.5868623405092*^9, 3.5868624369337997`*^9, 
   3.5868629335794*^9, 3.5868630347454*^9, 3.5868632944034*^9, 
   3.5868633916548*^9, 3.5868636371772003`*^9, 3.5868637522372*^9, 
   3.5868638352302*^9, 3.5868638836057997`*^9, 3.5868639310142*^9, 
   3.5868639789842*^9, 3.5868640215108*^9, 3.5868640617060003`*^9, 
   3.5868642003588*^9, 3.5868643155648003`*^9, 3.5868643563472*^9, 
   3.5868644096836*^9, 3.5868644665144*^9, 3.5868645252016*^9, 
   3.5868645703792*^9, 3.5868646763752003`*^9, 3.586864735156*^9, 
   3.5868647912536*^9, 3.5868649140724*^9, 3.5868649699924*^9, 
   3.586865043094*^9, 3.5868653116334*^9, 3.5868653603536*^9, 
   3.5868654074208*^9, 3.586865552722*^9, {3.586865618398*^9, 
   3.5868656479132*^9}, 3.5868657079264*^9, 3.5868657709854*^9, 
   3.5868658060386*^9, {3.5868658532130003`*^9, 3.5868658784226*^9}, 
   3.5868664109598*^9, 3.5868665438406*^9, 3.5868666340086*^9, 
   3.5868666760671997`*^9, 3.5868667460488*^9, 3.5908978931847878`*^9, 
   3.590897966411188*^9, 3.590898192845188*^9, 3.5908982327967877`*^9, 
   3.5908983431199875`*^9, 3.5908987839403877`*^9, 3.5908989342005877`*^9, 
   3.590898976991388*^9, 3.5908990228241878`*^9, 3.590899060045788*^9, 
   3.5908990951613874`*^9, 3.590899147234188*^9, 3.590899215546588*^9, 
   3.590899252955388*^9, {3.5908993104971876`*^9, 3.5908993397939878`*^9}, 
   3.5908993826003876`*^9, 3.590899447855188*^9, 3.5908995280235877`*^9, 
   3.5908995606587877`*^9, 3.590899631545188*^9, 3.590899699984388*^9, 
   3.590899769092388*^9, 3.5908999948399878`*^9, 3.5909000823715878`*^9, 
   3.590900142041588*^9, 3.5909001859711876`*^9, 3.5909002575595875`*^9, 
   3.590900305249788*^9, 3.590900344015788*^9, 3.5909003916269875`*^9, 
   3.590900427491388*^9, 3.590900471420988*^9, 3.590900504010388*^9, 
   3.590900542277188*^9, 3.590900584677988*^9, 3.590900621415988*^9, 
   3.590900663551588*^9, 3.590900703768388*^9, 3.5909007352491875`*^9, 
   3.590900767605588*^9, 3.590900807042388*^9, 3.590900841051388*^9, 
   3.5909008818453875`*^9, 3.590900930345788*^9, 3.590900990791788*^9, 
   3.5909010274361877`*^9, 3.5909010590885878`*^9, 3.5909011328307877`*^9, 
   3.590901216853388*^9, 3.590901253825388*^9, 3.590901287365388*^9, 
   3.5909013257735877`*^9, 3.5909014294703875`*^9, 3.5909014798271875`*^9, 
   3.5909015218847876`*^9, 3.5909015784659877`*^9, 3.5909016180899878`*^9, 
   3.590901672550788*^9, 3.5909017157159877`*^9, 3.590901768974388*^9, 
   3.590901818098788*^9, 3.590901855320388*^9, 3.590901923024388*^9, 
   3.590901957704188*^9, 3.5909020387133875`*^9, 3.5909020743145876`*^9, 
   3.5909021532505875`*^9, {3.5909021891773877`*^9, 3.590902218630188*^9}, 
   3.590902257505388*^9, 3.5909023516045876`*^9, 3.5909023850509877`*^9, 
   3.5909024592777877`*^9, 3.5909025146109877`*^9, 3.590902592408188*^9, {
   3.5909026225005875`*^9, 3.590902649628988*^9}, 3.5909027005785875`*^9, 
   3.590902732026988*^9, 3.5909027710737877`*^9, 3.5909028943293877`*^9, 
   3.590902924484188*^9, 3.590902956198988*^9, 3.590903017896988*^9, 
   3.590903115378788*^9, 3.590903193082388*^9, 3.5909032268095875`*^9, 
   3.5909032957147875`*^9, 3.5909033457127876`*^9, 3.590903473781388*^9, 
   3.590903517300388*^9, 3.5909035528763876`*^9, 3.5909035875223875`*^9, 
   3.590903638356388*^9, 3.5909036897183876`*^9, 3.5909037370933876`*^9, 
   3.590904092071388*^9, 3.5909042008313875`*^9, 3.590904277859388*^9, 
   3.5909043296403875`*^9, 3.590904396745388*^9, 3.590904518650388*^9, 
   3.590904831806388*^9, 3.5909049822113876`*^9, 3.5909050561783876`*^9, 
   3.5909051460063877`*^9, 3.590905562172388*^9, 3.5909056259943876`*^9, 
   3.5909056901903877`*^9, 3.590905744709388*^9, 3.5909058088173876`*^9, 
   3.590905868641388*^9, 3.5909059440743876`*^9, 3.590905995106388*^9, 
   3.5909060266473875`*^9, 3.590913247481388*^9, 3.5909132802773876`*^9, 
   3.590913312097388*^9, 3.5909133590083876`*^9, 3.5909134089753876`*^9, 
   3.5909134772723875`*^9, 3.590913509465388*^9, 3.590913546694388*^9, 
   3.5909136178713875`*^9, 3.590913651681388*^9, 3.590913732859388*^9, 
   3.590913786525388*^9, 3.590913837990388*^9, 3.590913888852388*^9, 
   3.590913926531388*^9, 3.5909139942033877`*^9, 3.590914078839388*^9, 
   3.590914117958388*^9, 3.590914188781388*^9, 3.590914230385388*^9, 
   3.590914268768388*^9, 3.590914300510388*^9, 3.5909143455263877`*^9, 
   3.590914390599388*^9, 3.590914543851388*^9, 3.590914606007388*^9, 
   3.590914642443388*^9, 3.5909146790783877`*^9, 3.590914726995388*^9, 
   3.5909147846903877`*^9, 3.590914867900388*^9, 3.590914935172388*^9, 
   3.590914999783388*^9, 3.590915055840388*^9, 3.590915091340388*^9, 
   3.590915152662388*^9, 3.590915217851388*^9, 3.590915273044388*^9, 
   3.590915320016388*^9, 3.590915393245388*^9, 3.5909154601333876`*^9, 
   3.590915509577388*^9, 3.590915568226388*^9, 3.590915616847388*^9, 
   3.590915666110388*^9, 3.590915714715388*^9, 3.590915778853388*^9, 
   3.5909158472033877`*^9, 3.5909159148613877`*^9, 3.5909159749823875`*^9, 
   3.590916024292388*^9, 3.590916078417388*^9, 3.5909161278243876`*^9, 
   3.590916171906388*^9, 3.5909162333763876`*^9, 3.5909162721513877`*^9, 
   3.590916308858388*^9, 3.590916364242388*^9, 3.5909164057433877`*^9, 
   3.5909164458383875`*^9, 3.590916505962388*^9, 3.5909165701663876`*^9, 
   3.590916617176388*^9, 3.590916651462388*^9, 3.590916759215388*^9, 
   3.590916811418388*^9, 3.590916843880388*^9, 3.590916937042388*^9, 
   3.5909169902983875`*^9, 3.590917125255388*^9, 3.590917157568388*^9, 
   3.5909800684133606`*^9, 3.590980105400961*^9, 3.590980176131361*^9, 
   3.590980246658961*^9, 3.590980293053361*^9, 3.5909803730033607`*^9, 
   3.5909804335881605`*^9, 3.5909805244455605`*^9, 3.5909805669399605`*^9, 
   3.590980616346161*^9, 3.590980677904761*^9, 3.590980989649161*^9, 
   3.590981045169561*^9, {3.590981107117161*^9, 3.5909811366801605`*^9}, 
   3.590981196663161*^9, 3.590981289202361*^9, 3.590981382037961*^9, 
   3.590981438572361*^9, 3.5909815337167606`*^9, 3.5909816458193607`*^9, 
   3.590981692900161*^9, 3.590981733617161*^9, 3.5909818994049606`*^9, 
   3.5909819449569607`*^9, 3.590982024610561*^9, 3.590982064593361*^9, 
   3.5909821324533606`*^9, 3.590982184214161*^9, 3.590982244242961*^9, {
   3.5909822963937607`*^9, 3.5909823173913608`*^9}, 3.5909824236897607`*^9, 
   3.590982467687361*^9, 3.590982571662361*^9, 3.5909826037203608`*^9, 
   3.590982712514761*^9, 3.590982850793161*^9, 3.590982947997761*^9, 
   3.590982992691761*^9, 3.5909830698493605`*^9, 3.590983334229761*^9, 
   3.590984529121361*^9, {3.5909846334229608`*^9, 3.5909846431885605`*^9}, 
   3.590985089469361*^9, 3.590985200462361*^9, 3.590985249212361*^9, 
   3.590985305243561*^9, 3.590985384054761*^9, 3.5909854454105606`*^9, 
   3.590985514768161*^9, 3.5909855536901608`*^9, 3.590985597463761*^9, 
   3.5909856495833607`*^9, 3.590985704058561*^9, 3.5909857397981606`*^9, 
   3.590985789967761*^9, 3.5909858273765607`*^9, 3.590986195614561*^9, 
   3.5909862655649605`*^9, 3.590986316857761*^9, 3.590986369648161*^9, 
   3.590986428865761*^9, 3.590986472312761*^9, 3.590986589655961*^9, 
   3.590986691523961*^9, 3.5909867374815607`*^9, 3.5909867757171607`*^9, 
   3.590986821908761*^9, 3.5909868658705606`*^9, 3.5909869211569605`*^9, 
   3.5909870026513605`*^9, 3.5909870906977606`*^9, 3.5909873420303607`*^9, 
   3.5909874449903607`*^9, 3.5909875001675606`*^9, 3.590987689970761*^9, 
   3.590988233221961*^9, 3.590988285717961*^9, 3.590988342397761*^9, 
   3.5909884442515607`*^9, 3.590988516729161*^9, 3.5909886524505606`*^9, 
   3.5909887484217606`*^9, 3.590988807015361*^9, 3.5909888766225605`*^9, 
   3.5909889538435607`*^9, 3.590989037225561*^9, 3.590989102404361*^9, 
   3.5909891660523605`*^9, 3.590989215847561*^9, 3.5909892800727606`*^9, 
   3.590989356559561*^9, 3.590989437570361*^9, 3.5909894846823606`*^9, 
   3.590989564773761*^9, 3.590989647594161*^9, 3.5909903111785607`*^9, 
   3.5909904726555605`*^9, 3.590990578329961*^9, 3.590990843186761*^9, 
   3.5909911185735607`*^9, 3.5909911508811607`*^9, 3.590991193547161*^9, 
   3.5909912281479607`*^9, 3.590991264497961*^9, 3.590991298973961*^9, 
   3.591530721308555*^9, 3.591530802018155*^9, 3.5915314320585294`*^9, 
   3.5915315679218254`*^9, 3.5915316458015456`*^9, 3.591531701120283*^9, 
   3.5915317594189997`*^9, 3.591531859242818*^9, 3.591531946732913*^9, 
   3.591532010743419*^9, 3.5915321957823086`*^9, 3.5915322599419127`*^9, 
   3.59153234659046*^9, 3.5915324258290815`*^9, 3.5915324970703907`*^9, 
   3.5915325454735346`*^9, 3.591532958385818*^9, 3.591533763335413*^9, 
   3.591533950767886*^9, 3.5915340015536127`*^9, 3.591534345677211*^9, 
   3.591535263278471*^9, 3.5915353460674515`*^9, 3.5915354124225206`*^9, 
   3.5915354920013657`*^9, 3.591535558598667*^9, 3.591535665617737*^9, 
   3.5915357385972033`*^9, 3.591535808198553*^9, 3.591535914083496*^9, 
   3.5915364253692203`*^9, 3.5915365260530024`*^9, 3.5915366197932577`*^9, 
   3.5915376045541396`*^9, 3.5915376685186195`*^9, 3.5915378250525737`*^9, 
   3.5915378790434294`*^9, 3.591537929011615*^9, 3.591538318773455*^9, 
   3.5915384108305902`*^9, 3.5915434713446174`*^9, 3.5915435318441067`*^9, 
   3.591543583689602*^9, 3.5915436649313064`*^9, 3.591543699307252*^9, 
   3.59154380512576*^9, 3.5915438527201433`*^9, 3.5915439253615627`*^9, 
   3.5915440942890673`*^9, 3.591544142672295*^9, 3.591544260479312*^9, 
   3.5915443491509066`*^9, 3.591544476850444*^9, 3.591544550315709*^9, 
   3.5915446034864044`*^9, 3.5915446507309246`*^9, 3.5915451510700006`*^9, 
   3.591545315189245*^9, 3.5915453731511307`*^9, 3.5919491699808164`*^9, 
   3.5919498931956997`*^9, 3.5919499385860343`*^9, {3.5919505340763893`*^9, 
   3.5919505625614333`*^9}, 3.5919505967799644`*^9, 3.591950668029508*^9, 
   3.591950714919833*^9, 3.5919510940565095`*^9, 3.5919511573369493`*^9, 
   3.591951192367751*^9, 3.5919512311797543`*^9, 3.5919512621168585`*^9, 
   3.5919513119096713`*^9, 3.5919516902562776`*^9, 3.5919517528784723`*^9, {
   3.591951995025509*^9, 3.5919520356804576`*^9}, 3.5919520951316805`*^9, 
   3.591952320515093*^9, 3.59195247418205*^9, 3.5919525530545263`*^9, 
   3.592137049173611*^9, 3.592137095110523*^9, 3.5921371437974*^9, 
   3.592137184796875*^9, {3.5921372839049816`*^9, 3.5921373097640257`*^9}, 
   3.592137372372599*^9, 3.5921379686505404`*^9, {3.592138011041436*^9, 
   3.5921380222133827`*^9}, 3.5921380553229694`*^9, 3.592547372820463*^9, 
   3.5925488573575897`*^9, {3.5925491062947817`*^9, 3.592549154932307*^9}, {
   3.5925493266891375`*^9, 3.5925493547502003`*^9}, 3.59254938521739*^9, 
   3.592549416825147*^9, 3.592549502821057*^9, 3.5933429450406675`*^9, 
   3.5933430834737377`*^9, 3.593343170005205*^9, 3.593345386944476*^9, 
   3.5933455543862624`*^9, 3.5933455894965363`*^9, 3.5933457644853907`*^9, 
   3.5933465110826283`*^9, 3.5933466381235485`*^9, 3.593346699941781*^9, 
   3.593346917550933*^9, 3.5933473985185614`*^9, 3.593347520277561*^9, 
   3.5933477008943615`*^9, 3.593347826489961*^9, 3.5933478886715612`*^9, {
   3.593347992021561*^9, 3.5933480372791615`*^9}, 3.593348142659161*^9, {
   3.593348174462961*^9, 3.5933482266761613`*^9}, 3.593348294785761*^9, 
   3.593348342443761*^9, 3.593348437152361*^9, 3.5933485672095613`*^9, 
   3.593348794679561*^9, 3.5934103531281433`*^9, 3.593410438350943*^9, 
   3.593410472202943*^9, 3.593410508348143*^9, 3.5934105522153435`*^9, 
   3.5934105921513433`*^9, 3.593410636377343*^9, 3.593410686025543*^9, 
   3.593410722888343*^9, 3.593410784415743*^9, 3.593411239920143*^9, {
   3.5934112921801434`*^9, 3.593411366373743*^9}, 3.5934114684133434`*^9, 
   3.593411502624143*^9, 3.593411561453743*^9, 3.5934116067027435`*^9, 
   3.593411641459543*^9, 3.5934117313311434`*^9, 3.593411770955143*^9, 
   3.593411835289543*^9, 3.5934119753307433`*^9, {3.5934120236127434`*^9, 
   3.5934120752799435`*^9}, 3.5934121327815433`*^9, 3.593412167244943*^9, 
   3.593412272622943*^9, 3.593412327831343*^9, 3.5934123997785435`*^9, 
   3.593412663578543*^9, 3.593412781483343*^9, 3.5934128991541433`*^9, 
   3.5934129873565435`*^9, 3.593413056963743*^9, {3.5934131011907434`*^9, 
   3.593413129209343*^9}, 3.5934131918433433`*^9, {3.593413238206543*^9, 
   3.593413268018143*^9}, {3.593413335784543*^9, 3.593413392421543*^9}, 
   3.593413450009743*^9, {3.593413503626943*^9, 3.5934135333605433`*^9}, 
   3.593413604699343*^9, 3.5934137066921434`*^9, 3.593413813981943*^9, {
   3.593414081893143*^9, 3.593414102158543*^9}, 3.593414187117143*^9, {
   3.5934142207039433`*^9, 3.5934142752883434`*^9}, 3.5934143263003435`*^9, 
   3.593414365690343*^9, 3.5934144457183433`*^9, 3.593414492206343*^9, 
   3.5934145354183435`*^9, {3.593414618004743*^9, 3.593414625945143*^9}, 
   3.593414659141943*^9, 3.5934147229561434`*^9, 3.5934148013305435`*^9, 
   3.5934148383493433`*^9, 3.5934150889381433`*^9, 3.593415479521343*^9, 
   3.5934155137321434`*^9, 3.5934155730277433`*^9, {3.5934156574237432`*^9, 
   3.593415681759743*^9}, 3.593415724473543*^9, 3.5934158703733435`*^9, 
   3.5934186795467997`*^9, 3.5934187914685717`*^9, 3.5934188308904467`*^9, 
   3.5934188688435717`*^9, 3.5934189497029467`*^9, 3.5934189962654467`*^9, 
   3.5934190836716967`*^9, 3.5934191294373217`*^9, {3.5934191867185717`*^9, 
   3.5934192109685717`*^9}, 3.5934192608279467`*^9, 3.5934193188591967`*^9, 
   3.5934194012029467`*^9, 3.5934194468435717`*^9, 3.593422165451536*^9, 
   3.593422238653256*^9, 3.593422417243915*^9, 3.5934229342563763`*^9, 
   3.5934230601157513`*^9, 3.5934231528188763`*^9, 3.5934255556491866`*^9, 
   3.5934258391960616`*^9, 3.593425958793578*^9, 3.593426033390193*^9, 
   3.5934261619732227`*^9, 3.5934262254896607`*^9, {3.5934262702089834`*^9, 
   3.5934262758496804`*^9}, 3.593426325194062*^9, 3.5934265713051715`*^9, 
   3.5934267801645465`*^9, 3.5934974066533537`*^9, 3.593497469292776*^9, 
   3.593497645697055*^9, 3.5934977169139814`*^9, 3.5934977516787167`*^9, {
   3.5934992261778555`*^9, 3.5934992560682898`*^9}, 3.5934995479414215`*^9, 
   3.5934997895858016`*^9, 3.5935009309978795`*^9, 3.5935010141856127`*^9, 
   3.5935011402941804`*^9, 3.593501252730961*^9, {3.5935014564952817`*^9, 
   3.5935014798076324`*^9}, 3.59350193844039*^9, 3.593503054777802*^9, 
   3.5935031408112545`*^9, {3.593503186421797*^9, 3.593503206922322*^9}, 
   3.5935046861410437`*^9, 3.5935047734847937`*^9, 3.5935048403706264`*^9, {
   3.5935049448768864`*^9, 3.593504969359068*^9}, 3.59350504114951*^9, 
   3.5935050826770387`*^9, 3.593505167283465*^9, 3.593505264717847*^9, 
   3.593505955221378*^9, 3.5935060162678623`*^9, 3.5935060676425333`*^9, 
   3.5935061389858265`*^9, 3.5935061751262207`*^9, {3.5935069198558292`*^9, 
   3.5935069460587864`*^9}, 3.5935070088708844`*^9, 3.5935132137417927`*^9, 
   3.593513256272771*^9, {3.593513305756829*^9, 3.593513355756509*^9}, 
   3.59351343216227*^9, 3.5935136255672817`*^9, 3.5935137020511675`*^9, 
   3.593513773503835*^9, 3.5935139600338917`*^9, 3.5935141107673016`*^9, 
   3.59351425482888*^9, 3.5935148344189205`*^9, 3.593514884902972*^9, 
   3.593514981011732*^9, 3.593515083276703*^9, 3.593515140370087*^9, 
   3.593515212682124*^9, 3.593517091170102*^9, 3.593517386215089*^9, 
   3.594313888580101*^9, 3.5943139478706784`*^9, 3.594314443438525*^9, 
   3.5943144936540446`*^9, 3.5943146065173836`*^9, 3.5943147075067964`*^9, 
   3.594315006710024*^9, 3.5943151488208857`*^9, 3.594315493190759*^9, 
   3.5943155240123367`*^9, {3.59431560824961*^9, 3.5943156195921817`*^9}, 
   3.594315687906783*^9, 3.5943157380792737`*^9, 3.59431577775776*^9, 
   3.5943158174082975`*^9, 3.5943159023960266`*^9, 3.5943159902706847`*^9, 
   3.5943161753962603`*^9, 3.594316229904647*^9, 3.5943162727742624`*^9, 
   3.594316311263955*^9, 3.594316377590229*^9, 3.594316502075327*^9, 
   3.5943165861034164`*^9, 3.594316636080778*^9, 3.594316761266344*^9, 
   3.594316882878521*^9, 3.5943169580707135`*^9, 3.5943170256388235`*^9, 
   3.594317066539119*^9, 3.594317167138938*^9, 3.5943172728104744`*^9, 
   3.5943173643203764`*^9, 3.594317446798027*^9, 3.594317566685054*^9, 
   3.594317641737677*^9, 3.5943177132594194`*^9, 3.5943177822250724`*^9, 
   3.594317853623734*^9, 3.5943179241808324`*^9, 3.594317981097824*^9, 
   3.5943180622019625`*^9, 3.5943180955542274`*^9, 3.5943181939769254`*^9, {
   3.5943182397224617`*^9, 3.594318293009033*^9}, 3.5943183507485757`*^9, 
   3.594318423961445*^9, 3.5943184808724365`*^9, 3.5943185395756216`*^9, 
   3.594318633999312*^9, 3.5943187547869864`*^9, 3.5943188273664336`*^9, 
   3.594318877960205*^9, 3.594318939651387*^9, 3.59431898363349*^9, 
   3.5943190172829523`*^9, 3.594319053059835*^9, 3.594319259130392*^9, 
   3.5943193386265025`*^9, 3.5943194085031457`*^9, 3.594319465401126*^9, 
   3.5943195101419926`*^9, 3.5943195788928857`*^9, 3.5943197160857067`*^9, 
   3.594319874574501*^9, 3.594319957346754*^9, 3.5943199904838743`*^9, 
   3.594320044488284*^9, {3.594320280771039*^9, 3.5943202999218225`*^9}, 
   3.594320377378528*^9, 3.5943204744243135`*^9, 3.5943205464003572`*^9, 
   3.5943206850755854`*^9, 3.594320725269416*^9, {3.5943207896944227`*^9, 
   3.5943208127328014`*^9}, 3.5943208495853977`*^9, 3.594320920196534*^9, 
   3.594320998024485*^9, 3.5943211922561398`*^9, 3.5943212661394567`*^9, {
   3.594321309340296*^9, 3.594321336004094*^9}, 3.594321369605524*^9, 
   3.594321467431825*^9, 3.5943215282794423`*^9, 3.594321594647744*^9, 
   3.59432163207873*^9, 3.594321750285635*^9, 3.5943217974291053`*^9, {
   3.594321839950489*^9, 3.594321865772725*^9}, 3.5943219354162583`*^9, 
   3.5943221374741716`*^9, 3.594322180120639*^9, 3.594322253487612*^9, 
   3.594322297434949*^9, 3.594322358654813*^9, {3.5943224041721983`*^9, 
   3.5943224445211315`*^9}, 3.594322483488145*^9, 3.594322536941825*^9, 
   3.5943226148168077`*^9, 3.5943226846304092`*^9, 3.5943227381961656`*^9, 
   3.594322774656504*^9, 3.594322834496456*^9, 3.594322884417771*^9, 
   3.594322919394698*^9, 3.594323002017851*^9, 3.594323080084962*^9, 
   3.594323129201747*^9, 3.5943232140613933`*^9, 3.594323287751584*^9, 
   3.5943233837236476`*^9, 3.5943234327333603`*^9, {3.594323493397331*^9, 
   3.594323504592806*^9}, 3.5943235457142553`*^9, 3.594323580523491*^9, 
   3.5943236499688463`*^9, 3.594323698823459*^9, 3.5943237507841434`*^9, 
   3.5943238165620537`*^9, 3.594323866043085*^9, 3.594323938524537*^9, 
   3.5943239731246343`*^9, 3.594324017274105*^9, 3.5943240597424517`*^9, 
   3.594324100019338*^9, 3.5943241786588306`*^9, 3.594324230187229*^9, 
   3.5943242841632595`*^9, 3.5943243620122232`*^9, 3.5943679695483255`*^9, 
   3.5943771710007253`*^9, 3.594377262479125*^9, 3.5943774373551254`*^9, 
   3.594377496604925*^9, 3.5943776402809253`*^9, 3.594377744832125*^9, 
   3.5943779361661253`*^9, 3.594377983512125*^9, 3.594378169839525*^9, 
   3.5943783258083253`*^9, 3.5943783717035255`*^9, 3.5943784386431255`*^9, 
   3.594378639259125*^9, 3.594378703422925*^9, 3.594378786524125*^9, 
   3.594378822887725*^9, 3.5943789265497255`*^9, 3.594379037824525*^9, 
   3.594379205540125*^9, 3.594379409808525*^9, 3.594379457872125*^9, 
   3.594379539039925*^9, 3.5943798041775255`*^9, 3.5943802720693254`*^9, 
   3.5943803025517254`*^9, 3.594380441578925*^9, 3.5943815272751255`*^9, 
   3.594381605165925*^9, 3.594381683665125*^9, 3.594381814003125*^9, 
   3.5943819323291254`*^9, 3.594381980096325*^9, 3.594382133272725*^9, 
   3.594382263814525*^9, 3.594383266965525*^9, 3.594383313524925*^9, 
   3.5943839631845255`*^9, 3.594384088889325*^9, 3.5943842016773252`*^9, 
   3.594384286732525*^9, 3.594384403155325*^9, 3.594384479362325*^9, 
   3.5943845299647255`*^9, 3.594384580851925*^9, 3.594384621177925*^9, 
   3.5943846689919252`*^9, 3.594384732516125*^9, {3.594384792560525*^9, 
   3.5943848203839254`*^9}, 3.594439210545537*^9, 3.5944393737839365`*^9, {
   3.5944414496399364`*^9, 3.594441471058737*^9}, 3.5944415423195367`*^9, 
   3.594441933785937*^9, 3.594442015701537*^9, 3.5944420646231365`*^9, 
   3.594442166241537*^9, 3.594442213540737*^9, 3.5944422683591366`*^9, 
   3.594445795223137*^9, 3.594445827343537*^9, 3.594445901677537*^9, 
   3.594445946199937*^9, 3.5944459814217367`*^9, 3.594446061208737*^9, 
   3.594446129458737*^9, 3.5944464180365367`*^9, 3.5944464954749365`*^9, 
   3.594446641764737*^9, 3.5944477762811365`*^9, 3.594447867231137*^9, 
   3.594447924249137*^9, 3.594447977959937*^9, 3.594448033839137*^9, 
   3.594448080639137*^9, 3.5944481130583367`*^9, 3.5944481661295366`*^9, 
   3.594448218857537*^9, 3.594448292115137*^9, 3.5944483335523367`*^9, 
   3.5944484021299367`*^9, {3.594448434063137*^9, 3.594448459990337*^9}, {
   3.5944484966659365`*^9, 3.594448520268737*^9}, 3.594448569549137*^9, 
   3.594448607675537*^9, 3.5944487596819367`*^9, 3.5944487961703367`*^9, 
   3.594448832362337*^9, 3.594448894497137*^9, 3.5944489282489367`*^9, 
   3.5944489597609367`*^9, 3.5944490594449368`*^9, 3.594449115511337*^9, 
   3.594449156664137*^9, 3.594449197336137*^9, 3.5944492308605366`*^9, 
   3.594449293541337*^9, {3.594449338937337*^9, 3.594449367173337*^9}, 
   3.594449424145537*^9, 3.594449460478937*^9, 3.594450078192537*^9, 
   3.594450335640337*^9, 3.594450373112537*^9, 3.5944505093493366`*^9, 
   3.594450553388137*^9, 3.5944505981601367`*^9, 3.594450738826337*^9, 
   3.5944507973585367`*^9, {3.5944508738317366`*^9, 3.5944509030193367`*^9}, 
   3.5944509456239367`*^9, 3.5944509788051367`*^9, 3.5944511871673365`*^9, 
   3.5944513585957365`*^9, 3.5944513936489367`*^9, 3.594452054795537*^9, 
   3.594452180719737*^9, {3.594452658251337*^9, 3.594452678094537*^9}, 
   3.5944528006793365`*^9, 3.594453037060337*^9, {3.5944530915979366`*^9, 
   3.5944531192411366`*^9}, 3.594453202023337*^9, 3.5947205762096305`*^9, 
   3.5947206285355587`*^9, 3.5947231749617996`*^9, 3.594723266577952*^9, 
   3.5947232975706453`*^9, 3.5947233288665314`*^9, 3.594723581930519*^9, 
   3.594723744061744*^9, 3.594723981774423*^9, 3.5947241399650173`*^9, 
   3.594732924940566*^9, 3.594732973999316*^9, 3.594733034594763*^9, 
   3.5947331208603497`*^9, 3.594733199309718*^9, 3.5947332824730687`*^9, 
   3.594733327848121*^9, 3.5947333659805746`*^9, 3.594733647489092*^9, 
   3.5947338462417665`*^9, 3.5947339260780554`*^9, 3.59473398810046*^9, 
   3.594734092952448*^9, 3.594734155785391*^9, 3.5947343085783825`*^9, 
   3.594734413232242*^9, 3.5947345033463955`*^9, 3.5947345901593485`*^9, 
   3.5947346622914987`*^9, 3.5947347430504065`*^9, 3.594734949296076*^9, 
   3.594735069656419*^9, 3.5947352181625495`*^9, 3.594735336077261*^9, 
   3.5947354976070848`*^9, 3.5947355499650354`*^9, 3.59473562413455*^9, 
   3.594735785364174*^9, 3.594735862481649*^9, 3.594736005371029*^9, 
   3.594736078338736*^9, 3.594736143847464*^9, 3.594736190121353*^9, 
   3.5947364608897266`*^9, 3.596107415320054*^9, 3.596362044596094*^9, 
   3.5963630418707495`*^9, 3.5963631095048776`*^9, 3.5963631768906603`*^9, 
   3.596364154031719*^9, {3.596367715721449*^9, 3.5963677427434053`*^9}, 
   3.596367785673934*^9, 3.5963681115035257`*^9, 3.5963682261667223`*^9, 
   3.663483666669719*^9, 3.663483932777591*^9, 3.6634840021531477`*^9, 
   3.6634840466951685`*^9, 3.6634841327320566`*^9, 3.66348422850611*^9, 
   3.6634843957816467`*^9, 3.663484465284234*^9, 3.6634845061980343`*^9, 
   3.6634846160593653`*^9, 3.6634846816371984`*^9, 3.6634847959144135`*^9, 
   3.6634848955309925`*^9, 3.66348495018029*^9, 3.663485018211651*^9, 
   3.663485223451418*^9, 3.663485387556134*^9, 3.6634854417769794`*^9, 
   3.6634855826350417`*^9, 3.663485656582077*^9, 3.6634857434470882`*^9, 
   3.663485809261339*^9, 3.6634858771316833`*^9, 3.6634859454410105`*^9, 
   3.663486012511589*^9, 3.663486343762823*^9, 3.6634863832832413`*^9, {
   3.663486504304864*^9, 3.663486551957162*^9}, 3.6634866060128775`*^9, 
   3.6634866694197865`*^9, 3.663486789028842*^9, 3.663486864833089*^9, 
   3.663486993070303*^9, 3.66348707283253*^9, 3.663487111311431*^9, 
   3.6634872617416406`*^9, 3.6634873438379946`*^9, 3.663488272015529*^9, 
   3.663488307775218*^9, 3.6634883572493114`*^9, 3.6634884057398663`*^9, 
   3.663488443467639*^9, 3.6634884920642157`*^9, 3.6634885790204535`*^9, 
   3.6634886192907877`*^9, 3.663488672312559*^9, 3.6634891148629255`*^9, {
   3.663489260531838*^9, 3.6634892866170754`*^9}, 3.663489346638405*^9, 
   3.6634900170159225`*^9, 3.6634900664673996`*^9, 3.663490148297989*^9, 
   3.6634902431158266`*^9, 3.6634905996389704`*^9, 3.6634906313503113`*^9, 
   3.663490706067917*^9, 3.6635698469651766`*^9, 3.663569915067607*^9, 
   3.663570013896763*^9, 3.6635700750150995`*^9, 3.6635701304804363`*^9, 
   3.6635701704619427`*^9, 3.6635702778258257`*^9, 3.6635704899488645`*^9, 
   3.6635705638320045`*^9, 3.6635706193757963`*^9, 3.6635706583257456`*^9, 
   3.6635707319313464`*^9, 3.663570984752812*^9, 3.663571157350419*^9, 
   3.6635720606518974`*^9, 3.6635723176872354`*^9, 3.6635900970958357`*^9, 
   3.663590224494483*^9, 3.663590312005367*^9, 3.663590374021759*^9, 
   3.663590472457841*^9, 3.663590550415539*^9, 3.6635907107989063`*^9, 
   3.663591152251875*^9, 3.6635916004550796`*^9, 3.663591635193919*^9, 
   3.663591782014969*^9, 3.6635919232919874`*^9, 3.663591967863017*^9, 
   3.6635925022098646`*^9, 3.6635926153262577`*^9, 3.663592833369777*^9, 
   3.6635929515293026`*^9, 3.663593044647302*^9, {3.663593113914835*^9, 
   3.6635931282652526`*^9}, 3.663593220403235*^9, 3.6635933288835382`*^9, 
   3.6635933724845476`*^9, 3.6635934547863245`*^9, 3.6635935739848194`*^9, 
   3.6635939319007015`*^9, 3.663594011902277*^9, 3.663594100126323*^9, 
   3.663594136679414*^9, 3.663594223715392*^9, 3.6635943637204*^9, 
   3.6635946349679146`*^9, 3.663594688108954*^9, 3.6635947462492795`*^9, 
   3.663594859941782*^9, 3.663594982741806*^9, 3.663928174953024*^9, 
   3.663933075026091*^9, 3.6639337019350767`*^9, 3.66393394099675*^9, 
   3.6639345032508926`*^9, 3.663935204879082*^9, 3.663935277725586*^9, 
   3.663935370438447*^9, 3.663935461629675*^9, 3.663935881024763*^9, 
   3.6639359849850245`*^9, 3.663936023323654*^9, 3.6639361103957305`*^9, 
   3.6639362290596085`*^9, 3.663936349024991*^9, 3.6639369056034193`*^9, 
   3.6639370390673804`*^9, 3.6639371109773674`*^9, 3.663937170025325*^9, 
   3.6639373007577133`*^9, 3.6639374479721966`*^9, 3.6639378444650545`*^9, 
   3.6639379034575663`*^9, 3.6639379466373854`*^9, 3.663938049151637*^9, 
   3.663938095587589*^9, 3.6639382214500113`*^9, 3.6639382901539707`*^9, 
   3.6639383379452114`*^9, 3.6639383825166545`*^9, 3.663938418796562*^9, 
   3.6639385217466354`*^9, 3.663938621797793*^9, 3.663938734657164*^9, 
   3.663938784615864*^9, 3.663938850296928*^9, 3.663939061723632*^9, 
   3.663939121882113*^9, 3.6639392077476234`*^9, 3.663939328348076*^9, 
   3.6639393603840017`*^9, 3.6639394274392424`*^9, 3.663939482834551*^9, 
   3.6639395494398184`*^9, 3.663939596342291*^9, 3.663939627559637*^9, 
   3.6639396578984685`*^9, 3.6639397263343105`*^9, 3.6639397795690455`*^9, 
   3.663939815139061*^9, 3.663939878812214*^9, 3.663939920963573*^9, 
   3.6639399740034256`*^9, 3.66394004537236*^9, 3.663940139788236*^9, 
   3.6639401974596367`*^9, 3.663940237909376*^9, 3.6639402837718334`*^9, 
   3.663940342427268*^9, 3.663940426551736*^9, 3.663940514024832*^9, {
   3.6639406125818915`*^9, 3.6639406407051105`*^9}, 3.663940711557547*^9, 
   3.6639407457585087`*^9, 3.6639407803444605`*^9, 3.6639408117982883`*^9, 
   3.6639408536495514`*^9, 3.663940909918397*^9, {3.6639409424937983`*^9, 
   3.6639409693429656`*^9}, 3.6639410054900026`*^9, 3.66394106301086*^9, 
   3.6639411125039053`*^9, 3.663941151019018*^9, 3.663941204849271*^9, 
   3.663941248516586*^9, 3.6639413157733545`*^9, 3.663941369344123*^9, 
   3.6639418241183386`*^9, 3.663941871696349*^9, {3.6639422617271185`*^9, 
   3.663942288079746*^9}, {3.6639423353764086`*^9, 3.6639423619575896`*^9}, 
   3.6639423921723223`*^9, 3.6639426266959133`*^9, 3.663942739320003*^9, 
   3.6639430160815043`*^9, 3.6639433660825176`*^9, 3.6639437348883905`*^9, 
   3.663943817283849*^9, 3.6639439647604837`*^9, 3.6639440608505397`*^9, 
   3.663944133294582*^9, 3.663944198566801*^9, 3.6639446534981885`*^9, 
   3.6639447114340925`*^9, 3.66394476583484*^9, 3.663944832862651*^9, 
   3.663944873446846*^9, 3.663945311874017*^9, 3.6639453816344337`*^9, 
   3.663945616042062*^9, 3.663945694978795*^9, 3.6639457773017254`*^9, 
   3.663994861550467*^9, 3.6639951303308496`*^9, 3.663995272584972*^9, 
   3.6639953225746*^9, 3.663995396144493*^9, 3.6639954406858253`*^9, 
   3.66399551577806*^9, {3.6639955480724945`*^9, 3.663995570284922*^9}, 
   3.663995612886856*^9, 3.6639956668998632`*^9, 3.663995719486862*^9, 
   3.6639978309250093`*^9, 3.6639978867786446`*^9, 3.663998445327569*^9, 
   3.6639986355033884`*^9, 3.663998728907248*^9, 3.664001117207658*^9, 
   3.664001304657214*^9, 3.664001392366681*^9, 3.6640015945888023`*^9, 
   3.6640016407510867`*^9, 3.664001680772029*^9, 3.6640023677029285`*^9, 
   3.664002538577778*^9, 3.664002573923973*^9, 3.6640026986215096`*^9, 
   3.6640027878197117`*^9, 3.664003349525326*^9, 3.6640043342634172`*^9, 
   3.6640044010871744`*^9, 3.6640044613931065`*^9, 3.6640045214187994`*^9, 
   3.6640056278065233`*^9, 3.6640058260309906`*^9, 3.664007529519247*^9, 
   3.664007595311241*^9, {3.6640077207068872`*^9, 3.664007747852565*^9}, 
   3.664007781110616*^9, 3.6640078125705566`*^9, 3.664007876104448*^9, {
   3.664007906144314*^9, 3.664007932621961*^9}, {3.6640079675688057`*^9, 
   3.6640079972376785`*^9}, {3.6640080407680206`*^9, 3.664008069232939*^9}, 
   3.6640083581799507`*^9, 3.6640084322982936`*^9, 3.6640084949183197`*^9, {
   3.6640085359216537`*^9, 3.6640085728253784`*^9}, 3.6640086059790936`*^9, 
   3.6640887837619762`*^9, 3.6640888867322817`*^9, 3.6640889965978985`*^9, 
   3.664089456083003*^9, 3.6640896599079237`*^9, 3.664089691266086*^9, 
   3.6640897696361217`*^9, {3.6640898344445667`*^9, 3.6640898622470284`*^9}, 
   3.6640899155553136`*^9, 3.6640900628911333`*^9, 3.6640916066799088`*^9, 
   3.6640916662289934`*^9, 3.664091708097246*^9, 3.664091771370489*^9, 
   3.664091810450487*^9, 3.6640920261473937`*^9, 3.6640921670926394`*^9, 
   3.6640924062067957`*^9, 3.664092469594091*^9, 3.6640925245300245`*^9, 
   3.664092584711136*^9, 3.6640926704375896`*^9, 3.664092723444339*^9, {
   3.6640927539589415`*^9, 3.66409277230892*^9}, 3.6640931999157734`*^9, 
   3.664093244356185*^9, 3.664093354295844*^9, 3.664093451256319*^9, 
   3.664093706421015*^9, 3.6640988598399997`*^9, 3.6640990400237293`*^9, 
   3.6640992926175203`*^9, 3.664099425599683*^9, 3.664099515708763*^9, 
   3.664099690140909*^9, 3.664099887227048*^9, 3.664100076175827*^9, 
   3.664100198860827*^9, 3.6641005750287037`*^9, 3.664100789220085*^9, 
   3.6641008365113926`*^9, 3.6641009138831377`*^9, 3.664101418149305*^9, 
   3.66410148616481*^9, 3.664101761951945*^9, 3.664101861369625*^9, 
   3.664102005543356*^9, 3.6641022526336174`*^9, 3.6641025584394636`*^9, 
   3.6641109106157827`*^9, 3.6641120884967623`*^9, 3.664176397715892*^9, 
   3.669369547504711*^9, 3.669370516962368*^9, 3.6693706322173986`*^9, 
   3.6693708523050747`*^9, 3.6693756570677004`*^9, 3.669375706771821*^9, 
   3.669375749067219*^9, 3.6693760531883216`*^9, 3.669376496134754*^9, 
   3.6693767271499414`*^9, 3.6693770686517563`*^9, 3.669377198264404*^9, 
   3.669456309532972*^9, 3.6694590616881227`*^9, 3.66945928383158*^9, 
   3.6694593884022975`*^9, 3.669459562426313*^9, 3.6694596629298773`*^9, 
   3.6694597120353737`*^9, {3.669459805897691*^9, 3.6694598579808817`*^9}, 
   3.6694644576592627`*^9, 3.6694655426173286`*^9, 3.6694655976331663`*^9, 
   3.669465826789917*^9, 3.669720113417411*^9, 3.6697204114674587`*^9, 
   3.670135060852167*^9, 3.6766309092826405`*^9, 3.6767897404089146`*^9, 
   3.6768821083539925`*^9, 3.676887713447097*^9, 3.681540836079119*^9, 
   3.6816219129722986`*^9, 3.6816397324794035`*^9, 3.6840379644715805`*^9, 
   3.6846610491338415`*^9, 3.684673432042624*^9, 3.6846735411438646`*^9, 
   3.684673678222705*^9, 3.6846737654136915`*^9, 3.6846738635003023`*^9, 
   3.7005594340656757`*^9, 3.7005595459010725`*^9, 3.7364146193971643`*^9, 
   3.736414997444787*^9, 3.736426187255808*^9, 3.73642628729453*^9, 
   3.73642645898335*^9, 3.73642653085046*^9, 3.7364269699835773`*^9, 
   3.736427721770577*^9, 3.73642777410357*^9},
 FontFamily->"Courier New",
 FontSize->10]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["2. Estimation of AR(1) process for leverage", "Section",
 CellChangeTimes->{{3.7362539717319775`*^9, 3.7362539879049025`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Estimation", " ", "of", " ", "AR", 
    RowBox[{"(", "1", ")"}], " ", "with", " ", "constant"}], "   ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"stp", "=", "1"}], ";"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Series", " ", "to", " ", "be", " ", "used", " ", "and", " ", "matrices", 
    " ", "to", " ", "store", " ", "results"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"series", "=", 
     RowBox[{"yepsilon", "[", 
      RowBox[{"[", 
       RowBox[{"1", ";;", 
        RowBox[{"Length", "[", "yepsilon", "]"}]}], " ", "]"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cL", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Length", "[", "series", "]"}], "-", "1"}], "}"}]}], "]"}]}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"vL", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Length", "[", "series", "]"}], "-", "1"}], "}"}]}], "]"}]}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lv", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"series", "[", 
          RowBox[{"[", "jj", "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"jj", ",", "1", ",", 
         RowBox[{"Length", "[", "series", "]"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"x", "=", 
     RowBox[{"Drop", "[", 
      RowBox[{"lv", ",", 
       RowBox[{"-", "1"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"y", "=", 
     RowBox[{"Drop", "[", 
      RowBox[{"series", ",", "1"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Initial", " ", 
     RowBox[{"value", ":", " ", 
      RowBox[{"OLS", " ", "estimate"}]}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"beta0", "=", 
     RowBox[{"LeastSquares", "[", 
      RowBox[{
       RowBox[{"x", "[", 
        RowBox[{"[", 
         RowBox[{"1", ";;", "2"}], "]"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"[", 
         RowBox[{"1", ";;", "2"}], "]"}], "]"}]}], " ", "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"R0", "=", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"x", "[", 
        RowBox[{"[", 
         RowBox[{"1", ";;", "2"}], "]"}], "]"}], " ", "]"}], ".", 
      RowBox[{"x", "[", 
       RowBox[{"[", 
        RowBox[{"1", ";;", "2"}], "]"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"cL", "[", 
      RowBox[{"[", "2", "]"}], "]"}], "=", "beta0"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"vL", "[", 
      RowBox[{"[", "2", "]"}], "]"}], "=", "R0"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Full", " ", "sample", " ", "OLS", " ", "estimate"}], " ", "*)"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ar1coeff", "=", 
     RowBox[{"LeastSquares", "[", 
      RowBox[{"x", ",", "y"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Exp", "[", 
     RowBox[{
      RowBox[{"ar1coeff", "[", 
       RowBox[{"[", "1", " ", "]"}], "]"}], "/", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"ar1coeff", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ")"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.7364272456113424`*^9},
 FontSize->10],

Cell[CellGroupData[{

Cell["a. Adaptive learning", "Subsection",
 CellChangeTimes->{{3.7364174206233854`*^9, 3.736417422335483*^9}, {
  3.7364174558233986`*^9, 3.736417460847686*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Adaptive", " ", "learning"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    StyleBox[
     RowBox[{"gain", "=", "0.004"}],
     FontVariations->{"Underline"->True}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gamm", "=", "gain"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"rAvar", "[", 
      RowBox[{"rAold_", ",", "xt1_"}], "]"}], ":=", 
     RowBox[{"rAold", "+", 
      RowBox[{"gamm", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Outer", "[", " ", 
          RowBox[{"Times", ",", "xt1", ",", "xt1"}], " ", "]"}], " ", "-", 
         " ", "rAold"}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"cAvar", "[", 
      RowBox[{"cAold_", ",", "rM_", ",", "yt_", ",", "xt1_"}], "]"}], ":=", 
     RowBox[{"cAold", "+", 
      RowBox[{"gamm", "*", 
       RowBox[{"(", 
        RowBox[{"yt", "-", 
         RowBox[{"cAold", ".", "xt1"}]}], ")"}], "*", 
       RowBox[{"xt1", ".", 
        RowBox[{"Inverse", "[", " ", "rM", " ", "]"}]}]}]}]}], " ", ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", "Recursion", " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"ii", "=", "3"}], ",", 
      RowBox[{"ii", "<", 
       RowBox[{"Length", "[", "series", "]"}]}], ",", 
      RowBox[{"ii", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"z", "=", 
        RowBox[{"Prepend", "[", 
         RowBox[{"x", ",", "1"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"vL", "[", 
         RowBox[{"[", "ii", "]"}], "]"}], "=", 
        RowBox[{"rAvar", "[", 
         RowBox[{
          RowBox[{"vL", "[", 
           RowBox[{"[", 
            RowBox[{"ii", "-", "1"}], "]"}], "]"}], ",", 
          RowBox[{"x", "[", 
           RowBox[{"[", "ii", "]"}], "]"}]}], " ", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"cL", "[", 
         RowBox[{"[", "ii", "]"}], "]"}], " ", "=", " ", 
        RowBox[{"cAvar", "[", 
         RowBox[{
          RowBox[{"cL", "[", 
           RowBox[{"[", 
            RowBox[{"ii", "-", "1"}], "]"}], "]"}], ",", 
          RowBox[{"vL", "[", 
           RowBox[{"[", "ii", "]"}], "]"}], ",", 
          RowBox[{"y", "[", 
           RowBox[{"[", "ii", "]"}], "]"}], ",", 
          RowBox[{"x", "[", 
           RowBox[{"[", "ii", "]"}], "]"}]}], " ", "]"}]}], ";"}]}], 
     "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"meanPhi", "=", 
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"cL", "[", 
        RowBox[{"[", 
         RowBox[{
          RowBox[{"1", ";;", 
           RowBox[{"Length", "[", "cL", "]"}]}], ",", "1"}], " ", "]"}], 
        "]"}], "/", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"cL", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"1", ";;", 
             RowBox[{"Length", "[", "cL", "]"}]}], ",", "2"}], "]"}], "]"}]}],
         ")"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Storing", " ", "results"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cLCG", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Length", "[", "series", "]"}], "-", "1"}], "}"}]}], "]"}]}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"constCG", "=", 
     RowBox[{"cL", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "1"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rhoCG", "=", 
     RowBox[{"cL", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cLCG", "=", 
     RowBox[{"cL", "[", 
      RowBox[{"[", "All", "]"}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.571988657331338*^9, 3.571988691128271*^9}, 
   3.571988856631737*^9, {3.5719888876955137`*^9, 3.5719889552763796`*^9}, {
   3.571989738572181*^9, 3.571989748658758*^9}, {3.571990003667344*^9, 
   3.5719900408664713`*^9}, {3.5719901170118265`*^9, 3.571990208255046*^9}, {
   3.571990254818709*^9, 3.571990314423118*^9}, {3.5719903522252803`*^9, 
   3.5719903799778676`*^9}, {3.571990429118678*^9, 3.571990449849864*^9}, {
   3.571990633336359*^9, 3.5719906559006495`*^9}, {3.5719908987625403`*^9, 
   3.571990917176594*^9}, {3.57199097463188*^9, 3.571991134420019*^9}, {
   3.571996890463029*^9, 3.5719968905210323`*^9}, {3.571996975413888*^9, 
   3.5719970221955643`*^9}, 3.5719970687182245`*^9, {3.571997453361225*^9, 
   3.571997469375141*^9}, {3.5719975023180256`*^9, 3.5719975039281178`*^9}, {
   3.571997620833804*^9, 3.5719976255420732`*^9}, {3.571997879080575*^9, 
   3.5719979063711357`*^9}, 3.5719979488515654`*^9, {3.5720032621424685`*^9, 
   3.5720032742301598`*^9}, {3.572003370843686*^9, 3.5720034046646204`*^9}, {
   3.572003479609907*^9, 3.57200348105799*^9}, {3.5720037878675385`*^9, 
   3.5720038565314655`*^9}, {3.572003893246566*^9, 3.572004038484873*^9}, {
   3.5720041269129305`*^9, 3.57200413057514*^9}, {3.5720041959758806`*^9, 
   3.5720042686440372`*^9}, {3.572004336122897*^9, 3.5720043410881805`*^9}, {
   3.572004398755479*^9, 3.5720045004142933`*^9}, {3.572004576133624*^9, 
   3.5720046764673634`*^9}, 3.572004779297245*^9, {3.5720048714985185`*^9, 
   3.5720048797969933`*^9}, {3.5720049547012773`*^9, 
   3.5720049553603153`*^9}, {3.572005282413021*^9, 3.5720053127777576`*^9}, {
   3.572005975209647*^9, 3.5720059769577475`*^9}, {3.5720060101986485`*^9, 
   3.572006035496095*^9}, {3.5720060915663023`*^9, 3.5720061131975393`*^9}, {
   3.5720061596731977`*^9, 3.572006160198228*^9}, {3.5720061908099785`*^9, 
   3.5720062064538736`*^9}, {3.5720063307609835`*^9, 3.57200637668661*^9}, 
   3.572006967428399*^9, {3.5720070217085037`*^9, 3.5720070227635636`*^9}, 
   3.5720072586840577`*^9, {3.572007330638173*^9, 3.572007430952911*^9}, {
   3.5720081671120167`*^9, 3.5720081671780205`*^9}, {3.57200861876685*^9, 
   3.5720086791443033`*^9}, {3.572008727845089*^9, 3.572008799958214*^9}, 
   3.572766537770922*^9, {3.5727666144369087`*^9, 3.5727666412161016`*^9}, {
   3.5727669382787275`*^9, 3.572766950199992*^9}, {3.57276703799292*^9, 
   3.5727670415396357`*^9}, {3.5727670736175857`*^9, 
   3.5727670822120504`*^9}, {3.572767122074742*^9, 3.5727671359040174`*^9}, {
   3.5728636481930485`*^9, 3.5728636753848486`*^9}, {3.5728644357084484`*^9, 
   3.572864438812848*^9}, {3.5728659052802486`*^9, 3.5728659176666484`*^9}, {
   3.5728660144178486`*^9, 3.5728660297526484`*^9}, {3.5728666890252485`*^9, 
   3.5728666902576485`*^9}, {3.572866731847248*^9, 3.5728667331108484`*^9}, {
   3.5728669452084484`*^9, 3.5728669737252483`*^9}, {3.5729296979840913`*^9, 
   3.5729296997312913`*^9}, {3.5729298833462915`*^9, 
   3.5729298841418915`*^9}, {3.5729305407998915`*^9, 
   3.5729305418138914`*^9}, {3.5729306028722916`*^9, 
   3.5729306034026914`*^9}, {3.572959285313759*^9, 3.5729593540875254`*^9}, {
   3.5729594424841566`*^9, 3.572959496962604*^9}, 3.572959565595761*^9, 
   3.5729597798380737`*^9, {3.572959816240363*^9, 3.5729598176152134`*^9}, {
   3.5729602455530233`*^9, 3.572960249286992*^9}, 3.57296033312162*^9, {
   3.5729615988744*^9, 3.5729615994203997`*^9}, {3.5729617233*^9, 
   3.5729617236744003`*^9}, {3.5729618161512003`*^9, 3.5729618190216*^9}, {
   3.572961889908*^9, 3.5729618911092*^9}, {3.573042776234375*^9, 
   3.5730427831875*^9}, {3.57304363815625*^9, 3.573043638203125*^9}, {
   3.57304376084375*^9, 3.5730437649375*^9}, {3.57304385321875*^9, 
   3.57304387490625*^9}, {3.57304422540625*^9, 3.573044227609375*^9}, {
   3.57304437546875*^9, 3.573044377640625*^9}, {3.5730447484375*^9, 
   3.573044750078125*^9}, {3.573046035578125*^9, 3.573046038453125*^9}, {
   3.573046147703125*^9, 3.573046148234375*^9}, {3.573046744125*^9, 
   3.57304674415625*^9}, {3.573047184203125*^9, 3.573047184375*^9}, {
   3.573047360125*^9, 3.573047360203125*^9}, {3.573047651734375*^9, 
   3.573047652453125*^9}, {3.57304780040625*^9, 3.57304780096875*^9}, {
   3.573048184859375*^9, 3.573048185890625*^9}, {3.573048721875*^9, 
   3.57304872278125*^9}, 3.573048867625*^9, {3.573049704734375*^9, 
   3.573049705953125*^9}, 3.573055383578125*^9, {3.573056949734375*^9, 
   3.573056951015625*^9}, {3.573057346890625*^9, 3.5730573469375*^9}, {
   3.573057404046875*^9, 3.57305740540625*^9}, {3.573057551171875*^9, 
   3.5730575616875*^9}, {3.57305882528125*^9, 3.573058825359375*^9}, {
   3.573058916734375*^9, 3.573058918484375*^9}, {3.573059019375*^9, 
   3.57305902046875*^9}, {3.5730591258125*^9, 3.573059127203125*^9}, {
   3.573059234890625*^9, 3.57305923675*^9}, {3.573060843234375*^9, 
   3.57306084415625*^9}, {3.57306091953125*^9, 3.57306092215625*^9}, {
   3.57306212078125*^9, 3.573062121078125*^9}, {3.5730621949375*^9, 
   3.57306219590625*^9}, {3.57306228971875*^9, 3.5730622901875*^9}, {
   3.57306252465625*^9, 3.573062525171875*^9}, 3.573062851328125*^9, {
   3.573063417453125*^9, 3.5730634175625*^9}, {3.573063922640625*^9, 
   3.57306392275*^9}, {3.573064001234375*^9, 3.57306400325*^9}, {
   3.573064112640625*^9, 3.573064112875*^9}, 3.573064196078125*^9, {
   3.573064270578125*^9, 3.57306427071875*^9}, {3.573064342453125*^9, 
   3.573064345328125*^9}, {3.573064443328125*^9, 3.57306444459375*^9}, {
   3.573064519421875*^9, 3.573064523015625*^9}, 3.573064626796875*^9, {
   3.573064701078125*^9, 3.5730647015625*^9}, {3.573064779828125*^9, 
   3.5730647811875*^9}, 3.573064866171875*^9, {3.5730649419375*^9, 
   3.57306494334375*^9}, {3.5730650235*^9, 3.573065023859375*^9}, {
   3.57306510709375*^9, 3.57306510859375*^9}, {3.57306707134375*^9, 
   3.5730670730625*^9}, {3.5730671775*^9, 3.573067177578125*^9}, {
   3.573067264953125*^9, 3.57306726771875*^9}, {3.57310554678125*^9, 
   3.573105548046875*^9}, 3.573105927640625*^9, {3.57310621434375*^9, 
   3.573106214828125*^9}, {3.573107055921875*^9, 3.573107057*^9}, {
   3.57310833525*^9, 3.573108337515625*^9}, {3.573108675234375*^9, 
   3.573108676390625*^9}, {3.573109392953125*^9, 3.573109394390625*^9}, {
   3.57310949990625*^9, 3.5731095005625*^9}, {3.573198910315511*^9, 
   3.573198911563511*^9}, {3.573198992206311*^9, 3.5731989931579113`*^9}, {
   3.5731990644031115`*^9, 3.573199067476311*^9}, {3.573199138894111*^9, 
   3.5731991398301115`*^9}, {3.573199289839711*^9, 3.573199290276511*^9}, {
   3.573199372676711*^9, 3.573199373253911*^9}, {3.573206795392911*^9, 
   3.5732067974521112`*^9}, {3.5732070780857115`*^9, 
   3.5732070792713113`*^9}, {3.573223630625*^9, 3.573223748203125*^9}, {
   3.57322384728125*^9, 3.5732238839375*^9}, {3.5732239739375*^9, 
   3.5732239744375*^9}, {3.573224157484375*^9, 3.573224158796875*^9}, {
   3.573224419015625*^9, 3.57322441940625*^9}, {3.573224501046875*^9, 
   3.5732245023125*^9}, {3.57322703621875*^9, 3.573227063515625*^9}, {
   3.573227180859375*^9, 3.573227182875*^9}, {3.5732272666875*^9, 
   3.573227267375*^9}, {3.573227612046875*^9, 3.5732276135625*^9}, {
   3.57322769365625*^9, 3.5732276949375*^9}, 3.57322779121875*^9, {
   3.5732324478125*^9, 3.573232452515625*^9}, {3.573232513234375*^9, 
   3.5732325253125*^9}, {3.573295187671875*^9, 3.57329519090625*^9}, {
   3.573295288453125*^9, 3.573295289390625*^9}, {3.573295336484375*^9, 
   3.57329535196875*^9}, {3.573295387515625*^9, 3.573295390109375*^9}, 
   3.573295480109375*^9, {3.573295573671875*^9, 3.5732955741875*^9}, {
   3.573295762546875*^9, 3.573295764078125*^9}, {3.57329598659375*^9, 
   3.57329598665625*^9}, {3.57329639359375*^9, 3.573296393640625*^9}, {
   3.573538116716642*^9, 3.573538118058242*^9}, {3.573538198320242*^9, 
   3.573538199053442*^9}, {3.573538378720642*^9, 3.5735383796410418`*^9}, {
   3.573538464395842*^9, 3.573538491820642*^9}, {3.5735390209696417`*^9, 
   3.573539021437642*^9}, {3.573539076084442*^9, 3.573539077706842*^9}, {
   3.5735391657376423`*^9, 3.573539166533242*^9}, {3.573539420662242*^9, 
   3.5735394214422417`*^9}, {3.573539632016642*^9, 3.5735396329682417`*^9}, {
   3.573539828047242*^9, 3.573539828499642*^9}, {3.573539911415642*^9, 
   3.573539912460842*^9}, {3.573540116946642*^9, 3.5735401174146423`*^9}, {
   3.573540257911242*^9, 3.573540288736842*^9}, 3.573540328891242*^9, {
   3.573540536215242*^9, 3.5735405373228416`*^9}, {3.573540583203442*^9, 
   3.5735405837182417`*^9}, {3.573540717722042*^9, 3.573540724960442*^9}, {
   3.573540785488442*^9, 3.573540789419642*^9}, {3.5735412903200417`*^9, 
   3.5735412906632423`*^9}, {3.5735421493516417`*^9, 3.573542177354642*^9}, {
   3.5735422691712418`*^9, 3.573542269561242*^9}, {3.573542347125442*^9, 
   3.573542347889842*^9}, {3.5735424109918423`*^9, 3.5735424114286423`*^9}, {
   3.573542463083242*^9, 3.573542463598042*^9}, {3.5735436431620417`*^9, 
   3.573543643552042*^9}, {3.573543678687242*^9, 3.573543679514042*^9}, {
   3.5735438459504423`*^9, 3.573543846356042*^9}, {3.573543914247242*^9, 
   3.5735439148088417`*^9}, {3.573544007748042*^9, 3.573544008231642*^9}, {
   3.573544092034842*^9, 3.5735440924560423`*^9}, 3.5735442819240417`*^9, {
   3.573544462629842*^9, 3.573544464423842*^9}, {3.573544546980042*^9, 
   3.573544548914442*^9}, {3.573544632703042*^9, 3.573544633108642*^9}, 
   3.573544798578842*^9, {3.573545012658642*^9, 3.573545014827042*^9}, {
   3.573545635273242*^9, 3.573545636521242*^9}, {3.5735456855988417`*^9, 
   3.573545686020042*^9}, {3.573545932135042*^9, 3.573545934365842*^9}, {
   3.573546133095242*^9, 3.573546133500842*^9}, {3.573553056999042*^9, 
   3.573553057498242*^9}, {3.5735533896302423`*^9, 3.573553390051442*^9}, {
   3.5735534236070423`*^9, 3.573553424761442*^9}, {3.573553463277842*^9, 
   3.573553490702642*^9}, 3.573553528658442*^9, {3.573553703612442*^9, 
   3.573553704688842*^9}, {3.5735537472924423`*^9, 3.573553747713642*^9}, {
   3.573553804934442*^9, 3.573553805449242*^9}, 3.573553843701442*^9, 
   3.573553963538642*^9, {3.5735551626604424`*^9, 3.573555163144042*^9}, {
   3.573555195281042*^9, 3.573555195749042*^9}, 3.5735552289146423`*^9, {
   3.5735552617994423`*^9, 3.573555320502242*^9}, {3.573555621692442*^9, 
   3.573555622129242*^9}, {3.5735556613320417`*^9, 3.5735556628296423`*^9}, {
   3.573555734309442*^9, 3.573555735058242*^9}, 3.573737226796875*^9, 
   3.573737276765625*^9, {3.57373737540625*^9, 3.57373737553125*^9}, {
   3.5737374821875*^9, 3.573737483625*^9}, {3.5737382245625*^9, 
   3.573738225*^9}, {3.573738484015625*^9, 3.57373848578125*^9}, {
   3.573738529046875*^9, 3.573738529703125*^9}, {3.5737386641875*^9, 
   3.573738664734375*^9}, {3.573738802046875*^9, 3.5737388025625*^9}, 
   3.573738851390625*^9, {3.57373891575*^9, 3.5737389158125*^9}, {
   3.5737389905*^9, 3.57373899103125*^9}, {3.573739032875*^9, 
   3.573736922703125*^9}, {3.57373707853125*^9, 3.573737078671875*^9}, {
   3.5738958758526525`*^9, 3.5738958768666525`*^9}, {3.573895930234253*^9, 
   3.5738959306242523`*^9}, {3.5738959743540525`*^9, 
   3.5738959759140525`*^9}, {3.5738962706720524`*^9, 
   3.5738962719044523`*^9}, {3.5739591799542403`*^9, 
   3.5739592264266405`*^9}, {3.5739592726338406`*^9, 
   3.5739592734918404`*^9}, {3.5787174218865967`*^9, 
   3.5787174290157967`*^9}, {3.5787470818513966`*^9, 3.578747127434597*^9}, {
   3.578747302138997*^9, 3.5787473180821967`*^9}, {3.578747435753997*^9, 
   3.5787474365339966`*^9}, {3.578748003829997*^9, 3.578748005015597*^9}, {
   3.5787480462775965`*^9, 3.578748050255597*^9}, {3.578748093344797*^9, 
   3.578748096386797*^9}, {3.5788218967291975`*^9, 3.5788219132651978`*^9}, {
   3.5788219798781977`*^9, 3.5788220265845976`*^9}, {3.5788220691101975`*^9, 
   3.5788220974397974`*^9}, {3.5788222780409975`*^9, 
   3.5788223113001976`*^9}, {3.5788224215765977`*^9, 3.578822427083398*^9}, {
   3.5788224607637978`*^9, 3.578822611859398*^9}, {3.5788232499929976`*^9, 
   3.5788232503205976`*^9}, {3.5788232995853977`*^9, 
   3.5788233002717977`*^9}, {3.578823336994198*^9, 3.5788233380237975`*^9}, {
   3.5788233865569973`*^9, 3.5788233871965976`*^9}, {3.5788234497233973`*^9, 
   3.5788234504721975`*^9}, {3.578906705241407*^9, 3.578906733820607*^9}, {
   3.5789077010246067`*^9, 3.578907704581407*^9}, {3.578907737544207*^9, 
   3.578907738636207*^9}, {3.5789078495990067`*^9, 3.578907853857807*^9}, {
   3.5789080994340067`*^9, 3.5789080996524067`*^9}, {3.5789081538010073`*^9, 
   3.578908158231407*^9}, {3.578908220350607*^9, 3.578908220943407*^9}, 
   3.578908269959607*^9, {3.578908562054007*^9, 3.578908604345607*^9}, {
   3.5789188004228067`*^9, 3.578918843323807*^9}, {3.5789189468298073`*^9, 
   3.578918951275807*^9}, {3.5789189878266068`*^9, 3.578918988372607*^9}, {
   3.5789190597582073`*^9, 3.578919060163807*^9}, {3.578919096217407*^9, 
   3.578919096779007*^9}, {3.578919145685007*^9, 3.578919163859007*^9}, {
   3.578919202765407*^9, 3.578919203966607*^9}, {3.578919252451407*^9, 
   3.5789192533874073`*^9}, {3.578919316442607*^9, 3.578919316879407*^9}, {
   3.578988605282399*^9, 3.5789886074975996`*^9}, {3.5789886526283994`*^9, 
   3.5789886532367992`*^9}, {3.5789886972599993`*^9, 3.578988714778799*^9}, {
   3.5789887469771996`*^9, 3.5789887475387993`*^9}, {3.5789887931687994`*^9, 
   3.5789887992371993`*^9}, 3.5789888396723995`*^9, {3.5790001700947995`*^9, 
   3.5790001713271995`*^9}, {3.5790002647399993`*^9, 
   3.5790002652391996`*^9}, {3.5790003128503995`*^9, 
   3.5790003136147995`*^9}, {3.5790003652673993`*^9, 
   3.5790003657509995`*^9}, {3.5868620179848003`*^9, 3.5868620233356*^9}, {
   3.5868620819292*^9, 3.5868620829432*^9}, {3.5868621590868*^9, 
   3.5868621644688*^9}, {3.5868633843696003`*^9, 3.5868633865848*^9}, {
   3.5868636334955997`*^9, 3.586863634572*^9}, {3.5868636895151997`*^9, 
   3.5868637136328*^9}, 3.586863881999*^9, {3.586863927083*^9, 
   3.5868639276914*^9}, {3.5868639730562*^9, 3.5868639741638002`*^9}, 
   3.586864017252*^9, {3.5868640556532*^9, 3.5868640561836*^9}, {
   3.586864311696*^9, 3.5868643121328*^9}, {3.5868643524316*^9, 
   3.586864352962*^9}, 3.5868644054560003`*^9, {3.5868644589796*^9, 
   3.586864460212*^9}, {3.5868645086188*^9, 3.5868645160288*^9}, {
   3.5868645549976*^9, 3.5868645555436*^9}, 3.5868647263264*^9, {
   3.5868647832352*^9, 3.5868647842492*^9}, {3.5868649085188*^9, 
   3.5868649097044*^9}, 3.5868649661236*^9, {3.5868650383048*^9, 
   3.5868650392408*^9}, {3.5868653024918003`*^9, 3.5868653096678*^9}, {
   3.5868653582924*^9, 3.5868653590109997`*^9}, {3.5868654038952*^9, 
   3.5868654042384*^9}, {3.5868656466652*^9, 3.5868656468368*^9}, {
   3.5868657061792*^9, 3.5868657064288*^9}, {3.5868657684426003`*^9, 
   3.586865769675*^9}, {3.5868658025442*^9, 3.5868658157574*^9}, {
   3.5868658729938*^9, 3.5868658737581997`*^9}, {3.5868662403426*^9, 
   3.5868662440554*^9}, {3.5868664999266*^9, 3.5868665099262*^9}, {
   3.5868666299994*^9, 3.5868666305922003`*^9}, 3.5868666717771997`*^9, 
   3.5868667422111998`*^9, {3.5908974373637877`*^9, 3.5908974483461876`*^9}, {
   3.5908979448363876`*^9, 3.590897948861188*^9}, 3.5908981902555876`*^9, 
   3.590898231673588*^9, {3.590898341294788*^9, 3.5908983418095875`*^9}, {
   3.590898781881188*^9, 3.5908987826923876`*^9}, 3.590899058314188*^9, 
   3.5908990943033876`*^9, 3.590899146235788*^9, {3.590899212566988*^9, 
   3.590899214095788*^9}, {3.590899249741788*^9, 3.5908992514733877`*^9}, {
   3.5908993072679877`*^9, 3.590899309420788*^9}, 3.5908995261359878`*^9, 
   3.590899559363988*^9, {3.5908996296263876`*^9, 3.590899630172388*^9}, {
   3.5908997672203875`*^9, 3.5908997678599877`*^9}, {3.590899993170788*^9, 
   3.5908999935919876`*^9}, {3.590900080577588*^9, 3.5909000815603876`*^9}, {
   3.590900139826388*^9, 3.5909001406531878`*^9}, {3.590900181478388*^9, 
   3.5909001829603877`*^9}, {3.590900247778388*^9, 3.590900249166788*^9}, {
   3.5909003003981876`*^9, 3.590900304220188*^9}, {3.590900342268588*^9, 
   3.590900342908188*^9}, {3.5909003900357876`*^9, 3.590900390597388*^9}, {
   3.5909004248237877`*^9, 3.5909004258065877`*^9}, {3.590900469751788*^9, 
   3.5909004702197876`*^9}, 3.5909005029807878`*^9, 3.590900536676788*^9, {
   3.590900576004388*^9, 3.590900576815588*^9}, {3.5909006199807878`*^9, 
   3.5909006204175878`*^9}, {3.590900660571988*^9, 3.5909006619915876`*^9}, 
   3.5909007025827875`*^9, {3.5909007338763876`*^9, 3.590900734344388*^9}, {
   3.590900764766388*^9, 3.590900765593188*^9}, {3.5909008045463877`*^9, 
   3.590900805903588*^9}, {3.590900839491388*^9, 3.590900840037388*^9}, {
   3.5909008792089877`*^9, 3.590900880644188*^9}, {3.5909009277405877`*^9, 
   3.590900929347388*^9}, {3.590900987609388*^9, 3.5909009895905876`*^9}, {
   3.5909010243785877`*^9, 3.590901026000988*^9}, 3.5909010580277877`*^9, {
   3.590901094328988*^9, 3.5909010956081877`*^9}, {3.5909011262475877`*^9, 
   3.590901127355188*^9}, 3.5909012150593877`*^9, {3.5909012521249876`*^9, 
   3.5909012526241875`*^9}, {3.590901284853788*^9, 3.590901285352988*^9}, {
   3.5909013228875875`*^9, 3.590901345975588*^9}, {3.590901424150788*^9, 
   3.5909014264907875`*^9}, {3.590901467955588*^9, 3.590901469094388*^9}, {
   3.590901514724388*^9, 3.590901517469988*^9}, {3.5909015737703876`*^9, 
   3.5909015770307875`*^9}, 3.590901615406788*^9, {3.5909016706787877`*^9, 
   3.590901671692788*^9}, {3.590901713219988*^9, 3.5909017142651877`*^9}, {
   3.590901765823188*^9, 3.590901767663988*^9}, {3.5909018102363877`*^9, 
   3.5909018125295877`*^9}, {3.590901852715188*^9, 3.5909018537135878`*^9}, {
   3.590901895427988*^9, 3.590901895958388*^9}, 3.5909019566901875`*^9, {
   3.590902036810188*^9, 3.5909020377773876`*^9}, {3.5909020727077875`*^9, 
   3.5909020730821877`*^9}, {3.590902149428588*^9, 3.590902152267788*^9}, {
   3.590902348094588*^9, 3.5909023507465878`*^9}, {3.5909023835221877`*^9, 
   3.590902384146188*^9}, {3.5909024570625877`*^9, 3.5909024578425875`*^9}, {
   3.590902512161788*^9, 3.590902512957388*^9}, {3.5909026988313875`*^9, 
   3.590902699361788*^9}, {3.5909027304045877`*^9, 3.590902730919388*^9}, 
   3.5909027680785875`*^9, {3.590902878791788*^9, 3.590902891287388*^9}, {
   3.5909029222689877`*^9, 3.590902922736988*^9}, 3.5909029551537876`*^9, {
   3.590903016180988*^9, 3.590903016664588*^9}, {3.5909031117751875`*^9, 
   3.5909031140839877`*^9}, {3.590903191350788*^9, 3.590903191849988*^9}, {
   3.590903225530388*^9, 3.590903225982788*^9}, {3.590903344168388*^9, 
   3.590903344417988*^9}, 3.590903472352388*^9, {3.5909035090933876`*^9, 
   3.5909035103483877`*^9}, {3.590903550787388*^9, 3.5909035515623875`*^9}, {
   3.5909035854873877`*^9, 3.5909035859893875`*^9}, {3.590903634938388*^9, 
   3.5909036353683877`*^9}, {3.590903687452388*^9, 3.5909036879703875`*^9}, {
   3.590903732540388*^9, 3.590903735717388*^9}, {3.590904036097388*^9, 
   3.590904066971388*^9}, {3.590904169944388*^9, 3.590904174441388*^9}, {
   3.590904264175388*^9, 3.590904268030388*^9}, {3.5909043126613874`*^9, 
   3.5909043165413876`*^9}, {3.590904369898388*^9, 3.590904375754388*^9}, {
   3.5909044721523876`*^9, 3.5909044844993877`*^9}, {3.590904590353388*^9, 
   3.590904654000388*^9}, {3.590904813261388*^9, 3.5909048192493877`*^9}, {
   3.590905622717388*^9, 3.5909056248943877`*^9}, {3.5909059936593876`*^9, 
   3.590905994160388*^9}, 3.590906025544388*^9, 3.590913279325388*^9, {
   3.5909134749143877`*^9, 3.590913475349388*^9}, 3.5909135086043878`*^9, 
   3.5909135446383877`*^9, {3.590913607981388*^9, 3.590913608425388*^9}, {
   3.5909136491443877`*^9, 3.5909136502363877`*^9}, {3.590913730096388*^9, 
   3.590913731922388*^9}, {3.5909137787493877`*^9, 3.590913779967388*^9}, {
   3.590913832632388*^9, 3.590913836425388*^9}, {3.590914228123388*^9, 
   3.590914229465388*^9}, {3.5909142669613876`*^9, 3.5909142679073877`*^9}, 
   3.590914299568388*^9, {3.5909143440953875`*^9, 3.5909143445593877`*^9}, {
   3.590914388833388*^9, 3.590914389056388*^9}, {3.590914780167388*^9, 
   3.5909147816263876`*^9}, {3.5909149337463875`*^9, 3.5909149338413877`*^9},
    {3.5909150529943876`*^9, 3.590915054778388*^9}, {3.590915089811388*^9, 
   3.5909150904563875`*^9}, {3.5909151426593876`*^9, 3.590915142707388*^9}, 
   3.5909153906263876`*^9, {3.5909154586043878`*^9, 3.590915459125388*^9}, 
   3.590915615991388*^9, {3.590915658693388*^9, 3.5909156591593876`*^9}, {
   3.590915845898388*^9, 3.590915846316388*^9}, {3.590915895129388*^9, 
   3.5909158962183876`*^9}, 3.590916126219388*^9, {3.590916170200388*^9, 
   3.590916170646388*^9}, {3.5909163621053877`*^9, 3.5909163632323875`*^9}, 
   3.590916403886388*^9, {3.5909164438483877`*^9, 3.590916444538388*^9}, {
   3.590916499347388*^9, 3.5909165049793878`*^9}, {3.5909165687533875`*^9, 
   3.590916569268388*^9}, {3.5909166158483877`*^9, 3.590916616226388*^9}, {
   3.5909167405953875`*^9, 3.590916741043388*^9}, 3.590916809372388*^9, 
   3.590916842804388*^9, 3.5909801729021606`*^9, {3.590980431606961*^9, 
   3.590980432371361*^9}, {3.5909805650523605`*^9, 3.590980565801161*^9}, {
   3.590980613382161*^9, 3.590980615269761*^9}, 3.590980675143561*^9, 
   3.590980988369961*^9, {3.5909810408951607`*^9, 3.590981043703161*^9}, {
   3.590981105759961*^9, 3.5909811357285604`*^9}, {3.590981638768161*^9, 
   3.5909816437445607`*^9}, {3.5909816907473607`*^9, 3.590981691698961*^9}, {
   3.5909817286251607`*^9, 3.590981732244361*^9}, {3.5909818977981606`*^9, 
   3.590981898344161*^9}, {3.5909820226605606`*^9, 3.5909820235965605`*^9}, 
   3.5909821248249607`*^9, {3.5909821828881607`*^9, 3.590982182966161*^9}, {
   3.590982242573761*^9, 3.590982243166561*^9}, {3.590982290590561*^9, 
   3.5909823136941605`*^9}, {3.5909826952143607`*^9, 3.590982710627161*^9}, {
   3.5909827877223606`*^9, 3.5909827884243608`*^9}, {3.5909828297019606`*^9, 
   3.5909828497791605`*^9}, {3.590982936235361*^9, 3.5909829450649605`*^9}, {
   3.590984640380561*^9, 3.5909846421745605`*^9}, {3.590985064071561*^9, 
   3.5909850652103605`*^9}, {3.5909851966247606`*^9, 
   3.5909851995419607`*^9}, {3.590985246373161*^9, 3.5909852473091607`*^9}, 
   3.5909852999083605`*^9, {3.5909853824947605`*^9, 3.590985383025161*^9}, 
   3.590985444334161*^9, 3.5909855124905605`*^9, {3.590985701422161*^9, 
   3.590985703169361*^9}, {3.590985737598561*^9, 3.5909857383473606`*^9}, 
   3.5909857887821608`*^9, {3.590985824771361*^9, 3.590985825426561*^9}, {
   3.590986191979761*^9, 3.590986194163761*^9}, {3.5909862630221605`*^9, 
   3.590986264394961*^9}, 3.5909863158437605`*^9, {3.590986368134961*^9, 
   3.5909863685249605`*^9}, {3.590986426322961*^9, 3.590986426775361*^9}, {
   3.5909865875031605`*^9, 3.5909865880335608`*^9}, {3.590986690275961*^9, 
   3.590986690634761*^9}, {3.590986736077561*^9, 3.590986736514361*^9}, 
   3.5909867749527607`*^9, {3.590986817852761*^9, 3.590986820442361*^9}, {
   3.590986856136161*^9, 3.5909868639673605`*^9}, {3.590986912327361*^9, 
   3.5909869189885607`*^9}, {3.5909869946641607`*^9, 3.590987000560961*^9}, {
   3.590987069575361*^9, 3.5909870881549606`*^9}, 3.590987339690361*^9, {
   3.5909874354743605`*^9, 3.590987439280761*^9}, {3.5909874870479608`*^9, 
   3.590987493787161*^9}, {3.590988203191961*^9, 3.590988203847161*^9}, {
   3.590988321041361*^9, 3.5909883259709606`*^9}, {3.590988513172361*^9, 
   3.5909885149351606`*^9}, {3.5909886475677605`*^9, 3.5909886518733606`*^9}, 
   3.590989101249961*^9, {3.5909891639931607`*^9, 3.590989164585961*^9}, {
   3.590989214256361*^9, 3.5909892147399607`*^9}, {3.590989277576761*^9, 
   3.590989279043161*^9}, {3.5909893535019608`*^9, 3.590989354671961*^9}, {
   3.5909894361507607`*^9, 3.5909894365719604`*^9}, {3.5909894827167606`*^9, 
   3.590989483309561*^9}, {3.590989645394561*^9, 3.5909896460029607`*^9}, {
   3.590990457710761*^9, 3.590990459021161*^9}, {3.590990565693961*^9, 
   3.590990566037161*^9}, {3.590990637157561*^9, 3.590990647703161*^9}, {
   3.5909908416111608`*^9, 3.5909908421883607`*^9}, {3.5909911092447605`*^9, 
   3.5909911096815605`*^9}, {3.590991149102761*^9, 3.590991149617561*^9}, {
   3.5909911825335608`*^9, 3.5909911825959606`*^9}, {3.590991226712761*^9, 
   3.590991227165161*^9}, {3.590991262735161*^9, 3.5909912629847608`*^9}, {
   3.590991297694761*^9, 3.590991298115961*^9}, {3.5915306142333856`*^9, 
   3.591530616898155*^9}, {3.5915314300962267`*^9, 3.5915314303203797`*^9}, {
   3.5915314953996687`*^9, 3.5915314957729163`*^9}, {3.591531699018893*^9, 
   3.591531700096608*^9}, {3.591531756158839*^9, 3.591531756965375*^9}, {
   3.591531857601718*^9, 3.591531857844879*^9}, {3.591531932180468*^9, 
   3.591531934085515*^9}, {3.5915320074872603`*^9, 3.591532009787789*^9}, {
   3.5915321945504913`*^9, 3.591532194840684*^9}, {3.5915322577434525`*^9, 
   3.591532258972274*^9}, {3.5915323435434327`*^9, 3.5915323440307584`*^9}, {
   3.591532423979851*^9, 3.5915324245662403`*^9}, {3.591532495213157*^9, 
   3.5915324956644616`*^9}, {3.5915325435072303`*^9, 
   3.5915325444668665`*^9}, {3.5915376646210327`*^9, 3.591537666502277*^9}, {
   3.591537876248575*^9, 3.5915378776254897`*^9}, {3.591537926931234*^9, 
   3.59153792700128*^9}, {3.591538407877631*^9, 3.5915384096468067`*^9}, 
   3.5915435821255636`*^9, 3.591543663288216*^9, {3.5915436974750366`*^9, 
   3.591543697974368*^9}, {3.59154423374856*^9, 3.5915442425173826`*^9}, {
   3.591544312842279*^9, 3.591544320428317*^9}, {3.591544547886096*^9, 
   3.5915445485275216`*^9}, 3.5915446018953533`*^9, {3.591544648599514*^9, 
   3.5915446492709603`*^9}, {3.5919510867909775`*^9, 3.591951087712841*^9}, 
   3.5919511561807146`*^9, 3.5919511911802664`*^9, 3.5919513106441593`*^9, 
   3.5919517496129932`*^9, {3.593347396506161*^9, 3.5933473968025613`*^9}, {
   3.5933475187955613`*^9, 3.593347519247961*^9}, {3.5933478195635614`*^9, 
   3.5933478250079613`*^9}, {3.593347876129161*^9, 3.5933478795143614`*^9}, {
   3.5933484356703615`*^9, 3.5933484361227612`*^9}, {3.5934129818185434`*^9, 
   3.5934129862489433`*^9}, {3.593413029585743*^9, 3.593413055434943*^9}, {
   3.593413094872743*^9, 3.593413095418743*^9}, {3.593413127820943*^9, 
   3.593413128320143*^9}, {3.5934131858529434`*^9, 3.593413186773343*^9}, {
   3.593414183700743*^9, 3.593414185619543*^9}, {3.593414216538743*^9, 
   3.593414274180743*^9}, {3.5934143617903433`*^9, 3.593414364255143*^9}, {
   3.5934147789913435`*^9, 3.593414798085743*^9}, {3.593414834776943*^9, 
   3.5934148363837433`*^9}, {3.593415084928943*^9, 3.5934150876277432`*^9}, {
   3.593415157283743*^9, 3.593415160247743*^9}, {3.593415512390543*^9, 
   3.593415512827343*^9}, {3.5934155630749435`*^9, 3.5934155635741434`*^9}, {
   3.593415680121743*^9, 3.5934156805273433`*^9}, {3.593415720526743*^9, 
   3.593415721322343*^9}, 3.59342616014506*^9, {3.593499459223239*^9, 
   3.593499488223054*^9}, 3.5934995963942366`*^9, 3.5934997538971596`*^9, {
   3.5935003562484837`*^9, 3.593500389185773*^9}, 3.5935011392004375`*^9, 
   3.5935012260592566`*^9, {3.593501687212555*^9, 3.59350171421303*^9}, 
   3.5935017629023995`*^9, {3.5935019247367387`*^9, 3.5935019249867487`*^9}, {
   3.5935031841717396`*^9, 3.5935032057504168`*^9}, {3.593504943220785*^9, 
   3.593504967796708*^9}, 3.593505002934184*^9, 3.5935052472340317`*^9, {
   3.594316271056117*^9, 3.5943162718016195`*^9}, {3.5943199556816444`*^9, 
   3.5943199822633867`*^9}, {3.594322251824504*^9, 3.5943222524979544`*^9}, 
   3.5943223574660225`*^9, {3.5943225284911833`*^9, 3.594322532198663*^9}, {
   3.594322682423937*^9, 3.594322683109397*^9}, {3.5943227366571383`*^9, 
   3.5943227372885637`*^9}, {3.594322807755598*^9, 3.594322808426049*^9}, {
   3.594323430795068*^9, 3.594323431640635*^9}, {3.594323491275916*^9, 
   3.594323492035427*^9}, {3.5943235441332045`*^9, 3.5943235449227304`*^9}, {
   3.59432357857419*^9, 3.5943235792726607`*^9}, {3.5943236472480307`*^9, 
   3.5943236482897315`*^9}, 3.594323697735732*^9, {3.5943237476540527`*^9, 
   3.5943237482374444`*^9}, 3.594323815106084*^9, {3.5943238640657654`*^9, 
   3.5943238648863163`*^9}, 3.594323937665966*^9, {3.5943239706800013`*^9, 
   3.5943239722240314`*^9}, {3.5943240127080545`*^9, 
   3.5943240163965225`*^9}, {3.5943240574219027`*^9, 
   3.5943240587177706`*^9}, {3.594324095834544*^9, 3.5943240983962545`*^9}, {
   3.5943241765073953`*^9, 3.5943241775961275`*^9}, {3.594378167983125*^9, 
   3.594378168451125*^9}, {3.5943783227507253`*^9, 3.594378323125125*^9}, {
   3.594378370003125*^9, 3.5943783705959253`*^9}, {3.5943784363655252`*^9, 
   3.5943784371299253`*^9}, {3.594378784121725*^9, 3.594378785073325*^9}, {
   3.594378820344925*^9, 3.594378821452525*^9}, {3.594384579011125*^9, 
   3.5943845798067255`*^9}, {3.5943846185727253`*^9, 3.594384619290325*^9}, 
   3.594384731564525*^9, {3.594384789206525*^9, 3.594384819260725*^9}, {
   3.5944392965171366`*^9, 3.594439299964737*^9}, {3.594439467868537*^9, 
   3.5944394770101366`*^9}, {3.5944401538255367`*^9, 3.594440159035937*^9}, 
   3.594442163105937*^9, 3.5944422122615366`*^9, 3.5944478658583364`*^9, 
   3.594447922969937*^9, {3.594447976275137*^9, 3.594447976930337*^9}, {
   3.5944480301575365`*^9, 3.5944480317643366`*^9}, {3.5944480792039366`*^9, 
   3.594448079812337*^9}, {3.594448111373537*^9, 3.594448111888337*^9}, 
   3.594448164725537*^9, 3.594448217656337*^9, {3.5944482905239367`*^9, 
   3.5944482909607368`*^9}, {3.5944483308535366`*^9, 
   3.5944483592923365`*^9}, {3.594448518973937*^9, 3.594448519395137*^9}, {
   3.594448566335537*^9, 3.594448568691137*^9}, {3.5944486056631365`*^9, 
   3.594448606723937*^9}, {3.594448753192337*^9, 3.594448758511937*^9}, {
   3.5944487948443365`*^9, 3.594448795312337*^9}, {3.594448830895937*^9, 
   3.594448831363937*^9}, {3.594448891829537*^9, 3.594448893030737*^9}, {
   3.594448926891737*^9, 3.594448927406537*^9}, {3.594448958247737*^9, 
   3.594448958481737*^9}, {3.594449057869337*^9, 3.594449057962937*^9}, {
   3.594449113545737*^9, 3.5944491146689367`*^9}, 3.5944491554005365`*^9, {
   3.5944491958697367`*^9, 3.5944491963065367`*^9}, {3.594449228442537*^9, 
   3.594449229565737*^9}, {3.5944492919189367`*^9, 3.5944492924649367`*^9}, {
   3.5944493371745367`*^9, 3.5944493663465366`*^9}, {3.594450334173937*^9, 
   3.594450334626337*^9}, {3.594450371614937*^9, 3.5944503721141367`*^9}, {
   3.5944505520309367`*^9, 3.5944505524677367`*^9}, {3.594450596210137*^9, 
   3.5944505966001368`*^9}, {3.5944507375003366`*^9, 3.5944507379215364`*^9}, 
   3.5944507950185366`*^9, {3.594450870321737*^9, 3.5944508708989367`*^9}, {
   3.594450901662137*^9, 3.594450902114537*^9}, 3.5944509448283367`*^9, 
   3.594450977619537*^9, {3.594451185685337*^9, 3.5944511861689367`*^9}, {
   3.59473415254123*^9, 3.5947341535328894`*^9}, {3.5947343043725767`*^9, 
   3.5947343055343556`*^9}, 3.5947344098419833`*^9, {3.594734471510148*^9, 
   3.594734472717954*^9}, {3.594734658641059*^9, 3.5947346600530043`*^9}, {
   3.5947349180452194`*^9, 3.594734921307397*^9}, {3.5947354947721977`*^9, 
   3.594735495639776*^9}, {3.5947355465517616`*^9, 3.5947355471471586`*^9}, 
   3.594735918819253*^9, {3.5947359730004253`*^9, 3.5947360031705647`*^9}, 
   3.594736076341408*^9, {3.5947361874105434`*^9, 3.594736188229095*^9}, {
   3.5947364311678915`*^9, 3.5947364320054502`*^9}, 3.6634841318625374`*^9, {
   3.663484226688573*^9, 3.6634842272510843`*^9}, {3.6634843779482193`*^9, 
   3.6634843787932873`*^9}, {3.6634892589593067`*^9, 3.663489259501817*^9}, {
   3.6634893447083664`*^9, 3.663489345253377*^9}, {3.6635701288679037`*^9, 
   3.663570129227911*^9}, {3.663570168709906*^9, 3.6635701692644186`*^9}, 
   3.663570245429634*^9, {3.663570562236972*^9, 3.663570562731982*^9}, {
   3.6635706179182663`*^9, 3.663570618410776*^9}, {3.6635706555341854`*^9, 
   3.6635706561666985`*^9}, {3.663570728577776*^9, 3.6635707300253053`*^9}, 
   3.663935984154991*^9, {3.6639360218260937`*^9, 3.6639360223061132`*^9}, {
   3.663936107838128*^9, 3.6639361086581607`*^9}, 3.6639367954519434`*^9, 
   3.663939327480541*^9, 3.6639393593464603`*^9, 3.6639401383471785`*^9, {
   3.6639401929069543`*^9, 3.663940194522019*^9}, {3.6639402360643024`*^9, 
   3.6639402366068244`*^9}, 3.6639403414022274`*^9, 3.6639405131627955`*^9, {
   3.6639406117243576`*^9, 3.663940639757573*^9}, 3.663944652413145*^9, {
   3.6639447068094063`*^9, 3.6639447101690416`*^9}, {3.6639447642347755`*^9, 
   3.6639447647372956`*^9}, {3.663944830153042*^9, 3.6639448317056036`*^9}, {
   3.6639448693566823`*^9, 3.663944869929205*^9}, {3.663945380266879*^9, 
   3.6639453807893996`*^9}, {3.663994847226094*^9, 3.6639948481552258`*^9}, {
   3.6639951289494834`*^9, 3.6639951294324613`*^9}, {3.6639952599018745`*^9, 
   3.6639952604546614`*^9}, {3.6639953204910173`*^9, 3.663995321714153*^9}, {
   3.663995366003307*^9, 3.6639953750400066`*^9}, {3.6640016388109508`*^9, 
   3.6640016700217624`*^9}, {3.6640043992040977`*^9, 3.664004400114134*^9}, {
   3.6640075277791433`*^9, 3.6640075284391823`*^9}, {3.6640084928182564`*^9, 
   3.6640084933582726`*^9}, {3.6640085600165825`*^9, 
   3.6640085607366185`*^9}, {3.6640889942977834`*^9, 3.664088995327835*^9}, {
   3.6640890936788416`*^9, 3.6640890941188636`*^9}, {3.664091706507167*^9, 
   3.6640917070471935`*^9}, {3.664091769738406*^9, 3.6640917703204365`*^9}, 
   3.6640918093404317`*^9, {3.664092023516261*^9, 3.6640920246873207`*^9}, {
   3.664092151509859*^9, 3.664092152089888*^9}, {3.6640925225124226`*^9, 
   3.6640925235074725`*^9}, {3.664092571165454*^9, 3.664092582968548*^9}, {
   3.6640926574249325`*^9, 3.664092658236975*^9}, 3.6640931981461816`*^9, {
   3.664093242216077*^9, 3.6640932426786003`*^9}, {3.664093684256857*^9, 
   3.664093684802391*^9}, {3.6640992895874596`*^9, 3.664099291037489*^9}, {
   3.664099687380936*^9, 3.664099687893431*^9}, {3.664100195278327*^9, 
   3.664100196033327*^9}, {3.664100573641467*^9, 3.6641005740490365`*^9}, {
   3.664101416442217*^9, 3.664101416934742*^9}, {3.6641017471504936`*^9, 
   3.664101747643008*^9}, {3.664110904980613*^9, 3.664110906055646*^9}, {
   3.6641110766178493`*^9, 3.6641110775928783`*^9}, {3.664112086236627*^9, 
   3.664112086866665*^9}, {3.6641763895636463`*^9, 3.66417638970365*^9}, {
   3.669369527403096*^9, 3.669369527938116*^9}, {3.669370514677322*^9, 
   3.669370515249833*^9}, {3.6693706300723553`*^9, 3.669370630509864*^9}, {
   3.669370850275034*^9, 3.669370851180052*^9}, {3.66937565405011*^9, 
   3.669375654545124*^9}, {3.6693760511882615`*^9, 3.6693760516307745`*^9}, {
   3.669376493629677*^9, 3.669376494192194*^9}, {3.6693770662046814`*^9, 
   3.6693770667496977`*^9}, 3.6846734122864943`*^9, {3.6846735368086166`*^9, 
   3.684673539113748*^9}, {3.68467367394246*^9, 3.6846736772576494`*^9}, {
   3.6846737586133027`*^9, 3.6846737642746267`*^9}, {3.6846738606801405`*^9, 
   3.6846738615821924`*^9}, {3.736413539086374*^9, 3.7364136113405066`*^9}, {
   3.7364145584406776`*^9, 3.736414578042799*^9}, {3.7364146543311625`*^9, 
   3.7364146604725137`*^9}, {3.736414757353055*^9, 3.736414834804485*^9}, {
   3.736414958998588*^9, 3.736414961508732*^9}, 3.7364161849107065`*^9, {
   3.7364168857047896`*^9, 3.736416938724822*^9}, 3.7364174699592066`*^9, {
   3.73641754134829*^9, 3.7364175414762974`*^9}, {3.7364273136432333`*^9, 
   3.736427317691465*^9}},
 FontFamily->"Courier New",
 FontSize->10]
}, Open  ]],

Cell[CellGroupData[{

Cell["b. OLS / Rational Expectations", "Subsection",
 CellChangeTimes->{{3.7364175003989477`*^9, 3.7364175112155666`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "OLS", " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"cL", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Length", "[", "series", "]"}], "-", "1"}], "}"}]}], "]"}]}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"vL", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Length", "[", "series", "]"}], "-", "1"}], "}"}]}], "]"}]}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lv", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"series", "[", 
          RowBox[{"[", "jj", "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"jj", ",", "1", ",", 
         RowBox[{"Length", "[", "series", "]"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"x", "=", 
     RowBox[{"Drop", "[", 
      RowBox[{"lv", ",", 
       RowBox[{"-", "1"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"y", "=", 
     RowBox[{"Drop", "[", 
      RowBox[{"series", ",", "1"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cOLS", "=", 
     RowBox[{"LeastSquares", "[", 
      RowBox[{"x", ",", "y"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"beta0", "=", 
     RowBox[{"LeastSquares", "[", 
      RowBox[{
       RowBox[{"x", "[", 
        RowBox[{"[", 
         RowBox[{"1", ";;", "2"}], "]"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"[", 
         RowBox[{"1", ";;", "2"}], "]"}], "]"}]}], " ", "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"R0", "=", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"x", "[", 
        RowBox[{"[", 
         RowBox[{"1", ";;", "2"}], "]"}], "]"}], " ", "]"}], ".", 
      RowBox[{"x", "[", 
       RowBox[{"[", 
        RowBox[{"1", ";;", "2"}], "]"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"cL", "[", 
      RowBox[{"[", "2", "]"}], "]"}], "=", "beta0"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"vL", "[", 
      RowBox[{"[", "2", "]"}], "]"}], "=", "R0"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"ii", "=", "3"}], ",", 
     RowBox[{"ii", "<", 
      RowBox[{
       RowBox[{"Length", "[", "x", "]"}], "+", "1"}]}], ",", 
     RowBox[{"ii", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"gamm", "=", 
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"ii", "-", "1"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"vL", "[", 
        RowBox[{"[", "ii", "]"}], "]"}], "=", 
       RowBox[{"rAvar", "[", 
        RowBox[{
         RowBox[{"vL", "[", 
          RowBox[{"[", 
           RowBox[{"ii", "-", "1"}], "]"}], "]"}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"[", "ii", "]"}], "]"}]}], " ", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"cL", "[", 
        RowBox[{"[", "ii", "]"}], "]"}], " ", "=", " ", 
       RowBox[{"cAvar", "[", 
        RowBox[{
         RowBox[{"cL", "[", 
          RowBox[{"[", 
           RowBox[{"ii", "-", "1"}], "]"}], "]"}], ",", 
         RowBox[{"vL", "[", 
          RowBox[{"[", "ii", "]"}], "]"}], ",", 
         RowBox[{"y", "[", 
          RowBox[{"[", "ii", "]"}], "]"}], ",", 
         RowBox[{"x", "[", 
          RowBox[{"[", 
           RowBox[{"ii", "-", "1"}], "]"}], "]"}]}], " ", "]"}]}], ";"}]}], 
    "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"meanPhiOLS", "=", 
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"cL", "[", 
        RowBox[{"[", 
         RowBox[{
          RowBox[{"1", ";;", 
           RowBox[{"Length", "[", "cL", "]"}]}], ",", "1"}], " ", "]"}], 
        "]"}], "/", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"cL", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"1", ";;", 
             RowBox[{"Length", "[", "cL", "]"}]}], ",", "2"}], "]"}], "]"}]}],
         ")"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Storing", " ", "results"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"constRE", "=", 
     RowBox[{"cL", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "series", "]"}], "-", "1"}], ",", "1"}], 
       "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rhoRE", "=", 
     RowBox[{"cL", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "series", "]"}], "-", "1"}], ",", "2"}], 
       "]"}], "]"}]}], ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.5719979810334063`*^9, 3.5719980444990363`*^9}, {
   3.571998128583846*^9, 3.571998199711914*^9}, 3.571998272691088*^9, {
   3.571998785567423*^9, 3.571998801175316*^9}, {3.5719988707012925`*^9, 
   3.5719988796148024`*^9}, {3.5719989184140215`*^9, 3.571998939142207*^9}, {
   3.5719990357197313`*^9, 3.5719990384048843`*^9}, {3.5719992977057157`*^9, 
   3.571999370196862*^9}, {3.571999623112328*^9, 3.5719997677265997`*^9}, {
   3.571999799507417*^9, 3.5719999738193874`*^9}, {3.572000023809246*^9, 
   3.572000026368393*^9}, {3.5720000692338448`*^9, 3.572000123720961*^9}, 
   3.5720051337595186`*^9, {3.572005191158802*^9, 3.572005199934304*^9}, 
   3.5720052331402035`*^9, {3.572005317164009*^9, 3.5720053242024117`*^9}, {
   3.5720053968165646`*^9, 3.57200543449072*^9}, {3.5720055131492186`*^9, 
   3.572005513660248*^9}, {3.5720056057465153`*^9, 3.572005615767088*^9}, 
   3.572005817762642*^9, {3.5720074836049223`*^9, 3.5720075228771687`*^9}, {
   3.5728636012526484`*^9, 3.5728636325462484`*^9}, {3.5728636844952483`*^9, 
   3.5728636848696485`*^9}, {3.572864489029248*^9, 3.572864495721648*^9}, {
   3.5728648655674486`*^9, 3.572864867501848*^9}, {3.5728649399014482`*^9, 
   3.5728649405722485`*^9}, {3.5728653916638484`*^9, 
   3.5728653920538483`*^9}, {3.5728657206230483`*^9, 
   3.5728657221206484`*^9}, {3.5728657616198483`*^9, 
   3.5728657658474483`*^9}, {3.572928346567891*^9, 3.5729283548202915`*^9}, {
   3.573042796921875*^9, 3.573042835296875*^9}, {3.573044262671875*^9, 
   3.57304426440625*^9}, {3.57304478753125*^9, 3.573044803953125*^9}, {
   3.573556296099642*^9, 3.573556301700042*^9}, {3.5735563338516417`*^9, 
   3.5735563657224417`*^9}, {3.5735564005728416`*^9, 3.573556470367242*^9}, {
   3.5739597427962403`*^9, 3.57395974586944*^9}, {3.5786570525158*^9, 
   3.5786570579914*^9}, {3.5786571583618*^9, 3.578657160499*^9}, {
   3.5787351144715967`*^9, 3.578735115095597*^9}, {3.578735157355997*^9, 
   3.5787351838759966`*^9}, {3.5787352645435967`*^9, 
   3.5787352659631968`*^9}, {3.578746740646197*^9, 3.578746749413397*^9}, {
   3.5787468420305967`*^9, 3.578746844261397*^9}, {3.5788231533977976`*^9, 
   3.5788231543805976`*^9}, {3.578906297239007*^9, 3.578906297457407*^9}, {
   3.5789069386184072`*^9, 3.578906938805607*^9}, {3.5789072531622066`*^9, 
   3.578907258294607*^9}, {3.578907423779407*^9, 3.578907465151607*^9}, {
   3.5789075673160067`*^9, 3.578907570919607*^9}, {3.578907761349807*^9, 
   3.5789077671374073`*^9}, {3.578907882920607*^9, 3.578907886227807*^9}, 
   3.5789086732196074`*^9, {3.5868663986982*^9, 3.586866407793*^9}, {
   3.5868665346521997`*^9, 3.5868665422494*^9}, {3.5908979595315876`*^9, 
   3.590897964461188*^9}, {3.5909040723973875`*^9, 3.5909040896923876`*^9}, {
   3.590904186117388*^9, 3.590904194577388*^9}, {3.5909042502913876`*^9, 
   3.590904253900388*^9}, {3.590904323568388*^9, 3.5909043271833878`*^9}, {
   3.590904389196388*^9, 3.5909043931703877`*^9}, {3.590904491649388*^9, 
   3.590904502307388*^9}, {3.590904825946388*^9, 3.590904829873388*^9}, {
   3.5909875915523605`*^9, 3.5909875963571606`*^9}, {3.5909882716457605`*^9, 
   3.590988272035761*^9}, {3.590988332834961*^9, 3.590988336625761*^9}, {
   3.590990574695161*^9, 3.590990574991561*^9}, {3.590990656002361*^9, 
   3.5909906563923607`*^9}, {3.590991114954361*^9, 3.5909911151571608`*^9}, {
   3.5909911913319607`*^9, 3.590991191456761*^9}, {3.591531417851095*^9, 
   3.5915314180852547`*^9}, {3.591531502785574*^9, 3.591531503692176*^9}, {
   3.591544250380605*^9, 3.5915442589422913`*^9}, {3.5915443391387405`*^9, 
   3.591544346457603*^9}, {3.594439333863537*^9, 3.5944393505867367`*^9}, {
   3.7364175326297913`*^9, 3.736417587519931*^9}, 3.7364273229557657`*^9},
 FontFamily->"Courier New",
 FontSize->10]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
c. Recovering financial shocks / innovations\
\>", "Subsection",
 CellChangeTimes->{{3.7364176014867296`*^9, 3.7364176196947713`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"OLS", " ", "innovations"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"innovOLS", "=", 
     RowBox[{
      RowBox[{"Drop", "[", 
       RowBox[{"series", ",", "1"}], "]"}], "-", 
      RowBox[{"rhoRE", "*", 
       RowBox[{"Drop", "[", 
        RowBox[{"series", ",", 
         RowBox[{"-", "1"}]}], "]"}]}], "-", "constRE"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"innovOLS", "=", 
     RowBox[{"Prepend", "[", 
      RowBox[{"innovOLS", ",", "0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   " ", "\[IndentingNewLine]", "\n", 
   RowBox[{"(*", " ", 
    RowBox[{"Constant", " ", "Gain", " ", "Learning", " ", "innovations"}], 
    " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"innovCG", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"Length", "[", "series", "]"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"xx", "=", "series"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"ii", "=", "4"}], ",", 
      RowBox[{"ii", "<", 
       RowBox[{
        RowBox[{"Length", "[", "series", "]"}], "+", "1"}]}], ",", 
      RowBox[{"ii", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"innovCG", "[", 
         RowBox[{"[", "ii", "]"}], "]"}], " ", "=", " ", 
        RowBox[{
         RowBox[{"xx", "[", 
          RowBox[{"[", "ii", "]"}], "]"}], "-", 
         RowBox[{
          RowBox[{"cLCG", "[", 
           RowBox[{"[", 
            RowBox[{
             RowBox[{"ii", "-", "1"}], ",", "2"}], "]"}], "]"}], "*", 
          RowBox[{"xx", "[", 
           RowBox[{"[", 
            RowBox[{"ii", "-", "1"}], "]"}], "]"}]}], "-", 
         RowBox[{"cLCG", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"ii", "-", "1"}], ",", "1"}], "]"}], "]"}]}]}], ";"}]}], 
     "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Standard deviation =\>\"", ",", 
      RowBox[{"StandardDeviation", "[", "innovOLS", "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.5728637265840483`*^9, 3.5728637275512486`*^9}, {
   3.5728637702172484`*^9, 3.5728638135384483`*^9}, {3.5728638450660486`*^9, 
   3.572863926529248*^9}, {3.5728639957754483`*^9, 3.5728640420606484`*^9}, {
   3.5728642196842484`*^9, 3.5728642293094482`*^9}, {3.572864260697648*^9, 
   3.5728642724756484`*^9}, {3.572864641378848*^9, 3.572864678413248*^9}, {
   3.5728647120936484`*^9, 3.5728647333096485`*^9}, {3.5728649165170484`*^9, 
   3.5728649238490486`*^9}, {3.5728650070594482`*^9, 
   3.5728650409738483`*^9}, {3.5728650821266484`*^9, 
   3.5728651264316483`*^9}, {3.5728652021228485`*^9, 
   3.5728652058512487`*^9}, {3.5728652888900485`*^9, 3.572865289560848*^9}, {
   3.572865336189248*^9, 3.5728653574520483`*^9}, {3.5728654426758485`*^9, 
   3.572865446466648*^9}, {3.5728655540462484`*^9, 3.5728655821574483`*^9}, {
   3.5728657979834485`*^9, 3.5728658007446485`*^9}, {3.5728660505162487`*^9, 
   3.5728660599542484`*^9}, {3.5728661980922484`*^9, 
   3.5728662024914484`*^9}, {3.5729586868476295`*^9, 3.572958697143384*^9}, {
   3.5730454456875*^9, 3.573045452609375*^9}, {3.573226778171875*^9, 
   3.573226802453125*^9}, {3.57322695471875*^9, 3.573226980796875*^9}, {
   3.7364176280202475`*^9, 3.7364176584049854`*^9}, 3.736417787426365*^9, {
   3.7364179960492973`*^9, 3.7364180227168226`*^9}, {3.7364263703382797`*^9, 
   3.7364263711213245`*^9}, {3.7364273678983364`*^9, 3.736427419519289*^9}, 
   3.7364275285215235`*^9},
 FontFamily->"Courier New",
 FontSize->10],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Standard deviation =\"\>", "\[InvisibleSpace]", 
   "0.03402029991214663`"}],
  SequenceForm["Standard deviation =", 0.03402029991214663],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.5728658038334484`*^9, {3.5728660201898484`*^9, 3.5728660326854486`*^9}, 
   3.5728660631522484`*^9, 3.5728662485738487`*^9, {3.5728663951982484`*^9, 
   3.572866419192048*^9}, {3.5728665777816486`*^9, 3.572866600947648*^9}, 
   3.5728666926132483`*^9, 3.572866741753248*^9, 3.572866777758048*^9, {
   3.5728669483440485`*^9, 3.5728669762992487`*^9}, 3.572925318246291*^9, 
   3.5729276910392914`*^9, {3.5729277383384914`*^9, 3.5729277607868915`*^9}, 
   3.5729283696090913`*^9, {3.572928475642291*^9, 3.5729284899006915`*^9}, 
   3.5729292114318914`*^9, 3.5729294647914915`*^9, 3.5729297189846916`*^9, 
   3.572929889211891*^9, 3.5729299830490913`*^9, 3.5729301846810913`*^9, 
   3.5729303347374916`*^9, 3.572930568271491*^9, 3.5729306251178913`*^9, 
   3.5729308112424917`*^9, 3.5729309643158913`*^9, 3.5729310044088917`*^9, 
   3.5729310992724915`*^9, 3.5729311311432915`*^9, 3.5729311844016914`*^9, 
   3.572931251544091*^9, 3.5729314347660913`*^9, 3.5729315647452917`*^9, 
   3.5729568605037575`*^9, 3.572958015092599*^9, 3.572958697830809*^9, 
   3.5729589099327297`*^9, 3.572959602263646*^9, 3.572959749419509*^9, 
   3.57295978308772*^9, 3.5729599081366134`*^9, 3.5729602552550926`*^9, 
   3.572960336605616*^9, 3.5729611198824*^9, 3.5729612247144003`*^9, 
   3.5729612849244003`*^9, 3.5729613782904*^9, 3.5729616309168*^9, 
   3.5729617263576*^9, 3.5729618217672*^9, 3.5729618988311996`*^9, 
   3.572961954492*^9, 3.57296218155*^9, 3.5729630863042*^9, 
   3.57304292015625*^9, 3.5730434289375*^9, 3.573043578171875*^9, 
   3.573043645359375*^9, 3.573043768421875*^9, 3.573043878046875*^9, 
   3.573043940796875*^9, 3.573044027*^9, 3.573044131765625*^9, 
   3.57304423075*^9, 3.573044382203125*^9, 3.573044754234375*^9, 
   3.573044896203125*^9, 3.573044985671875*^9, 3.573046041671875*^9, 
   3.573046151359375*^9, 3.57304625525*^9, 3.57304636721875*^9, 
   3.57304651796875*^9, 3.57304674740625*^9, 3.57304700059375*^9, 
   3.573047187328125*^9, 3.5730473630625*^9, 3.573047655703125*^9, 
   3.573047804171875*^9, 3.573047899921875*^9, 3.573048014640625*^9, 
   3.573048098734375*^9, 3.573048189203125*^9, 3.5730482823125*^9, 
   3.57304850165625*^9, 3.573048616609375*^9, {3.57304871103125*^9, 
   3.57304872896875*^9}, 3.573048877828125*^9, 3.5730490211875*^9, 
   3.573049117859375*^9, 3.5730492111875*^9, 3.573049328625*^9, 
   3.5730496845*^9, 3.573049782171875*^9, 3.573049899421875*^9, 
   3.57305006384375*^9, 3.57305028971875*^9, 3.573050598640625*^9, 
   3.573050724703125*^9, 3.573050925765625*^9, 3.5730510404375*^9, 
   3.5730532355*^9, 3.5730537496875*^9, 3.57305410790625*^9, 
   3.57305514765625*^9, 3.57305527896875*^9, 3.573055386578125*^9, 
   3.57305617640625*^9, 3.57305628909375*^9, 3.573056386109375*^9, 
   3.573056887*^9, 3.573057246078125*^9, 3.57305735728125*^9, 
   3.573057426421875*^9, 3.57305756975*^9, 3.5730576773125*^9, 
   3.5730577673125*^9, 3.573057870875*^9, 3.573057967609375*^9, 
   3.5730580545625*^9, 3.573058145796875*^9, 3.573058239265625*^9, 
   3.5730583766875*^9, 3.573058490015625*^9, 3.57305862175*^9, 
   3.5730587294375*^9, 3.573058828515625*^9, 3.573058921828125*^9, 
   3.5730590235625*^9, 3.573059133875*^9, 3.57305925421875*^9, 
   3.573060605796875*^9, 3.573060641078125*^9, 3.57306067690625*^9, 
   3.573060738203125*^9, 3.573060846671875*^9, 3.5730609315625*^9, 
   3.57306100509375*^9, 3.57306109275*^9, 3.573061159109375*^9, 
   3.573061224359375*^9, 3.573061922*^9, 3.57306204540625*^9, 3.573062124*^9, 
   3.5730621995625*^9, 3.57306228484375*^9, 3.573062365375*^9, 
   3.573062441109375*^9, 3.57306253221875*^9, 3.57306261903125*^9, 
   3.573062703625*^9, 3.573062778328125*^9, 3.57306285415625*^9, 
   3.57306303034375*^9, 3.573063106125*^9, 3.573063183671875*^9, 
   3.573063264203125*^9, 3.5730633460625*^9, 3.573063420703125*^9, 
   3.57306351490625*^9, 3.57306358628125*^9, 3.573063666140625*^9, 
   3.573063751375*^9, 3.573063823140625*^9, 3.573063925546875*^9, 
   3.573064005984375*^9, 3.573064115984375*^9, 3.57306419865625*^9, 
   3.573064273578125*^9, 3.573064348015625*^9, 3.573064446921875*^9, 
   3.573064525796875*^9, 3.573064629453125*^9, 3.57306470471875*^9, 
   3.573064784234375*^9, 3.573064869765625*^9, 3.5730649489375*^9, 
   3.5730650268125*^9, 3.57306512034375*^9, 3.57306521875*^9, 
   3.573065388171875*^9, 3.57306546815625*^9, 3.573065557625*^9, 
   3.573065668265625*^9, 3.57306707640625*^9, 3.57306718059375*^9, 
   3.573067270578125*^9, 3.57306735134375*^9, 3.573067455*^9, 
   3.57306762825*^9, 3.573067734359375*^9, 3.573105095640625*^9, 
   3.573105176640625*^9, 3.573105285203125*^9, 3.57310555121875*^9, 
   3.5731057266875*^9, 3.573105823140625*^9, 3.5731059305*^9, 
   3.573106030609375*^9, 3.5731061183125*^9, 3.57310621828125*^9, 
   3.57310633878125*^9, 3.573106440296875*^9, 3.5731065435*^9, 
   3.573106667953125*^9, 3.573106767390625*^9, 3.573106881109375*^9, 
   3.573107092984375*^9, 3.573107238578125*^9, 3.57310738021875*^9, 
   3.573107648609375*^9, 3.573108107078125*^9, 3.573108222984375*^9, 
   3.573108346390625*^9, 3.57310870428125*^9, 3.57310887240625*^9, 
   3.573108983578125*^9, 3.573109160453125*^9, 3.57310927528125*^9, 
   3.573109397171875*^9, 3.573109508859375*^9, 3.573109607015625*^9, 
   3.57310969171875*^9, 3.57310990359375*^9, 3.57310998315625*^9, 
   3.57311007071875*^9, 3.573110152078125*^9, 3.573110239125*^9, 
   3.57311033909375*^9, 3.5731104205*^9, 3.5731105454375*^9, 
   3.5731114245625*^9, 3.573112967390625*^9, 3.573113057609375*^9, 
   3.57311322346875*^9, 3.573113308890625*^9, 3.573113504671875*^9, 
   3.573113866625*^9, 3.57311415175*^9, 3.57311457815625*^9, 
   3.573115204546875*^9, 3.573115521671875*^9, 3.5731158391875*^9, 
   3.5731161171875*^9, 3.573116591765625*^9, 3.573117518203125*^9, 
   3.573196241685911*^9, 3.573196329716711*^9, 3.573196541480111*^9, 
   3.573197594471711*^9, 3.573197712346311*^9, 3.573197792390911*^9, 
   3.573197912557711*^9, 3.573198015598111*^9, 3.573198100274911*^9, 
   3.5731982025505114`*^9, 3.5731983803491116`*^9, 3.5731984429207115`*^9, 
   3.5731985124665112`*^9, 3.573198603196111*^9, 3.573198670603711*^9, 
   3.573198744095311*^9, 3.5731988203005114`*^9, 3.573198913903511*^9, 
   3.573198995529111*^9, 3.573199070112711*^9, 3.5731991423261113`*^9, 
   3.573199292959711*^9, 3.573199427307911*^9, 3.573206799901311*^9, 
   3.573207091673311*^9, {3.573209207605711*^9, 3.573209230974511*^9}, 
   3.5732093662577114`*^9, 3.573223869671875*^9, 3.573223987171875*^9, 
   3.57322416125*^9, 3.573224301671875*^9, 3.573224422671875*^9, 
   3.5732245051875*^9, 3.57322682328125*^9, 3.573226985953125*^9, 
   3.573227042125*^9, 3.57322718575*^9, 3.573227272859375*^9, 
   3.57322737325*^9, 3.5732274543125*^9, 3.573227616796875*^9, 
   3.573227697640625*^9, 3.5732277939375*^9, 3.57322791725*^9, 
   3.5732281936875*^9, 3.573228301734375*^9, 3.573232456578125*^9, 
   3.5732325543125*^9, 3.573232665515625*^9, 3.573232790265625*^9, 
   3.57323285946875*^9, 3.573232973078125*^9, 3.5732331703125*^9, 
   3.573233274140625*^9, 3.573234369421875*^9, 3.573234595984375*^9, 
   3.57323587884375*^9, 3.573235910625*^9, 3.573236052328125*^9, 
   3.57323622025*^9, 3.57323635715625*^9, 3.573272252625*^9, 
   3.573272651375*^9, 3.57328387828125*^9, 3.573284728640625*^9, 
   3.573285294703125*^9, 3.57328537971875*^9, 3.573286778640625*^9, 
   3.573293547046875*^9, 3.573294652578125*^9, 3.573295087765625*^9, 
   3.573295193421875*^9, 3.5732952925*^9, 3.573295392890625*^9, 
   3.57329548409375*^9, 3.5732955786875*^9, 3.57329576859375*^9, 
   3.573295861109375*^9, 3.573296059578125*^9, 3.5732961740625*^9, 
   3.573296276765625*^9, 3.573296406453125*^9, 3.573298055859375*^9, 
   3.57329817090625*^9, 3.573298253625*^9, 3.573535599925642*^9, 
   3.573536791576642*^9, 3.5735368481276417`*^9, 3.573536940323642*^9, 
   3.573537047980242*^9, 3.573537081771842*^9, 3.573537172875842*^9, 
   3.5735372198474417`*^9, 3.5735372774738417`*^9, 3.573537345661442*^9, 
   3.573537503231042*^9, 3.573537899705042*^9, 3.573538119805442*^9, 
   3.573538172159042*^9, 3.573538207337042*^9, 3.5735382461810417`*^9, {
   3.573538309003242*^9, 3.573538336429042*^9}, 3.5735383817470417`*^9, {
   3.573538466595442*^9, 3.573538494676442*^9}, 3.573538693810442*^9, 
   3.573538742919242*^9, 3.5735388281108418`*^9, 3.5735388727580423`*^9, 
   3.573538985166642*^9, 3.5735390287540417`*^9, 3.573539080187242*^9, 
   3.573539124007642*^9, 3.573539234096842*^9, 3.573539293486042*^9, 
   3.573539331612442*^9, 3.573539423329842*^9, 3.573539493519842*^9, 
   3.5735395407566423`*^9, 3.573539635308242*^9, 3.573539830761642*^9, 
   3.573539881477242*^9, 3.573539914473242*^9, 3.573539986499442*^9, 
   3.573540119754642*^9, 3.573540261218442*^9, 3.573540291404442*^9, 
   3.5735403313404417`*^9, {3.5735403634296417`*^9, 3.573540372727242*^9}, 
   3.573540451819242*^9, 3.573540485967642*^9, 3.573540539881242*^9, 
   3.573540728033642*^9, 3.573540792212042*^9, 3.573541293798842*^9, 
   3.573541622631242*^9, 3.573541673378042*^9, 3.5735421522688417`*^9, 
   3.5735421838910418`*^9, 3.573542272306842*^9, 3.573542351368642*^9, 
   3.5735424142678423`*^9, {3.5735424742372417`*^9, 3.573542496139642*^9}, {
   3.573543530031042*^9, 3.5735435573776417`*^9}, 3.573543646250842*^9, 
   3.5735436860192423`*^9, 3.573543849257642*^9, 3.573543917663642*^9, 
   3.573544010946042*^9, 3.573544095170442*^9, 3.573544129428042*^9, 
   3.573544196228242*^9, 3.573544230378642*^9, 3.573544284544842*^9, 
   3.573544342767042*^9, 3.5735443882334423`*^9, 3.573544426921442*^9, 
   3.573544466607842*^9, 3.573544550864442*^9, {3.573544622001442*^9, 
   3.573544641501442*^9}, 3.5735446934026423`*^9, {3.573544732091642*^9, 
   3.573544756474442*^9}, 3.573544800248042*^9, 3.5735449101344423`*^9, 
   3.573544958198042*^9, 3.573545017042242*^9, 3.573545096165442*^9, 
   3.573545145227442*^9, 3.573545182293042*^9, 3.5735452323846416`*^9, 
   3.573545380881042*^9, 3.573545424654642*^9, 3.573545525761242*^9, 
   3.5735455876620417`*^9, 3.573545638034442*^9, 3.573545687486442*^9, 
   3.5735457497460423`*^9, 3.573545897347042*^9, 3.573545935941442*^9, 
   3.5735459758004417`*^9, 3.573546011836442*^9, {3.573546041850842*^9, 
   3.5735460691508417`*^9}, 3.5735461372292423`*^9, 3.573552990687442*^9, 
   3.573553028886842*^9, 3.573553063473042*^9, 3.573553094423442*^9, 
   3.573553151337242*^9, 3.573553219805642*^9, 3.5735532529254417`*^9, 
   3.5735532857488422`*^9, {3.573553319399042*^9, 3.573553348415042*^9}, 
   3.573553391580242*^9, 3.573553426477442*^9, {3.5735534662418423`*^9, 
   3.573553492309442*^9}, 3.573553530499242*^9, {3.5735536783872423`*^9, 
   3.573553706576442*^9}, 3.573553749460842*^9, 3.573553807446042*^9, {
   3.573553846369042*^9, 3.573553874293042*^9}, {3.573553913677042*^9, 
   3.5735539922582417`*^9}, {3.573554036204442*^9, 3.573554063036442*^9}, 
   3.573554173688242*^9, 3.573554224748042*^9, 3.573554283497642*^9, {
   3.573554333152442*^9, 3.573554363042042*^9}, 3.5735544125480423`*^9, 
   3.573554454903042*^9, 3.573554490393042*^9, 3.5735545264602423`*^9, 
   3.5735547405244417`*^9, 3.5735548268352423`*^9, 3.5735549184560423`*^9, 
   3.573554963462042*^9, 3.573555124549642*^9, 3.5735551651564417`*^9, 
   3.5735551976990423`*^9, 3.573555231441842*^9, {3.573555265543442*^9, 
   3.573555322467842*^9}, 3.5735553657734423`*^9, 3.573555398065442*^9, 
   3.573555448703042*^9, {3.573555499279242*^9, 3.573555528108042*^9}, 
   3.573555582396042*^9, 3.5735556247344418`*^9, 3.573555664920042*^9, 
   3.573555736992642*^9, 3.573555816253242*^9, 3.5735559016028423`*^9, 
   3.573555932772642*^9, 3.5735559719598417`*^9, 3.573556146618442*^9, 
   3.573556182639842*^9, 3.573556936118842*^9, {3.573558879741042*^9, 
   3.5735588938278418`*^9}, 3.57373560640625*^9, 3.5737356526875*^9, 
   3.573735690578125*^9, 3.5737370890625*^9, 3.573737229796875*^9, 
   3.57373728071875*^9, 3.573737378390625*^9, {3.573737419734375*^9, 
   3.573737448015625*^9}, 3.5737374873125*^9, 3.573737564234375*^9, 
   3.573737746*^9, 3.5737378533125*^9, 3.573738046359375*^9, 
   3.573738105015625*^9, 3.57373817946875*^9, 3.573738219671875*^9, 
   3.573738265484375*^9, 3.573738335734375*^9, 3.573738488609375*^9, 
   3.573738532578125*^9, 3.573738577734375*^9, 3.57373862778125*^9, 
   3.573738668375*^9, 3.573738709203125*^9, 3.573738805125*^9, 
   3.57373885478125*^9, 3.573738918921875*^9, 3.573738994453125*^9, 
   3.57373903771875*^9, 3.573739084296875*^9, 3.573739167703125*^9, {
   3.573739453609375*^9, 3.573736689828125*^9}, 3.573736786078125*^9, 
   3.57373692584375*^9, 3.573737081796875*^9, 3.5738957487906523`*^9, 
   3.5738958801894526`*^9, 3.5738960499068527`*^9, 3.5738962751180525`*^9, 
   3.5738963592800527`*^9, 3.5738969532842526`*^9, 3.5738970154502525`*^9, 
   3.5738970769298525`*^9, 3.5739591691746407`*^9, 3.5739597647766404`*^9, 
   3.5786340227398567`*^9, 3.578634091629457*^9, 3.5786529850914*^9, 
   3.5786532301302*^9, 3.5786535581298*^9, 3.5786545460741997`*^9, 
   3.5786548064538*^9, 3.578717255775797*^9, 3.578717790467797*^9, 
   3.5787180965241966`*^9, 3.578721408535597*^9, 3.578735209038797*^9, 
   3.578746852232997*^9, 3.5787470980753965`*^9, 3.5787471306481967`*^9, 
   3.5787473272081966`*^9, 3.5787474386555967`*^9, 3.578748006965597*^9, 
   3.578748055294397*^9, 3.5788221004037976`*^9, 3.578822284982998*^9, 
   3.5788228525985975`*^9, 3.5788229373533974`*^9, 3.5788231980761976`*^9, 
   3.5788232537993975`*^9, 3.5788233028145976`*^9, 3.5788233407605977`*^9, 
   3.5788233890529976`*^9, 3.5788234523753977`*^9, {3.578906717815007*^9, 
   3.5789067456922073`*^9}, 3.5789077837982073`*^9, 3.578907889503807*^9, 
   3.578908103521207*^9, 3.578908159978607*^9, 3.578908224219407*^9, 
   3.578908272440007*^9, 3.578910246304407*^9, 3.578918858845807*^9, 
   3.578918953647007*^9, 3.5789189901510067`*^9, 3.578919070742607*^9, 
   3.578919122597007*^9, 3.5789191662926073`*^9, 3.578919206883807*^9, 
   3.578919255181407*^9, 3.578919318845007*^9, 3.578919656986807*^9, 
   3.5789886217715993`*^9, 3.578988657807599*^9, 3.578988720457199*^9, 
   3.5789887514387994`*^9, 3.5789888017019997`*^9, 3.5789888422463994`*^9, 
   3.5789889852827997`*^9, 3.579000029601199*^9, 3.5790001230607996`*^9, 
   3.5790001730743995`*^9, 3.5790002672515993`*^9, 3.5790003156583996`*^9, 
   3.579000367436799*^9, 3.579002880728999*^9, 3.5868503842216*^9, 
   3.5868505531071997`*^9, 3.5868508349212*^9, 3.5868620266428003`*^9, 
   3.5868620890271997`*^9, 3.5868622448868*^9, 3.5868623411644*^9, 
   3.5868624375734*^9, 3.586862934219*^9, 3.5868630353694*^9, 
   3.586863295043*^9, 3.58686339231*^9, 3.5868636377855997`*^9, 
   3.5868637528768*^9, 3.5868638358698*^9, 3.5868638842454*^9, 
   3.5868639316538*^9, 3.5868639796082*^9, 3.586864022166*^9, 
   3.5868640623456*^9, 3.586864201014*^9, 3.5868643162044*^9, 
   3.5868643569712*^9, 3.5868644103232*^9, 3.5868644672164*^9, 
   3.5868645258568*^9, 3.5868645710032*^9, 3.5868646773112*^9, 
   3.5868647360452003`*^9, 3.5868647920024*^9, 3.5868649148212*^9, 
   3.5868649707256002`*^9, 3.5868650438272*^9, 3.5868653123666*^9, 
   3.5868653610878*^9, 3.5868654081228*^9, 3.5868655534396*^9, {
   3.5868656191468*^9, 3.5868656486619997`*^9}, 3.5868657086752*^9, 
   3.586865771703*^9, 3.5868658067562*^9, {3.5868658539306*^9, 
   3.5868658791558*^9}, 3.5868664116774*^9, 3.5868665445425997`*^9, 
   3.5868666347262*^9, 3.5868666767692003`*^9, 3.5868667467664003`*^9, 
   3.5908978938399878`*^9, 3.5908979670351877`*^9, 3.5908981934691877`*^9, 
   3.590898233420788*^9, 3.590898343759588*^9, 3.5908987845799875`*^9, 
   3.5908989348089876`*^9, 3.5908989775997877`*^9, 3.5908990234325876`*^9, 
   3.590899060669788*^9, 3.5908990958009877`*^9, 3.590899147889388*^9, 
   3.5908992161861877`*^9, 3.590899253594988*^9, {3.5908993111211877`*^9, 
   3.590899340417988*^9}, 3.590899383442788*^9, 3.5908994484635878`*^9, 
   3.590899528663188*^9, 3.5908995612983875`*^9, 3.5908996321847878`*^9, 
   3.590899700623988*^9, 3.5908997697007875`*^9, 3.5908999954795876`*^9, 
   3.590900082995588*^9, 3.5909001426811876`*^9, 3.590900186610788*^9, 
   3.590900258183588*^9, 3.590900305873788*^9, 3.5909003446397877`*^9, 
   3.590900392250988*^9, 3.590900428130988*^9, 3.590900472076188*^9, 
   3.590900504634388*^9, 3.590900542916788*^9, 3.590900585317588*^9, 
   3.5909006220399876`*^9, 3.5909006641755877`*^9, 3.590900704392388*^9, 
   3.5909007358887877`*^9, 3.5909007682451878`*^9, 3.590900807681988*^9, 
   3.5909008416909876`*^9, 3.5909008824849877`*^9, 3.590900931000988*^9, 
   3.590900991446988*^9, 3.5909010280757875`*^9, 3.5909010597281876`*^9, 
   3.5909011334859877`*^9, 3.590901217508588*^9, 3.5909012544493876`*^9, 
   3.590901288020588*^9, 3.590901326413188*^9, 3.590901430484388*^9, 
   3.590901480529188*^9, 3.590901522649188*^9, 3.590901579167988*^9, 
   3.5909016188075876`*^9, 3.590901673283988*^9, 3.590901716433588*^9, 
   3.5909017697231874`*^9, 3.590901818800788*^9, 3.5909018560379877`*^9, 
   3.590901923757588*^9, 3.5909019584373875`*^9, 3.590902039462188*^9, 
   3.5909020750477877`*^9, 3.590902153968188*^9, {3.590902189879388*^9, 
   3.5909022193321877`*^9}, 3.590902258207388*^9, 3.5909023523377876`*^9, 
   3.590902385768588*^9, 3.590902459995388*^9, 3.5909025153285875`*^9, 
   3.5909025931101875`*^9, {3.590902623186988*^9, 3.590902650362188*^9}, 
   3.590902701296188*^9, 3.590902732744588*^9, 3.590902771760188*^9, 
   3.5909028950625877`*^9, 3.590902925217388*^9, 3.590902956916588*^9, 
   3.5909030185209875`*^9, 3.590903116018388*^9, 3.5909031937063875`*^9, 
   3.590903227433588*^9, 3.590903296323188*^9, 3.5909033463367877`*^9, 
   3.590903474462388*^9, 3.590903517967388*^9, 3.590903553535388*^9, 
   3.5909035881923876`*^9, 3.5909036391523876`*^9, 3.590903690372388*^9, 
   3.5909037377623878`*^9, 3.5909042039013877`*^9, 3.590904278576388*^9, 
   3.590904330352388*^9, 3.590904397483388*^9, 3.5909045195083876`*^9, 
   3.5909048325123878`*^9, 3.5909049829213877`*^9, 3.5909050569113874`*^9, 
   3.5909051467373877`*^9, 3.590905562889388*^9, 3.5909056267183876`*^9, 
   3.590905690905388*^9, 3.590905745431388*^9, 3.590905809538388*^9, 
   3.5909058693543878`*^9, 3.5909059448033876`*^9, 3.5909059958313875`*^9, 
   3.5909060273553877`*^9, 3.590913248208388*^9, 3.590913280985388*^9, 
   3.590913312830388*^9, 3.5909133597443876`*^9, 3.5909134096843877`*^9, 
   3.5909134779823875`*^9, 3.5909135101903877`*^9, 3.590913547418388*^9, 
   3.5909136185933876`*^9, 3.5909136524023876`*^9, 3.590913733564388*^9, 
   3.5909137872443876`*^9, 3.590913838705388*^9, 3.590913889564388*^9, 
   3.590913927255388*^9, 3.590913994926388*^9, 3.590914079563388*^9, 
   3.590914118672388*^9, 3.590914189488388*^9, 3.5909142311043878`*^9, 
   3.590914269481388*^9, 3.590914301235388*^9, 3.5909143462563877`*^9, 
   3.590914391313388*^9, 3.5909145445653877`*^9, 3.590914606702388*^9, 
   3.5909146431473875`*^9, 3.5909146797763877`*^9, 3.590914727693388*^9, 
   3.590914785399388*^9, 3.5909148686043878`*^9, 3.590914935891388*^9, 
   3.590915000497388*^9, 3.5909150565623875`*^9, 3.590915092066388*^9, 
   3.590915153372388*^9, 3.590915218561388*^9, 3.5909152737563877`*^9, 
   3.590915320708388*^9, 3.5909153939613876`*^9, 3.5909154608483877`*^9, 
   3.5909155102843876`*^9, 3.590915568950388*^9, 3.5909156175583878`*^9, 
   3.5909156668283877`*^9, 3.5909157154403877`*^9, 3.5909157795723877`*^9, 
   3.590915847922388*^9, 3.5909159155793877`*^9, 3.590915975689388*^9, 
   3.5909160249943876`*^9, 3.5909160791053877`*^9, 3.5909161285533876`*^9, 
   3.590916172632388*^9, 3.5909162340793877`*^9, 3.5909162728623877`*^9, 
   3.590916309571388*^9, 3.590916364971388*^9, 3.590916406450388*^9, 
   3.5909164465463877`*^9, 3.5909165066733875`*^9, 3.5909165708763876`*^9, 
   3.590916617884388*^9, 3.5909166521773877`*^9, 3.590916759918388*^9, 
   3.5909168121313877`*^9, 3.5909168446073875`*^9, 3.590916937761388*^9, 
   3.5909169910153875`*^9, 3.590917125985388*^9, 3.590917158290388*^9, 
   3.5909800696613607`*^9, 3.590980106009361*^9, 3.590980176770961*^9, 
   3.590980247282961*^9, 3.5909802936929607`*^9, 3.5909803736429605`*^9, 
   3.590980434227761*^9, 3.590980525069561*^9, 3.5909805675951605`*^9, 
   3.590980617594161*^9, 3.590980678544361*^9, 3.590980990288761*^9, 
   3.590981045824761*^9, {3.590981107757761*^9, 3.5909811373353605`*^9}, 
   3.5909811977863607`*^9, 3.590981289841961*^9, 3.590981382693161*^9, 
   3.590981439211961*^9, 3.590981534793161*^9, 3.590981646443361*^9, 
   3.590981693524161*^9, 3.590981734225561*^9, 3.5909819000289607`*^9, 
   3.5909819455809608`*^9, 3.590982025218961*^9, 3.590982065201761*^9, 
   3.590982133092961*^9, 3.590982184822561*^9, 3.5909822448669605`*^9, {
   3.590982297002161*^9, 3.590982318015361*^9}, 3.590982424329361*^9, 
   3.5909824683269606`*^9, 3.5909825722863607`*^9, 3.5909826043599606`*^9, 
   3.5909827131387606`*^9, 3.590982851417161*^9, 3.590982948621761*^9, 
   3.5909829933157606`*^9, 3.590983070473361*^9, 3.590983334884961*^9, 
   3.5909845299013605`*^9, 3.590984643796961*^9, 3.590985090108961*^9, 
   3.5909852010551605`*^9, 3.5909852500391607`*^9, 3.590985305851961*^9, 
   3.590985384663161*^9, 3.590985446034561*^9, 3.5909855154077606`*^9, 
   3.5909855543297606`*^9, 3.590985598243761*^9, 3.5909856503165607`*^9, 
   3.5909857047293606`*^9, 3.590985740468961*^9, 3.590985790638561*^9, 
   3.5909858280629606`*^9, 3.590986196285361*^9, 3.590986266251361*^9, 
   3.5909863174973607`*^9, 3.590986370334561*^9, 3.590986429536561*^9, 
   3.5909864729835606`*^9, 3.590986590295561*^9, 3.590986692194761*^9, 
   3.590986738152361*^9, 3.5909867763723607`*^9, 3.5909868226731606`*^9, 
   3.590986866572561*^9, 3.590986921843361*^9, 3.590987003353361*^9, 
   3.590987342872761*^9, 3.5909874456611605`*^9, 3.5909875008695607`*^9, 
   3.590988343614561*^9, 3.5909884450159607`*^9, 3.590988517493561*^9, 
   3.590988653168161*^9, 3.590988749186161*^9, 3.590988807779761*^9, 
   3.590988877386961*^9, 3.5909889545923605`*^9, 3.590989038005561*^9, 
   3.590989103137561*^9, 3.590989166816761*^9, 3.590989216611961*^9, 
   3.590989280852761*^9, 3.590989357292761*^9, 3.5909894383191605`*^9, 
   3.590989485431161*^9, 3.590989565522561*^9, 3.5909896482805605`*^9, 
   3.590990311880561*^9, 3.590990473357561*^9, 3.5909905790475607`*^9, 
   3.5909908438887606`*^9, 3.590991119244361*^9, 3.5909911516455607`*^9, 
   3.590991194217961*^9, 3.590991228849961*^9, 3.5909912651843605`*^9, 
   3.590991299660361*^9, 3.591530722168127*^9, 3.591530802806684*^9, 
   3.591531432835046*^9, 3.5915315686663246`*^9, 3.59153164656105*^9, 
   3.591531701879792*^9, 3.5915317601885138`*^9, 3.59153186007436*^9, 
   3.591531947493415*^9, 3.5915320115659695`*^9, 3.591532196576831*^9, 
   3.591532260722431*^9, 3.5915323473859854`*^9, 3.591532426625611*^9, 
   3.5915324978559165`*^9, 3.5915325462710686`*^9, 3.591532959140319*^9, 
   3.591533764090913*^9, 3.591533951544403*^9, 3.591534002343134*^9, 
   3.5915343464437294`*^9, 3.5915352641480484`*^9, 3.5915353468469687`*^9, 
   3.591535413192029*^9, 3.5915354927578683`*^9, 3.591535559370174*^9, 
   3.591535666384248*^9, 3.591535739350704*^9, 3.591535808952059*^9, 
   3.5915359148329945`*^9, 3.5915364261177173`*^9, 3.5915365268235164`*^9, 
   3.59153662054175*^9, 3.5915376053977003`*^9, 3.591537669276122*^9, 
   3.5915378258190823`*^9, 3.5915378797919273`*^9, 3.5915379297791233`*^9, 
   3.591538319515949*^9, 3.5915384115971036`*^9, 3.5915434722342043`*^9, 
   3.591543532710697*^9, 3.5915435845592337`*^9, 3.5915436658019104`*^9, 
   3.5915437001629653`*^9, 3.5915438059983587`*^9, 3.5915438535916543`*^9, 
   3.5915439262336645`*^9, 3.5915440952432194`*^9, 3.5915441435588846`*^9, 
   3.5915442613064156`*^9, 3.591544350013481*^9, 3.591544477814601*^9, 
   3.5915445512504244`*^9, 3.5915446044700737`*^9, 3.5915446516900845`*^9, 
   3.5915451519555845`*^9, 3.591545316042148*^9, 3.591545374040716*^9, 
   3.5919491710120463`*^9, 3.5919498943363175`*^9, 3.5919499471484795`*^9, {
   3.591950534732661*^9, 3.5919505631551795`*^9}, 3.5919505976080837`*^9, 
   3.5919506686388793`*^9, 3.5919507154823294`*^9, 3.5919510951189957`*^9, 
   3.591951158415061*^9, 3.5919511934458623`*^9, 3.5919512317266226`*^9, 
   3.5919512626637263`*^9, 3.5919513130189466`*^9, 3.5919516908656254`*^9, 
   3.591951753800306*^9, {3.5919519956036153`*^9, 3.59195203624294*^9}, 
   3.5919520957254114`*^9, 3.5919523214994364`*^9, 3.591952474775781*^9, 
   3.5919525536482573`*^9, 3.592137050298597*^9, 3.5921370957198906`*^9, 
   3.592137144359893*^9, 3.59213718559374*^9, {3.592137284483099*^9, 
   3.592137310326518*^9}, 3.592137372935092*^9, 3.5921379692599187`*^9, {
   3.592138011588315*^9, 3.5921380227758865`*^9}, 3.5921380559010983`*^9, 
   3.592547374007925*^9, 3.5925488579825497`*^9, {3.5925491068259983`*^9, 
   3.5925491555260267`*^9}, {3.5925493272047358`*^9, 3.5925493553126717`*^9}, 
   3.5925493857798615`*^9, 3.592549417434491*^9, 3.5925495033366585`*^9, 
   3.5933429456968966`*^9, 3.5933430851924324`*^9, 3.5933431706458344`*^9, 
   3.5933453875851173`*^9, 3.5933455554019136`*^9, 3.5933455900590506`*^9, 
   3.593345765110407*^9, 3.5933466392796135`*^9, 3.5933467005979257`*^9, 
   3.593346918332148*^9, 3.593347399080161*^9, 3.5933475207923613`*^9, 
   3.593347701409161*^9, 3.593347827004761*^9, 3.593347889170761*^9, {
   3.5933479925207615`*^9, 3.5933480377783613`*^9}, 3.5933481432207613`*^9, {
   3.5933481749933615`*^9, 3.593348227190961*^9}, 3.5933482953317614`*^9, 
   3.5933483429897614`*^9, 3.5933484376983614`*^9, 3.5933485677867613`*^9, 
   3.5933487951631613`*^9, 3.5934103537209435`*^9, 3.593410438881343*^9, 
   3.593410472702143*^9, 3.593410508878543*^9, 3.5934105527457433`*^9, 
   3.593410592650543*^9, 3.5934106369077435`*^9, 3.593410686524743*^9, 
   3.593410723418743*^9, 3.593410784930543*^9, 3.593411240434943*^9, {
   3.593411292710543*^9, 3.5934113669041433`*^9}, 3.5934114689281435`*^9, 
   3.5934115031233435`*^9, 3.5934115619841433`*^9, 3.593411607186343*^9, 
   3.5934116419743433`*^9, 3.5934117318459435`*^9, 3.5934117715011435`*^9, 
   3.5934118358199434`*^9, 3.593411975845543*^9, {3.593412024158743*^9, 
   3.5934120757791433`*^9}, 3.593412133311943*^9, 3.593412167790943*^9, 
   3.5934122731221433`*^9, 3.5934123283929434`*^9, 3.5934124002777433`*^9, 
   3.593412664171343*^9, 3.593412781982543*^9, 3.593412899715743*^9, 
   3.5934129879181433`*^9, 3.593413057540943*^9, {3.5934131017679434`*^9, 
   3.593413129786543*^9}, 3.5934131924049435`*^9, {3.593413238783743*^9, 
   3.5934132685797434`*^9}, {3.593413336361743*^9, 3.5934133931235433`*^9}, 
   3.593413450602543*^9, {3.5934135041885433`*^9, 3.593413533922143*^9}, 
   3.5934136052609434`*^9, 3.593413707238143*^9, 3.593413814559143*^9, {
   3.593414082439143*^9, 3.5934141027201433`*^9}, 3.593414187694343*^9, {
   3.593414221312343*^9, 3.5934142758655434`*^9}, 3.593414326908743*^9, 
   3.5934143662675433`*^9, 3.5934144462799435`*^9, 3.5934144927679434`*^9, 
   3.593414660077943*^9, 3.593414801954543*^9, 3.593414838988943*^9, 
   3.593415089530943*^9, 3.593415480129743*^9, 3.593415514356143*^9, 
   3.593415573651743*^9, {3.593415658032143*^9, 3.593415682368143*^9}, 
   3.5934157251443434`*^9, 3.5934158710129433`*^9, 3.5934186825624056`*^9, 
   3.5934187920310717`*^9, 3.5934188314529467`*^9, 3.5934188695935717`*^9, 
   3.5934189503123217`*^9, 3.5934189968904467`*^9, 3.5934190842810717`*^9, 
   3.5934191300310717`*^9, {3.5934191873123217`*^9, 3.5934192115623217`*^9}, 
   3.5934192614216967`*^9, 3.5934193194529467`*^9, 3.5934194017966967`*^9, 
   3.5934194474373217`*^9, 3.5934221660765247`*^9, 3.5934222392469945`*^9, 
   3.593422417837658*^9, 3.5934229348501263`*^9, 3.5934230607095013`*^9, 
   3.5934231534282513`*^9, 3.5934255564616866`*^9, 3.5934258398523116`*^9, 
   3.5934259593561*^9, 3.593426033983966*^9, 3.593426163176363*^9, 
   3.593426226036543*^9, {3.59342627074024*^9, 3.593426276380937*^9}, 
   3.593426325740944*^9, 3.5934265718832965`*^9, 3.5934267811489215`*^9, 
   3.5934974105751534`*^9, 3.5934974699802628`*^9, 3.5934976469626474`*^9, 
   3.5934977176014643`*^9, 3.5934977523505745`*^9, {3.5934992268653517`*^9, 
   3.5934992567089105`*^9}, 3.5934997905858335`*^9, 3.593500931544758*^9, 
   3.593501014779359*^9, 3.593501141653547*^9, 3.593501253730954*^9, 
   3.593501939377926*^9, 3.5935030557153263`*^9, 3.593503141373769*^9, {
   3.5935031873436956`*^9, 3.5935032078910966`*^9}, 3.5935046869535437`*^9, 
   3.5935047741097937`*^9, 3.5935048409799466`*^9, {3.5935049461111507`*^9, 
   3.5935049706245794`*^9}, 3.59350504175883*^9, 3.593505083239488*^9, 
   3.5935051678771963`*^9, 3.5935052653897004`*^9, 3.5935059557994995`*^9, 
   3.5935060168459835`*^9, 3.5935060681894045`*^9, 3.5935061395951977`*^9, 
   3.593506175688717*^9, {3.593506920668324*^9, 3.5935069469806557`*^9}, 
   3.593507009636504*^9, 3.593513214694912*^9, 3.593513256866517*^9, {
   3.593513306819322*^9, 3.593513356459629*^9}, 3.593513432771641*^9, 
   3.593513626270403*^9, 3.5935137028636627`*^9, 3.5935137742694554`*^9, 
   3.593513961408883*^9, 3.5935141114547977`*^9, 3.5935142556413746`*^9, 
   3.5935148353720393`*^9, 3.593514885559218*^9, 3.593514981683603*^9, 
   3.593515084261071*^9, 3.593515141026333*^9, 3.593515213275871*^9, 
   3.5935171140449553`*^9, 3.5935173871682076`*^9, 3.5943138889043264`*^9, 
   3.5943139482699456`*^9, 3.5943144437457294`*^9, 3.5943144939772615`*^9, 
   3.5943146068375983`*^9, 3.5943147078130007`*^9, 3.594315007016228*^9, 
   3.5943151491330943`*^9, 3.5943154935009656`*^9, 3.594315524326543*^9, {
   3.5943156085378027`*^9, 3.5943156198943825`*^9}, 3.5943156882139883`*^9, 
   3.594315738375472*^9, 3.59431577805696*^9, 3.5943158177135005`*^9, 
   3.594315902699231*^9, 3.5943159905658817`*^9, 3.594316175704466*^9, 
   3.594316230221857*^9, 3.5943162730814676`*^9, 3.5943163115671573`*^9, 
   3.5943163778894286`*^9, 3.594316502392538*^9, 3.594316586403617*^9, 
   3.5943166363869815`*^9, 3.594316761576548*^9, 3.5943168831807213`*^9, 
   3.5943169583789177`*^9, 3.594317025951025*^9, 3.594317066899358*^9, 
   3.5943171674641542`*^9, 3.594317273115679*^9, 3.5943173646165657`*^9, 
   3.594317447110235*^9, 3.5943175669882565`*^9, 3.5943176420618935`*^9, 
   3.5943177135736294`*^9, 3.594317782532277*^9, 3.594317853959957*^9, 
   3.5943179245090523`*^9, 3.5943179814380517`*^9, 3.5943180625261793`*^9, 
   3.5943180958834457`*^9, 3.5943181943161526`*^9, {3.594318240057685*^9, 
   3.594318293340253*^9}, 3.594318351091803*^9, 3.5943184243026733`*^9, 
   3.5943184812406807`*^9, 3.5943185398978357`*^9, 3.594318634347543*^9, 
   3.594318755192257*^9, 3.5943188276586285`*^9, 3.5943188782524023`*^9, 
   3.594318939947584*^9, 3.5943189839276886`*^9, 3.594319017581151*^9, 
   3.594319053364038*^9, 3.594319259453607*^9, 3.594319338955721*^9, 
   3.594319408856449*^9, 3.594319465745356*^9, 3.594319510448196*^9, 
   3.5943195792231045`*^9, 3.5943197163969154`*^9, 3.5943198748817053`*^9, 
   3.5943199576649666`*^9, 3.594319990777069*^9, 3.5943200448185034`*^9, {
   3.5943202810942554`*^9, 3.5943203002560453`*^9}, 3.594320377681729*^9, 
   3.594320474739517*^9, 3.5943205467075577`*^9, 3.5943206854018035`*^9, 
   3.5943207255996346`*^9, {3.5943207900466547`*^9, 3.5943208130730247`*^9}, 
   3.594320849910615*^9, 3.594320920534758*^9, 3.59432099837572*^9, 
   3.5943211925573406`*^9, 3.594321266433653*^9, {3.5943213096304874`*^9, 
   3.5943213363213043`*^9}, 3.5943213699137287`*^9, 3.594321467752039*^9, 
   3.594321528589649*^9, 3.5943215949419403`*^9, 3.5943216324099517`*^9, 
   3.594321750604849*^9, 3.5943217977553225`*^9, {3.5943218402737045`*^9, 
   3.594321866066922*^9}, 3.5943219357254667`*^9, 3.594322137836412*^9, 
   3.5943221804608645`*^9, 3.59432225382784*^9, 3.5943222978041935`*^9, 
   3.5943223590050488`*^9, {3.5943224045434465`*^9, 3.594322444872367*^9}, 
   3.5943224838526297`*^9, 3.594322537317075*^9, 3.59432261516404*^9, 
   3.5943226849646316`*^9, 3.594322738552404*^9, 3.594322775020746*^9, 
   3.594322834852685*^9, 3.5943228847520013`*^9, 3.59432291975694*^9, 
   3.5943230023510733`*^9, 3.5943230804452024`*^9, 3.5943231295509815`*^9, 
   3.5943232143996186`*^9, 3.594323288102817*^9, 3.594323384062874*^9, 
   3.5943234330765905`*^9, {3.5943234937355566`*^9, 3.594323504958048*^9}, 
   3.594323546071496*^9, 3.594323580862718*^9, 3.594323650308078*^9, 
   3.594323699192704*^9, 3.594323751128374*^9, 3.594323816933302*^9, 
   3.5943238664023237`*^9, 3.594323938866764*^9, 3.5943239734618587`*^9, 
   3.5943240176203346`*^9, 3.594324060082679*^9, 3.594324100378579*^9, 
   3.5943241789960575`*^9, 3.5943242305454664`*^9, 3.5943242844984813`*^9, 
   3.594324362372465*^9, 3.5943679701099253`*^9, 3.5943771715467253`*^9, 
   3.594377263056325*^9, 3.5943774378699255`*^9, 3.594377497166525*^9, 
   3.594377640811325*^9, 3.594377745362525*^9, 3.5943779367121253`*^9, 
   3.594377984089325*^9, 3.5943781703699255`*^9, 3.594378326338725*^9, 
   3.594378372249525*^9, 3.594378439173525*^9, 3.594378639867525*^9, 
   3.5943787040625253`*^9, 3.594378787148125*^9, 3.594378823496125*^9, 
   3.594378927142525*^9, 3.594379038432925*^9, 3.594379206132925*^9, 
   3.594379410401325*^9, 3.594379458496125*^9, 3.5943795396327252`*^9, 
   3.594379804785925*^9, 3.594380272662125*^9, 3.5943803031601253`*^9, 
   3.5943804421717253`*^9, 3.5943815278523254`*^9, 3.594381605743125*^9, 
   3.5943816842111254`*^9, 3.5943818145335255`*^9, 3.5943819329063253`*^9, 
   3.594381980626725*^9, 3.594382133849925*^9, 3.5943822643761253`*^9, 
   3.594383267542725*^9, 3.594383314086525*^9, 3.594383963808525*^9, 
   3.5943840894977255`*^9, 3.594384202254525*^9, 3.5943842873097253`*^9, 
   3.5943844037793255`*^9, 3.594384479939525*^9, 3.594384530588725*^9, 
   3.594384581444725*^9, 3.594384621801925*^9, 3.5943846696159253`*^9, 
   3.594384733124525*^9, {3.594384793153325*^9, 3.594384821007925*^9}, 
   3.5944392124799366`*^9, 3.594439374579537*^9, {3.594441450217137*^9, 
   3.5944414716359367`*^9}, 3.594441542896737*^9, 3.5944419343787365`*^9, 
   3.594442016278737*^9, 3.5944420651847367`*^9, 3.594442166771937*^9, 
   3.594442214102337*^9, 3.5944422689363365`*^9, 3.5944457961435366`*^9, 
   3.594445827827137*^9, 3.594445902192337*^9, 3.5944459466991367`*^9, 
   3.594445982154937*^9, 3.594446061754737*^9, 3.594446129926737*^9, 
   3.594446418613737*^9, 3.5944464959897366`*^9, 3.594446642248337*^9, 
   3.5944477771547365`*^9, 3.594447867745937*^9, 3.594447924763937*^9, 
   3.594447978459137*^9, 3.594448034353937*^9, 3.594448081122737*^9, 
   3.594448113635537*^9, 3.5944481666443367`*^9, 3.594448219356737*^9, 
   3.5944482926611366`*^9, 3.5944483340515366`*^9, 3.5944484026603365`*^9, {
   3.594448434562337*^9, 3.5944484605051365`*^9}, {3.5944484971963367`*^9, 
   3.594448520799137*^9}, 3.594448570048337*^9, 3.594448608205937*^9, 
   3.594448760196737*^9, 3.594448796685137*^9, 3.5944488328771367`*^9, 
   3.5944488949807367`*^9, 3.594448928732537*^9, 3.5944489602601366`*^9, 
   3.594449059959737*^9, 3.594449116026137*^9, 3.5944491571633368`*^9, 
   3.594449197866537*^9, 3.5944492313597364`*^9, 3.594449294071737*^9, {
   3.594449339452137*^9, 3.5944493677349367`*^9}, 3.594449424800737*^9, 
   3.5944494610093365`*^9, 3.5944500786917367`*^9, 3.594450336155137*^9, 
   3.594450373611737*^9, 3.5944505098485365`*^9, 3.5944505538873367`*^9, 
   3.594450598674937*^9, 3.5944507393255367`*^9, 3.594450797842137*^9, {
   3.5944508743465366`*^9, 3.594450903534137*^9}, 3.5944509461231365`*^9, 
   3.594450979335537*^9, 3.5944511876977367`*^9, 3.594451359141737*^9, 
   3.5944513943041368`*^9, 3.5944520553571367`*^9, 3.5944521812657366`*^9, {
   3.5944526587973366`*^9, 3.5944526786717367`*^9}, 3.594452801287737*^9, 
   3.594453037637537*^9, {3.594453092143937*^9, 3.5944531198339367`*^9}, 
   3.5944532026161366`*^9, 3.594720576917103*^9, 3.5947206291259527`*^9, 
   3.594723175944453*^9, 3.5947232674635487`*^9, 3.594723298497259*^9, 
   3.5947233297751427`*^9, 3.5947235822737484`*^9, 3.594723744479022*^9, 
   3.594723982125656*^9, 3.5947241403312626`*^9, 3.5947329258701916`*^9, 
   3.5947329748388743`*^9, 3.594733035387292*^9, 3.5947331217349305`*^9, 
   3.594733200157284*^9, 3.59473328328861*^9, 3.5947333286836834`*^9, 
   3.5947333668141313`*^9, 3.5947336483236494`*^9, 3.594733847062316*^9, 
   3.594733926923623*^9, 3.594733988930011*^9, 3.59473409376399*^9, 
   3.594734156625952*^9, 3.5947343093839207`*^9, 3.5947344140517893`*^9, 
   3.594734504161944*^9, 3.594734590972887*^9, 3.5947346630970316`*^9, 
   3.5947347438629465`*^9, 3.594734950129632*^9, 3.59473507048197*^9, 
   3.594735219050147*^9, 3.594735336968856*^9, 3.5947354984436436`*^9, 
   3.594735550777578*^9, 3.5947356249620996`*^9, 3.594735786305798*^9, 
   3.5947358632981963`*^9, 3.5947360061805687`*^9, 3.594736079166288*^9, 
   3.5947361447060366`*^9, 3.594736190946904*^9, 3.5947364616982665`*^9, 
   3.596107415638265*^9, 3.5963620449413233`*^9, 3.59636304218596*^9, 
   3.5963631098310957`*^9, 3.5963631772058682`*^9, 3.59636415434793*^9, 
   3.596367786116227*^9, 3.663483667308256*^9, 3.6634839333771224`*^9, 
   3.6634840028611975`*^9, 3.6634840472721987`*^9, 3.6634841333265877`*^9, 
   3.6634842292166724`*^9, 3.6634843963791995`*^9, 3.663484465880287*^9, 
   3.6634845067855864`*^9, 3.663484616666419*^9, 3.663484682226736*^9, 
   3.6634847965029516`*^9, 3.663484896108031*^9, 3.6634849507978315`*^9, 
   3.6634850188476925`*^9, 3.663485224147459*^9, 3.6634853881921835`*^9, 
   3.663485442404028*^9, 3.663485583273589*^9, 3.6634856571991224`*^9, 
   3.663485744074128*^9, 3.663485809888381*^9, 3.6634858777702236`*^9, 
   3.6634859460680513`*^9, 3.6634860131756353`*^9, 3.6634863444048557`*^9, 
   3.663486383951779*^9, {3.663486504951899*^9, 3.663486552629198*^9}, 
   3.6634866066699133`*^9, 3.6634866700568204`*^9, 3.6634867896658745`*^9, 
   3.6634868654991226`*^9, 3.66348699371834*^9, 3.663487073459565*^9, 
   3.663487111968465*^9, 3.6634872624186726`*^9, 3.663487344517028*^9, 
   3.663488272672569*^9, 3.6634883084397573`*^9, 3.663488357897848*^9, 
   3.6634884065349307`*^9, 3.6634884441251774`*^9, 3.6634884928407803`*^9, 
   3.6634885796889915`*^9, 3.6634886207023535`*^9, 3.663488672972094*^9, 
   3.6634891155499616`*^9, {3.663489261201371*^9, 3.6634892873306203`*^9}, 
   3.66348934730544*^9, 3.6634900176429815`*^9, 3.6634900671144605`*^9, 
   3.6634901489340363`*^9, 3.663490243770375*^9, 3.6634906002705135`*^9, 
   3.663490631977353*^9, 3.663490706727461*^9, 3.663569853203805*^9, 
   3.663569915938659*^9, 3.6635700146337957`*^9, 3.663570075724137*^9, 
   3.6635701312424736`*^9, 3.663570171251481*^9, 3.6635702790108805`*^9, 
   3.663570490690403*^9, 3.663570564748554*^9, 3.663570620065829*^9, 
   3.66357065909828*^9, 3.663570732646383*^9, 3.6635709861008587`*^9, 
   3.6635711580274477`*^9, 3.663572061382934*^9, 3.6635723184032702`*^9, 
   3.6635901047359886`*^9, 3.663590225320505*^9, 3.663590313062462*^9, 
   3.663590374795785*^9, 3.66359047352488*^9, 3.663590551122573*^9, 
   3.66359071158994*^9, 3.6635911541699286`*^9, 3.6635916011821165`*^9, 
   3.663591635870954*^9, 3.6635917827520075`*^9, 3.6635919239890237`*^9, 
   3.663591968570053*^9, 3.6635925028889*^9, 3.663592616033293*^9, 
   3.6635928342388372`*^9, 3.663592952234336*^9, 3.6635930453843365`*^9, {
   3.6635931146418715`*^9, 3.6635931289342823`*^9}, 3.6635932211502705`*^9, 
   3.663593329594575*^9, 3.663593373214583*^9, 3.6635934554833565`*^9, 
   3.6635935746748476`*^9, 3.663593932486735*^9, 3.6635940124993114`*^9, 
   3.6635941007403584`*^9, 3.663594137287449*^9, 3.6635942242984257`*^9, 
   3.663594364314434*^9, 3.6635946354999447`*^9, 3.6635946886479845`*^9, 
   3.663594746805311*^9, 3.663594860498814*^9, 3.6635949833108387`*^9, 
   3.6639281759952602`*^9, 3.6639330755408916`*^9, 3.663933702676119*^9, 
   3.663933941457776*^9, 3.663934503750296*^9, 3.663935205577631*^9, 
   3.6639352783716288`*^9, 3.6639353710554867`*^9, 3.6639354622657175`*^9, 
   3.6639358816508036`*^9, 3.66393598564357*^9, 3.663936023949693*^9, 
   3.6639361110267706`*^9, 3.663936229695649*^9, 3.6639363496645317`*^9, 
   3.663936910637635*^9, 3.6639370396834197`*^9, 3.663937111573406*^9, 
   3.663937170603862*^9, 3.66393730132475*^9, 3.6639374485692363`*^9, 
   3.663937845102101*^9, 3.6639379040856085`*^9, 3.663937947214423*^9, 
   3.663938049737675*^9, 3.6639380961646266`*^9, 3.66393822203699*^9, 
   3.66393829073995*^9, 3.6639383385321903`*^9, 3.663938383112633*^9, 
   3.6639384193825417`*^9, 3.6639385223436627`*^9, 3.663938622384822*^9, 
   3.663938735385232*^9, 3.66393878529792*^9, 3.6639388509029636`*^9, 
   3.6639390623306704`*^9, 3.6639391224981527`*^9, 3.663939208364664*^9, 
   3.6639393290051203`*^9, 3.6639393610315413`*^9, 3.6639394280727854`*^9, 
   3.6639394834515905`*^9, 3.663939550164381*^9, 3.663939596965831*^9, 
   3.663939628215681*^9, 3.6639396587550335`*^9, 3.663939726973851*^9, 
   3.663939780195086*^9, 3.663939815783106*^9, 3.6639398795062814`*^9, 
   3.663939921600613*^9, 3.663939974642967*^9, 3.663940045999402*^9, 
   3.6639401404883003`*^9, 3.6639401981141768`*^9, 3.6639402385654182`*^9, 
   3.6639402844573803`*^9, 3.66394034309431*^9, 3.6639404272087765`*^9, 
   3.6639405146698713`*^9, {3.6639406132314324`*^9, 3.663940641372155*^9}, 
   3.663940712192587*^9, 3.6639407464200487`*^9, 3.6639407810115056`*^9, 
   3.6639408124913454`*^9, 3.6639408557886534`*^9, 3.6639409105754375`*^9, {
   3.6639409431498413`*^9, 3.6639409699800053`*^9}, 3.6639410061570454`*^9, 
   3.6639410636499014`*^9, 3.663941113162945*^9, 3.6639411516785593`*^9, 
   3.6639412055263186`*^9, 3.6639412491861286`*^9, 3.6639413165304174`*^9, 
   3.6639413700011654`*^9, 3.6639418248323984`*^9, 3.6639418723458905`*^9, {
   3.663942262376652*^9, 3.6639422888298187`*^9}, {3.6639423360759516`*^9, 
   3.663942362614622*^9}, 3.6639423928418546`*^9, 3.663942627395952*^9, 
   3.6639427400470414`*^9, 3.6639430167585464`*^9, 3.6639433672966013`*^9, 
   3.6639437355754404`*^9, 3.663943817909889*^9, 3.663943965439534*^9, 
   3.663944061509082*^9, 3.6639441339366245`*^9, 3.6639441991963415`*^9, 
   3.6639446540977273`*^9, 3.663944712074134*^9, 3.6639447664678817`*^9, 
   3.6639448334696903`*^9, 3.6639448740568852`*^9, 3.663945312530061*^9, 
   3.663945382242972*^9, 3.663945616650603*^9, 3.6639456956348424`*^9, 
   3.663945777911265*^9, 3.66399486310754*^9, 3.6639951309599752`*^9, 
   3.6639952731823034`*^9, 3.663995323181939*^9, 3.66399539675183*^9, 
   3.663995441302168*^9, 3.663995516400416*^9, {3.663995548718852*^9, 
   3.6639955709521756`*^9}, 3.663995613535104*^9, 3.663995667568118*^9, 
   3.6639957201037216`*^9, 3.6639978315509233`*^9, 3.6639978873845577`*^9, 
   3.6639984459746313`*^9, 3.66399863609948*^9, 3.66399872950334*^9, 
   3.664001117966713*^9, 3.664001305312752*^9, 3.6640013930037146`*^9, 
   3.6640015952248545`*^9, 3.6640016414001393`*^9, 3.6640016814490857`*^9, 
   3.664002368359964*^9, 3.6640025393288407`*^9, 3.6640025755630817`*^9, 
   3.6640026992385564`*^9, 3.6640027884167604`*^9, 3.664003350161374*^9, 
   3.664004334890457*^9, 3.6640044019412518`*^9, 3.664004462020154*^9, 
   3.6640045220448475`*^9, 3.664005628433575*^9, 3.664005826697049*^9, 
   3.664007530173299*^9, 3.6640075959782915`*^9, {3.6640077213739386`*^9, 
   3.6640077484676094`*^9}, 3.6640077817476645`*^9, 3.6640078132076054`*^9, 
   3.6640078767715015`*^9, {3.6640079068313656`*^9, 3.6640079332590094`*^9}, {
   3.6640079682057905`*^9, 3.6640079979266596`*^9}, {3.6640080414050055`*^9, 
   3.664008069891922*^9}, 3.6640083588979936`*^9, 3.664008432995333*^9, 
   3.6640084956053596`*^9, {3.6640085374257183`*^9, 3.6640085734124203`*^9}, 
   3.6640086066741476`*^9, 3.6640887845280256`*^9, 3.6640888874303293`*^9, 
   3.6640889971949406`*^9, 3.664089456709052*^9, 3.664089660524967*^9, 
   3.6640896918531284`*^9, 3.6640897702346644`*^9, {3.6640898350406113`*^9, 
   3.664089862846571*^9}, 3.6640899163943853`*^9, 3.6640900635681963`*^9, 
   3.664091607423951*^9, 3.6640916668950405`*^9, 3.6640917086882863`*^9, 
   3.664091771977532*^9, 3.6640918111075306`*^9, 3.664092026899454*^9, 
   3.664092167758684*^9, 3.664092406963847*^9, 3.6640924701911335`*^9, 
   3.6640925251370673`*^9, 3.6640925853181796`*^9, 3.6640926710436325`*^9, 
   3.664092724067383*^9, {3.664092754570984*^9, 3.6640927729059615`*^9}, 
   3.6640932006278286`*^9, 3.664093244958227*^9, 3.6640933549373903`*^9, 
   3.6640934518858633`*^9, 3.6640937074995804`*^9, 3.6640988613120785`*^9, 
   3.664099040629759*^9, 3.6640992932035522`*^9, 3.6640994263406663`*^9, 
   3.664099516854724*^9, 3.664099690816907*^9, 3.6640998886885357`*^9, 
   3.664100076797827*^9, 3.664100199457827*^9, 3.6641005756458163`*^9, 
   3.6641007898376393`*^9, 3.6641008371009445`*^9, 3.664100914502694*^9, 
   3.66410141876435*^9, 3.6641014867743545`*^9, 3.66410176255398*^9, 
   3.664101865748272*^9, 3.6641020061568937`*^9, 3.6641022532576413`*^9, 
   3.664102559055495*^9, 3.6641109135193768`*^9, 3.664112089241815*^9, 
   3.6641764055161257`*^9, 3.66936954904432*^9, 3.669370517609401*^9, 
   3.6693706330124645`*^9, 3.669370852952108*^9, 3.6693756577587357`*^9, 
   3.669375707367856*^9, 3.6693757496807566`*^9, 3.669376053838359*^9, 
   3.6693764968137927`*^9, 3.669376727780978*^9, 3.6693770693087926`*^9, 
   3.6693771995439596`*^9, 3.66946445836581*^9, 3.66946554337438*^9, 
   3.669465598348713*^9, 3.669465827510964*^9, 3.669720115550533*^9, 
   3.6697204120134897`*^9, 3.67013506148997*^9, 3.676630910213694*^9, 
   3.6767897414199677`*^9, 3.6768821091269956`*^9, 3.676887714482156*^9, 
   3.6815408371521807`*^9, 3.681621913747343*^9, 3.681639733207445*^9, 
   3.6840379653306303`*^9, 3.6846610496878433`*^9, 3.6846734328406696`*^9, 
   3.6846735417619*^9, 3.6846736787747364`*^9, 3.6846737659887247`*^9, 
   3.6846738640733347`*^9, 3.7005594347597156`*^9, 3.7005595463210964`*^9, 
   3.736414619582175*^9, 3.736414997636798*^9, 3.736426187445819*^9, 
   3.7364262874365377`*^9, 3.73642645915936*^9, 3.7364265310344706`*^9, 
   3.736426970100584*^9, 3.736427721881583*^9, 3.736427774170574*^9},
 FontSize->10]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. Model with learning", "Section",
 CellChangeTimes->{{3.73641808631546*^9, 3.7364180913227468`*^9}}],

Cell[CellGroupData[{

Cell["\<\
a. Set the parameters of the model\
\>", "Subsection",
 CellChangeTimes->{{3.7364181534022975`*^9, 3.736418158922613*^9}, 
   3.7364186178148603`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"betal", "=", "0.99"}], ";"}], "     ", 
  RowBox[{"(*", " ", 
   RowBox[{"world", " ", "discount", " ", "rate"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"beta", "=", 
    RowBox[{"0.96", "*", "betal"}]}], ";"}], "    ", 
  RowBox[{"(*", " ", 
   RowBox[{"domestic", " ", "discount", " ", "rate"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"chi", "=", 
    RowBox[{"1", "/", "3"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"labor", " ", "disutility", " ", "elasticity"}], " ", "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"delta", "=", " ", "0.025"}], ";"}], "     ", 
  RowBox[{"(*", " ", 
   RowBox[{"capital", " ", "depreciation", " ", "rate"}], "  ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"alpha", "=", " ", "0.33"}], ";"}], "        ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "capital", " ", "share", " ", "in", " ", "the", " ", "production", " ", 
    "function"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gamma", "=", "0.0093"}], ";"}], "    ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "land", " ", "share", " ", "in", " ", "the", " ", "production", " ", 
    "function"}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"rhoRE", "=", 
    RowBox[{"ar1coeff", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], ";"}], "         ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "estimated", " ", "financial", " ", "shock", " ", "persistence", " ", 
    "under", " ", "RE"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"rhotau", "=", "0.0"}], ";"}], "                              ", 
  RowBox[{"(*", " ", 
   RowBox[{"land", "-", 
    RowBox[{"price", " ", "shock", " ", "persistence"}]}], " ", "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"theta", "=", 
    RowBox[{"Exp", "[", 
     RowBox[{
      RowBox[{"ar1coeff", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "/", 
      RowBox[{"(", 
       RowBox[{"1", "-", "rhoRE"}], ")"}]}], "]"}]}], ";"}], "  ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"estimated", " ", "steady"}], "-", 
    RowBox[{"state", " ", "level", " ", "of", " ", "leverage"}]}], " ", 
   "*)"}], " ", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"epsilon", " ", "=", 
    RowBox[{"-", "0.5"}]}], ";"}], "           ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "land", " ", "price", " ", "elasticity", " ", "of", " ", "leverage"}], " ",
    "*)"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rho", "=", "rhoRE"}], ";"}]}], "Input",
 CellChangeTimes->{{3.504007390289319*^9, 3.504007397714932*^9}, {
   3.5040074500062237`*^9, 3.504007455887434*^9}, {3.5040075131083345`*^9, 
   3.5040076036508937`*^9}, {3.504007674085017*^9, 3.5040076883902426`*^9}, {
   3.5040078721429653`*^9, 3.5040079042166214`*^9}, {3.5040080321992464`*^9, 
   3.5040080354128523`*^9}, {3.5040093763756075`*^9, 
   3.5040094079188623`*^9}, {3.5040107656360474`*^9, 
   3.5040108154469347`*^9}, {3.5055631293089504`*^9, 3.505563158714636*^9}, {
   3.5056331310851574`*^9, 3.505633160679097*^9}, 3.505633223132622*^9, {
   3.5056333397114925`*^9, 3.505633363758522*^9}, {3.50573064515106*^9, 
   3.5057306765382595`*^9}, {3.5057307442890596`*^9, 3.50573076280626*^9}, 
   3.50573098061466*^9, {3.5057312705046597`*^9, 3.50573129206386*^9}, {
   3.50573137711506*^9, 3.50573137856586*^9}, {3.50573255449386*^9, 
   3.5057325571458597`*^9}, {3.50573262578586*^9, 3.50573263137066*^9}, {
   3.50573278933626*^9, 3.5057327909274597`*^9}, {3.50573283652626*^9, 
   3.50573284129986*^9}, {3.50573387693106*^9, 3.50573395879986*^9}, {
   3.5060650487194757`*^9, 3.506065103678276*^9}, 3.5060722676924763`*^9, {
   3.5060724653444757`*^9, 3.506072534187276*^9}, {3.506072564544876*^9, 
   3.506072604116076*^9}, {3.506072636548476*^9, 3.506072636720076*^9}, 
   3.5060726753612757`*^9, {3.506072845151676*^9, 3.506072928596076*^9}, {
   3.506073152115676*^9, 3.506073152552476*^9}, {3.506073308614876*^9, 
   3.506073342030076*^9}, {3.506073380343676*^9, 3.506073411793276*^9}, {
   3.506073456159676*^9, 3.506073469731676*^9}, {3.5060735114616756`*^9, 
   3.506073547513276*^9}, {3.5060735828940763`*^9, 3.506073583533676*^9}, {
   3.5060736181344757`*^9, 3.506073653374876*^9}, {3.506073745524076*^9, 
   3.506073784477276*^9}, {3.5060738549736757`*^9, 3.5060738554104757`*^9}, {
   3.5060739359532757`*^9, 3.506074038351676*^9}, {3.506074145679676*^9, 
   3.506074167738076*^9}, {3.5068615523952*^9, 3.5068615843752003`*^9}, {
   3.5068632663828*^9, 3.5068632667572002`*^9}, 3.5068637390316*^9, {
   3.506864144538*^9, 3.5068641766896*^9}, {3.5068642186692*^9, 
   3.5068642440972*^9}, 3.5068643455752*^9, {3.5069370981494737`*^9, 
   3.506937114935074*^9}, 3.5069374640318737`*^9, {3.5069377812434735`*^9, 
   3.5069377818362737`*^9}, 3.5069378741882734`*^9, {3.5069380004390736`*^9, 
   3.5069380009226737`*^9}, 3.5069380974866734`*^9, {3.5069418455042734`*^9, 
   3.5069418461126738`*^9}, {3.5069419707098737`*^9, 
   3.5069419710842733`*^9}, {3.506942096055874*^9, 3.5069420964770737`*^9}, 
   3.5069421774098735`*^9, {3.5069423959190736`*^9, 3.5069423965898733`*^9}, {
   3.5069425000334735`*^9, 3.5069425005014734`*^9}, {3.5069431506470737`*^9, 
   3.5069431768706737`*^9}, {3.506943207992674*^9, 3.5069432089754734`*^9}, {
   3.5069432783954735`*^9, 3.5069433068966737`*^9}, {3.5069433451010733`*^9, 
   3.5069433452726736`*^9}, {3.5069433789686737`*^9, 
   3.5069433801230736`*^9}, {3.5069520669766736`*^9, 3.5069520673042736`*^9}, 
   3.5069522512282734`*^9, 3.5069523113038735`*^9, {3.506952778164674*^9, 
   3.5069528297070737`*^9}, {3.5069528610786734`*^9, 
   3.5069529174726734`*^9}, {3.5069530577010736`*^9, 
   3.5069530581690736`*^9}, {3.5069531124570737`*^9, 3.506953130693474*^9}, {
   3.507006452780294*^9, 3.507006453107894*^9}, {3.507006731614694*^9, 
   3.507006732145094*^9}, {3.507007044940694*^9, 3.507007045455494*^9}, {
   3.507007259846294*^9, 3.507007265259494*^9}, {3.5070073628686943`*^9, 
   3.507007365208694*^9}, {3.507007470571094*^9, 3.507007476748694*^9}, {
   3.507007596853094*^9, 3.507007598849894*^9}, 3.507008788749894*^9, 
   3.5070098650814943`*^9, {3.507017393439694*^9, 3.507017396606494*^9}, {
   3.507017443624894*^9, 3.507017446167694*^9}, {3.507019203675494*^9, 
   3.507019228557494*^9}, 3.507020041631094*^9, {3.507020123546694*^9, 
   3.507020125075494*^9}, {3.507020201322294*^9, 3.507020204270694*^9}, {
   3.507021380415094*^9, 3.507021382411894*^9}, {3.507021604032694*^9, 
   3.507021605499094*^9}, 3.507021739481494*^9, {3.507021853579894*^9, 
   3.507021863314294*^9}, {3.507021931579894*^9, 3.507021935058694*^9}, {
   3.5070399723876*^9, 3.5070399784248*^9}, {3.50765538096875*^9, 
   3.50765539396875*^9}, {3.507655471265625*^9, 3.507655513109375*^9}, {
   3.50765554459375*^9, 3.507655546265625*^9}, {3.5076556545*^9, 
   3.507655657296875*^9}, {3.507655695046875*^9, 3.507655695875*^9}, {
   3.50765576446875*^9, 3.50765576609375*^9}, {3.507655821203125*^9, 
   3.50765582353125*^9}, {3.507655878109375*^9, 3.507655879546875*^9}, {
   3.50765594934375*^9, 3.507655960875*^9}, {3.50765601709375*^9, 
   3.50765601959375*^9}, {3.507656075859375*^9, 3.507656121484375*^9}, {
   3.507656210671875*^9, 3.50765621171875*^9}, {3.5076562586875*^9, 
   3.50765629278125*^9}, {3.507656353171875*^9, 3.507656357046875*^9}, {
   3.515466995109375*^9, 3.515467030046875*^9}, {3.515467113328125*^9, 
   3.515467116234375*^9}, {3.515467219484375*^9, 3.515467221765625*^9}, {
   3.515467298265625*^9, 3.515467302796875*^9}, {3.51546738928125*^9, 
   3.51546739259375*^9}, {3.5154679925625*^9, 3.51546801503125*^9}, {
   3.515468216328125*^9, 3.51546821678125*^9}, {3.5154683084375*^9, 
   3.51546831815625*^9}, {3.515468463390625*^9, 3.51546849809375*^9}, {
   3.51546884590625*^9, 3.51546886059375*^9}, {3.51546898371875*^9, 
   3.515468989015625*^9}, {3.515469054609375*^9, 3.5154690550625*^9}, {
   3.515469127046875*^9, 3.515469136484375*^9}, {3.5154692203125*^9, 
   3.5154692213125*^9}, {3.51546927471875*^9, 3.51546928378125*^9}, {
   3.51546932684375*^9, 3.515469333484375*^9}, {3.515469385171875*^9, 
   3.515469385796875*^9}, {3.515469425515625*^9, 3.51546942590625*^9}, {
   3.51546948021875*^9, 3.51546948459375*^9}, {3.51546954509375*^9, 
   3.515469545296875*^9}, 3.515469583703125*^9, {3.515469644234375*^9, 
   3.515469652109375*^9}, 3.5154697133125*^9, 3.515469858875*^9, {
   3.51546989825*^9, 3.515469898625*^9}, 3.515469942421875*^9, {
   3.515469981765625*^9, 3.515469991890625*^9}, {3.515470035875*^9, 
   3.515470036171875*^9}, {3.515470074453125*^9, 3.51547009965625*^9}, {
   3.51547013103125*^9, 3.5154701608125*^9}, {3.515470233265625*^9, 
   3.515470266328125*^9}, {3.515470341578125*^9, 3.5154703493125*^9}, 
   3.515470382921875*^9, {3.515470420328125*^9, 3.515470449421875*^9}, {
   3.515470482734375*^9, 3.515470486203125*^9}, {3.515470557515625*^9, 
   3.515470582140625*^9}, {3.51547829321875*^9, 3.515478294875*^9}, {
   3.515478548171875*^9, 3.51547854846875*^9}, {3.515478685765625*^9, 
   3.515478712328125*^9}, {3.51547923953125*^9, 3.5154792421875*^9}, {
   3.5154792929375*^9, 3.5154792970625*^9}, {3.515479339625*^9, 
   3.51547934240625*^9}, {3.515479385625*^9, 3.5154793880625*^9}, {
   3.515479429265625*^9, 3.5154794351875*^9}, {3.515479488703125*^9, 
   3.51547949328125*^9}, {3.51547953971875*^9, 3.515479543109375*^9}, {
   3.515480708875*^9, 3.515480709015625*^9}, {3.515480868859375*^9, 
   3.515480869703125*^9}, {3.51548966315625*^9, 3.515489665296875*^9}, 
   3.5154899631875*^9, {3.515490068828125*^9, 3.515490073953125*^9}, {
   3.515490379046875*^9, 3.51549038078125*^9}, {3.515490505453125*^9, 
   3.51549050575*^9}, {3.515494830265625*^9, 3.51549485834375*^9}, {
   3.515495005421875*^9, 3.51549501646875*^9}, {3.515495193640625*^9, 
   3.515495195890625*^9}, {3.515495355015625*^9, 3.515495355390625*^9}, {
   3.51549558353125*^9, 3.51549561465625*^9}, {3.515495812015625*^9, 
   3.5154958143125*^9}, {3.51550406728125*^9, 3.515504070796875*^9}, {
   3.515504197078125*^9, 3.5155041985625*^9}, {3.515504232984375*^9, 
   3.51550423546875*^9}, {3.51550428784375*^9, 3.515504289375*^9}, {
   3.515504339109375*^9, 3.515504380859375*^9}, {3.5155044371875*^9, 
   3.51550443746875*^9}, {3.51550449278125*^9, 3.515504494*^9}, {
   3.51550453578125*^9, 3.515504536140625*^9}, {3.5155055084375*^9, 
   3.51550551353125*^9}, {3.515505559015625*^9, 3.51550556359375*^9}, {
   3.515505608328125*^9, 3.5155056148125*^9}, {3.515505675875*^9, 
   3.515505680421875*^9}, {3.51550572603125*^9, 3.515505726578125*^9}, 
   3.515505757125*^9, {3.515505787765625*^9, 3.51550578825*^9}, {
   3.5155058274375*^9, 3.515505906453125*^9}, {3.51550599775*^9, 
   3.51550599846875*^9}, {3.5155060308125*^9, 3.51550605921875*^9}, {
   3.515506089359375*^9, 3.515506090453125*^9}, 3.515506120625*^9, 
   3.51550615465625*^9, 3.51550623046875*^9, 3.515506276796875*^9, 
   3.515506347828125*^9, {3.515506378578125*^9, 3.515506379265625*^9}, 
   3.5155064108125*^9, {3.51550644575*^9, 3.51550647540625*^9}, {
   3.5155065223125*^9, 3.515506522390625*^9}, {3.515506553453125*^9, 
   3.51550655575*^9}, {3.51550659903125*^9, 3.51550662759375*^9}, {
   3.515506675453125*^9, 3.515506677484375*^9}, {3.5155067583125*^9, 
   3.515506782921875*^9}, {3.515506826859375*^9, 3.515506829390625*^9}, {
   3.51550686621875*^9, 3.5155068755*^9}, {3.5155069068125*^9, 
   3.515506907078125*^9}, {3.5155069570625*^9, 3.515506984*^9}, {
   3.515508246890625*^9, 3.51550824725*^9}, {3.51550828165625*^9, 
   3.515508282984375*^9}, 3.515508336453125*^9, {3.5155083724375*^9, 
   3.5155083744375*^9}, {3.51550840503125*^9, 3.51550845565625*^9}, {
   3.5155084889375*^9, 3.5155084905625*^9}, {3.515508528671875*^9, 
   3.515508533359375*^9}, 3.515508570140625*^9, 3.515508605734375*^9, {
   3.51550864478125*^9, 3.51550864525*^9}, {3.515508709015625*^9, 
   3.51550870934375*^9}, 3.51550902284375*^9, {3.515509239171875*^9, 
   3.515509262984375*^9}, {3.51550931225*^9, 3.51550931353125*^9}, {
   3.515509348578125*^9, 3.515509349890625*^9}, {3.51550937990625*^9, 
   3.51550940590625*^9}, {3.5155094380625*^9, 3.51550943815625*^9}, {
   3.51550949309375*^9, 3.515509495875*^9}, {3.5155095274375*^9, 
   3.51550952771875*^9}, {3.5235996364375*^9, 3.523599643109375*^9}, {
   3.523599740578125*^9, 3.5235997420625*^9}, {3.523599798234375*^9, 
   3.5235998550625*^9}, {3.523599978328125*^9, 3.523599978484375*^9}, {
   3.523600020171875*^9, 3.523600045703125*^9}, {3.523600076171875*^9, 
   3.523600077078125*^9}, {3.523600109390625*^9, 3.523600120453125*^9}, {
   3.523600157734375*^9, 3.523600184046875*^9}, {3.523600227140625*^9, 
   3.523600228046875*^9}, {3.52360026615625*^9, 3.5236002678125*^9}, 
   3.52360031265625*^9, {3.523600348546875*^9, 3.523600447671875*^9}, {
   3.52360047959375*^9, 3.523600480015625*^9}, {3.5236005264375*^9, 
   3.523600526734375*^9}, {3.52360055678125*^9, 3.52360055765625*^9}, {
   3.523600589515625*^9, 3.5236006440625*^9}, {3.5236007015*^9, 
   3.523600750890625*^9}, {3.52360079053125*^9, 3.523600807515625*^9}, {
   3.5236008454375*^9, 3.523600845578125*^9}, {3.5236008875625*^9, 
   3.52360089996875*^9}, {3.5236010915625*^9, 3.52360112303125*^9}, {
   3.52360140309375*^9, 3.523601417453125*^9}, {3.523601450171875*^9, 
   3.52360145165625*^9}, {3.523601497453125*^9, 3.5236015130625*^9}, {
   3.52360154375*^9, 3.523601543859375*^9}, {3.5236015775*^9, 
   3.523601582796875*^9}, {3.523601877953125*^9, 3.523601880265625*^9}, {
   3.523602115921875*^9, 3.52360215915625*^9}, {3.523602200921875*^9, 
   3.523602218015625*^9}, {3.523602309421875*^9, 3.523602354140625*^9}, {
   3.5236023955625*^9, 3.52360240609375*^9}, {3.523607953453125*^9, 
   3.523607974640625*^9}, {3.523609316140625*^9, 3.52360935146875*^9}, {
   3.523609416734375*^9, 3.523609439046875*^9}, {3.523609765359375*^9, 
   3.523609825*^9}, {3.52361140596875*^9, 3.523611477625*^9}, {
   3.523611516046875*^9, 3.523611518625*^9}, {3.523611565625*^9, 
   3.523611573203125*^9}, {3.523611604734375*^9, 3.523611605953125*^9}, 
   3.523611642296875*^9, {3.523611672453125*^9, 3.523611697140625*^9}, {
   3.523611743390625*^9, 3.523611745609375*^9}, {3.523611796625*^9, 
   3.52361184540625*^9}, {3.523611881546875*^9, 3.523611921203125*^9}, {
   3.523611958390625*^9, 3.52361198203125*^9}, {3.5236120374375*^9, 
   3.523612088265625*^9}, {3.523612120453125*^9, 3.523612121515625*^9}, {
   3.52361220615625*^9, 3.523612206234375*^9}, {3.5236122395625*^9, 
   3.52361232725*^9}, {3.5236123671875*^9, 3.523612387046875*^9}, {
   3.523612419921875*^9, 3.52361245784375*^9}, {3.5236124935*^9, 
   3.5236126214375*^9}, {3.523612660421875*^9, 3.523612687640625*^9}, {
   3.5236127235*^9, 3.523612797796875*^9}, {3.523612882984375*^9, 
   3.523612974390625*^9}, {3.52361304640625*^9, 3.523613085625*^9}, {
   3.5236131474375*^9, 3.523613160734375*^9}, {3.52361500115625*^9, 
   3.523615055796875*^9}, {3.5236150906875*^9, 3.523615091078125*^9}, {
   3.523615241921875*^9, 3.52361524234375*^9}, {3.523615279265625*^9, 
   3.52361536153125*^9}, {3.523615428359375*^9, 3.523615607796875*^9}, {
   3.523615695046875*^9, 3.523615719234375*^9}, {3.52361577165625*^9, 
   3.52361586325*^9}, {3.523615897046875*^9, 3.523616151890625*^9}, {
   3.5236162418125*^9, 3.523616280421875*^9}, {3.523616315875*^9, 
   3.52361631646875*^9}, {3.52361636865625*^9, 3.52361639071875*^9}, {
   3.523616939078125*^9, 3.5236169394375*^9}, {3.523616983765625*^9, 
   3.52361698428125*^9}, {3.523617036625*^9, 3.523617036953125*^9}, {
   3.523617076703125*^9, 3.523617076765625*^9}, {3.5236171339375*^9, 
   3.52361716115625*^9}, {3.52361720165625*^9, 3.523617214375*^9}, {
   3.5236173329375*^9, 3.52361735521875*^9}, {3.5236173869375*^9, 
   3.52361738728125*^9}, {3.52361742834375*^9, 3.52361745609375*^9}, {
   3.523617628921875*^9, 3.523617667671875*^9}, {3.52361770209375*^9, 
   3.52361773359375*^9}, {3.523617773890625*^9, 3.523617774015625*^9}, {
   3.523617828171875*^9, 3.5236178591875*^9}, {3.523617902109375*^9, 
   3.52361796978125*^9}, {3.523618005109375*^9, 3.523618005640625*^9}, {
   3.523618626390625*^9, 3.52361862934375*^9}, {3.523618679765625*^9, 
   3.5236186803125*^9}, {3.52361873025*^9, 3.523618730734375*^9}, {
   3.523618888421875*^9, 3.523618977765625*^9}, {3.523624952953125*^9, 
   3.52362495446875*^9}, {3.523624986921875*^9, 3.523625010265625*^9}, {
   3.52362505184375*^9, 3.523625052984375*^9}, {3.523638680953125*^9, 
   3.523638681734375*^9}, {3.523639637640625*^9, 3.52363964384375*^9}, {
   3.5236399041875*^9, 3.52363990628125*^9}, {3.5236399485*^9, 
   3.5236399715*^9}, {3.5236400199375*^9, 3.523640020125*^9}, {
   3.523640071421875*^9, 3.5236401036875*^9}, {3.523640373015625*^9, 
   3.5236403731875*^9}, {3.523640808375*^9, 3.523640841515625*^9}, {
   3.523640891546875*^9, 3.52364089165625*^9}, {3.523641488265625*^9, 
   3.523641498234375*^9}, {3.52364154396875*^9, 3.523641545953125*^9}, {
   3.526105727046875*^9, 3.5261057276875*^9}, {3.526105905*^9, 
   3.526105909359375*^9}, {3.526105961734375*^9, 3.526105962125*^9}, {
   3.526105999375*^9, 3.526106000421875*^9}, {3.526106159046875*^9, 
   3.526106161984375*^9}, 3.52610619640625*^9, {3.52610623296875*^9, 
   3.5261062548125*^9}, {3.52610631646875*^9, 3.526106318390625*^9}, {
   3.526106359359375*^9, 3.5261063596875*^9}, {3.526106392109375*^9, 
   3.526106392734375*^9}, {3.526106455203125*^9, 3.526106537734375*^9}, {
   3.526106583703125*^9, 3.526106584171875*^9}, {3.526106636015625*^9, 
   3.5261066993125*^9}, {3.526106733359375*^9, 3.52610677278125*^9}, {
   3.52610680290625*^9, 3.52610680446875*^9}, {3.526106838359375*^9, 
   3.5261068673125*^9}, {3.526107042375*^9, 3.5261070685625*^9}, {
   3.526107108890625*^9, 3.52610713584375*^9}, {3.52700946571875*^9, 
   3.527009473890625*^9}, {3.527009662828125*^9, 3.5270096673125*^9}, 
   3.527009890765625*^9, {3.527010069578125*^9, 3.52701011625*^9}, 
   3.527010242046875*^9, {3.52701031790625*^9, 3.5270103210625*^9}, {
   3.527010427109375*^9, 3.527010435265625*^9}, {3.527010507140625*^9, 
   3.527010509265625*^9}, {3.527010582875*^9, 3.52701058584375*^9}, 
   3.5270106495625*^9, {3.52701069790625*^9, 3.527010699453125*^9}, {
   3.5270108014375*^9, 3.52701080984375*^9}, {3.527010879265625*^9, 
   3.527010880234375*^9}, {3.527010929671875*^9, 3.527010939140625*^9}, {
   3.527011104765625*^9, 3.527011108390625*^9}, 3.527060750765625*^9, 
   3.527060805890625*^9, {3.527060887859375*^9, 3.52706088834375*^9}, 
   3.527060919859375*^9, {3.527060963390625*^9, 3.52706098628125*^9}, 
   3.527061028140625*^9, {3.52706947759375*^9, 3.527069498078125*^9}, {
   3.52706967325*^9, 3.527069673640625*^9}, {3.527069712609375*^9, 
   3.527069722890625*^9}, {3.52706978253125*^9, 3.52706978390625*^9}, {
   3.527069845015625*^9, 3.52706984696875*^9}, {3.5270699631875*^9, 
   3.5270699644375*^9}, {3.527070031515625*^9, 3.5270700319375*^9}, 
   3.52707012415625*^9, {3.527070159*^9, 3.527070159390625*^9}, {
   3.527070364765625*^9, 3.52707036721875*^9}, {3.527070401609375*^9, 
   3.527070402546875*^9}, {3.52707046446875*^9, 3.52707046790625*^9}, {
   3.52707050921875*^9, 3.527070514578125*^9}, {3.52707066440625*^9, 
   3.527070664875*^9}, {3.527070909234375*^9, 3.527070912796875*^9}, {
   3.52707096009375*^9, 3.52707097628125*^9}, {3.527071026953125*^9, 
   3.527071029484375*^9}, {3.52707126925*^9, 3.527071288265625*^9}, {
   3.527071336515625*^9, 3.52707133909375*^9}, {3.52707141540625*^9, 
   3.527071459296875*^9}, {3.527071629796875*^9, 3.52707172909375*^9}, {
   3.52709316640625*^9, 3.527093198671875*^9}, {3.527095351984375*^9, 
   3.527095380015625*^9}, {3.52709705640625*^9, 3.52709706375*^9}, {
   3.527097677953125*^9, 3.527097682515625*^9}, 3.527097741125*^9, {
   3.527097797484375*^9, 3.5270977976875*^9}, {3.527098568953125*^9, 
   3.527098589515625*^9}, 3.5270986860625*^9, {3.527098718140625*^9, 
   3.527098741734375*^9}, {3.52709877378125*^9, 3.52709877484375*^9}, {
   3.527099065734375*^9, 3.52709907346875*^9}, {3.527100021703125*^9, 
   3.527100022125*^9}, {3.52710005321875*^9, 3.52710005590625*^9}, {
   3.527100181515625*^9, 3.52710018171875*^9}, {3.527100369109375*^9, 
   3.52710039803125*^9}, {3.527100545828125*^9, 3.52710055753125*^9}, {
   3.527100589015625*^9, 3.527100596109375*^9}, 3.527100633296875*^9, {
   3.527100667671875*^9, 3.5271006700625*^9}, {3.52710072584375*^9, 
   3.52710072653125*^9}, {3.527100796375*^9, 3.5271008324375*^9}, {
   3.52710104234375*^9, 3.5271010429375*^9}, {3.52710131796875*^9, 
   3.5271013395625*^9}, {3.527101400875*^9, 3.527101401828125*^9}, {
   3.527101473421875*^9, 3.527101516828125*^9}, {3.5271016740625*^9, 
   3.527101707890625*^9}, {3.527101783171875*^9, 3.52710184484375*^9}, {
   3.527101879296875*^9, 3.527101881078125*^9}, {3.527101992625*^9, 
   3.527102012640625*^9}, {3.527102091421875*^9, 3.527102094421875*^9}, 
   3.527102181640625*^9, 3.52710222484375*^9, {3.52710234809375*^9, 
   3.52710235903125*^9}, {3.527102398484375*^9, 3.527102401359375*^9}, {
   3.52710249915625*^9, 3.527102509375*^9}, {3.52710256909375*^9, 
   3.52710258853125*^9}, {3.5271026748125*^9, 3.527102699265625*^9}, {
   3.527102748921875*^9, 3.527102752015625*^9}, 3.52710281609375*^9, {
   3.527102849203125*^9, 3.527102899609375*^9}, {3.527102950609375*^9, 
   3.5271029720625*^9}, 3.5271030704375*^9, {3.527103125734375*^9, 
   3.527103125828125*^9}, {3.527103210875*^9, 3.527103290546875*^9}, {
   3.527103347515625*^9, 3.527103348734375*^9}, {3.52710338078125*^9, 
   3.527103381203125*^9}, {3.527103434703125*^9, 3.527103434859375*^9}, 
   3.5271035210625*^9, {3.527103582359375*^9, 3.527103582421875*^9}, {
   3.527103646125*^9, 3.5271036464375*^9}, {3.527103710828125*^9, 
   3.52710371309375*^9}, {3.52710377853125*^9, 3.52710377884375*^9}, {
   3.527104068984375*^9, 3.5271040700625*^9}, {3.527104117703125*^9, 
   3.527104119546875*^9}, 3.527104255375*^9, {3.527104304265625*^9, 
   3.527104304875*^9}, {3.527104443859375*^9, 3.527104475609375*^9}, 
   3.527104509484375*^9, 3.52710457959375*^9, {3.527104639828125*^9, 
   3.527104644046875*^9}, {3.527104682546875*^9, 3.527104683640625*^9}, 
   3.527104727359375*^9, {3.527104795859375*^9, 3.527104798875*^9}, {
   3.527104910328125*^9, 3.527104910671875*^9}, {3.52710495475*^9, 
   3.527104956625*^9}, {3.52710518403125*^9, 3.527105212234375*^9}, {
   3.52710538359375*^9, 3.527105404078125*^9}, 3.52710543528125*^9, 
   3.527105469734375*^9, {3.52710552134375*^9, 3.527105567015625*^9}, {
   3.527105608421875*^9, 3.527105609953125*^9}, {3.527105741578125*^9, 
   3.527105741984375*^9}, 3.5271057776875*^9, {3.52710587453125*^9, 
   3.52710589815625*^9}, 3.527105931546875*^9, 3.527105963578125*^9, {
   3.52710600303125*^9, 3.527106004265625*^9}, {3.5271060408125*^9, 
   3.5271061488125*^9}, {3.52710620334375*^9, 3.52710620384375*^9}, {
   3.52710630478125*^9, 3.5271063220625*^9}, {3.5271063566875*^9, 
   3.52710635746875*^9}, {3.52710677871875*^9, 3.527106796296875*^9}, 
   3.527107011828125*^9, 3.527107069078125*^9, {3.52710711703125*^9, 
   3.527107118171875*^9}, 3.5271071565*^9, {3.5271072478125*^9, 
   3.527107250515625*^9}, {3.5271073178125*^9, 3.527107317984375*^9}, {
   3.5271073856875*^9, 3.527107385796875*^9}, {3.52710744721875*^9, 
   3.52710747778125*^9}, 3.52710752440625*^9, {3.5271076566875*^9, 
   3.527107657578125*^9}, {3.527107862734375*^9, 3.52710786284375*^9}, {
   3.52710820375*^9, 3.527108205328125*^9}, {3.527108258015625*^9, 
   3.5271082799375*^9}, {3.5271083158125*^9, 3.527108338765625*^9}, {
   3.527108801703125*^9, 3.52710884853125*^9}, {3.527108945953125*^9, 
   3.5271089470625*^9}, 3.527108983484375*^9, {3.5271090146875*^9, 
   3.527109054640625*^9}, {3.527109113328125*^9, 3.52710912815625*^9}, {
   3.527109163640625*^9, 3.52710918678125*^9}, {3.527109245*^9, 
   3.527109245109375*^9}, 3.527109292140625*^9, 3.527109359390625*^9, {
   3.527109399421875*^9, 3.527109402234375*^9}, {3.527109464265625*^9, 
   3.5271094659375*^9}, {3.527138027390625*^9, 3.52713803640625*^9}, {
   3.52713806840625*^9, 3.527138068875*^9}, {3.52713822134375*^9, 
   3.527138221578125*^9}, 3.527138383296875*^9, {3.527138569171875*^9, 
   3.5271385824375*^9}, 3.527138612734375*^9, {3.527138650390625*^9, 
   3.527138652390625*^9}, {3.5271387468125*^9, 3.52713875171875*^9}, {
   3.5271388109375*^9, 3.527138811265625*^9}, {3.5271388821875*^9, 
   3.527138883625*^9}, {3.527139007890625*^9, 3.5271390085*^9}, {
   3.52713904728125*^9, 3.5271390973125*^9}, {3.527139135203125*^9, 
   3.527139163640625*^9}, {3.527139290375*^9, 3.527139290640625*^9}, {
   3.527139340734375*^9, 3.527139400453125*^9}, {3.527139490265625*^9, 
   3.527139648109375*^9}, {3.527139679484375*^9, 3.527139704015625*^9}, {
   3.527146549875*^9, 3.527146550328125*^9}, {3.52714659928125*^9, 
   3.527146601390625*^9}, {3.527146647046875*^9, 3.527146672765625*^9}, {
   3.52714672578125*^9, 3.527146811359375*^9}, {3.527146866125*^9, 
   3.527146900109375*^9}, {3.527146933875*^9, 3.527146934328125*^9}, {
   3.527147016078125*^9, 3.527147016375*^9}, {3.5271470655625*^9, 
   3.52714706884375*^9}, {3.52714825446875*^9, 3.527148272828125*^9}, {
   3.5271483676875*^9, 3.527148368015625*^9}, {3.52714843046875*^9, 
   3.527148433*^9}, {3.527148481828125*^9, 3.5271484876875*^9}, {
   3.527148566984375*^9, 3.527148594125*^9}, {3.527148627*^9, 
   3.52714865425*^9}, {3.52714869690625*^9, 3.527148729796875*^9}, {
   3.527148770796875*^9, 3.52714877171875*^9}, {3.527148821921875*^9, 
   3.52714883390625*^9}, {3.527148867796875*^9, 3.527148868890625*^9}, {
   3.5271489949375*^9, 3.5271490030625*^9}, {3.527149066984375*^9, 
   3.527149067734375*^9}, {3.52714914725*^9, 3.5271491619375*^9}, {
   3.527149236203125*^9, 3.527149258671875*^9}, {3.527149300546875*^9, 
   3.527149301921875*^9}, {3.52714935978125*^9, 3.527149380546875*^9}, {
   3.527149432*^9, 3.52714943340625*^9}, {3.527149470375*^9, 
   3.5271495471875*^9}, {3.52714962278125*^9, 3.527149625734375*^9}, {
   3.527149702375*^9, 3.527149726078125*^9}, {3.527149793453125*^9, 
   3.527149810828125*^9}, 3.52714984296875*^9, {3.52714987615625*^9, 
   3.527149900125*^9}, {3.52714993078125*^9, 3.52714995003125*^9}, {
   3.52714998184375*^9, 3.527149991265625*^9}, {3.527150069359375*^9, 
   3.527150090109375*^9}, {3.52715013109375*^9, 3.527150156359375*^9}, {
   3.527150221*^9, 3.5271502241875*^9}, {3.527150270765625*^9, 
   3.527150305765625*^9}, {3.5271503385*^9, 3.527150341203125*^9}, {
   3.52715038834375*^9, 3.527150388671875*^9}, {3.527150462515625*^9, 
   3.527150462921875*^9}, {3.527150522640625*^9, 3.52715052534375*^9}, {
   3.5271505831875*^9, 3.527150601203125*^9}, {3.527150662171875*^9, 
   3.527150695765625*^9}, {3.52715073809375*^9, 3.527150774890625*^9}, {
   3.527150805390625*^9, 3.52715082825*^9}, {3.527150899390625*^9, 
   3.527150900453125*^9}, {3.527150965984375*^9, 3.52715098209375*^9}, {
   3.527151051703125*^9, 3.527151053359375*^9}, {3.52715109253125*^9, 
   3.527151099796875*^9}, {3.527151151421875*^9, 3.52715123015625*^9}, {
   3.52715133925*^9, 3.527151340890625*^9}, {3.52715137653125*^9, 
   3.5271513774375*^9}, {3.527151485359375*^9, 3.52715160309375*^9}, {
   3.527151659953125*^9, 3.5271517173125*^9}, {3.527151823125*^9, 
   3.527151823828125*^9}, {3.52715185415625*^9, 3.52715190128125*^9}, {
   3.527151933953125*^9, 3.527151934765625*^9}, {3.5271519906875*^9, 
   3.527152028015625*^9}, {3.527152090703125*^9, 3.527152091109375*^9}, {
   3.527152147515625*^9, 3.527152151625*^9}, {3.52715223465625*^9, 
   3.527152240078125*^9}, {3.527152278453125*^9, 3.52715228003125*^9}, {
   3.52715233025*^9, 3.527152335625*^9}, {3.5271523724375*^9, 
   3.527152407859375*^9}, {3.527152474140625*^9, 3.52715251865625*^9}, {
   3.527152549109375*^9, 3.52715255115625*^9}, {3.527152585140625*^9, 
   3.52715264446875*^9}, {3.52715268065625*^9, 3.527152753609375*^9}, {
   3.527152821375*^9, 3.52715282196875*^9}, {3.52715289196875*^9, 
   3.52715289275*^9}, {3.527153031953125*^9, 3.5271530330625*^9}, 
   3.527153066671875*^9, {3.527153100421875*^9, 3.527153101375*^9}, {
   3.527153453453125*^9, 3.527153573046875*^9}, {3.5271536080625*^9, 
   3.527153667921875*^9}, {3.5271537118125*^9, 3.52715374934375*^9}, {
   3.527153820625*^9, 3.527153911984375*^9}, {3.527153945625*^9, 
   3.527153963578125*^9}, {3.52715399896875*^9, 3.527153999921875*^9}, {
   3.527221082505728*^9, 3.5272210940497274`*^9}, {3.527221155638528*^9, 
   3.5272211954185276`*^9}, {3.5272212592693276`*^9, 3.527221260408128*^9}, {
   3.5272213243525276`*^9, 3.5272213261621275`*^9}, {3.527221524213728*^9, 
   3.5272215678469276`*^9}, {3.5272216284997272`*^9, 
   3.5272216292329273`*^9}, {3.5272217312725277`*^9, 
   3.5272217383237276`*^9}, {3.5272217686913276`*^9, 
   3.5272217911397276`*^9}, {3.527221916594928*^9, 3.5272219173593273`*^9}, 
   3.5272222189641275`*^9, {3.527222305793728*^9, 3.5272223059653273`*^9}, {
   3.5272224025917273`*^9, 3.5272224036993275`*^9}, {3.5272224348837276`*^9, 
   3.5272224360069275`*^9}, {3.5272224780021276`*^9, 3.527222507844928*^9}, {
   3.5272229035993276`*^9, 3.5272229048005276`*^9}, {3.5272230262933273`*^9, 
   3.5272230267145276`*^9}, {3.5272232439993277`*^9, 
   3.5272232444205275`*^9}, {3.5272233253221273`*^9, 
   3.5272233259773273`*^9}, {3.5272234918209276`*^9, 3.527223492569728*^9}, {
   3.5272238015735273`*^9, 3.5272238023847275`*^9}, {3.5272239169823275`*^9, 
   3.5272239807707276`*^9}, {3.5272240592541275`*^9, 
   3.5272240784577274`*^9}, {3.527224217968528*^9, 3.5272242180153275`*^9}, {
   3.5272243408497276`*^9, 3.5272243420041275`*^9}, {3.5272245109929276`*^9, 
   3.527224515314128*^9}, {3.5272246307229276`*^9, 3.527224631144128*^9}, {
   3.527224724135728*^9, 3.5272247245413275`*^9}, {3.527225068686928*^9, 
   3.5272250703873277`*^9}, {3.5272255274703274`*^9, 
   3.5272255291551275`*^9}, {3.527226024651128*^9, 3.5272260255715275`*^9}, {
   3.5272265223535275`*^9, 3.5272265238355274`*^9}, {3.5272266782599277`*^9, 
   3.5272266792739277`*^9}, {3.5272269944719276`*^9, 
   3.5272269956419277`*^9}, {3.527236291355528*^9, 3.5272362922447276`*^9}, {
   3.5272370342869277`*^9, 3.5272370364085274`*^9}, {3.527237253638528*^9, 
   3.5272372555417275`*^9}, {3.5272373172085276`*^9, 3.5272373371453276`*^9}, 
   3.5272373746633277`*^9, {3.5272374194509277`*^9, 3.5272374455965276`*^9}, {
   3.5272375703809276`*^9, 3.5272375714261274`*^9}, {3.5272377255385275`*^9, 
   3.5272377552409277`*^9}, {3.5272379894125276`*^9, 
   3.5272380088501277`*^9}, {3.527238101155328*^9, 3.5272381014829273`*^9}, 
   3.5272381440397277`*^9, 3.527238220776128*^9, {3.5273304197907267`*^9, 
   3.5273304206643267`*^9}, {3.527330852533327*^9, 3.527330853937327*^9}, {
   3.5273316380969267`*^9, 3.5273316522617273`*^9}, {3.527331724037327*^9, 
   3.527331724988927*^9}, {3.5273978572723427`*^9, 3.527397858489143*^9}, 
   3.527397990168743*^9, {3.5273981701303425`*^9, 3.5273981722207427`*^9}, 
   3.527398353321143*^9, {3.527398429729943*^9, 3.5273984306191425`*^9}, {
   3.5273984689795427`*^9, 3.527398561908743*^9}, {3.5273987918059425`*^9, 
   3.527399085317543*^9}, {3.527399137983143*^9, 3.5273991705715427`*^9}, {
   3.5273994637891426`*^9, 3.5273994694363427`*^9}, {3.5273998145083427`*^9, 
   3.527399872384343*^9}, {3.527399927811143*^9, 3.527399948247143*^9}, {
   3.527400019991543*^9, 3.5274000915019426`*^9}, {3.5274001293787427`*^9, 
   3.5274001535743427`*^9}, 3.527400184821143*^9, {3.527400221761943*^9, 
   3.5274002296711426`*^9}, {3.527400281166743*^9, 3.5274003009007425`*^9}, {
   3.5274004181191425`*^9, 3.527400466603943*^9}, {3.5274005150419426`*^9, 
   3.527400571264343*^9}, {3.527400724924343*^9, 3.527400726468743*^9}, 
   3.5274007623643427`*^9, {3.527400803407943*^9, 3.527400865932743*^9}, {
   3.5274011649637427`*^9, 3.527401179378143*^9}, {3.527401211498543*^9, 
   3.527401247768543*^9}, {3.5274013058629427`*^9, 3.5274013067209425`*^9}, {
   3.5278274707545214`*^9, 3.5278274777121215`*^9}, {3.52982241545096*^9, 
   3.52982241807176*^9}, {3.5298225869261603`*^9, 3.5298226102949605`*^9}, 
   3.52982267862296*^9, {3.5298227504609604`*^9, 3.5298227514749603`*^9}, 
   3.5298228233753605`*^9, {3.5298309053738003`*^9, 3.529830906185*^9}, {
   3.5298309529538*^9, 3.5298309534686003`*^9}, {3.5298313071362*^9, 
   3.5298313079474*^9}, {3.5298313448414*^9, 3.5298313453094*^9}, {
   3.5298313858382*^9, 3.5298314109386*^9}, {3.5298314425442*^9, 
   3.5298314433554*^9}, {3.5298315346778*^9, 3.529831592039*^9}, {
   3.5298316321934*^9, 3.5298316331918*^9}, {3.529831727369*^9, 
   3.5298317468845997`*^9}, {3.5298322439718*^9, 3.5298322446893997`*^9}, {
   3.5298323541858*^9, 3.5298324050886*^9}, {3.5298324438389997`*^9, 
   3.5298324447906*^9}, {3.5298325455354*^9, 3.5298325767822*^9}, {
   3.5298326550942*^9, 3.529832655843*^9}, {3.5298335275394*^9, 
   3.5298336748190002`*^9}, {3.5298338436266003`*^9, 3.5298338441258*^9}, {
   3.5298340031678*^9, 3.5298340051022*^9}, {3.5298340410914*^9, 
   3.5298340419026003`*^9}, {3.5298340927274*^9, 3.5298341168918*^9}, {
   3.5298341484662*^9, 3.529834148981*^9}, {3.5298342343598003`*^9, 
   3.5298342381194*^9}, {3.5298343487390003`*^9, 3.529834349207*^9}, {
   3.5298345800713997`*^9, 3.5298345839714003`*^9}, {3.5298349969814*^9, 
   3.529834998635*^9}, {3.5298357549793997`*^9, 3.5298357650882*^9}, {
   3.529835798363*^9, 3.5298358013894*^9}, {3.5298374536633997`*^9, 
   3.5298374826482*^9}, 3.529904784281836*^9, {3.529904884636636*^9, 
   3.529904885853436*^9}, {3.529922320773036*^9, 3.529922320991436*^9}, {
   3.5299223564502363`*^9, 3.529922362362636*^9}, {3.529922503698636*^9, 
   3.529922521077036*^9}, {3.5299226439582357`*^9, 3.5299226445822363`*^9}, {
   3.529922731037436*^9, 3.5299227334554358`*^9}, {3.5299238745916357`*^9, 
   3.529923893982436*^9}, {3.529924011590836*^9, 3.529924040856436*^9}, 
   3.529924707881236*^9, {3.529926392555636*^9, 3.529926393413636*^9}, {
   3.529926579506036*^9, 3.529926626586836*^9}, {3.529928851174036*^9, 
   3.529928862156436*^9}, {3.5305147994294405`*^9, 3.53051481555984*^9}, {
   3.5305149485966406`*^9, 3.5305149491894407`*^9}, {3.5305151722382402`*^9, 
   3.53051517375144*^9}, {3.5305152720314407`*^9, 3.5305152727334404`*^9}, 
   3.5305153329026403`*^9, {3.5305153872530403`*^9, 3.5305153922762403`*^9}, {
   3.5305155033014402`*^9, 3.5305155046118402`*^9}, {3.5305155682286406`*^9, 
   3.53051556936744*^9}, {3.53051560727544*^9, 3.5305156077902403`*^9}, {
   3.5305156855250406`*^9, 3.5305156866170406`*^9}, {3.53051572288704*^9, 
   3.5305157529482403`*^9}, {3.5305159150322404`*^9, 3.53051591570304*^9}, 
   3.5305159812230406`*^9, 3.5305160144510403`*^9, {3.53058500028125*^9, 
   3.530585008359375*^9}, {3.530585209546875*^9, 3.530585216984375*^9}, {
   3.53058533896875*^9, 3.530585344328125*^9}, {3.530585440515625*^9, 
   3.530585441234375*^9}, {3.530585554828125*^9, 3.53058555565625*^9}, {
   3.530585630640625*^9, 3.5305856316875*^9}, {3.53058568221875*^9, 
   3.5305856888125*^9}, 3.5305857901875*^9, {3.530585834875*^9, 
   3.530585836125*^9}, {3.53058594371875*^9, 3.530585943953125*^9}, {
   3.530586049359375*^9, 3.530586050140625*^9}, {3.53058619409375*^9, 
   3.530586196421875*^9}, {3.530586282484375*^9, 3.530586286234375*^9}, {
   3.5305863526875*^9, 3.530586352859375*^9}, 3.530586397671875*^9, {
   3.53058644421875*^9, 3.53058647646875*^9}, {3.530586545859375*^9, 
   3.530586551296875*^9}, {3.530586682171875*^9, 3.53058668378125*^9}, {
   3.530586775265625*^9, 3.53058677734375*^9}, {3.530586844953125*^9, 
   3.530586849453125*^9}, {3.5305869201875*^9, 3.530586926328125*^9}, {
   3.530587487*^9, 3.530587490140625*^9}, {3.53058789084375*^9, 
   3.530587892109375*^9}, {3.530587979140625*^9, 3.530587979625*^9}, 
   3.530588031234375*^9, {3.530588083390625*^9, 3.530588110390625*^9}, {
   3.530588552421875*^9, 3.530588555125*^9}, {3.530588904546875*^9, 
   3.53058890759375*^9}, {3.530589786328125*^9, 3.530589787015625*^9}, {
   3.530590578078125*^9, 3.530590578375*^9}, {3.530590635390625*^9, 
   3.530590635734375*^9}, {3.53059070453125*^9, 3.530590706375*^9}, {
   3.53059074775*^9, 3.530590753796875*^9}, {3.530590932296875*^9, 
   3.530590937828125*^9}, {3.53059150684375*^9, 3.53059151196875*^9}, {
   3.530591607*^9, 3.53059160828125*^9}, {3.530600927453125*^9, 
   3.530600954515625*^9}, {3.530601811875*^9, 3.5306018123125*^9}, {
   3.530601961171875*^9, 3.530601962015625*^9}, {3.530602599640625*^9, 
   3.530602600078125*^9}, 3.530602645765625*^9, {3.530603613828125*^9, 
   3.53060361528125*^9}, {3.530614265828125*^9, 3.530614266390625*^9}, {
   3.530617948171875*^9, 3.5306179676875*^9}, {3.5306205450625*^9, 
   3.53062054675*^9}, {3.530620652578125*^9, 3.53062069215625*^9}, {
   3.5306208683125*^9, 3.53062086971875*^9}, {3.53062099484375*^9, 
   3.5306210013125*^9}, {3.5306219528125*^9, 3.530621960015625*^9}, {
   3.5306221865625*^9, 3.53062218996875*^9}, {3.53062229171875*^9, 
   3.53062229271875*^9}, {3.530623355640625*^9, 3.5306233566875*^9}, {
   3.530623491359375*^9, 3.530623493*^9}, {3.530631950265625*^9, 
   3.5306319506875*^9}, {3.530631992234375*^9, 3.530632010109375*^9}, {
   3.5306320858125*^9, 3.530632091421875*^9}, {3.530632494359375*^9, 
   3.5306324975*^9}, {3.530632824734375*^9, 3.5306328255625*^9}, 
   3.5306329378125*^9, {3.53063307409375*^9, 3.530633075046875*^9}, {
   3.530633794625*^9, 3.530633795015625*^9}, {3.530633939453125*^9, 
   3.530633942890625*^9}, {3.530634032625*^9, 3.53063403425*^9}, {
   3.5306358186875*^9, 3.530635839421875*^9}, {3.5306360201875*^9, 
   3.530636021859375*^9}, {3.530636069859375*^9, 3.530636073640625*^9}, {
   3.530636110796875*^9, 3.5306361184375*^9}, {3.5306362439375*^9, 
   3.5306362510625*^9}, {3.530637456765625*^9, 3.53063746265625*^9}, 
   3.530637526515625*^9, {3.530637679921875*^9, 3.5306376800625*^9}, {
   3.530981948890625*^9, 3.53098194928125*^9}, {3.530982559265625*^9, 
   3.530982560859375*^9}, {3.530982593796875*^9, 3.530982641671875*^9}, 
   3.53098271178125*^9, {3.530982932296875*^9, 3.53098293246875*^9}, {
   3.530984578265625*^9, 3.530984584734375*^9}, 3.53098634009375*^9, {
   3.530987144859375*^9, 3.530987146890625*^9}, {3.53098738125*^9, 
   3.530987382625*^9}, {3.530987626046875*^9, 3.5309876265625*^9}, 
   3.530987881375*^9, 3.53098914*^9, {3.530989996125*^9, 
   3.530990054359375*^9}, {3.530990121421875*^9, 3.530990121546875*^9}, {
   3.530990267109375*^9, 3.530990267625*^9}, {3.531035758630763*^9, 
   3.531035760034763*^9}, {3.531035846224763*^9, 3.531035847129563*^9}, {
   3.532082946055738*^9, 3.532082946632938*^9}, {3.532082989252138*^9, 
   3.532083039562138*^9}, {3.532083333653338*^9, 3.532083334464538*^9}, {
   3.5320835076401377`*^9, 3.532083508014538*^9}, {3.5320835690261383`*^9, 
   3.5320835748449383`*^9}, {3.532083608213338*^9, 3.532083636776938*^9}, {
   3.532083710533738*^9, 3.532083711266938*^9}, {3.5320837627157383`*^9, 
   3.532083766615738*^9}, 3.532083941048938*^9, {3.532083987443338*^9, 
   3.5320840122005377`*^9}, {3.532085004176938*^9, 3.532085004816538*^9}, 
   3.532086383803738*^9, {3.532088576994738*^9, 3.532088577852738*^9}, 
   3.532088619676338*^9, {3.532088666554338*^9, 3.532088666850738*^9}, {
   3.532088699735538*^9, 3.532088701155138*^9}, 3.5320895931967382`*^9, 
   3.532089629092338*^9, {3.532150776753553*^9, 3.532150777798753*^9}, {
   3.532150856999953*^9, 3.532150857639553*^9}, {3.532150907278753*^9, 
   3.532150908791953*^9}, 3.532150970474353*^9, {3.532151012173153*^9, 
   3.5321510190527525`*^9}, 3.532151053357153*^9, 3.532151086600753*^9, {
   3.5321512057379527`*^9, 3.5321512064243526`*^9}, 3.532151258575153*^9, 
   3.5321513271059527`*^9, {3.532151423123953*^9, 3.532151423591953*^9}, {
   3.532151553961153*^9, 3.5321515645535526`*^9}, {3.532151626438753*^9, 
   3.5321516274059525`*^9}, {3.532151785043953*^9, 3.532151788616353*^9}, 
   3.532151860501153*^9, 3.5321519328947525`*^9, {3.532152068287153*^9, 
   3.5321520689579525`*^9}, {3.5321521607639527`*^9, 
   3.5321521873463526`*^9}, {3.5321522749847527`*^9, 3.5321522982755527`*^9}, 
   3.532152330161953*^9, {3.532244832301936*^9, 3.532244855982736*^9}, {
   3.532244908913536*^9, 3.532244909646736*^9}, {3.532322429037751*^9, 
   3.532322434419751*^9}, 3.5323224771481514`*^9, 3.5323225166629515`*^9, {
   3.532323352988551*^9, 3.532323353721751*^9}, {3.5323234878349514`*^9, 
   3.532323491875351*^9}, {3.5323235338081512`*^9, 3.532323534307351*^9}, {
   3.5323235763961515`*^9, 3.532323577347751*^9}, {3.532323642945751*^9, 
   3.5323236436945515`*^9}, {3.5323246346845512`*^9, 3.532324635074551*^9}, 
   3.532324671718951*^9, {3.532324745787751*^9, 3.532324746661351*^9}, {
   3.532324789218151*^9, 3.532324789654951*^9}, {3.5323248307453513`*^9, 
   3.532324831166551*^9}, {3.5323251031741514`*^9, 3.532325110069351*^9}, {
   3.532325210948551*^9, 3.5323252116973515`*^9}, {3.532336838265625*^9, 
   3.53233686178125*^9}, {3.532336942359375*^9, 3.532336944140625*^9}, {
   3.53233708409375*^9, 3.532337089875*^9}, {3.53233712628125*^9, 
   3.53233712728125*^9}, {3.5323372915625*^9, 3.532337297875*^9}, {
   3.532337339109375*^9, 3.53233733975*^9}, {3.532337396640625*^9, 
   3.532337396921875*^9}, {3.53233767428125*^9, 3.5323377076875*^9}, {
   3.532337794015625*^9, 3.532337794828125*^9}, {3.532340652140625*^9, 
   3.532340655109375*^9}, {3.532340699953125*^9, 3.532340700953125*^9}, {
   3.532340953984375*^9, 3.53234095409375*^9}, {3.532341003140625*^9, 
   3.53234101525*^9}, {3.532341086421875*^9, 3.532341096203125*^9}, 
   3.532341238578125*^9, {3.53234128103125*^9, 3.53234128190625*^9}, {
   3.532342416171875*^9, 3.53234242334375*^9}, {3.53234446278125*^9, 
   3.532344464546875*^9}, {3.532344544078125*^9, 3.532344546*^9}, {
   3.532344807078125*^9, 3.53234481521875*^9}, {3.532344868953125*^9, 
   3.53234486978125*^9}, {3.53234492371875*^9, 3.53234493065625*^9}, {
   3.5323449923125*^9, 3.532344993171875*^9}, {3.53234505953125*^9, 
   3.53234506375*^9}, {3.532345101125*^9, 3.532345101953125*^9}, {
   3.53234628225*^9, 3.532346295203125*^9}, {3.5323463833125*^9, 
   3.53234638421875*^9}, {3.533120465453125*^9, 3.533120466421875*^9}, {
   3.54512876675*^9, 3.545128767328125*^9}, {3.54512885721875*^9, 
   3.5451288735*^9}, {3.545129007109375*^9, 3.545129007421875*^9}, {
   3.54512904596875*^9, 3.545129059640625*^9}, {3.54512909915625*^9, 
   3.5451291*^9}, {3.5451291474375*^9, 3.545129149640625*^9}, {
   3.5451292249375*^9, 3.5451292301875*^9}, {3.54512928509375*^9, 
   3.545129323484375*^9}, {3.545129354*^9, 3.545129354421875*^9}, {
   3.54512939740625*^9, 3.54512942415625*^9}, {3.54512946009375*^9, 
   3.54512946646875*^9}, {3.54512953271875*^9, 3.545129540046875*^9}, {
   3.54512969115625*^9, 3.545129693328125*^9}, {3.54512979246875*^9, 
   3.545129798046875*^9}, {3.545129852625*^9, 3.54512985471875*^9}, {
   3.545129959484375*^9, 3.545129987796875*^9}, {3.5451300368125*^9, 
   3.545130060484375*^9}, {3.545130145015625*^9, 3.545130145859375*^9}, {
   3.54513021690625*^9, 3.545130220140625*^9}, {3.5451302674375*^9, 
   3.54513026815625*^9}, {3.545130300078125*^9, 3.545130300375*^9}, {
   3.54513033909375*^9, 3.54513033959375*^9}, {3.545130396953125*^9, 
   3.5451303973125*^9}, {3.54513048665625*^9, 3.545130512484375*^9}, {
   3.545130595234375*^9, 3.54513059578125*^9}, {3.545130637890625*^9, 
   3.545130640421875*^9}, {3.545130699546875*^9, 3.54513070078125*^9}, {
   3.545130748484375*^9, 3.54513074890625*^9}, {3.545130787921875*^9, 
   3.5451308220625*^9}, {3.5451308935625*^9, 3.54513089484375*^9}, {
   3.54513092503125*^9, 3.545130927609375*^9}, {3.54513098225*^9, 
   3.545131005578125*^9}, {3.545131035734375*^9, 3.545131110125*^9}, {
   3.545131213265625*^9, 3.545131216234375*^9}, {3.54513127703125*^9, 
   3.54513128559375*^9}, {3.54513133125*^9, 3.545131332859375*^9}, {
   3.545131407296875*^9, 3.545131409078125*^9}, {3.54513145734375*^9, 
   3.54513145875*^9}, {3.5451321284375*^9, 3.5451321390625*^9}, 
   3.54513222396875*^9, {3.5451322611875*^9, 3.545132265375*^9}, 
   3.54513231915625*^9, {3.54513235084375*^9, 3.545132351390625*^9}, {
   3.545132393921875*^9, 3.545132394484375*^9}, {3.545132439625*^9, 
   3.545132508578125*^9}, {3.545132588703125*^9, 3.545132589125*^9}, {
   3.54513267978125*^9, 3.5451326965*^9}, {3.545132737109375*^9, 
   3.545132739484375*^9}, 3.54513277221875*^9, {3.5451330338125*^9, 
   3.54513305965625*^9}, {3.545133113*^9, 3.545133176640625*^9}, 
   3.54513327115625*^9, {3.545133317171875*^9, 3.5451333255625*^9}, {
   3.545133413953125*^9, 3.545133527296875*^9}, {3.545133584515625*^9, 
   3.54513365321875*^9}, 3.5451337083125*^9, {3.545133748703125*^9, 
   3.5451337831875*^9}, {3.545133925546875*^9, 3.54513392759375*^9}, {
   3.545133978765625*^9, 3.54513400121875*^9}, 3.545134039203125*^9, {
   3.545134078*^9, 3.545134106953125*^9}, {3.545134160890625*^9, 
   3.545134176171875*^9}, {3.545134230484375*^9, 3.545134231546875*^9}, {
   3.545134392046875*^9, 3.545134392671875*^9}, {3.545134429484375*^9, 
   3.545134490875*^9}, 3.54513457703125*^9, {3.545134607484375*^9, 
   3.545134632234375*^9}, {3.545134685765625*^9, 3.545134712578125*^9}, {
   3.54513482046875*^9, 3.545134842953125*^9}, {3.54513492146875*^9, 
   3.5451350106875*^9}, {3.545135057875*^9, 3.545135110328125*^9}, {
   3.545135156015625*^9, 3.545135179078125*^9}, {3.54513527353125*^9, 
   3.5451352775*^9}, {3.545135434015625*^9, 3.545135434953125*^9}, {
   3.545135524953125*^9, 3.545135553015625*^9}, {3.545135584640625*^9, 
   3.545135586234375*^9}, {3.54513656290625*^9, 3.5451365816875*^9}, 
   3.54513663365625*^9, {3.54513669071875*^9, 3.545136707734375*^9}, {
   3.545136742984375*^9, 3.54513675184375*^9}, {3.54513681703125*^9, 
   3.545136818640625*^9}, 3.545136882796875*^9, 3.545136913921875*^9, {
   3.54513694828125*^9, 3.545136992734375*^9}, {3.545137055640625*^9, 
   3.545137080625*^9}, {3.545137138875*^9, 3.5451371775*^9}, {
   3.545137210640625*^9, 3.54513723559375*^9}, {3.5451372765*^9, 
   3.545137277734375*^9}, {3.54513731365625*^9, 3.545137342453125*^9}, {
   3.545137372828125*^9, 3.545137400234375*^9}, {3.5451374380625*^9, 
   3.545137442*^9}, {3.5451375428125*^9, 3.545137545265625*^9}, {
   3.545137600390625*^9, 3.545137601125*^9}, {3.545137665171875*^9, 
   3.54513766578125*^9}, {3.545137731890625*^9, 3.5451377325*^9}, {
   3.545137826296875*^9, 3.54513782684375*^9}, {3.5451381059375*^9, 
   3.545138140390625*^9}, {3.545138183140625*^9, 3.54513821121875*^9}, {
   3.545138338*^9, 3.545138340484375*^9}, {3.5451384036875*^9, 
   3.545138404828125*^9}, {3.54513843628125*^9, 3.545138473703125*^9}, {
   3.545138517578125*^9, 3.545138522203125*^9}, {3.545138577234375*^9, 
   3.54513861140625*^9}, {3.5451386838125*^9, 3.545138684734375*^9}, {
   3.545138810109375*^9, 3.545138810625*^9}, {3.545138849890625*^9, 
   3.5451388560625*^9}, {3.545138916828125*^9, 3.54513900615625*^9}, {
   3.545139056671875*^9, 3.545139057515625*^9}, {3.545139092*^9, 
   3.545139092046875*^9}, {3.54513915053125*^9, 3.545139203625*^9}, {
   3.54513926878125*^9, 3.545139322109375*^9}, 3.545139353484375*^9, {
   3.545139402078125*^9, 3.545139430890625*^9}, {3.54513946634375*^9, 
   3.545139497703125*^9}, {3.545139544265625*^9, 3.545139676359375*^9}, {
   3.545139715453125*^9, 3.545139715859375*^9}, {3.545139767046875*^9, 
   3.545139817890625*^9}, {3.5451398959375*^9, 3.54513990203125*^9}, {
   3.54513994896875*^9, 3.545140006578125*^9}, {3.545140041015625*^9, 
   3.54514007659375*^9}, {3.545140106875*^9, 3.545140112640625*^9}, {
   3.545140171578125*^9, 3.54514025753125*^9}, {3.54514031034375*^9, 
   3.545140311046875*^9}, {3.54514034234375*^9, 3.54514034303125*^9}, {
   3.54514918965625*^9, 3.545149196921875*^9}, {3.5451492724375*^9, 
   3.545149273703125*^9}, {3.54514936596875*^9, 3.5451493686875*^9}, {
   3.545149495859375*^9, 3.545149569359375*^9}, {3.54514961653125*^9, 
   3.545149644453125*^9}, {3.545149684546875*^9, 3.5451496856875*^9}, {
   3.545149717171875*^9, 3.545149772203125*^9}, {3.545149836421875*^9, 
   3.545149901671875*^9}, {3.54514994728125*^9, 3.545149998484375*^9}, {
   3.545150038859375*^9, 3.5451501115*^9}, {3.545150173046875*^9, 
   3.545150222640625*^9}, {3.545150505953125*^9, 3.54515050609375*^9}, {
   3.545150569875*^9, 3.545150602796875*^9}, {3.545150858359375*^9, 
   3.54515087721875*^9}, {3.545150925671875*^9, 3.5451509280625*^9}, {
   3.545150980703125*^9, 3.545150996453125*^9}, {3.54515104165625*^9, 
   3.545151043453125*^9}, {3.54515122571875*^9, 3.54515127653125*^9}, {
   3.54515131028125*^9, 3.545151412828125*^9}, {3.545151463984375*^9, 
   3.545151466140625*^9}, {3.545151534390625*^9, 3.545151535515625*^9}, {
   3.54515159784375*^9, 3.54515177665625*^9}, {3.545151819625*^9, 
   3.54515182040625*^9}, {3.545152089859375*^9, 3.54515208996875*^9}, {
   3.54515216778125*^9, 3.545152169390625*^9}, {3.545152199609375*^9, 
   3.545152206765625*^9}, {3.545152267390625*^9, 3.545152289359375*^9}, {
   3.545152403859375*^9, 3.54515243471875*^9}, {3.5451525475625*^9, 
   3.545152602953125*^9}, 3.545152703859375*^9, {3.545152743625*^9, 
   3.5451527653125*^9}, {3.545152820140625*^9, 3.545152843328125*^9}, {
   3.545152903921875*^9, 3.54515290465625*^9}, {3.545300070875*^9, 
   3.545300071859375*^9}, {3.54530010209375*^9, 3.54530010353125*^9}, {
   3.548846632921875*^9, 3.54884668334375*^9}, {3.548846944125*^9, 
   3.548846946015625*^9}, 3.54884698384375*^9, {3.5488470283125*^9, 
   3.548847031*^9}, {3.54884707109375*^9, 3.5488470770625*^9}, 
   3.548847149640625*^9, {3.548847204109375*^9, 3.548847209796875*^9}, {
   3.54884725346875*^9, 3.54884725675*^9}, {3.548847325109375*^9, 
   3.548847326109375*^9}, {3.5488473875625*^9, 3.54884738890625*^9}, {
   3.548847449296875*^9, 3.548847473328125*^9}, {3.548847527828125*^9, 
   3.54884752878125*^9}, {3.54884758371875*^9, 3.548847616234375*^9}, {
   3.548847658109375*^9, 3.54884765959375*^9}, {3.548847692046875*^9, 
   3.548847779890625*^9}, {3.548847858625*^9, 3.548847915984375*^9}, {
   3.548847979625*^9, 3.54884798065625*^9}, {3.5488480995625*^9, 
   3.5488481006875*^9}, {3.54884813515625*^9, 3.548848135984375*^9}, {
   3.549085208734375*^9, 3.549085218796875*^9}, {3.54908546415625*^9, 
   3.549085468734375*^9}, {3.549085500625*^9, 3.549085506234375*^9}, {
   3.549085630875*^9, 3.549085631671875*^9}, {3.549085699984375*^9, 
   3.5490857545*^9}, {3.54908583425*^9, 3.549085834703125*^9}, 
   3.549085870921875*^9, 3.549085910234375*^9, {3.549086076578125*^9, 
   3.5490861005625*^9}, {3.549086229953125*^9, 3.54908624334375*^9}, {
   3.549086336859375*^9, 3.54908633909375*^9}, {3.54908637865625*^9, 
   3.549086387359375*^9}, {3.5490864183125*^9, 3.549086419359375*^9}, {
   3.5490864518125*^9, 3.549086452546875*^9}, {3.54908648890625*^9, 
   3.549086524984375*^9}, {3.54908687125*^9, 3.54908687265625*^9}, {
   3.54908709296875*^9, 3.54908709525*^9}, 3.549087539015625*^9, {
   3.549458725546875*^9, 3.549458736125*^9}, {3.5494588055625*^9, 
   3.5494588079375*^9}, {3.54945884646875*^9, 3.54945885090625*^9}, {
   3.549458881328125*^9, 3.549458883046875*^9}, {3.54945892290625*^9, 
   3.54945892359375*^9}, {3.54980336934375*^9, 3.549803525578125*^9}, {
   3.549803565046875*^9, 3.549803651*^9}, {3.549803686890625*^9, 
   3.5498037155625*^9}, {3.54980377696875*^9, 3.549803777640625*^9}, {
   3.549803820171875*^9, 3.54980382240625*^9}, {3.54980385315625*^9, 
   3.549803853265625*^9}, {3.549805155265625*^9, 3.54980516278125*^9}, {
   3.54980519803125*^9, 3.549805199*^9}, {3.549805319875*^9, 
   3.549805342140625*^9}, {3.549805464296875*^9, 3.54980550571875*^9}, {
   3.54980553765625*^9, 3.549805576609375*^9}, {3.549805685140625*^9, 
   3.54980568590625*^9}, {3.549805800390625*^9, 3.549805800515625*^9}, {
   3.549805936109375*^9, 3.54980593896875*^9}, {3.549805990921875*^9, 
   3.549805996921875*^9}, {3.54980606859375*^9, 3.54980607059375*^9}, {
   3.549806123265625*^9, 3.549806137984375*^9}, {3.549806181046875*^9, 
   3.549806182453125*^9}, {3.54980692328125*^9, 3.549806923921875*^9}, {
   3.549813377703125*^9, 3.54981337996875*^9}, {3.54981344846875*^9, 
   3.549813448859375*^9}, {3.549813500265625*^9, 3.5498135004375*^9}, {
   3.54981397615625*^9, 3.549814001453125*^9}, {3.549814214734375*^9, 
   3.54981422153125*^9}, {3.54981434053125*^9, 3.54981434103125*^9}, {
   3.549814379890625*^9, 3.549814381609375*^9}, {3.5498144398125*^9, 
   3.5498145019375*^9}, {3.549814702453125*^9, 3.5498147056875*^9}, {
   3.549814764953125*^9, 3.549814773078125*^9}, {3.54981487578125*^9, 
   3.54981487740625*^9}, 3.54981496615625*^9, {3.54981500521875*^9, 
   3.549815006484375*^9}, {3.54981505090625*^9, 3.54981505265625*^9}, {
   3.549815108921875*^9, 3.549815136515625*^9}, {3.54981516925*^9, 
   3.549815172875*^9}, {3.549815203578125*^9, 3.549815232703125*^9}, {
   3.549815263484375*^9, 3.549815267296875*^9}, {3.549815303671875*^9, 
   3.54981530434375*^9}, {3.549815912609375*^9, 3.549815935671875*^9}, 
   3.549815966234375*^9, 3.550575554140625*^9, {3.5505756344375*^9, 
   3.55057563596875*^9}, {3.5505782956875*^9, 3.550578345515625*^9}, {
   3.550578540703125*^9, 3.550578662625*^9}, {3.550578752640625*^9, 
   3.55057875571875*^9}, {3.55058220634375*^9, 3.5505822215625*^9}, {
   3.550582252453125*^9, 3.550582306203125*^9}, {3.550582362375*^9, 
   3.550582363484375*^9}, {3.550582414671875*^9, 3.5505824159375*^9}, {
   3.550582456234375*^9, 3.55058245721875*^9}, {3.55058254309375*^9, 
   3.550582623828125*^9}, {3.55058266378125*^9, 3.550582728140625*^9}, {
   3.550582767703125*^9, 3.55058278128125*^9}, {3.55058281615625*^9, 
   3.550582845859375*^9}, {3.550582886234375*^9, 3.5505828905625*^9}, {
   3.55058292328125*^9, 3.550582962578125*^9}, {3.550582998375*^9, 
   3.550582998578125*^9}, {3.550583100359375*^9, 3.55058310121875*^9}, {
   3.550583141734375*^9, 3.550583145125*^9}, {3.5505831786875*^9, 
   3.55058320725*^9}, {3.550583280140625*^9, 3.5505832810625*^9}, {
   3.55058348275*^9, 3.55058348425*^9}, {3.550583532546875*^9, 
   3.550583554359375*^9}, {3.550583634859375*^9, 3.55058363615625*^9}, {
   3.550590809875*^9, 3.5505908305625*^9}, {3.5505908725625*^9, 
   3.550590873453125*^9}, {3.55059092109375*^9, 3.550590949625*^9}, {
   3.55059100659375*^9, 3.550591007515625*^9}, {3.550591045734375*^9, 
   3.550591051296875*^9}, {3.55059111359375*^9, 3.55059111475*^9}, {
   3.55059115278125*^9, 3.550591219796875*^9}, {3.5505912524375*^9, 
   3.55059125328125*^9}, {3.5701719609375*^9, 3.570171990328125*^9}, {
   3.570172033703125*^9, 3.57017203521875*^9}, {3.572155349734375*^9, 
   3.57215536359375*^9}, {3.572155446515625*^9, 3.572155452546875*^9}, {
   3.5721561617505884`*^9, 3.5721561631099634`*^9}, {3.5721562151724634`*^9, 
   3.5721562160943384`*^9}, {3.5721562523912134`*^9, 
   3.5721562560474634`*^9}, {3.5721563497974634`*^9, 
   3.5721563540318384`*^9}, {3.572174605328125*^9, 3.57217461284375*^9}, {
   3.57218194484375*^9, 3.572181947546875*^9}, {3.572182935859375*^9, 
   3.572182937734375*^9}, {3.57219074003125*^9, 3.57219074159375*^9}, {
   3.572191080625*^9, 3.572191083296875*^9}, {3.57219291653125*^9, 
   3.5721929174375*^9}, {3.572335599360083*^9, 3.5723356175340834`*^9}, {
   3.572759780141444*^9, 3.572759785305044*^9}, {3.5727599131878443`*^9, 
   3.572759918959844*^9}, {3.572760008550644*^9, 3.572760010235444*^9}, 
   3.572760049609844*^9, {3.572760084897044*^9, 3.572760091932644*^9}, {
   3.572760140043044*^9, 3.5727601411038437`*^9}, 3.572760714291244*^9, {
   3.572760767877244*^9, 3.572760791199244*^9}, {3.572760822430444*^9, 
   3.572760823210444*^9}, {3.572765684332644*^9, 3.5727657066094437`*^9}, {
   3.5729254264820914`*^9, 3.5729254412240915`*^9}, {3.5729283632754917`*^9, 
   3.5729283652878914`*^9}, {3.5729566713104386`*^9, 
   3.5729566808560305`*^9}, {3.573061214546875*^9, 3.5730612153125*^9}, {
   3.573236045875*^9, 3.57323604709375*^9}, {3.57323632309375*^9, 
   3.573236324296875*^9}, {3.573537538299842*^9, 3.573537571184642*^9}, {
   3.5737356196875*^9, 3.5737356496875*^9}, {3.573735686515625*^9, 
   3.573735686890625*^9}, {3.573735788265625*^9, 3.5737357893125*^9}, {
   3.578634005283457*^9, 3.578634012631057*^9}, {3.578634088384657*^9, 
   3.578634088883857*^9}, {3.5786529792102003`*^9, 3.5786529799122*^9}, {
   3.5786532231726*^9, 3.5786532271506*^9}, {3.5786535503766003`*^9, 
   3.5786535546666*^9}, {3.578722470394397*^9, 3.5787224823595967`*^9}, {
   3.5788227956429977`*^9, 3.5788228239101973`*^9}, {3.578822873502598*^9, 
   3.5788229192105975`*^9}, 3.5788229532341976`*^9, {3.5788230865829973`*^9, 
   3.5788230900773973`*^9}, {3.578823234330598*^9, 3.5788232360933976`*^9}, {
   3.578920004726407*^9, 3.578920017877207*^9}, 3.5868607076284*^9, {
   3.590904978650388*^9, 3.590904979221388*^9}, {3.590905053014388*^9, 
   3.5909050539213877`*^9}, {3.5909051359373875`*^9, 3.590905144893388*^9}, {
   3.590905559768388*^9, 3.5909055603573875`*^9}, {3.5909056783363876`*^9, 
   3.5909056879663877`*^9}, 3.590905743182388*^9, 3.590905806538388*^9, {
   3.590905864919388*^9, 3.590905867606388*^9}, {3.590905937233388*^9, 
   3.5909059377463875`*^9}, {3.590913245281388*^9, 3.5909132456333876`*^9}, 
   3.590913311037388*^9, 3.590913356011388*^9, 3.590913407208388*^9, 
   3.5909138874213877`*^9, {3.5909139233383875`*^9, 3.590913925191388*^9}, {
   3.590913992391388*^9, 3.5909139930743876`*^9}, {3.5909140758903875`*^9, 
   3.590914076625388*^9}, {3.5909141157443876`*^9, 3.5909141168153877`*^9}, {
   3.590914180492388*^9, 3.5909141844873877`*^9}, {3.5909145414633875`*^9, 
   3.5909145418313875`*^9}, 3.590914604451388*^9, {3.590914641153388*^9, 
   3.590914641313388*^9}, {3.5909146748953876`*^9, 3.590914678047388*^9}, 
   3.5909147226853876`*^9, {3.5909148542463875`*^9, 3.5909148568353877`*^9}, {
   3.590914920418388*^9, 3.590914921313388*^9}, {3.5909149977893877`*^9, 
   3.590914998333388*^9}, {3.590915150853388*^9, 3.590915151316388*^9}, {
   3.590915216465388*^9, 3.590915216944388*^9}, {3.5909152714373875`*^9, 
   3.5909152720293875`*^9}, {3.590915317531388*^9, 3.5909153181663876`*^9}, {
   3.590915507952388*^9, 3.590915508544388*^9}, 3.5909155674043875`*^9, {
   3.5909157107563877`*^9, 3.590915711396388*^9}, 3.590915777872388*^9, {
   3.590915905865388*^9, 3.590915911188388*^9}, {3.590915972373388*^9, 
   3.590915973474388*^9}, {3.590916022851388*^9, 3.590916023439388*^9}, 
   3.5909160767203875`*^9, {3.590916227943388*^9, 3.5909162293953876`*^9}, {
   3.5909162701643877`*^9, 3.590916270833388*^9}, 3.590916307842388*^9, {
   3.5909166488153877`*^9, 3.590916649530388*^9}, {3.590916755209388*^9, 
   3.5909167558293877`*^9}, {3.590916935502388*^9, 3.590916936014388*^9}, {
   3.5909803616153607`*^9, 3.5909803622237606`*^9}, {3.5909856422045608`*^9, 
   3.590985644606961*^9}, {3.5909864670087605`*^9, 3.590986470097561*^9}, {
   3.5909889949807606`*^9, 3.590988997289561*^9}, {3.5909895538537607`*^9, 
   3.590989562605361*^9}, {3.590989598110961*^9, 3.5909896106065607`*^9}, {
   3.591535258768481*^9, 3.591535261434252*^9}, {3.5915353367943*^9, 
   3.5915353383893576`*^9}, {3.591535406675707*^9, 3.591535409965892*^9}, {
   3.5915354793209505`*^9, 3.5915354903152514`*^9}, {3.591535555285466*^9, 
   3.591535555823824*^9}, 3.591535663162108*^9, 3.591535735039839*^9, {
   3.591535804151871*^9, 3.5915358051175127`*^9}, {3.591535897168644*^9, 
   3.591535912799642*^9}, {3.591536371229266*^9, 3.5915363722099123`*^9}, {
   3.5915364224742975`*^9, 3.5915364227624893`*^9}, {3.591536522605713*^9, 
   3.5915365241067123`*^9}, {3.591536600766623*^9, 3.5915366026488724`*^9}, {
   3.591537822158654*^9, 3.5915378228621235`*^9}, {3.591543459770932*^9, 
   3.5915434602442465`*^9}, {3.5915435276233034`*^9, 
   3.5915435302850685`*^9}, {3.5915438028782682`*^9, 3.59154380335559*^9}, {
   3.5915438471264277`*^9, 3.591543850789861*^9}, {3.591543914233173*^9, 
   3.5915439166167555`*^9}, {3.5933431539582276`*^9, 3.5933431590051346`*^9}, 
   3.5933478872363615`*^9, {3.5933479902587614`*^9, 3.593347990820361*^9}, {
   3.5933480810235615`*^9, 3.593348086998361*^9}, {3.5933481714833612`*^9, 
   3.593348224445361*^9}, {3.593348340556161*^9, 3.593348341507761*^9}, 
   3.593348565072361*^9, {3.5933487892039614`*^9, 3.593348793119561*^9}, {
   3.593410436712943*^9, 3.5934104697069435`*^9}, 3.593410590497743*^9, {
   3.593413446000543*^9, 3.593413449058143*^9}, {3.5934134891345434`*^9, 
   3.5934134978705435`*^9}, {3.593413530880143*^9, 3.593413531379343*^9}, {
   3.5934143192335434`*^9, 3.593414322556343*^9}, {3.593414430601943*^9, 
   3.593414442582743*^9}, {3.5934144764815435`*^9, 3.5934144904435434`*^9}, 
   3.5934255533835616`*^9, 3.5934259570903883`*^9, 3.5934260316245003`*^9, {
   3.5934995220040874`*^9, 3.593499523785326*^9}, 3.5935061326264925`*^9, 
   3.5935061739231033`*^9, {3.593506918121465*^9, 3.593506945136917*^9}, 
   3.5935070066990232`*^9, {3.594314604581094*^9, 3.594314605143467*^9}, {
   3.5943180601636066`*^9, 3.594318061088224*^9}, {3.594318093321742*^9, 
   3.594318119889476*^9}, {3.594321465981859*^9, 3.594321466331094*^9}, {
   3.5943215096009755`*^9, 3.5943215256596975`*^9}, {3.5943217432159195`*^9, 
   3.5943217485825014`*^9}, {3.5943218339915133`*^9, 
   3.5943218376649637`*^9}, {3.594322131901453*^9, 3.5943221355679*^9}, {
   3.594324225177887*^9, 3.594324228522118*^9}, {3.594324271542836*^9, 
   3.5943242829284363`*^9}, {3.594324342714345*^9, 3.5943243464678526`*^9}, 
   3.594367967099125*^9, {3.594377165337925*^9, 3.594377166445525*^9}, {
   3.594377260341925*^9, 3.594377261075125*^9}, {3.5943774326283255`*^9, 
   3.594377435358325*^9}, 3.594377494857725*^9, {3.594377637363725*^9, 
   3.594377638814525*^9}, {3.594377740869725*^9, 3.594377741290925*^9}, {
   3.594381929177925*^9, 3.594381930691125*^9}, {3.594381973981125*^9, 
   3.594381977927925*^9}, {3.5943821160035253`*^9, 3.594382116299925*^9}, {
   3.594383239196525*^9, 3.5943832646879253`*^9}, {3.5943833113565254`*^9, 
   3.5943833117933254`*^9}, {3.594383957740125*^9, 3.5943839621861253`*^9}, {
   3.594384084661725*^9, 3.594384087485325*^9}, {3.594384199040925*^9, 
   3.594384200132925*^9}, 3.5943842856093254`*^9, 3.594384401766925*^9, 
   3.5943844773655252`*^9, {3.594724004045288*^9, 3.594724012342827*^9}, 
   3.5947241389823647`*^9, {3.5947329216944036`*^9, 3.5947329224168854`*^9}, {
   3.594732970331871*^9, 3.594732971132405*^9}, {3.594733029576418*^9, 
   3.5947330313385935`*^9}, {3.5947331181045074`*^9, 3.594733118973092*^9}, 
   3.5947332673259597`*^9, {3.5947338310586333`*^9, 3.5947338320282774`*^9}, {
   3.6634834095776157`*^9, 3.6634834132623014`*^9}, {3.6634839302399893`*^9, 
   3.6634839306650066`*^9}, {3.663484000028599*^9, 3.6634840005061083`*^9}, 
   3.663484045490144*^9, 3.6634842171858816`*^9, 3.6634843940520077`*^9, {
   3.663484463521593*^9, 3.6634844640866385`*^9}, {3.6634845030177803`*^9, 
   3.6634845035728245`*^9}, 3.6634846144022317`*^9, {3.6634856538869143`*^9, 
   3.6634856544494486`*^9}, {3.6634857291020126`*^9, 3.663485740891986*^9}, {
   3.663485803398605*^9, 3.6634858081512947`*^9}, {3.663485875239107*^9, 
   3.66348587579163*^9}, {3.66348593844073*^9, 3.66348594317342*^9}, 
   3.663486011684064*^9, 3.6634863428553047`*^9, {3.6634863816532083`*^9, 
   3.663486382285721*^9}, {3.663486481096895*^9, 3.663486481689407*^9}, {
   3.6634866665822287`*^9, 3.663486667262243*^9}, {3.66348678741381*^9, 
   3.66348678792632*^9}, 3.66348698744269*^9, {3.663488268203413*^9, 
   3.6634882687459297`*^9}, 3.6634883060406656`*^9, {3.663488353764207*^9, 
   3.6634883559867735`*^9}, {3.6634884003747044`*^9, 3.663488404037315*^9}, {
   3.66348844183759*^9, 3.663488442410107*^9}, 3.6634884896841445`*^9, 
   3.6634900157083044`*^9, 3.663490065322296*^9, {3.663490146505399*^9, 
   3.663490146967922*^9}, {3.663490217984563*^9, 3.663490219272127*^9}, {
   3.6634905979269*^9, 3.6634906289827166`*^9}, 3.6634907050128746`*^9, {
   3.6635698391925173`*^9, 3.6635698395875254`*^9}, 3.6635699136455765`*^9, {
   3.6635700099691825`*^9, 3.6635700124292316`*^9}, {3.663570064852893*^9, 
   3.663570073815075*^9}, {3.6635701112650404`*^9, 3.6635701120120573`*^9}, {
   3.663570272915721*^9, 3.663570274270748*^9}, 3.663570488608837*^9, {
   3.663570979560706*^9, 3.663570983112779*^9}, {3.6635711552103767`*^9, 
   3.663571156080394*^9}, {3.663572054257267*^9, 3.663572055664795*^9}, {
   3.6635723134671507`*^9, 3.6635723140471625`*^9}, {3.6635900844155817`*^9, 
   3.663590084975593*^9}, {3.663590221804429*^9, 3.6635902223044395`*^9}, {
   3.663590310096325*^9, 3.6635903105663342`*^9}, {3.6635903708016944`*^9, 
   3.6635903715017085`*^9}, {3.6635904573275275`*^9, 
   3.6635904678457465`*^9}, {3.663590537963288*^9, 3.6635905438554077`*^9}, {
   3.663590708128853*^9, 3.663590708738865*^9}, {3.6635915957229815`*^9, 
   3.6635916281637783`*^9}, {3.6635919101577206`*^9, 3.663591917971881*^9}, 
   3.6635919658189726`*^9, {3.6635924977177725`*^9, 3.6635924997678137`*^9}, {
   3.6635926121161933`*^9, 3.6635926128062067`*^9}, {3.6635929393450556`*^9, 
   3.6635929473372173`*^9}, {3.663593106214681*^9, 3.6635931121548*^9}, {
   3.6635932091610084`*^9, 3.6635932131910887`*^9}, {3.6635933154212656`*^9, 
   3.663593324373448*^9}, 3.663593449296215*^9, {3.6635935374620876`*^9, 
   3.6635935695147305`*^9}, 3.6635938560483627`*^9, 3.663593929358556*^9, {
   3.6635939774913087`*^9, 3.6635939780403404`*^9}, 3.6635940101271753`*^9, 
   3.663594094718014*^9, {3.6635942064654055`*^9, 3.6635942197721663`*^9}, {
   3.6635943521377373`*^9, 3.66359435934715*^9}, {3.6635947234279737`*^9, 
   3.6635947359716916`*^9}, 3.663934978897513*^9, {3.6639351758484197`*^9, 
   3.663935187365882*^9}, {3.6639352757680073`*^9, 3.6639352763430305`*^9}, {
   3.663935318827879*^9, 3.6639353199729247`*^9}, {3.6639354596820974`*^9, 
   3.6639354604071264`*^9}, {3.6639358793521957`*^9, 3.6639358800672245`*^9}, 
   3.663936228074569*^9, {3.6639368262946796`*^9, 3.6639368454149456`*^9}, {
   3.6639370373273106`*^9, 3.663937037989837*^9}, 3.663937109759819*^9, {
   3.663937162742533*^9, 3.6639371687477736`*^9}, 3.663937299722672*^9, {
   3.6639374460596204`*^9, 3.6639374466846457`*^9}, {3.6639378291664295`*^9, 
   3.66393784210496*^9}, {3.663937890327041*^9, 3.6639379020175085`*^9}, 
   3.6639379451073236`*^9, 3.663938048031592*^9, {3.6639380924654627`*^9, 
   3.663938093935521*^9}, 3.663938220170088*^9, {3.6639382817944727`*^9, 
   3.6639382883440795`*^9}, {3.663938331451598*^9, 3.663938335025387*^9}, 
   3.663938381376723*^9, {3.663938416444702*^9, 3.6639384173146496`*^9}, {
   3.6639385188166065`*^9, 3.663938520366622*^9}, {3.6639385852954254`*^9, 
   3.663938588215455*^9}, {3.6639386812865267`*^9, 3.663938685866573*^9}, 
   3.6639387828328104`*^9, {3.6639388482068653`*^9, 3.663938848726881*^9}, {
   3.66393904868311*^9, 3.663939059273534*^9}, {3.663939117681945*^9, 
   3.663939118231967*^9}, {3.663939201957392*^9, 3.6639392065375757`*^9}, 
   3.663939423686592*^9, {3.663939478659384*^9, 3.663939479624422*^9}, {
   3.663939543414576*^9, 3.663939547381736*^9}, {3.6639395951522436`*^9, 
   3.663939622209421*^9}, {3.663939655705881*^9, 3.66393965668342*^9}, {
   3.6639397222366467`*^9, 3.6639397250192585`*^9}, 3.663939778579006*^9, {
   3.663939813587999*^9, 3.66393981411302*^9}, 3.6639398773046536`*^9, {
   3.663939915427331*^9, 3.6639399199285316`*^9}, {3.6639399650330667`*^9, 
   3.6639399701107697`*^9}, {3.663940034291917*^9, 3.663940043659792*^9}, {
   3.6639402727473917`*^9, 3.663940278495122*^9}, 3.663940710359999*^9, 
   3.66394074453846*^9, {3.663940777677353*^9, 3.6639407787523956`*^9}, {
   3.6639408102337255`*^9, 3.6639408108562503`*^9}, {3.663940908220829*^9, 
   3.6639409088383536`*^9}, {3.6639409407162275`*^9, 
   3.6639409682954235`*^9}, {3.663941003497423*^9, 3.663941004144949*^9}, {
   3.6639410563585925`*^9, 3.6639410617058077`*^9}, {3.6639411052486153`*^9, 
   3.6639411111363506`*^9}, {3.663941147416374*^9, 3.6639411490164385`*^9}, {
   3.663941203024198*^9, 3.6639412036267223`*^9}, 3.6639412473140373`*^9, {
   3.663941313853277*^9, 3.6639413145083036`*^9}, {3.6639413559260864`*^9, 
   3.663941356471108*^9}, {3.6639418182656045`*^9, 3.6639418230007935`*^9}, {
   3.663941869043743*^9, 3.663941870038783*^9}, {3.6639422599245825`*^9, 
   3.6639422864897137`*^9}, {3.663942331981825*^9, 3.6639423910627985`*^9}, {
   3.663942621308251*^9, 3.663942625040863*^9}, {3.6639427370774355`*^9, 
   3.663942737649953*^9}, {3.66394372666606*^9, 3.6639437338083467`*^9}, {
   3.6639438091635237`*^9, 3.6639438156037817`*^9}, {3.663943958870745*^9, 
   3.6639439636104364`*^9}, {3.663944054375779*^9, 3.6639440597179947`*^9}, {
   3.6639441320170307`*^9, 3.6639441324395475`*^9}, {3.663944195834192*^9, 
   3.663944196206707*^9}, {3.6639456147125072`*^9, 3.663945615175026*^9}, {
   3.6639456842483654`*^9, 3.663945684700884*^9}, {3.663995271016657*^9, 
   3.663995271732029*^9}, {3.6639954390599804`*^9, 3.6639954396452847`*^9}, {
   3.663995507913973*^9, 3.663995569359589*^9}, {3.6639956067726545`*^9, 
   3.6639956077755156`*^9}, 3.663995718287162*^9, {3.6639978295282574`*^9, 
   3.6639978300656605`*^9}, {3.6639984389339924`*^9, 3.663998439456539*^9}, {
   3.6639986320209684`*^9, 3.6639986328880744`*^9}, {3.6639987179259305`*^9, 
   3.6639987215938706`*^9}, {3.6640012946555104`*^9, 3.664001300160621*^9}, {
   3.6640013870965743`*^9, 3.664001391381661*^9}, {3.664001581995919*^9, 
   3.6640015873687954`*^9}, 3.6640016795324416`*^9, {3.664001740661695*^9, 
   3.664001741314247*^9}, {3.6640023478285275`*^9, 3.6640023661828985`*^9}, {
   3.6640025356256*^9, 3.6640025360356245`*^9}, {3.664002694429257*^9, 
   3.6640026964593787`*^9}, {3.664002766016185*^9, 3.664002786179597*^9}, {
   3.664002824468318*^9, 3.6640028270685*^9}, {3.664003338332653*^9, 
   3.6640033485852695`*^9}, {3.6640043218309174`*^9, 3.664004329661231*^9}, {
   3.664004459923018*^9, 3.664004460553056*^9}, {3.6640045080759983`*^9, 
   3.6640045198567047`*^9}, {3.6640056032588015`*^9, 3.664005626586438*^9}, 
   3.664005824780903*^9, {3.664007454962647*^9, 3.664007455462677*^9}, {
   3.6640075194866447`*^9, 3.664007520496705*^9}, {3.664007582858493*^9, 
   3.6640075924910717`*^9}, {3.6640077175867004`*^9, 3.6640077181567345`*^9}, 
   3.664007775308267*^9, {3.664007807510253*^9, 3.664007811190474*^9}, {
   3.6640078642537365`*^9, 3.664007864853773*^9}, {3.664007904924241*^9, 
   3.6640079316319017`*^9}, {3.664007965388893*^9, 3.664007995897732*^9}, {
   3.6640080379381337`*^9, 3.664008067663002*^9}, 3.664088781527842*^9, {
   3.6640888837491302`*^9, 3.664088885141201*^9}, {3.664089445787484*^9, 
   3.6640894546554317`*^9}, {3.664089648457348*^9, 3.6640896897885103`*^9}, {
   3.6640897670314903`*^9, 3.6640897674740124`*^9}, {3.6640898330144944`*^9, 
   3.664089860696951*^9}, {3.6640899076369133`*^9, 3.664089955578473*^9}, {
   3.6640900535691576`*^9, 3.6640900609760375`*^9}, {3.664091553029145*^9, 
   3.6640915554392653`*^9}, {3.664091603999775*^9, 3.664091604539802*^9}, {
   3.664091662688816*^9, 3.664091663278846*^9}, 3.664092011468655*^9, {
   3.6640921617123704`*^9, 3.664092165342552*^9}, {3.6640924644038315`*^9, 
   3.664092467814002*^9}, {3.6640926638622584`*^9, 3.6640926676974516`*^9}, {
   3.6640927216007442`*^9, 3.6640927221232705`*^9}, 3.6640933515507064`*^9, 
   3.6640934039254313`*^9, {3.6641009074401226`*^9, 3.6641009079626637`*^9}, {
   3.6641019991392145`*^9, 3.6641019996417246`*^9}, {3.6694655384546623`*^9, 
   3.6694655414322815`*^9}, {3.6694655914059153`*^9, 3.669465591945937*^9}, {
   3.669465821939723*^9, 3.6694658228747606`*^9}, {3.7364181926205406`*^9, 
   3.736418239100199*^9}, {3.736418421148612*^9, 3.736418542538555*^9}, {
   3.73641863039258*^9, 3.736418635207855*^9}, {3.7364275630975018`*^9, 
   3.7364275670647287`*^9}},
 FontSize->10]
}, Open  ]],

Cell[CellGroupData[{

Cell["b. Find steady state", "Subsection",
 CellChangeTimes->{{3.7364181534022975`*^9, 3.736418158922613*^9}, 
   3.7364186178148603`*^9, {3.7364186781833134`*^9, 3.736418684535677*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"R", "=", 
   RowBox[{"1", "/", "betal"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ky", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"beta", "*", "alpha"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"beta", "*", 
       RowBox[{"(", 
        RowBox[{"1", "-", "delta"}], ")"}]}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"qly", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"beta", "*", "gamma"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"1", "-", "beta", "-", 
      RowBox[{"theta", "*", 
       RowBox[{"(", 
        RowBox[{"betal", "-", "beta"}], ")"}]}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"by", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"theta", "/", "R"}], ")"}], "*", "qly"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cy", "=", 
   RowBox[{"1", "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"R", "-", "1"}], ")"}], "*", "by"}], "-", 
    RowBox[{"delta", "*", "ky"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xy", "=", 
   RowBox[{"cy", "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "alpha", "-", "gamma"}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"1", "+", "chi"}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tfp", " ", "=", " ", 
   RowBox[{"ky", "^", 
    RowBox[{"(", 
     RowBox[{"-", "alpha"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"yss", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"tfp", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", "ky", ")"}], "^", "alpha"}], ")"}]}], ")"}], "^", 
    RowBox[{"(", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"1", "-", "alpha", "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "alpha", "-", "gamma"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"1", "+", "chi"}], ")"}]}]}], ")"}]}], ")"}]}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"css", "=", 
   RowBox[{"cy", "*", "yss"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bss", "=", 
   RowBox[{"by", "*", "yss"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"qss", "=", 
   RowBox[{"qly", "*", "yss"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kss", "=", 
   RowBox[{"ky", "*", "yss"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"psi", "=", 
    RowBox[{"1", "-", "alpha", "-", "gamma"}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nss", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "alpha", "-", "gamma"}], ")"}], "*", 
      RowBox[{"yss", "/", "psi"}]}], ")"}], "^", 
    RowBox[{"(", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", "chi"}], ")"}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sigmab", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"cy", "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "alpha", "-", "gamma"}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"1", "+", "chi"}], ")"}]}]}], ")"}], "/", "cy"}]}], ";"}], 
  RowBox[{"(*", "  ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"cy", "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "alpha", "-", "gamma"}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"1", "+", "chi"}], ")"}]}]}], ")"}], "/", "cy"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lambdass", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"css", "-", 
      RowBox[{"psi", "*", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"nss", "^", 
          RowBox[{"(", 
           RowBox[{"1", "+", "chi"}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"1", "+", "chi"}], ")"}]}]}]}], ")"}], "^", 
    RowBox[{"(", 
     RowBox[{"-", "sigmab"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"phiss", "=", 
   RowBox[{"lambdass", "*", 
    RowBox[{"(", 
     RowBox[{"betal", "-", "beta"}], ")"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5040079188494473`*^9, 3.504007959175518*^9}, {
   3.504008160649872*^9, 3.504008189603523*^9}, {3.5040082265755873`*^9, 
   3.5040082348124022`*^9}, {3.504008543443344*^9, 3.504008555580166*^9}, {
   3.5040086676351624`*^9, 3.5040086830323896`*^9}, {3.5040090035817523`*^9, 
   3.5040090383542137`*^9}, 3.5040095284290743`*^9, {3.5040097982315483`*^9, 
   3.5040098031611567`*^9}, 3.5045919538153086`*^9, {3.5055630889503503`*^9, 
   3.5055631272152405`*^9}, {3.5055631774174013`*^9, 3.505563187292212*^9}, {
   3.5055632429005194`*^9, 3.505563252337838*^9}, {3.505565705860118*^9, 
   3.505565738764683*^9}, {3.506071864724476*^9, 3.5060718652704763`*^9}, 
   3.515470387390625*^9, {3.51549552425*^9, 3.515495546453125*^9}, 
   3.515495620515625*^9, {3.515504079734375*^9, 3.515504087375*^9}, 
   3.5261059481875*^9, {3.527093205140625*^9, 3.527093210015625*^9}, {
   3.527149164734375*^9, 3.52714922090625*^9}, 3.527149509734375*^9, {
   3.52715001390625*^9, 3.52715003375*^9}, {3.52715204203125*^9, 
   3.527152044953125*^9}, {3.5271520995625*^9, 3.527152107390625*^9}, 
   3.527152198234375*^9, {3.527152414359375*^9, 3.527152435734375*^9}, {
   3.5271534375*^9, 3.5271534455625*^9}, {3.5272239628151274`*^9, 
   3.527223964671528*^9}, {3.572174616421875*^9, 3.57217472915625*^9}, 
   3.5721765699375*^9, {3.57217670515625*^9, 3.572176710109375*^9}, {
   3.572177812765625*^9, 3.57217781625*^9}, {3.57217889353125*^9, 
   3.572178893875*^9}, 3.572180828390625*^9, {3.572181000515625*^9, 
   3.572181015109375*^9}, {3.572190951125*^9, 3.572190964109375*^9}, {
   3.572192920609375*^9, 3.572192940015625*^9}, {3.572192983234375*^9, 
   3.5721929866875*^9}, {3.572193038140625*^9, 3.5721930829375*^9}, {
   3.57219416453125*^9, 3.57219416546875*^9}, {3.573107082859375*^9, 
   3.5731070849375*^9}, {3.573107231015625*^9, 3.573107234875*^9}, {
   3.573107325390625*^9, 3.573107326171875*^9}, {3.573196231935911*^9, 
   3.573196235118311*^9}, {3.5731963242879114`*^9, 3.573196326050711*^9}, {
   3.5731965372057114`*^9, 3.573196538126111*^9}, {3.5731975699017115`*^9, 
   3.5731975707597113`*^9}, {3.573197707276311*^9, 3.5731977085555115`*^9}, {
   3.573197787586111*^9, 3.573197788834111*^9}, {3.573198086063311*^9, 
   3.573198096499711*^9}, {3.573198199009311*^9, 3.5731981996489115`*^9}, {
   3.573224294421875*^9, 3.573224298859375*^9}, 3.573224410640625*^9, 
   3.573227914015625*^9, {3.573228190421875*^9, 3.573228190515625*^9}, {
   3.5732282959375*^9, 3.573228297453125*^9}, 3.5732343483125*^9, 
   3.573234593515625*^9, {3.573235870046875*^9, 3.57323589965625*^9}, 
   3.57323604921875*^9, {3.57323610178125*^9, 3.573236105953125*^9}, 
   3.573236212703125*^9, {3.57323631990625*^9, 3.573236342984375*^9}, {
   3.57327224359375*^9, 3.573272243625*^9}, {3.573272646921875*^9, 
   3.57327264721875*^9}, {3.573739079921875*^9, 3.5737390800625*^9}, {
   3.573739132375*^9, 3.573739132734375*^9}, 3.5933421801560125`*^9, {
   3.6634834362869616`*^9, 3.6634834442668657`*^9}, {3.6639351805356083`*^9, 
   3.6639352023239803`*^9}, 3.6639368518602057`*^9, {3.663940423481613*^9, 
   3.663940424006634*^9}, 3.6639433910716114`*^9, {3.663945692726205*^9, 
   3.663945693198724*^9}, {3.663945746517994*^9, 3.6639457475380344`*^9}, {
   3.6639956647240806`*^9, 3.6639956651042175`*^9}, {3.6639956956983075`*^9, 
   3.6639956964031315`*^9}, {3.6640083529857917`*^9, 3.664008354237831*^9}, {
   3.664008428854187*^9, 3.6640084293742027`*^9}, {3.6641007856773014`*^9, 
   3.6641007859798255`*^9}, {3.6641008301773844`*^9, 
   3.6641008313119755`*^9}, {3.7364186929061556`*^9, 3.7364187082980356`*^9}},
 FontSize->10]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
c. Compute matrices A, D, F, G, N\
\>", "Subsection",
 CellChangeTimes->{{3.7356438967811546`*^9, 3.735643917449336*^9}, {
   3.735815557672407*^9, 3.7358155918143597`*^9}, 3.736418723110883*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"m0p", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "by"}], ",", "ky", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m1p", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"0", "*", 
          RowBox[{"(", 
           RowBox[{"1", "+", "epsilon"}], ")"}]}], ",", "0", ",", "0"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "cy"}], ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m2p", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"1", "*", 
          RowBox[{"(", 
           RowBox[{"1", "+", "epsilon"}], ")"}]}], ",", "0", ",", "0"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m3p", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "R"}], "*", "by"}], ",", 
         RowBox[{
          RowBox[{"ky", "*", 
           RowBox[{"(", 
            RowBox[{"1", "-", "delta"}], ")"}]}], "+", "alpha", "+", 
          RowBox[{"alpha", "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", "alpha", "-", "gamma"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"chi", "+", "alpha", "+", "gamma"}], ")"}]}]}]}], ",", 
         "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "rho", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "rhotau"}], "}"}]}], "}"}]}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m4p", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"1", "-", 
          RowBox[{"0", "*", "theta", "*", 
           RowBox[{"(", 
            RowBox[{"1", "+", "epsilon"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{"betal", "-", "beta"}], ")"}]}]}], ",", 
         RowBox[{"1", "-", 
          RowBox[{"theta", "*", "betal"}]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cy", "/", "xy"}], ",", "0", ",", 
         RowBox[{"1", "/", "sigmab"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "betal"}], ",", 
         RowBox[{"betal", "-", "beta"}]}], "}"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m5p", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"beta", "+", 
          RowBox[{"1", "*", "theta", "*", 
           RowBox[{"(", 
            RowBox[{"1", "+", "epsilon"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{"betal", "-", "beta"}], ")"}]}]}], ",", 
         RowBox[{"beta", "*", 
          RowBox[{"(", 
           RowBox[{"1", "-", "theta", "+", 
            RowBox[{"gamma", "/", "qly"}]}], ")"}]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"beta", "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"alpha", "/", "ky"}], "+", "1", "-", "delta"}], ")"}]}], 
         ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "beta"}], ",", "0"}], "}"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m6p", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"theta", "*", 
          RowBox[{"(", 
           RowBox[{"betal", "-", "beta"}], ")"}]}], ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "alpha", "-", "gamma"}], ")"}], "*", 
          RowBox[{
           RowBox[{"alpha", "/", 
            RowBox[{"(", 
             RowBox[{"chi", "+", "alpha", "+", "gamma"}], ")"}]}], "/", 
           "xy"}]}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m7p", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"alpha", "*", "beta", "*", 
           RowBox[{"gamma", "/", "qly"}]}], "+", 
          RowBox[{"alpha", "*", "beta", "*", "gamma", "*", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "alpha", "-", "gamma"}], ")"}], "/", "qly"}], 
            "/", 
            RowBox[{"(", 
             RowBox[{"chi", "+", "alpha", "+", "gamma"}], ")"}]}]}]}], ",", 
         "0", ",", "beta"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"alpha", "*", 
           RowBox[{"(", 
            RowBox[{"alpha", "-", "1"}], ")"}], "*", 
           RowBox[{"beta", "/", "ky"}]}], "+", 
          RowBox[{"alpha", "*", "alpha", "*", "beta", "*", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "alpha", "-", "gamma"}], ")"}], "/", "ky"}], 
            "/", 
            RowBox[{"(", 
             RowBox[{"chi", "+", "alpha", "+", "gamma"}], ")"}]}]}]}], ",", 
         "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m8p", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"n0p", " ", "=", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Log", "[", "bss", "]"}], " ", "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "epsilon"}], ")"}], 
         RowBox[{"Log", "[", "qss", "]"}]}], "-", 
        RowBox[{"Log", "[", "theta", "]"}]}], ",", 
       RowBox[{
        RowBox[{"ky", "*", 
         RowBox[{"Log", "[", "kss", "]"}]}], "-", 
        RowBox[{"by", "*", 
         RowBox[{"Log", "[", "bss", "]"}]}], "+", 
        RowBox[{"cy", "*", 
         RowBox[{"Log", "[", "css", "]"}]}], "+", 
        RowBox[{"R", "*", "by", "*", 
         RowBox[{"Log", "[", "bss", "]"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"alpha", "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", "delta"}], ")"}], "*", "ky"}], "+", 
           RowBox[{"alpha", "*", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "alpha", "-", "gamma"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"chi", "+", "alpha", "+", "gamma"}], ")"}]}]}]}], ")"}],
          "*", 
         RowBox[{"Log", "[", "kss", "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"Log", "[", "theta", "]"}], "*", 
        RowBox[{"(", 
         RowBox[{"1", "-", "rho"}], ")"}]}], ",", "0"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"n1p", " ", "=", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Log", "[", "qss", "]"}], "*", 
         RowBox[{"(", 
          RowBox[{"1", "-", "beta", "-", 
           RowBox[{"theta", "*", 
            RowBox[{"(", 
             RowBox[{"betal", "-", "beta"}], ")"}], "*", 
            RowBox[{"(", 
             RowBox[{"1", "+", "epsilon"}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"Log", "[", "lambdass", "]"}], "*", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"theta", "*", "betal"}], "-", 
           RowBox[{"beta", "*", 
            RowBox[{"(", 
             RowBox[{"1", "-", "theta"}], ")"}]}], "-", 
           RowBox[{"beta", "*", 
            RowBox[{"gamma", "/", "qly"}]}]}], ")"}]}], "-", 
        RowBox[{"alpha", "*", "beta", "*", "gamma", "*", 
         RowBox[{
          RowBox[{"Log", "[", "kss", "]"}], "/", "qly"}]}], "-", 
        RowBox[{"alpha", "*", "beta", "*", "gamma", "*", 
         RowBox[{"(", 
          RowBox[{"1", "-", "alpha", "-", "gamma"}], ")"}], "*", 
         RowBox[{
          RowBox[{
           RowBox[{"Log", "[", "kss", "]"}], "/", "qly"}], "/", 
          RowBox[{"(", 
           RowBox[{"chi", "+", "alpha", "+", "gamma"}], ")"}]}]}], "-", 
        RowBox[{"theta", "*", 
         RowBox[{"(", 
          RowBox[{"betal", "-", "beta"}], ")"}], "*", " ", 
         RowBox[{"Log", "[", "theta", "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Log", "[", "lambdass", "]"}], "*", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"beta", "*", 
            RowBox[{"(", 
             RowBox[{"1", "-", "delta"}], ")"}]}], "-", 
           RowBox[{"beta", "*", 
            RowBox[{"alpha", "/", "ky"}]}]}], ")"}]}], "-", 
        RowBox[{"beta", "*", "alpha", "*", 
         RowBox[{"(", 
          RowBox[{"alpha", "-", "1"}], ")"}], "*", 
         RowBox[{
          RowBox[{"Log", "[", "kss", "]"}], "/", "ky"}]}], "-", 
        RowBox[{"alpha", "*", "alpha", "*", "beta", "*", 
         RowBox[{"(", 
          RowBox[{"1", "-", "alpha", "-", "gamma"}], ")"}], "*", 
         RowBox[{
          RowBox[{
           RowBox[{"Log", "[", "kss", "]"}], "/", "ky"}], "/", 
          RowBox[{"(", 
           RowBox[{"chi", "+", "alpha", "+", "gamma"}], ")"}]}]}]}], ",", 
       RowBox[{
        RowBox[{"cy", "*", 
         RowBox[{
          RowBox[{"Log", "[", "css", "]"}], "/", "xy"}]}], "+", 
        RowBox[{
         RowBox[{"Log", "[", "lambdass", "]"}], "/", "sigmab"}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "alpha", "-", "gamma"}], ")"}], "*", 
         RowBox[{"alpha", "/", 
          RowBox[{"(", 
           RowBox[{"chi", "+", "alpha", "+", "gamma"}], ")"}]}], "*", 
         RowBox[{
          RowBox[{"Log", "[", "kss", "]"}], "/", "xy"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"betal", "-", "beta"}], ")"}], "*", 
         RowBox[{"Log", "[", "phiss", "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"beta", "-", "betal"}], ")"}], "*", 
         RowBox[{"Log", "[", "lambdass", "]"}]}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"v", "=", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1", ",", "0"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"w", "=", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m04x4", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "4", "}"}], ",", 
       RowBox[{"{", "4", "}"}]}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.505562733082183*^9, 3.5055627907529507`*^9}, {
   3.5055630073581667`*^9, 3.50556305357603*^9}, {3.505565745217478*^9, 
   3.505565756607519*^9}, {3.5055657939806056`*^9, 3.5055660216884356`*^9}, {
   3.505566059249734*^9, 3.505566102545223*^9}, {3.5055662782427254`*^9, 
   3.505566392224151*^9}, {3.505566423785843*^9, 3.505566618937326*^9}, {
   3.5056301270497985`*^9, 3.5056301310807905`*^9}, {3.5056301799214144`*^9, 
   3.5056301835461826`*^9}, 3.505630283480532*^9, {3.506071794290476*^9, 
   3.506071815709276*^9}, {3.52359961846875*^9, 3.523599623609375*^9}, {
   3.523599688171875*^9, 3.523599697265625*^9}, 3.527009545296875*^9, {
   3.527009588546875*^9, 3.527009591171875*^9}, {3.527009636296875*^9, 
   3.527009647796875*^9}, {3.527009993796875*^9, 3.527009995734375*^9}, {
   3.527093258515625*^9, 3.52709328340625*^9}, {3.52709348884375*^9, 
   3.52709367965625*^9}, {3.527093749859375*^9, 3.52709383621875*^9}, {
   3.527093873046875*^9, 3.527093950265625*^9}, {3.527093990890625*^9, 
   3.52709403021875*^9}, {3.52709460321875*^9, 3.5270947595625*^9}, 
   3.527094889609375*^9, {3.52709492653125*^9, 3.5270949519375*^9}, {
   3.52709711596875*^9, 3.527097229671875*^9}, {3.527098478359375*^9, 
   3.52709854275*^9}, {3.52710108084375*^9, 3.527101085890625*^9}, {
   3.527329769660727*^9, 3.527329834931127*^9}, {3.5298220708313603`*^9, 
   3.52982207179856*^9}, {3.52982220873536*^9, 3.5298222154745607`*^9}, {
   3.5298222983885603`*^9, 3.52982229924656*^9}, {3.5298223489169607`*^9, 
   3.5298223494005604`*^9}, {3.5298308553134003`*^9, 3.5298308733002*^9}, {
   3.5298312906626*^9, 3.5298313026745996`*^9}, {3.5298315142106*^9, 
   3.5298315260666*^9}, {3.53051484749304*^9, 3.5305148784590406`*^9}, {
   3.53058505603125*^9, 3.530585082890625*^9}, 3.530585134375*^9, {
   3.530585925328125*^9, 3.530585935046875*^9}, {3.530586119171875*^9, 
   3.5305861313125*^9}, {3.53098191878125*^9, 3.530981935734375*^9}, {
   3.531035417505563*^9, 3.531035433152363*^9}, {3.53233662925*^9, 
   3.532336631390625*^9}, {3.532336734734375*^9, 3.532336742484375*^9}, {
   3.532336792171875*^9, 3.5323368231875*^9}, {3.5323376049375*^9, 
   3.532337622078125*^9}, {3.532340961875*^9, 3.532340975609375*^9}, {
   3.53234272178125*^9, 3.53234273115625*^9}, {3.545128828328125*^9, 
   3.5451288396875*^9}, {3.5451288886875*^9, 3.5451289195625*^9}, {
   3.5451319084375*^9, 3.54513191784375*^9}, {3.572174892*^9, 
   3.572175144796875*^9}, {3.57217526328125*^9, 3.572175316453125*^9}, {
   3.572175360953125*^9, 3.57217541146875*^9}, {3.572175445859375*^9, 
   3.572175499125*^9}, {3.5721755291875*^9, 3.572175634875*^9}, {
   3.57217568553125*^9, 3.5721757180625*^9}, {3.572176555*^9, 
   3.572176565125*^9}, {3.5721778354375*^9, 3.57217784465625*^9}, {
   3.572178418546875*^9, 3.572178418625*^9}, {3.5721837524375*^9, 
   3.572183760046875*^9}, 3.57218466746875*^9, 3.572184918171875*^9, {
   3.57219096790625*^9, 3.572191055765625*^9}, {3.572193235203125*^9, 
   3.572193235625*^9}, {3.5721932943125*^9, 3.572193298015625*^9}, {
   3.572193330375*^9, 3.572193334984375*^9}, 3.5723346744954834`*^9, {
   3.572334733026683*^9, 3.5723347628382835`*^9}, {3.572334911381483*^9, 
   3.5723349417390833`*^9}, {3.572334977057483*^9, 3.5723350504428835`*^9}, {
   3.5723351095980835`*^9, 3.572335440910883*^9}, {3.572335490019683*^9, 
   3.572335534822883*^9}, 3.57270472124972*^9, {3.572757869590444*^9, 
   3.572757872757244*^9}, 3.5933422030472236`*^9, {3.5943145887865486`*^9, 
   3.5943145994586716`*^9}, {3.594321890894495*^9, 3.594321898877824*^9}, {
   3.5944520470423365`*^9, 3.5944520527987366`*^9}, {3.594452133077337*^9, 
   3.594452139707337*^9}, 3.663483488974118*^9},
 FontSize->10],

Cell[BoxData[{
 RowBox[{
  RowBox[{"aM11", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Inverse", "[", "m4p", "]"}], ".", "m6p", ".", 
     RowBox[{"Inverse", "[", "m0p", "]"}], ".", "m1p"}], "+", 
    RowBox[{
     RowBox[{"Inverse", "[", "m4p", "]"}], ".", "m8p"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"aM12", "=", 
   RowBox[{
    RowBox[{"Inverse", "[", "m4p", "]"}], ".", "m6p", ".", 
    RowBox[{"Inverse", "[", "m0p", "]"}], ".", "m3p"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"aM21", "=", 
   RowBox[{
    RowBox[{"Inverse", "[", "m0p", "]"}], ".", "m1p"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"aM22", "=", 
   RowBox[{
    RowBox[{"Inverse", "[", "m0p", "]"}], ".", "m3p"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dM11", "=", 
   RowBox[{
    RowBox[{"Inverse", "[", "m4p", "]"}], ".", "m6p", ".", 
    RowBox[{"Inverse", "[", "m0p", "]"}], ".", "m2p"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dM12", "=", "m04x4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dM21", "=", 
   RowBox[{
    RowBox[{"Inverse", "[", "m0p", "]"}], ".", "m2p"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dM22", "=", "m04x4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fM11", "=", 
   RowBox[{
    RowBox[{"Inverse", "[", "m4p", "]"}], ".", "m5p"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fM12", "=", 
   RowBox[{
    RowBox[{"Inverse", "[", "m4p", "]"}], ".", "m7p"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fM21", "=", "m04x4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fM22", "=", "m04x4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n1", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Inverse", "[", "m4p", "]"}], ".", "n1p"}], "+", 
    RowBox[{
     RowBox[{"Inverse", "[", "m4p", "]"}], ".", "m6p", ".", 
     RowBox[{"Inverse", "[", "m0p", "]"}], ".", "n0p"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n2", "=", 
   RowBox[{
    RowBox[{"Inverse", "[", "m0p", "]"}], ".", "n0p"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g1", "=", 
   RowBox[{
    RowBox[{"Inverse", "[", "m4p", "]"}], ".", "m6p", ".", 
    RowBox[{"Inverse", "[", "m0p", "]"}], ".", "v"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g2", "=", 
   RowBox[{
    RowBox[{"Inverse", "[", "m0p", "]"}], ".", "v"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gg1", "=", 
   RowBox[{
    RowBox[{"Inverse", "[", "m4p", "]"}], ".", "m6p", ".", 
    RowBox[{"Inverse", "[", "m0p", "]"}], ".", "w"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gg2", "=", 
   RowBox[{
    RowBox[{"Inverse", "[", "m0p", "]"}], ".", "w"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"aM", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "8", "}"}], ",", 
     RowBox[{"{", "8", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dM", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "8", "}"}], ",", 
     RowBox[{"{", "8", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fM", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "8", "}"}], ",", 
     RowBox[{"{", "8", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nM", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "8", "}"}], ",", 
     RowBox[{"{", "1", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gM", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "8", "}"}], ",", 
     RowBox[{"{", "1", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ggM", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "8", "}"}], ",", 
     RowBox[{"{", "1", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mI", " ", "=", " ", 
    RowBox[{"IdentityMatrix", "[", "8", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"aM", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{"1", ";;", "4"}], ",", 
      RowBox[{"1", ";;", "4"}]}], "]"}], "]"}], "=", "aM11"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"aM", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{"1", ";;", "4"}], ",", 
      RowBox[{"5", ";;", "8"}]}], "]"}], "]"}], "=", "aM12"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"aM", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{"5", ";;", "8"}], ",", 
      RowBox[{"1", ";;", "4"}]}], "]"}], "]"}], "=", "aM21"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"aM", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{"5", ";;", "8"}], ",", 
      RowBox[{"5", ";;", "8"}]}], "]"}], "]"}], "=", "aM22"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dM", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{"1", ";;", "4"}], ",", 
      RowBox[{"1", ";;", "4"}]}], "]"}], "]"}], "=", "dM11"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dM", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{"1", ";;", "4"}], ",", 
      RowBox[{"5", ";;", "8"}]}], "]"}], "]"}], "=", "dM12"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dM", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{"5", ";;", "8"}], ",", 
      RowBox[{"1", ";;", "4"}]}], "]"}], "]"}], "=", "dM21"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dM", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{"5", ";;", "8"}], ",", 
      RowBox[{"5", ";;", "8"}]}], "]"}], "]"}], "=", "dM22"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fM", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{"1", ";;", "4"}], ",", 
      RowBox[{"1", ";;", "4"}]}], "]"}], "]"}], "=", "fM11"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fM", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{"1", ";;", "4"}], ",", 
      RowBox[{"5", ";;", "8"}]}], "]"}], "]"}], "=", "fM12"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fM", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{"5", ";;", "8"}], ",", 
      RowBox[{"1", ";;", "4"}]}], "]"}], "]"}], "=", "fM21"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fM", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{"5", ";;", "8"}], ",", 
      RowBox[{"5", ";;", "8"}]}], "]"}], "]"}], "=", "fM22"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nM", "[", 
    RowBox[{"[", 
     RowBox[{"1", ";;", "4"}], "]"}], "]"}], "=", "n1"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nM", "[", 
    RowBox[{"[", 
     RowBox[{"5", ";;", "8"}], "]"}], "]"}], "=", "n2"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gM", "[", 
    RowBox[{"[", 
     RowBox[{"1", ";;", "4"}], "]"}], "]"}], "=", "g1"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gM", "[", 
    RowBox[{"[", 
     RowBox[{"5", ";;", "8"}], "]"}], "]"}], "=", "g2"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ggM", "[", 
    RowBox[{"[", 
     RowBox[{"1", ";;", "4"}], "]"}], "]"}], "=", "gg1"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ggM", "[", 
    RowBox[{"[", 
     RowBox[{"5", ";;", "8"}], "]"}], "]"}], "=", "gg2"}], 
  ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.505567032163767*^9, 3.5055672802683783`*^9}, 
   3.5056294879191484`*^9, {3.5056299926990223`*^9, 3.505630022868966*^9}, {
   3.505630075631214*^9, 3.5056301227531986`*^9}, {3.5056302401532393`*^9, 
   3.5056302794649844`*^9}, {3.5056326532069764`*^9, 
   3.5056327382545185`*^9}, {3.505632903161824*^9, 3.5056329272869787`*^9}, {
   3.505633386743044*^9, 3.505633405055661*^9}, {3.5056335456833324`*^9, 
   3.5056336216066656`*^9}, {3.5056336814359393`*^9, 
   3.5056337161864924`*^9}, {3.505652370241458*^9, 3.5056523794758916`*^9}, {
   3.527009563171875*^9, 3.52700956796875*^9}, {3.527093976546875*^9, 
   3.527093979671875*^9}, {3.527094051859375*^9, 3.5270941784375*^9}, {
   3.527094769859375*^9, 3.527094862234375*^9}, {3.52709497990625*^9, 
   3.527094988203125*^9}, {3.530981992546875*^9, 3.53098202884375*^9}, 
   3.531033093883563*^9, {3.531035340457163*^9, 3.5310353424695625`*^9}, {
   3.54512893434375*^9, 3.545128946328125*^9}, {3.572174896078125*^9, 
   3.572174907328125*^9}, {3.572175737875*^9, 3.57217575190625*^9}, {
   3.572175855359375*^9, 3.572175962390625*^9}, {3.572175999109375*^9, 
   3.572176052109375*^9}, {3.5727024425570545`*^9, 3.572702456805231*^9}, {
   3.572705241042553*^9, 3.572705241261275*^9}, 3.5933422233914948`*^9},
 FontSize->10]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
d. Compute the solution to the model consistent with this coeffcients\
\>", "Subsection",
 CellChangeTimes->{{3.735643980604949*^9, 3.7356439875223446`*^9}, {
   3.7357284943999343`*^9, 3.7357285037754707`*^9}, 3.7364187544866776`*^9}],

Cell["Let mM be matrix of coefficients in PLM. Then", "Text",
 CellChangeTimes->{{3.5056343153153267`*^9, 3.505634349831173*^9}},
 FontSize->10],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"mALM", "[", "mM_", "]"}], ":=", 
     RowBox[{
      RowBox[{"Inverse", "[", 
       RowBox[{
        RowBox[{"IdentityMatrix", "[", "8", "]"}], "-", 
        RowBox[{"fM", ".", "mM"}]}], "]"}], ".", 
      RowBox[{"(", 
       RowBox[{"aM", "+", 
        RowBox[{"dM", ".", "mM"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"gALM", "[", "mM_", "]"}], ":=", 
     RowBox[{
      RowBox[{"Inverse", "[", 
       RowBox[{
        RowBox[{"IdentityMatrix", "[", "8", "]"}], "-", 
        RowBox[{"fM", ".", "mM"}]}], "]"}], ".", "gM"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ggALM", "[", "mM_", "]"}], ":=", 
     RowBox[{
      RowBox[{"Inverse", "[", 
       RowBox[{
        RowBox[{"IdentityMatrix", "[", "8", "]"}], "-", 
        RowBox[{"fM", ".", "mM"}]}], "]"}], ".", "ggM"}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.505634375065709*^9, 3.5056344984737473`*^9}, {
   3.505634624616794*^9, 3.505634640492099*^9}, {3.505634845292107*^9, 
   3.505634848479648*^9}, {3.505634928090042*^9, 3.5056349338088655`*^9}, 
   3.5056351918423214`*^9, {3.506777521720786*^9, 3.5067775430164347`*^9}, {
   3.50765559725*^9, 3.50765559775*^9}, {3.523615141140625*^9, 
   3.52361514346875*^9}, {3.527010395203125*^9, 3.527010405203125*^9}, {
   3.52709508246875*^9, 3.527095084125*^9}, 3.52709888278125*^9, {
   3.527099991765625*^9, 3.52709999490625*^9}, 3.5272232202561274`*^9, {
   3.5272233035913277`*^9, 3.527223303965728*^9}, 3.527223350968528*^9, 
   3.5272365019785275`*^9, 3.529923961202836*^9, 3.530589984578125*^9, 
   3.53063718046875*^9, 3.53063725515625*^9, {3.57217624528125*^9, 
   3.572176254203125*^9}, {3.572176342953125*^9, 3.572176367296875*^9}, {
   3.57217668246875*^9, 3.572176683203125*^9}, {3.57217683903125*^9, 
   3.572176841296875*^9}, {3.572176935953125*^9, 3.572176936796875*^9}, {
   3.573295084984375*^9, 3.573295085078125*^9}, {3.5732958328125*^9, 
   3.573295833234375*^9}, {3.573296050421875*^9, 3.57329605084375*^9}, {
   3.57329615690625*^9, 3.573296157484375*^9}, 3.5933422357668114`*^9},
 FontSize->10],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"mMold", "=", " ", 
    RowBox[{"Table", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", "8", "}"}], ",", 
      RowBox[{"{", "8", "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", 
    RowBox[{"i", "<", "30002"}], ",", 
    RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"mMnew", "=", 
      RowBox[{"mMold", "+", 
       RowBox[{"0.4", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"mALM", "[", "mMold", "]"}], "-", "mMold"}], ")"}]}]}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"mMold", "=", "mMnew"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mMRE", "=", "mMnew"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Print", "[", "\"\<Initial (for adaptive learning) matrix M:\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"MatrixForm", "[", "mMRE", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  "\"\<Veryfing that all eigevnalues are inside the unit circle:\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"Eigenvalues", "[", "mMRE", "]"}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"hMRE", " ", "=", " ", 
  RowBox[{
   RowBox[{"Inverse", "[", 
    RowBox[{
     RowBox[{"IdentityMatrix", "[", "8", "]"}], "-", 
     RowBox[{
      RowBox[{"Inverse", "[", 
       RowBox[{
        RowBox[{"IdentityMatrix", "[", "8", "]"}], "-", 
        RowBox[{"fM", ".", "mMRE"}]}], "]"}], ".", 
      RowBox[{"(", 
       RowBox[{"dM", "+", "fM"}], ")"}]}]}], "]"}], ".", 
   RowBox[{"Inverse", "[", 
    RowBox[{
     RowBox[{"IdentityMatrix", "[", "8", "]"}], "-", 
     RowBox[{"fM", ".", "mMRE"}]}], "]"}], ".", 
   "nM"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gMRE", "=", 
   RowBox[{
    RowBox[{"Inverse", "[", 
     RowBox[{
      RowBox[{"IdentityMatrix", "[", "8", "]"}], "-", 
      RowBox[{"fM", ".", "mMRE"}]}], "]"}], ".", "gM"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ggMRE", "=", 
   RowBox[{
    RowBox[{"Inverse", "[", 
     RowBox[{
      RowBox[{"IdentityMatrix", "[", "8", "]"}], "-", 
      RowBox[{"fM", ".", "mMRE"}]}], "]"}], ".", "ggM"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Print", "[", "\"\<Initial (for adaptive learning) matrix H:\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"MatrixForm", "[", "hMRE", "]"}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mMInitialAL", "=", "mMRE"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hMInitialAL", "=", "hMRE"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"initialALss", " ", "=", " ", 
   RowBox[{
    RowBox[{"Inverse", "[", 
     RowBox[{
      RowBox[{"IdentityMatrix", "[", "8", "]"}], "-", "mMInitialAL"}], "]"}], 
    ".", "hMInitialAL"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mMwrong", "=", "mMRE"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hMwrong", "=", "hMRE"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"wrongss", " ", "=", " ", 
   RowBox[{
    RowBox[{"Inverse", "[", 
     RowBox[{
      RowBox[{"IdentityMatrix", "[", "8", "]"}], "-", "mMwrong"}], "]"}], ".",
     "hMwrong"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5056346741489954`*^9, 3.505634855042232*^9}, {
   3.5056350332631817`*^9, 3.505635102279248*^9}, {3.5056351532326994`*^9, 
   3.5056351663577833`*^9}, 3.5056352169206066`*^9, {3.5056352476708035`*^9, 
   3.5056352876398096`*^9}, {3.5056419997315617`*^9, 
   3.5056420099035015`*^9}, {3.505647832665542*^9, 3.5056479103535395`*^9}, {
   3.5056479678695326`*^9, 3.505647971697682*^9}, 3.505648366872086*^9, {
   3.505648407903599*^9, 3.5056484278881016`*^9}, {3.5056484636383305`*^9, 
   3.505648465732094*^9}, {3.505649780912386*^9, 3.505649816240737*^9}, 
   3.505649848897196*^9, {3.5056499014600325`*^9, 3.5056499813355436`*^9}, {
   3.5056500180545287`*^9, 3.5056500219295535`*^9}, {3.505650095914402*^9, 
   3.5056501066019707`*^9}, {3.5056502645873566`*^9, 
   3.5056502755718017`*^9}, {3.5057297014164886`*^9, 
   3.5057297147125125`*^9}, {3.505729930557431*^9, 3.505729935650758*^9}, {
   3.507655634125*^9, 3.5076556343125*^9}, {3.507655677515625*^9, 
   3.50765567778125*^9}, {3.527010003390625*^9, 3.527010023140625*^9}, {
   3.52701026153125*^9, 3.527010261765625*^9}, {3.527010336515625*^9, 
   3.527010360640625*^9}, 3.5270104710625*^9, 3.527010528203125*^9, {
   3.527010849390625*^9, 3.527010851421875*^9}, {3.52706066709375*^9, 
   3.527060683609375*^9}, {3.527060717359375*^9, 3.5270607210625*^9}, {
   3.5270608634375*^9, 3.527060879234375*^9}, 3.52706101115625*^9, 
   3.527069657765625*^9, 3.52707010309375*^9, 3.527070455359375*^9, {
   3.527071530390625*^9, 3.527071538234375*^9}, {3.52707182121875*^9, 
   3.527071868890625*^9}, {3.527095055953125*^9, 3.527095072765625*^9}, {
   3.527097265578125*^9, 3.52709726609375*^9}, {3.527098434265625*^9, 
   3.52709843603125*^9}, {3.527100284765625*^9, 3.527100316625*^9}, {
   3.527101643984375*^9, 3.52710164575*^9}, 3.527138346640625*^9, {
   3.5271386724375*^9, 3.527138720515625*^9}, 3.52713882009375*^9, {
   3.527153199890625*^9, 3.52715320415625*^9}, {3.5272218669245276`*^9, 
   3.5272218811985273`*^9}, {3.5272232295849276`*^9, 
   3.5272232301777277`*^9}, {3.5272232638893275`*^9, 3.527223264170128*^9}, 
   3.5272233075849276`*^9, 3.527223392589328*^9, {3.5272235790249276`*^9, 
   3.5272235888841276`*^9}, {3.5272238140067277`*^9, 
   3.5272238252387276`*^9}, {3.527226033745928*^9, 3.527226084024728*^9}, {
   3.5272261601527276`*^9, 3.5272261806199274`*^9}, {3.5272270032703276`*^9, 
   3.5272270066867275`*^9}, {3.5272354514611273`*^9, 
   3.5272354518043275`*^9}, {3.5272363072987275`*^9, 3.527236332102728*^9}, {
   3.5272363794487276`*^9, 3.5272363836451273`*^9}, {3.5272369640557275`*^9, 
   3.5272369699993277`*^9}, {3.5272370612125273`*^9, 
   3.5272370621017275`*^9}, {3.527237261204528*^9, 3.5272372643557277`*^9}, {
   3.527237550787328*^9, 3.5272375522069273`*^9}, {3.5272376841361275`*^9, 
   3.5272376846353273`*^9}, 3.5272378210729275`*^9, 3.5272379410993276`*^9, 
   3.5272379820181274`*^9, {3.5273304290103273`*^9, 3.527330431007127*^9}, 
   3.527331492080927*^9, 3.527331657940127*^9, 3.5273978681923428`*^9, {
   3.5273984755159426`*^9, 3.527398482379943*^9}, {3.527399256886343*^9, 
   3.527399259366743*^9}, {3.527399719207943*^9, 3.527399719675943*^9}, {
   3.527399886003143*^9, 3.527399904972743*^9}, {3.5273999723959427`*^9, 
   3.527399992020743*^9}, 3.5278279235601215`*^9, 3.5298225054005604`*^9, {
   3.5298226347089605`*^9, 3.52982264363216*^9}, {3.5298226861109605`*^9, 
   3.5298226899485607`*^9}, 3.5298323372130003`*^9, 3.5298324891102*^9, 
   3.5299221712686357`*^9, {3.529922531170236*^9, 3.529922576488236*^9}, 
   3.529923384704836*^9, 3.529923938177236*^9, {3.53051492440104*^9, 
   3.5305149245102406`*^9}, {3.5305156794410405`*^9, 
   3.5305156802210407`*^9}, {3.5305157590634403`*^9, 
   3.5305157593754406`*^9}, {3.5305159096190405`*^9, 3.5305159100402403`*^9}, 
   3.530585239046875*^9, 3.530587061359375*^9, 3.53058755678125*^9, 
   3.5305880575*^9, {3.5305885754375*^9, 3.530588576125*^9}, {
   3.53058876978125*^9, 3.530588770515625*^9}, {3.530588867484375*^9, 
   3.5305888718125*^9}, {3.530588933890625*^9, 3.530588939171875*^9}, {
   3.530589763734375*^9, 3.53058976746875*^9}, 3.53058979884375*^9, {
   3.530590040890625*^9, 3.530590058765625*^9}, {3.53059012953125*^9, 
   3.5305901298125*^9}, {3.53059080540625*^9, 3.530590806421875*^9}, 
   3.530590925*^9, 3.530591521375*^9, {3.530591597671875*^9, 
   3.5305915979375*^9}, {3.530600899671875*^9, 3.53060090121875*^9}, 
   3.53060096828125*^9, {3.5306214403125*^9, 3.530621442453125*^9}, {
   3.5306217703125*^9, 3.53062177090625*^9}, {3.530621975921875*^9, 
   3.53062197725*^9}, {3.5306234259375*^9, 3.530623426421875*^9}, {
   3.53063046753125*^9, 3.530630470140625*^9}, {3.530632113421875*^9, 
   3.53063212259375*^9}, 3.530632387515625*^9, 3.53063294953125*^9, 
   3.5306330983125*^9, 3.530633954546875*^9, 3.530634026890625*^9, 
   3.53063585625*^9, 3.530635961171875*^9, 3.530636125484375*^9, 
   3.530636277578125*^9, {3.530981960671875*^9, 3.53098196359375*^9}, {
   3.53098267284375*^9, 3.530982673578125*^9}, {3.5309829729375*^9, 
   3.530982973078125*^9}, {3.53098307065625*^9, 3.530983071390625*^9}, {
   3.53098459028125*^9, 3.530984594328125*^9}, 3.53098468578125*^9, {
   3.530986356484375*^9, 3.530986358625*^9}, {3.53098717225*^9, 
   3.53098717271875*^9}, {3.53098724803125*^9, 3.530987248703125*^9}, {
   3.531035669648363*^9, 3.5310356738759627`*^9}, {3.531035786273963*^9, 
   3.531035786741963*^9}, {3.5320831798217382`*^9, 3.532083180976138*^9}, {
   3.532083219445738*^9, 3.532083219882538*^9}, {3.532084575816538*^9, 
   3.5320846077185383`*^9}, {3.532084894087738*^9, 3.532084901357338*^9}, {
   3.532088722542738*^9, 3.532088747939538*^9}, 3.5321507697023525`*^9, {
   3.5321508845339527`*^9, 3.5321508875759525`*^9}, 3.5321510315639524`*^9, 
   3.5321511551315527`*^9, {3.5321512448315525`*^9, 3.5321512475771527`*^9}, 
   3.5321515714643526`*^9, {3.5321518021103525`*^9, 3.532151833138753*^9}, {
   3.5321520948695526`*^9, 3.532152099331153*^9}, {3.532244820633136*^9, 
   3.532244826545536*^9}, {3.532322491749751*^9, 3.5323224918433514`*^9}, {
   3.5323231980553513`*^9, 3.5323232041705513`*^9}, {3.5323236342253513`*^9, 
   3.5323236346933513`*^9}, {3.5323246779433513`*^9, 3.532324679768551*^9}, {
   3.532337817953125*^9, 3.532337822984375*^9}, {3.53234102503125*^9, 
   3.5323410255625*^9}, {3.533120111421875*^9, 3.53312011334375*^9}, {
   3.545128650765625*^9, 3.545128661484375*^9}, {3.5451300224375*^9, 
   3.5451300276875*^9}, {3.545130103953125*^9, 3.54513012884375*^9}, {
   3.54513130759375*^9, 3.54513130840625*^9}, {3.5451326658125*^9, 
   3.5451326685625*^9}, {3.545133205359375*^9, 3.54513320634375*^9}, {
   3.545135290859375*^9, 3.54513529128125*^9}, {3.5451355593125*^9, 
   3.545135560359375*^9}, {3.5451374494375*^9, 3.5451374499375*^9}, {
   3.545137538890625*^9, 3.545137539125*^9}, {3.545138346890625*^9, 
   3.54513834753125*^9}, {3.5451384204375*^9, 3.54513842090625*^9}, {
   3.545138649328125*^9, 3.545138674296875*^9}, {3.5453000161875*^9, 
   3.545300019078125*^9}, {3.5488466655625*^9, 3.548846667921875*^9}, 
   3.5488471413125*^9, 3.5488472200625*^9, 3.548847368625*^9, {
   3.5488474801875*^9, 3.548847480984375*^9}, {3.548847522125*^9, 
   3.548847523078125*^9}, {3.54884792853125*^9, 3.54884792903125*^9}, {
   3.54884798771875*^9, 3.54884798784375*^9}, 3.549085232984375*^9, 
   3.549085459578125*^9, {3.5490855159375*^9, 3.54908551615625*^9}, {
   3.54908561334375*^9, 3.549085614359375*^9}, {3.5490862490625*^9, 
   3.54908624946875*^9}, {3.549086331734375*^9, 3.54908633290625*^9}, {
   3.54908639628125*^9, 3.549086396609375*^9}, {3.549086459921875*^9, 
   3.549086461*^9}, {3.549458753640625*^9, 3.549458753984375*^9}, {
   3.5494588008125*^9, 3.549458802203125*^9}, {3.549803556015625*^9, 
   3.549803558171875*^9}, {3.549803830546875*^9, 3.5498038306875*^9}, {
   3.54980521025*^9, 3.549805210421875*^9}, {3.54980526515625*^9, 
   3.549805265265625*^9}, {3.54980551025*^9, 3.549805510359375*^9}, {
   3.54980562121875*^9, 3.549805621375*^9}, {3.54980582759375*^9, 
   3.54980585853125*^9}, {3.5498059429375*^9, 3.549805944625*^9}, {
   3.549806015359375*^9, 3.549806016046875*^9}, {3.54980608440625*^9, 
   3.54980608465625*^9}, {3.549814259640625*^9, 3.549814260328125*^9}, {
   3.5498143123125*^9, 3.549814313484375*^9}, {3.549814423109375*^9, 
   3.549814424984375*^9}, {3.549814639953125*^9, 3.549814640546875*^9}, {
   3.5498146793125*^9, 3.54981468134375*^9}, {3.5498147884375*^9, 
   3.549814791625*^9}, 3.5498148914375*^9, {3.549815018546875*^9, 
   3.5498150416875*^9}, {3.549815217453125*^9, 3.549815217640625*^9}, {
   3.550575575015625*^9, 3.55057557534375*^9}, {3.5505756178125*^9, 
   3.550575619125*^9}, {3.550578331109375*^9, 3.5505783318125*^9}, {
   3.550578554609375*^9, 3.550578554734375*^9}, {3.550578709421875*^9, 
   3.550578710453125*^9}, {3.550582472921875*^9, 3.550582473609375*^9}, {
   3.5505826799375*^9, 3.55058268003125*^9}, {3.55058301425*^9, 
   3.550583043703125*^9}, {3.55058312375*^9, 3.550583137625*^9}, {
   3.5505832255625*^9, 3.550583226140625*^9}, {3.550583296234375*^9, 
   3.550583296546875*^9}, {3.55058348925*^9, 3.5505834893125*^9}, {
   3.55058352803125*^9, 3.5505835281875*^9}, {3.550583559625*^9, 
   3.550583560203125*^9}, {3.55058362959375*^9, 3.55058362990625*^9}, {
   3.55059083878125*^9, 3.5505908389375*^9}, {3.55059097240625*^9, 
   3.550590973*^9}, {3.55059101909375*^9, 3.5505910198125*^9}, {
   3.5505910595625*^9, 3.5505910601875*^9}, {3.550591121625*^9, 
   3.550591122640625*^9}, 3.57017200146875*^9, {3.5721562067349634`*^9, 
   3.5721562078130884`*^9}, {3.5721562628130884`*^9, 
   3.5721562629537134`*^9}, {3.5721563068130884`*^9, 3.5721563093755884`*^9}, 
   3.5721564154849634`*^9, {3.572178252625*^9, 3.57217825675*^9}, 
   3.572181913515625*^9, {3.572182004828125*^9, 3.5721820061875*^9}, {
   3.572335626753683*^9, 3.572335627268483*^9}, 3.572759792434244*^9, 
   3.572759909802644*^9, 3.572760097938644*^9, 3.5727601525698442`*^9, {
   3.5729276436620913`*^9, 3.5729276439272914`*^9}, {3.5730607919375*^9, 
   3.573060794890625*^9}, {3.573060887234375*^9, 3.57306089128125*^9}, {
   3.573061236453125*^9, 3.573061239125*^9}, {3.573297888015625*^9, 
   3.5732978924375*^9}, {3.5933422404544315`*^9, 3.5933423089093084`*^9}, {
   3.594313942606165*^9, 3.5943139446515293`*^9}, {3.594315031970891*^9, 
   3.5943150331927032`*^9}, {3.594323125450246*^9, 3.5943231269592543`*^9}, {
   3.5944392409187365`*^9, 3.5944392417923365`*^9}, {3.5944481438683367`*^9, 
   3.5944481442739367`*^9}, {3.5944527618041368`*^9, 
   3.5944527623501368`*^9}, {3.59636417437824*^9, 3.5963641753208666`*^9}, {
   3.6634865199568453`*^9, 3.663486520641859*^9}, {3.663486550764638*^9, 
   3.663486571747681*^9}, {3.663486777776614*^9, 3.663486779214143*^9}, {
   3.6634868506628017`*^9, 3.6634868524828386`*^9}, {3.663489189706888*^9, 
   3.6634891903319035`*^9}, {3.7364189405683208`*^9, 
   3.7364189554791737`*^9}, {3.7364190684556355`*^9, 3.736419094358117*^9}, {
   3.7364265153305726`*^9, 3.736426515619589*^9}},
 FontSize->10],

Cell[CellGroupData[{

Cell[BoxData["\<\"Initial (for adaptive learning) matrix M:\"\>"], "Print",
 CellChangeTimes->{3.7364277753186398`*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", "0.17862545516527661`"}], "0.`", "0.`", "0.`", 
      RowBox[{"-", "0.07172874203297015`"}], "0.9683840933389262`", 
      "0.07516556149929877`", "0.`"},
     {
      RowBox[{"-", "0.04487095726724121`"}], "0.`", "0.`", "0.`", 
      RowBox[{"-", "0.018018357549411747`"}], "0.24325940124425152`", 
      "0.5345086409111353`", "0.`"},
     {"0.10213008431667153`", "0.`", "0.`", "0.`", "0.04101130191650351`", 
      RowBox[{"-", "0.5536789200179665`"}], 
      RowBox[{"-", "0.03696870199790217`"}], "0.`"},
     {"0.2236227654203519`", "0.`", "0.`", "0.`", "0.08979783782045136`", 
      RowBox[{"-", "1.2123284933894853`"}], 
      RowBox[{"-", "0.09722774754008813`"}], "0.`"},
     {
      RowBox[{"-", "0.02243547863362061`"}], "0.`", "0.`", "0.`", 
      RowBox[{"-", "0.009009178774705875`"}], "0.12162970062212577`", 
      "1.2672543204555675`", "0.`"},
     {
      RowBox[{"-", "0.2099249692437838`"}], "0.`", "0.`", "0.`", 
      RowBox[{"-", "0.08429735812980393`"}], "1.1380684842608095`", 
      "0.10482300389012408`", "0.`"},
     {"0.`", "0.`", "0.`", "0.`", "0.`", "0.`", "0.9756370543817914`", "0.`"},
     {"0.`", "0.`", "0.`", "0.`", "0.`", "0.`", "0.`", "0.`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{3.73642777532364*^9}],

Cell[BoxData["\<\"Veryfing that all eigevnalues are inside the unit circle:\"\
\>"], "Print",
 CellChangeTimes->{3.7364277753256397`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.9756370543817914`", ",", "0.9504338503208272`", ",", "0.`", ",", "0.`", 
   ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`"}], "}"}]], "Print",
 CellChangeTimes->{3.7364277753286405`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.5998580635735582`"}], ",", 
   RowBox[{"-", "1.0074806128281832`"}], ",", "1.261909028527294`", ",", 
   RowBox[{"-", "0.9608531761308201`"}], ",", 
   RowBox[{"-", "0.8983852628772268`"}], ",", 
   RowBox[{"-", "0.2855078686159559`"}], ",", 
   RowBox[{"-", "0.006340543399466482`"}], ",", "0.`"}], "}"}]], "Output",
 CellChangeTimes->{3.7364277753316402`*^9}],

Cell[CellGroupData[{

Cell[BoxData["\<\"Initial (for adaptive learning) matrix H:\"\>"], "Print",
 CellChangeTimes->{3.7364277753326406`*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       RowBox[{"-", "1.5998580635735582`"}]},
      {
       RowBox[{"-", "1.0074806128281832`"}]},
      {"1.261909028527294`"},
      {
       RowBox[{"-", "0.9608531761308201`"}]},
      {
       RowBox[{"-", "0.8983852628772268`"}]},
      {
       RowBox[{"-", "0.2855078686159559`"}]},
      {
       RowBox[{"-", "0.006340543399466482`"}]},
      {"0.`"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{3.7364277753336406`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Computing", " ", "E"}], "-", 
    RowBox[{"stability", " ", "condition"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   StyleBox[
    RowBox[{
     RowBox[{"ESTAB1", "=", 
      RowBox[{
       RowBox[{"KroneckerProduct", "[", 
        RowBox[{
         RowBox[{"Transpose", "[", 
          RowBox[{
           RowBox[{"Inverse", "[", 
            RowBox[{
             RowBox[{"IdentityMatrix", "[", "8", "]"}], "-", 
             RowBox[{"fM", ".", "mMRE"}]}], "]"}], ".", "aM"}], "]"}], ",", 
         RowBox[{
          RowBox[{"Inverse", "[", 
           RowBox[{
            RowBox[{"IdentityMatrix", "[", "8", "]"}], "-", 
            RowBox[{"fM", ".", "mMRE"}]}], "]"}], ".", "fM"}]}], "]"}], "+", 
       RowBox[{"KroneckerProduct", "[", 
        RowBox[{
         RowBox[{"Transpose", "[", 
          RowBox[{
           RowBox[{"Inverse", "[", 
            RowBox[{
             RowBox[{"IdentityMatrix", "[", "8", "]"}], "-", 
             RowBox[{"fM", ".", "mMRE"}]}], "]"}], ".", "dM", ".", "mMRE"}], 
          "]"}], ",", 
         RowBox[{
          RowBox[{"Inverse", "[", 
           RowBox[{
            RowBox[{"IdentityMatrix", "[", "8", "]"}], "-", 
            RowBox[{"fM", ".", "mMRE"}]}], "]"}], ".", "fM"}]}], "]"}], "+", 
       RowBox[{"KroneckerProduct", "[", 
        RowBox[{
         RowBox[{"IdentityMatrix", "[", "8", "]"}], ",", 
         RowBox[{
          RowBox[{"Inverse", "[", 
           RowBox[{
            RowBox[{"IdentityMatrix", "[", "8", "]"}], "-", 
            RowBox[{"fM", ".", "mMRE"}]}], "]"}], ".", "dM"}]}], "]"}]}]}], 
     ";"}],
    FontFamily->"Courier New",
    FontSize->10], 
   StyleBox["\[IndentingNewLine]",
    FontFamily->"Courier New",
    FontSize->10], 
   StyleBox[
    RowBox[{"Eigenvalues", "[", "ESTAB1", "]"}],
    FontFamily->"Courier New",
    FontSize->10], 
   StyleBox["\[IndentingNewLine]",
    FontFamily->"Courier New",
    FontSize->10], 
   StyleBox[
    RowBox[{
     RowBox[{"Eigenvalues", "[", 
      RowBox[{
       RowBox[{"Inverse", "[", 
        RowBox[{
         RowBox[{"IdentityMatrix", "[", "8", "]"}], "-", 
         RowBox[{"fM", ".", "mMRE"}]}], "]"}], ".", 
       RowBox[{"(", 
        RowBox[{"dM", "+", "fM"}], ")"}]}], "]"}], ";"}],
    FontFamily->"Courier New",
    FontSize->10], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.594451064105937*^9, 3.5944510651667366`*^9}, 
   3.5944511057579365`*^9, 3.5963630681171913`*^9, {3.736419104408692*^9, 
   3.736419112901178*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.9420170773400954`", ",", "0.9176792124694148`", ",", 
   "0.8822380127531546`", ",", "0.8594803079715039`", ",", 
   RowBox[{"-", "0.0007907259550771701`"}], ",", 
   RowBox[{"-", "0.0007906985280608486`"}], ",", "0.0003566362446911014`", 
   ",", "0.00035663624469079065`", ",", "0.00035663624469079065`", ",", 
   "0.00035663624469079065`", ",", "0.00035663624469079065`", ",", 
   "0.00035663624469063594`", ",", "2.213344435597303`*^-16", ",", 
   RowBox[{"-", "1.836019782987567`*^-16"}], ",", "1.4208099670035967`*^-17", 
   ",", "1.4208099670035967`*^-17", ",", "0.`", ",", "0.`", ",", "0.`", ",", 
   "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", 
   "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", 
   "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", 
   "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", 
   "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", 
   "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", 
   "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", 
   "0.`", ",", "0.`", ",", "0.`"}], "}"}]], "Output",
 CellChangeTimes->{{3.594451097957937*^9, 3.594451109096337*^9}, 
   3.594451194343337*^9, 3.5944514017609367`*^9, 3.594452062066137*^9, 
   3.5944521878801365`*^9, {3.5944526659265366`*^9, 3.5944526855311365`*^9}, 
   3.594452810853337*^9, 3.594453046872737*^9, {3.594453101503937*^9, 
   3.594453129452137*^9}, 3.5944532118357368`*^9, 3.5947205882866926`*^9, 
   3.5947206402974095`*^9, 3.594723192844734*^9, 3.5947232837464128`*^9, 
   3.594723315065324*^9, 3.5947233469566126`*^9, 3.594723588145667*^9, 
   3.5947237504119825`*^9, 3.5947239882037134`*^9, 3.5947241461451445`*^9, 
   3.5947329417738085`*^9, 3.5947329910386877`*^9, 3.594733052517727*^9, 
   3.5947331374974575`*^9, 3.5947332161549625`*^9, 3.594733299451399*^9, 
   3.594733344511399*^9, 3.5947333824938*^9, 3.5947336645624933`*^9, 
   3.5947338627788086`*^9, 3.5947339427391777`*^9, 3.594734004686529*^9, 
   3.594734109513503*^9, 3.5947341724114885`*^9, 3.594734325953219*^9, 
   3.5947344297902966`*^9, 3.594734519745342*^9, 3.5947346066763754`*^9, 
   3.594734679072696*^9, 3.5947347597855873`*^9, 3.5947349657870855`*^9, 
   3.5947350871420975`*^9, 3.59473523470159*^9, 3.5947353528744745`*^9, 
   3.5947355144063025`*^9, 3.5947355666461697`*^9, 3.594735640709609*^9, 
   3.594735802972928*^9, 3.5947358791757946`*^9, 3.5947360225655065`*^9, 
   3.594736094916807*^9, 3.5947361605987577`*^9, 3.5947362074379168`*^9, 
   3.5947364774707985`*^9, 3.5961074212710257`*^9, 3.5963620504960427`*^9, 
   3.596363047760664*^9, 3.59636311534676*^9, 3.5963631827715664`*^9, 
   3.596364159882613*^9, 3.596367789405412*^9, 3.66348367213147*^9, 
   3.6634839380602713`*^9, 3.663484007362812*^9, 3.6634840519813323`*^9, 
   3.6634841377626843`*^9, 3.6634842340598125`*^9, 3.6634844010380783`*^9, 
   3.6634844705161676`*^9, 3.6634845112439456`*^9, 3.663484621299294*^9, 
   3.663484686837431*^9, 3.663484801156663*^9, 3.663484900611238*^9, 
   3.663484955363521*^9, 3.6634850234393435`*^9, 3.663485228724625*^9, 
   3.663485392886985*^9, 3.6634854469443054`*^9, 3.6634855879528923`*^9, 
   3.663485661691899*^9, 3.663485748759843*^9, 3.663485814499582*^9, 
   3.6634858825174456`*^9, 3.663485950708748*^9, 3.6634860183743596`*^9, 
   3.663486349176983*^9, 3.6634863884928775`*^9, {3.663486509724536*^9, 
   3.6634865253724985`*^9}, 3.6634865592463727`*^9, 3.6634866155336204`*^9, 
   3.6634866790670624`*^9, 3.6634867990412006`*^9, 3.663486869175733*^9, 
   3.6634869972914276`*^9, 3.6634870770581703`*^9, 3.6634871154915457`*^9, 
   3.66348726604128*^9, 3.6634873480191126`*^9, 3.6634882762551928`*^9, 
   3.6634883119693766`*^9, 3.663488361420469*^9, 3.663488410112554*^9, 
   3.6634884477623124`*^9, 3.6634884963393955`*^9, 3.6634885832531157`*^9, 
   3.6634886243709784`*^9, 3.6634886765396767`*^9, 3.6634891194135923`*^9, {
   3.6634892631699195`*^9, 3.6634892895926948`*^9}, 3.663489349298508*^9, 
   3.663490019585658*^9, 3.6634900694251747`*^9, 3.6634901508956413`*^9, 
   3.6634902457839804`*^9, 3.6634906021996*^9, 3.6634906339004374`*^9, 
   3.6634907086705446`*^9, 3.6635698557833705`*^9, 3.6635699183367386`*^9, 
   3.663570016702346*^9, 3.6635700778802347`*^9, 3.6635701333470325`*^9, 
   3.6635701734575615`*^9, 3.663570281892*^9, 3.663570492708457*^9, 
   3.663570566911148*^9, 3.6635706223469057`*^9, 3.663570661308857*^9, 
   3.663570734649932*^9, 3.6635709883669386`*^9, 3.6635711601104975`*^9, 
   3.6635720635039916`*^9, 3.663572320593358*^9, 3.6635901071060357`*^9, 
   3.663590227474555*^9, 3.6635903154365606`*^9, 3.6635903770958843`*^9, 
   3.663590476629985*^9, 3.6635905532236314`*^9, 3.6635907137569914`*^9, 
   3.663591156379982*^9, 3.6635916033091736`*^9, 3.6635916379240046`*^9, 
   3.6635917849831085`*^9, 3.6635919260440755`*^9, 3.6635919705951056`*^9, 
   3.663592504939951*^9, 3.6635926180783396`*^9, 3.6635928362828894`*^9, 
   3.663592954319388*^9, 3.663593047651409*^9, {3.6635931168529363`*^9, 
   3.663593131031336*^9}, 3.6635932232673264`*^9, 3.6635933317576447`*^9, 
   3.663593375332634*^9, 3.663593457566408*^9, 3.663593576878933*^9, 
   3.6635939345968556`*^9, 3.663594014561429*^9, 3.6635941027914753`*^9, 
   3.663594139312565*^9, 3.6635942262565374`*^9, 3.663594366320549*^9, 
   3.6635946374930587`*^9, 3.6635946905990963`*^9, 3.6635947487814245`*^9, 
   3.6635948625179296`*^9, 3.663594985295952*^9, 3.663928177848905*^9, 
   3.6639330772900953`*^9, 3.6639337046482315`*^9, 3.6639339431748743`*^9, 
   3.663934505581702*^9, 3.6639352074487333`*^9, 3.6639352805442543`*^9, 
   3.6639353729285693`*^9, 3.6639354640772963`*^9, 3.663935883606409*^9, 
   3.6639359875426702`*^9, 3.663936025896782*^9, 3.6639361128473525`*^9, 
   3.663936231522229*^9, 3.663936351494114*^9, 3.6639369126032467`*^9, 
   3.6639370415980206`*^9, 3.6639371134975*^9, 3.6639371723964386`*^9, 
   3.6639373032028418`*^9, 3.663937450461322*^9, 3.663937847513273*^9, 
   3.6639379059036913`*^9, 3.663937949029503*^9, 3.6639380515857735`*^9, 
   3.663938097999711*^9, 3.663938223873885*^9, 3.6639382926768484`*^9, 
   3.6639383423589706`*^9, 3.663938384974526*^9, 3.6639384212384377`*^9, 
   3.663938524260709*^9, 3.6639386242198524`*^9, 3.6639387413334656`*^9, 
   3.663938787182992*^9, 3.6639388527270255`*^9, 3.6639390642657566`*^9, 
   3.663939124340232*^9, 3.6639392102077446`*^9, 3.663939330885702*^9, 
   3.6639393629021235`*^9, 3.6639394299198647`*^9, 3.663939485368682*^9, 
   3.6639395520319633`*^9, 3.6639395991154485`*^9, 3.663939630101765*^9, 
   3.663939660604114*^9, 3.663939728824931*^9, 3.663939782036667*^9, 
   3.663939817641686*^9, 3.663939881394368*^9, 3.6639399234811945`*^9, 
   3.6639399765575547`*^9, 3.6639400480445147`*^9, 3.663940142454893*^9, 
   3.66394020004726*^9, 3.6639402406400337`*^9, 3.6639402863599663`*^9, 
   3.6639403452504187`*^9, 3.663940429114355*^9, 3.6639405167809763`*^9, {
   3.663940615134515*^9, 3.6639406434087486`*^9}, 3.6639407140906696`*^9, 
   3.6639407482956295`*^9, 3.6639407829240904`*^9, 3.66394081470045*^9, 
   3.663940858125281*^9, 3.6639409125005226`*^9, {3.663940945063925*^9, 
   3.6639409718830876`*^9}, 3.663941008068127*^9, 3.663941065576486*^9, 
   3.6639411151160297`*^9, 3.663941153571642*^9, 3.663941207533906*^9, 
   3.663941251181716*^9, 3.6639413187060423`*^9, 3.663941371941749*^9, 
   3.663941826848503*^9, 3.663941874238973*^9, {3.6639422642746983`*^9, 
   3.6639422909614296`*^9}, {3.663942338008999*^9, 3.663942364599699*^9}, 
   3.6639423949039435`*^9, 3.6639426293985224`*^9, 3.6639427419326057`*^9, 
   3.663943018793642*^9, 3.6639433693646994`*^9, 3.6639437376765347`*^9, 
   3.6639438198139715`*^9, 3.6639439673731203`*^9, 3.663944063455666*^9, 
   3.6639441359962187`*^9, 3.663944201117423*^9, 3.66394465614482*^9, 
   3.66394471405372*^9, 3.6639447685364847`*^9, 3.66394483544228*^9, 
   3.663944876170005*^9, 3.6639453145931597`*^9, 3.663945384191558*^9, 
   3.6639456186121883`*^9, 3.6639456975769253`*^9, 3.6639457798673487`*^9, 
   3.6639948653662233`*^9, 3.6639951329254203`*^9, 3.6639952752508955`*^9, 
   3.6639953252055025`*^9, 3.6639953987598867`*^9, 3.6639954433662834`*^9, 
   3.663995518394967*^9, {3.663995550749922*^9, 3.663995573440081*^9}, 
   3.663995615604357*^9, 3.663995669937484*^9, 3.6639957223046813`*^9, 
   3.6639978335185823`*^9, 3.6639978894412117`*^9, 3.6639984481083283`*^9, 
   3.6639986380237255`*^9, 3.66399873142258*^9, 3.664001120150794*^9, 
   3.664001307312314*^9, 3.664001394998768*^9, 3.664001597180997*^9, 
   3.6640016433797827`*^9, 3.664001684505309*^9, 3.664002396763631*^9, 
   3.664002541239959*^9, 3.664002577650216*^9, 3.664002701179676*^9, 
   3.6640027904299107`*^9, 3.664003352075493*^9, 3.664004336815544*^9, 
   3.664004404896513*^9, 3.6640044640792856`*^9, 3.664004524062975*^9, 
   3.6640056304587216`*^9, 3.664005828699191*^9, 3.6640075320994177`*^9, 
   3.6640075982094336`*^9, {3.6640077233590727`*^9, 3.66400775040073*^9}, 
   3.664007783680785*^9, 3.664007815240742*^9, {3.6640078788606453`*^9, 
   3.664007935220131*^9}, {3.6640079703887243`*^9, 3.6640079999855957`*^9}, {
   3.664008043405929*^9, 3.664008071894846*^9}, 3.664008360860061*^9, 
   3.6640084351964064`*^9, 3.6640084976624355`*^9, {3.664008539603808*^9, 
   3.664008575417527*^9}, 3.6640086086692533`*^9, 3.6640887865121336`*^9, 
   3.6640888894794416`*^9, 3.6640889990700407`*^9, 3.66408945856365*^9, 
   3.664089662409574*^9, 3.664089693774229*^9, 3.664089772121763*^9, {
   3.6640898369622145`*^9, 3.6640898647576714`*^9}, 3.66408991852402*^9, 
   3.664090065524801*^9, 3.6640916093780527`*^9, 3.6640916692171965`*^9, 
   3.6640917105693855`*^9, 3.664091773880633*^9, 3.6640918130226307`*^9, 
   3.6640920289695883`*^9, 3.664092169630782*^9, 3.664092409020966*^9, 
   3.664092472102233*^9, 3.6640925270651712`*^9, 3.664092587226283*^9, 
   3.664092672999238*^9, 3.664092725952983*^9, {3.664092756486087*^9, 
   3.664092774807061*^9}, 3.664093202935005*^9, 3.664093246933339*^9, 
   3.664093356883996*^9, 3.6640934541430073`*^9, 3.6640937096777277`*^9, 
   3.664098863249139*^9, 3.664099042539812*^9, 3.66409929515561*^9, 
   3.6640994282015963`*^9, 3.6640995188291483`*^9, 3.66409969270339*^9, 
   3.664099890633518*^9, 3.664100078695827*^9, 3.6641002013308268`*^9, 
   3.664100577613662*^9, 3.664100791646286*^9, 3.664100838934593*^9, 
   3.664100916422353*^9, 3.664101420887476*^9, 3.6641014886279554`*^9, 
   3.664101764427046*^9, 3.6641018676618395`*^9, 3.664102007975438*^9, 
   3.6641022553187127`*^9, 3.664102560939541*^9, 3.6641109155919495`*^9, 
   3.664112091340974*^9, 3.6641764081782074`*^9, 3.6693695509878874`*^9, 
   3.6693705195104485`*^9, 3.6693706351165247`*^9, 3.669370854850155*^9, 
   3.6693756597743177`*^9, 3.6693757092219195`*^9, 3.66937575157032*^9, 
   3.66937605576293*^9, 3.669376498876364*^9, 3.6693767298045683`*^9, 
   3.669377071233364*^9, 3.6693772015670304`*^9, 3.6694644603358994`*^9, 
   3.6694655453324647`*^9, 3.6694656003623023`*^9, 3.669465829644062*^9, 
   3.6697201174316406`*^9, 3.6697204138215933`*^9, 3.6701350635036025`*^9, 
   3.676630914461937*^9, 3.6767897441431236`*^9, 3.6768821115280223`*^9, 
   3.6768877169122953`*^9, 3.681540839153295*^9, 3.6816219156654525`*^9, 
   3.6816397351705575`*^9, 3.6840379675037546`*^9, 3.684661051479857*^9, 
   3.684673434897787*^9, 3.6846735437580137`*^9, 3.6846736807618504`*^9, 
   3.6846737680498424`*^9, 3.6846738660664487`*^9, 3.7005594368908377`*^9, 
   3.7005595483922153`*^9, 3.7364146207702427`*^9, 3.7364149989038706`*^9, 
   3.7364261886078854`*^9, 3.736426288509599*^9, 3.7364265327975717`*^9, 
   3.736426971206647*^9, 3.736427775391644*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
4. Model-generated recession under adaptive (constant-gain) learning\
\>", "Section",
 CellChangeTimes->{{3.7356448623853836`*^9, 3.735644865758577*^9}, {
   3.735909063786222*^9, 3.7359091043105397`*^9}, {3.736419253570224*^9, 
   3.736419288226206*^9}, {3.736421928112199*^9, 3.736421942208005*^9}, 
   3.7364263916644993`*^9}],

Cell[CellGroupData[{

Cell["Initialization", "Subsubsection",
 CellChangeTimes->{{3.506692861375718*^9, 3.5066928842815285`*^9}, 
   3.7364204115914583`*^9},
 FontSize->10],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.5066928899689198`*^9, 3.5066928930782347`*^9}, {
   3.5066934010216074`*^9, 3.5066934848168736`*^9}, {3.5067754954703784`*^9, 
   3.5067755061221037`*^9}, {3.5067757154714785`*^9, 3.506775764159552*^9}, {
   3.506775851125236*^9, 3.50677585165653*^9}, {3.506776593689313*^9, 
   3.5067766000796924`*^9}, {3.5067768239919977`*^9, 3.50677683460083*^9}, {
   3.506777176005224*^9, 3.506777181911172*^9}, 3.506777228643154*^9, 
   3.506833143494232*^9, {3.506833244117836*^9, 3.5068332690081425`*^9}, {
   3.5068335104069643`*^9, 3.506833510906948*^9}, {3.506833656450548*^9, 
   3.506833667169161*^9}, {3.506833738246376*^9, 3.5068337696209745`*^9}, {
   3.5068339262595944`*^9, 3.5068339284001923`*^9}, 3.5068340225239873`*^9, {
   3.506834089273133*^9, 3.5068341508035955`*^9}, {3.506839922361108*^9, 
   3.5068399929535017`*^9}, {3.5068400512180085`*^9, 3.5068400584522443`*^9}, 
   3.5068401009514284`*^9, 3.506840227261503*^9, 3.506840468085204*^9, {
   3.50684072878666*^9, 3.5068407296460295`*^9}, 3.506841121921961*^9, {
   3.5068411758428*^9, 3.506841176030297*^9}, {3.5068412330917015`*^9, 
   3.5068412437008724`*^9}, {3.506841793303535*^9, 3.506841794912879*^9}, {
   3.506841859911631*^9, 3.5068418607866144`*^9}, 3.5068425652262135`*^9, 
   3.5068431992296658`*^9, 3.506843256619189*^9, {3.506843319446108*^9, 
   3.5068433208367057`*^9}, 3.50684376406288*^9, {3.5068450366260448`*^9, 
   3.5068450411259007`*^9}, {3.506845311945359*^9, 3.50684531583586*^9}, {
   3.506845384552411*^9, 3.506845385021146*^9}, 3.5068457219281807`*^9, {
   3.5068457808779097`*^9, 3.506845782409072*^9}, {3.506845924120825*^9, 
   3.506845924823923*^9}, 3.506845982071725*^9, 3.5068460965673275`*^9, 
   3.5068525540893865`*^9, 3.5068525927761436`*^9, {3.506861915766*^9, 
   3.5068619164056*^9}, 3.5068619501328*^9, {3.5068621651632*^9, 
   3.5068621654596*^9}, {3.5068624891127996`*^9, 3.5068624893624*^9}, {
   3.5068625300004*^9, 3.5068625326056004`*^9}, 3.5068626882936*^9, 
   3.506862970638*^9, 3.5068631527368*^9, {3.5068633571904*^9, 
   3.5068633578768*^9}, 3.5068638667332*^9, {3.5068639302564*^9, 
   3.5068639306932*^9}, {3.5068639618932*^9, 3.5068639897548*^9}, {
   3.5068640862096*^9, 3.5068641167855997`*^9}, {3.5069373648314734`*^9, 
   3.5069373653306737`*^9}, {3.5069422080482736`*^9, 3.506942209421074*^9}, {
   3.5069429716994734`*^9, 3.5069430043190737`*^9}, {3.5069431166546736`*^9, 
   3.5069431184642735`*^9}, {3.5069432227034736`*^9, 
   3.5069432630450735`*^9}, {3.5069434424138737`*^9, 
   3.5069434777322736`*^9}, {3.506952146567874*^9, 3.506952183961074*^9}, {
   3.5069522349886737`*^9, 3.5069522356594734`*^9}, {3.506952270915474*^9, 
   3.5069522968270736`*^9}, {3.5069523357646737`*^9, 
   3.5069523534706736`*^9}, {3.5069529472062736`*^9, 3.506952980449874*^9}, {
   3.5069531936082735`*^9, 3.5069532241530733`*^9}, {3.507006483808694*^9, 
   3.507006484479494*^9}, {3.5070065349142942`*^9, 3.507006535335494*^9}, 
   3.507007339421894*^9, 3.507007569849494*^9, {3.507008685649494*^9, 
   3.507008688909894*^9}, {3.5070088142246943`*^9, 3.507008814677094*^9}, 
   3.507009109173894*^9, {3.5070091495154943`*^9, 3.5070091500926943`*^9}, 
   3.507009313091094*^9, 3.507017522445694*^9, 3.507022137057094*^9, 
   3.507022172734294*^9, 3.507022215663094*^9, {3.507022251262294*^9, 
   3.507022254085894*^9}, {3.507655436359375*^9, 3.507655450109375*^9}, {
   3.515468778796875*^9, 3.51546878053125*^9}, {3.515468900375*^9, 
   3.5154689028125*^9}, {3.515469814890625*^9, 3.515469815*^9}, {
   3.515478810453125*^9, 3.515478810890625*^9}, {3.515478855625*^9, 
   3.515478857359375*^9}, 3.515497062140625*^9, {3.515497117546875*^9, 
   3.51549712009375*^9}, 3.515497156953125*^9, {3.5155041270625*^9, 
   3.515504129640625*^9}, {3.51550458859375*^9, 3.515504591171875*^9}, {
   3.51550463578125*^9, 3.515504635875*^9}, {3.5155046778125*^9, 
   3.51550467825*^9}, {3.515504736265625*^9, 3.51550476284375*^9}, 
   3.515504829515625*^9, {3.515504868984375*^9, 3.515504915421875*^9}, {
   3.515504975125*^9, 3.51550500453125*^9}, {3.515505061921875*^9, 
   3.51550507071875*^9}, {3.515505130453125*^9, 3.515505131140625*^9}, {
   3.51550518184375*^9, 3.51550522253125*^9}, 3.51550526234375*^9, {
   3.515505316234375*^9, 3.51550532015625*^9}, {3.51550544059375*^9, 
   3.515505471671875*^9}, {3.515506309234375*^9, 3.51550631346875*^9}, 
   3.51550669471875*^9, {3.515506726703125*^9, 3.5155067270625*^9}, 
   3.515509183234375*^9, {3.5236016355*^9, 3.523601636671875*^9}, {
   3.523602261078125*^9, 3.52360226828125*^9}, {3.523602429515625*^9, 
   3.523602429859375*^9}, {3.5236024645*^9, 3.523602464578125*^9}, {
   3.52360804615625*^9, 3.52360804734375*^9}, {3.523611756984375*^9, 
   3.523611771765625*^9}, {3.523612167203125*^9, 3.523612168640625*^9}, {
   3.523613002*^9, 3.52361300209375*^9}, {3.5236151778125*^9, 
   3.523615203078125*^9}, {3.52361527409375*^9, 3.523615274546875*^9}, {
   3.52361564921875*^9, 3.52361568240625*^9}, {3.52361575428125*^9, 
   3.523615754765625*^9}, 3.523616291171875*^9, 3.52361644959375*^9, 
   3.52361649034375*^9, {3.5236165239375*^9, 3.523616526421875*^9}, {
   3.52361656234375*^9, 3.52361666646875*^9}, {3.523616755765625*^9, 
   3.523616769546875*^9}, {3.523616866265625*^9, 3.523616868453125*^9}, {
   3.523616904375*^9, 3.523616908984375*^9}, {3.523617008296875*^9, 
   3.523617010015625*^9}, {3.5236170619375*^9, 3.52361706225*^9}, {
   3.523617108890625*^9, 3.52361710903125*^9}, {3.52361724715625*^9, 
   3.523617309703125*^9}, {3.5236175294375*^9, 3.523617529515625*^9}, {
   3.523617571984375*^9, 3.523617591796875*^9}, {3.523639988640625*^9, 
   3.523639991890625*^9}, {3.52364002821875*^9, 3.523640029109375*^9}, {
   3.52364040546875*^9, 3.523640439046875*^9}, {3.52364077328125*^9, 
   3.52364077465625*^9}, {3.52610577325*^9, 3.52610581434375*^9}, 
   3.5261061323125*^9, 3.526106190765625*^9, 3.526106344796875*^9, 
   3.52610690075*^9, 3.52701107353125*^9, 3.52707086053125*^9, {
   3.527099337046875*^9, 3.52709939628125*^9}, 3.5271005693125*^9, {
   3.527100876078125*^9, 3.5271009019375*^9}, {3.527100943921875*^9, 
   3.52710095140625*^9}, {3.52710100253125*^9, 3.52710100465625*^9}, {
   3.5271011334375*^9, 3.527101134953125*^9}, {3.52710116875*^9, 
   3.52710117246875*^9}, {3.527101224109375*^9, 3.527101224828125*^9}, 
   3.52710129834375*^9, 3.527101653890625*^9, 3.52710197853125*^9, 
   3.527102247734375*^9, 3.527102328109375*^9, 3.527102538140625*^9, 
   3.52710264546875*^9, 3.527102842515625*^9, 3.52710304665625*^9, 
   3.527103201296875*^9, 3.527103313296875*^9, 3.527103698921875*^9, 
   3.52710410609375*^9, 3.52710421459375*^9, {3.52710435090625*^9, 
   3.52710435153125*^9}, 3.527104936578125*^9, 3.527105325015625*^9, 
   3.527105364078125*^9, 3.527105732484375*^9, 3.52710586475*^9, 
   3.527106242328125*^9, 3.52710659975*^9, 3.52710666846875*^9, {
   3.5271067415625*^9, 3.527106744296875*^9}, 3.527106989484375*^9, 
   3.527107313109375*^9, 3.527107378734375*^9, 3.52710743034375*^9, 
   3.5271078089375*^9, {3.52710787653125*^9, 3.527107888125*^9}, 
   3.52710809934375*^9, {3.527108143296875*^9, 3.527108143390625*^9}, {
   3.52710835903125*^9, 3.527108360078125*^9}, {3.52710839665625*^9, 
   3.527108435234375*^9}, {3.52710847140625*^9, 3.527108542578125*^9}, {
   3.527108664171875*^9, 3.52710866625*^9}, 3.527108790265625*^9, 
   3.527108974140625*^9, 3.5271093185*^9, 3.52710942703125*^9, 
   3.527138377171875*^9, 3.527138605296875*^9, 3.5271387411875*^9, 
   3.527138837859375*^9, 3.527139363375*^9, 3.5271394443125*^9, 
   3.527139723*^9, 3.52714658546875*^9, 3.527146629484375*^9, 
   3.52714677209375*^9, {3.527146892046875*^9, 3.5271469181875*^9}, 
   3.527148385109375*^9, 3.52714850809375*^9, 3.527148544046875*^9, 
   3.527148675890625*^9, 3.527148753921875*^9, 3.527148850390625*^9, 
   3.5271490244375*^9, 3.52714927709375*^9, 3.52714941521875*^9, 
   3.5271496069375*^9, 3.52714982803125*^9, 3.527150056953125*^9, 
   3.52715020146875*^9, 3.52715032440625*^9, 3.527150543015625*^9, 
   3.527150724453125*^9, 3.52715085040625*^9, 3.527151132953125*^9, {
   3.527151257234375*^9, 3.527151281078125*^9}, {3.52715131240625*^9, 
   3.527151312484375*^9}, 3.527151426921875*^9, 3.527151558171875*^9, {
   3.527151748953125*^9, 3.5271518128125*^9}, 3.527151920890625*^9, 
   3.527152131828125*^9, 3.527152264796875*^9, 3.527152362015625*^9, 
   3.527152465421875*^9, 3.527152535515625*^9, 3.52715274303125*^9, 
   3.527152862453125*^9, 3.527153019859375*^9, {3.527153135296875*^9, 
   3.52715317246875*^9}, {3.527153221484375*^9, 3.527153298390625*^9}, {
   3.527153333328125*^9, 3.527153340203125*^9}, {3.527153383828125*^9, 
   3.527153399671875*^9}, 3.5271535923125*^9, 3.52715365715625*^9, 
   3.527153737796875*^9, 3.5271538456875*^9, 3.52715389878125*^9, 
   3.52715398175*^9, 3.527221218069728*^9, 3.527221287474128*^9, 
   3.5272213898881273`*^9, {3.527221492701728*^9, 3.5272215168037276`*^9}, 
   3.5272216038205276`*^9, 3.5272224942105274`*^9, {3.5272229302441273`*^9, 
   3.5272229336917276`*^9}, 3.5272237956143274`*^9, 3.5272243280421276`*^9, {
   3.5272245402741275`*^9, 3.5272245406017275`*^9}, 3.527224621035328*^9, 
   3.5272255228371277`*^9, 3.5272269878263273`*^9, 3.527237295040928*^9, 
   3.5272375368877277`*^9, 3.527238215690528*^9, 3.527330737645727*^9, {
   3.527331465248927*^9, 3.5273314702409267`*^9}, 3.5273317074857273`*^9, 
   3.527399368863143*^9, {3.5273997076015425`*^9, 3.527399708428343*^9}, 
   3.527399826099143*^9, 3.5274007040671425`*^9, 3.527401282540943*^9, {
   3.527827965368121*^9, 3.5278279658673215`*^9}, {3.527828236402521*^9, 
   3.5278282369017215`*^9}, {3.5278284177681217`*^9, 3.5278284204513216`*^9}, 
   3.5278295921517215`*^9, {3.527829646221321*^9, 3.527829664410921*^9}, {
   3.5278298235933213`*^9, 3.5278298237961216`*^9}, {3.5278299221229215`*^9, 
   3.5278299224661217`*^9}, {3.527937511522571*^9, 3.5279375119749713`*^9}, {
   3.5298224607689605`*^9, 3.52982246572976*^9}, 3.5298227422397604`*^9, 
   3.5298309373694*^9, 3.5298313381334*^9, 3.5298314366317997`*^9, 
   3.5298315553166*^9, 3.5298316150022*^9, 3.5298323296938*^9, 
   3.5298338361542*^9, 3.5298343363058*^9, 3.5298344034482*^9, {
   3.5298344857538*^9, 3.529834488281*^9}, 3.5298345742214003`*^9, {
   3.5298346166222*^9, 3.5298346194302*^9}, {3.5298357161822*^9, 
   3.5298357172586*^9}, 3.5298357915614*^9, 3.5298374759402*^9, 
   3.5299048154350357`*^9, {3.529919671424636*^9, 3.5299196718458357`*^9}, {
   3.529919708693036*^9, 3.5299197420614357`*^9}, {3.529922010851836*^9, 
   3.5299220172634363`*^9}, {3.529922155075836*^9, 3.529922156074236*^9}, {
   3.5299221932802362`*^9, 3.529922193857436*^9}, 3.529922618982636*^9, 
   3.529922722410636*^9, 3.529922963426836*^9, 3.529922999993236*^9, {
   3.5299231984252357`*^9, 3.529923199766836*^9}, {3.529923372630436*^9, 
   3.529923377107636*^9}, {3.5299234161700363`*^9, 3.529923419695636*^9}, {
   3.529923452830036*^9, 3.529923458056036*^9}, 3.5299235134516363`*^9, 
   3.5299239464764357`*^9, 3.529923987894436*^9, {3.529924163113636*^9, 
   3.529924214156836*^9}, {3.529924252782436*^9, 3.529924334916436*^9}, 
   3.529924446752836*^9, 3.5299244832412357`*^9, {3.5305151473094406`*^9, 
   3.5305151537678404`*^9}, 3.53051566802184*^9, 3.53051590027464*^9, {
   3.5305160217362404`*^9, 3.5305160410802402`*^9}, {3.5305179159512405`*^9, 
   3.5305179543896403`*^9}, {3.53051799872484*^9, 3.5305180217972403`*^9}, {
   3.53052451980844*^9, 3.5305245365784407`*^9}, 3.53052457699804*^9, {
   3.5305246730004406`*^9, 3.5305246730472403`*^9}, {3.53052470490244*^9, 
   3.5305247231544404`*^9}, {3.53052480327604*^9, 3.5305248442728405`*^9}, 
   3.530585315953125*^9, 3.530585620703125*^9, 3.530586042328125*^9, 
   3.53058625371875*^9, 3.530586539046875*^9, 3.5305867353125*^9, 
   3.530586914875*^9, {3.53058717959375*^9, 3.5305871804375*^9}, 
   3.530587256140625*^9, {3.53058730678125*^9, 3.5305873076875*^9}, {
   3.5305874209375*^9, 3.5305874215625*^9}, 3.530587881921875*^9, {
   3.5305881963125*^9, 3.53058820225*^9}, {3.53058834365625*^9, 
   3.530588345203125*^9}, 3.5305884575625*^9, 3.5305885195*^9, 
   3.530588889546875*^9, 3.530589002421875*^9, {3.530589117171875*^9, 
   3.530589220125*^9}, {3.53058925234375*^9, 3.5305894220625*^9}, {
   3.530589454578125*^9, 3.530589479734375*^9}, {3.530589509859375*^9, 
   3.530589560640625*^9}, {3.5305895921875*^9, 3.530589618375*^9}, 
   3.530590914*^9, {3.530591013640625*^9, 3.5305910138125*^9}, 
   3.53059105590625*^9, {3.530591140046875*^9, 3.530591140234375*^9}, 
   3.530591199546875*^9, {3.530591257875*^9, 3.530591285640625*^9}, {
   3.5305913645625*^9, 3.530591366015625*^9}, {3.5305914001875*^9, 
   3.53059140040625*^9}, 3.5305915841875*^9, {3.5305916484375*^9, 
   3.530591649171875*^9}, {3.530591703359375*^9, 3.53059196265625*^9}, {
   3.530592004640625*^9, 3.530592005328125*^9}, 3.530600372734375*^9, 
   3.53060041621875*^9, {3.530600883578125*^9, 3.530600884796875*^9}, {
   3.53060106090625*^9, 3.530601062328125*^9}, {3.530601139*^9, 
   3.530601141859375*^9}, 3.530601223921875*^9, {3.5306012566875*^9, 
   3.530601258515625*^9}, {3.53060140753125*^9, 3.530601407671875*^9}, {
   3.53060146828125*^9, 3.530601479984375*^9}, {3.530601544265625*^9, 
   3.530601544484375*^9}, 3.530601580359375*^9, {3.530601614046875*^9, 
   3.5306016235625*^9}, 3.530601657125*^9, {3.530601702734375*^9, 
   3.530601726015625*^9}, {3.5306018039375*^9, 3.530601804140625*^9}, 
   3.530601874796875*^9, {3.530601930875*^9, 3.530601931078125*^9}, 
   3.53060200584375*^9, {3.53060204296875*^9, 3.5306020431875*^9}, {
   3.53060224959375*^9, 3.530602249765625*^9}, {3.53060228521875*^9, 
   3.530602285546875*^9}, {3.5306026276875*^9, 3.530602637671875*^9}, 
   3.530602719046875*^9, {3.53060276309375*^9, 3.53060279471875*^9}, {
   3.53060286271875*^9, 3.5306028635*^9}, {3.5306029223125*^9, 
   3.530602923265625*^9}, 3.530602976390625*^9, 3.53060307*^9, {
   3.530603129984375*^9, 3.53060315059375*^9}, {3.53060323740625*^9, 
   3.530603238828125*^9}, {3.530603284234375*^9, 3.530603301390625*^9}, {
   3.53060334584375*^9, 3.5306033495625*^9}, {3.530603424171875*^9, 
   3.530603424234375*^9}, 3.530603651015625*^9, {3.530603811796875*^9, 
   3.530603819671875*^9}, {3.53060387190625*^9, 3.530603873296875*^9}, {
   3.53060574578125*^9, 3.53060575721875*^9}, {3.53060581803125*^9, 
   3.530605846515625*^9}, {3.53060587890625*^9, 3.530605878984375*^9}, 
   3.530605917125*^9, {3.530606108984375*^9, 3.53060611075*^9}, {
   3.530606166453125*^9, 3.530606166890625*^9}, {3.530606204453125*^9, 
   3.5306062046875*^9}, 3.530606254953125*^9, {3.530606697125*^9, 
   3.530606697390625*^9}, 3.530606739203125*^9, {3.5306067991875*^9, 
   3.53060679940625*^9}, {3.530606829828125*^9, 3.5306068351875*^9}, {
   3.530613882875*^9, 3.530613883375*^9}, {3.5306139569375*^9, 
   3.530613957109375*^9}, {3.53061403196875*^9, 3.5306140321875*^9}, {
   3.530614167078125*^9, 3.53061417171875*^9}, {3.53061422015625*^9, 
   3.5306142216875*^9}, {3.530614318296875*^9, 3.530614320671875*^9}, {
   3.530614421296875*^9, 3.530614421765625*^9}, {3.530615271234375*^9, 
   3.530615273265625*^9}, 3.530617802546875*^9, {3.530621041640625*^9, 
   3.530621069*^9}, {3.530621109265625*^9, 3.530621114265625*^9}, {
   3.530621185984375*^9, 3.530621186203125*^9}, 3.530621393203125*^9, 
   3.530621591125*^9, {3.530621786015625*^9, 3.53062178625*^9}, {
   3.530621868015625*^9, 3.53062190809375*^9}, {3.530622109484375*^9, 
   3.530622109640625*^9}, 3.53062224590625*^9, {3.530622669*^9, 
   3.5306226945625*^9}, 3.530622811390625*^9, 3.530622979890625*^9, {
   3.530623028265625*^9, 3.530623028515625*^9}, 3.5306234613125*^9, {
   3.53062358690625*^9, 3.530623587234375*^9}, {3.530624240234375*^9, 
   3.530624246234375*^9}, {3.5306242970625*^9, 3.530624298015625*^9}, {
   3.530630653734375*^9, 3.53063065709375*^9}, {3.53063071975*^9, 
   3.530630720109375*^9}, {3.530630797984375*^9, 3.530630799171875*^9}, {
   3.53063083234375*^9, 3.530630836953125*^9}, {3.53063090815625*^9, 
   3.53063094*^9}, 3.5306312141875*^9, 3.53063130853125*^9, {
   3.530631367296875*^9, 3.530631374296875*^9}, {3.53063154371875*^9, 
   3.5306315444375*^9}, {3.530631681203125*^9, 3.530631700796875*^9}, {
   3.53063180884375*^9, 3.530631811625*^9}, {3.5306318788125*^9, 
   3.530631879453125*^9}, {3.530632188375*^9, 3.530632216578125*^9}, 
   3.5306323253125*^9, {3.530632666421875*^9, 3.530632667953125*^9}, {
   3.530632741921875*^9, 3.53063274959375*^9}, 3.530633046921875*^9, {
   3.530633211625*^9, 3.530633212734375*^9}, {3.5306333933125*^9, 
   3.530633393546875*^9}, {3.5306336710625*^9, 3.530633679703125*^9}, {
   3.53063371409375*^9, 3.53063371496875*^9}, {3.530633823390625*^9, 
   3.530633824078125*^9}, {3.530633858265625*^9, 3.530633858625*^9}, {
   3.530633903015625*^9, 3.53063390321875*^9}, 3.5306340165625*^9, {
   3.53063408896875*^9, 3.5306341031875*^9}, {3.530634159671875*^9, 
   3.530634159796875*^9}, 3.530634252703125*^9, {3.530634430125*^9, 
   3.53063443159375*^9}, {3.530634536375*^9, 3.53063455175*^9}, {
   3.530635711703125*^9, 3.530635716546875*^9}, {3.530635757453125*^9, 
   3.530635757703125*^9}, 3.5306359171875*^9, {3.530636213578125*^9, 
   3.5306362273125*^9}, {3.53063631903125*^9, 3.530636319796875*^9}, {
   3.530636404234375*^9, 3.53063641609375*^9}, {3.53063664396875*^9, 
   3.530636646609375*^9}, 3.530636728640625*^9, 3.530636797375*^9, {
   3.530636891828125*^9, 3.53063689240625*^9}, {3.530982499796875*^9, 
   3.530982528375*^9}, 3.530983196625*^9, 3.53098326575*^9, {
   3.530983572234375*^9, 3.530983573828125*^9}, 3.53098471096875*^9, {
   3.5309848278125*^9, 3.530984844828125*^9}, 3.5309849099375*^9, {
   3.53098495678125*^9, 3.530984958390625*^9}, 3.53098502234375*^9, {
   3.53098505721875*^9, 3.530985083890625*^9}, {3.53098511659375*^9, 
   3.53098514521875*^9}, {3.53098520290625*^9, 3.530985202984375*^9}, {
   3.530985245921875*^9, 3.530985257828125*^9}, 3.530985317765625*^9, {
   3.530985380609375*^9, 3.53098538096875*^9}, {3.530985463375*^9, 
   3.530985534046875*^9}, {3.530985594484375*^9, 3.530985601984375*^9}, {
   3.53098567190625*^9, 3.53098567390625*^9}, {3.53098576884375*^9, 
   3.530985769125*^9}, {3.530985826203125*^9, 3.5309858263125*^9}, {
   3.53098602596875*^9, 3.53098602696875*^9}, {3.53098609984375*^9, 
   3.5309861378125*^9}, {3.53098625140625*^9, 3.530986279671875*^9}, {
   3.53098632940625*^9, 3.530986330203125*^9}, {3.53098654378125*^9, 
   3.530986544109375*^9}, {3.530986575328125*^9, 3.530986578734375*^9}, {
   3.530986629421875*^9, 3.530986629640625*^9}, {3.530986698625*^9, 
   3.530986701890625*^9}, {3.530986828296875*^9, 3.530986842875*^9}, {
   3.5309868869375*^9, 3.5309869145625*^9}, {3.530986955625*^9, 
   3.5309869599375*^9}, {3.530987003796875*^9, 3.5309870050625*^9}, {
   3.530987075140625*^9, 3.53098709553125*^9}, 3.53098725778125*^9, {
   3.53098735596875*^9, 3.530987356046875*^9}, {3.530987495578125*^9, 
   3.530987496953125*^9}, 3.530987562875*^9, {3.530987711421875*^9, 
   3.530987768078125*^9}, {3.530987953703125*^9, 3.530987954703125*^9}, {
   3.53098814621875*^9, 3.5309881465*^9}, {3.5309881905625*^9, 
   3.530988193*^9}, {3.530988231734375*^9, 3.530988268328125*^9}, {
   3.530988298625*^9, 3.530988299890625*^9}, {3.5309883319375*^9, 
   3.53098833425*^9}, {3.530988398921875*^9, 3.53098843171875*^9}, {
   3.53098846678125*^9, 3.53098851953125*^9}, {3.530988553484375*^9, 
   3.530988554140625*^9}, {3.53098872046875*^9, 3.53098872209375*^9}, {
   3.530988839140625*^9, 3.530988844890625*^9}, 3.53098887621875*^9, {
   3.530989017046875*^9, 3.53098902615625*^9}, {3.530989066328125*^9, 
   3.530989067515625*^9}, {3.530989191328125*^9, 3.530989221046875*^9}, {
   3.53098925465625*^9, 3.5309892600625*^9}, {3.530989301359375*^9, 
   3.530989301515625*^9}, {3.530989379828125*^9, 3.5309894075*^9}, {
   3.53098947921875*^9, 3.53098947971875*^9}, {3.53098955446875*^9, 
   3.530989556453125*^9}, {3.530989604234375*^9, 3.53098963240625*^9}, 
   3.53098973490625*^9, {3.5320830929453382`*^9, 3.532083121867738*^9}, {
   3.5320834086581383`*^9, 3.532083409219738*^9}, 3.5320834405601377`*^9, 
   3.532083682204138*^9, {3.532083775148938*^9, 3.532083775492138*^9}, 
   3.5320838244077377`*^9, 3.532083876714538*^9, {3.5320840217789383`*^9, 
   3.532084050467338*^9}, {3.532084141852138*^9, 3.5320841422733383`*^9}, {
   3.532084189619338*^9, 3.5320841898845377`*^9}, {3.532084257098938*^9, 
   3.532084257738538*^9}, {3.532084298033338*^9, 3.532084298969338*^9}, {
   3.532084355550538*^9, 3.532084368748138*^9}, 3.532084426452538*^9, {
   3.532084485264538*^9, 3.532084488556138*^9}, {3.5320845467693377`*^9, 
   3.532084547174938*^9}, 3.532084655922538*^9, 3.5320847693501377`*^9, {
   3.532084935958138*^9, 3.532084948640938*^9}, {3.5320849922897377`*^9, 
   3.532084994754538*^9}, 3.532085057357338*^9, {3.532085088806938*^9, 
   3.532085120662138*^9}, {3.532085190616138*^9, 3.532085191364938*^9}, 
   3.532085223610138*^9, {3.5320852632185383`*^9, 3.532085263702138*^9}, {
   3.532085305120138*^9, 3.532085305962538*^9}, {3.532085361716938*^9, 
   3.5320853620601377`*^9}, {3.5320854571265383`*^9, 3.532085458202938*^9}, {
   3.532085492819338*^9, 3.532085495564938*^9}, {3.532085572082938*^9, 
   3.532085578978138*^9}, {3.532085624420938*^9, 3.532085624779738*^9}, {
   3.532085667492538*^9, 3.532085667898138*^9}, {3.532085705478538*^9, 
   3.532085705696938*^9}, {3.532085747161738*^9, 3.5320857481289377`*^9}, {
   3.532085795584138*^9, 3.5320857958337383`*^9}, {3.5320858634477377`*^9, 
   3.532085864118538*^9}, {3.532085910809338*^9, 3.532085911121338*^9}, {
   3.532085941556938*^9, 3.532085963646538*^9}, {3.532086008917738*^9, 
   3.5320860093389378`*^9}, {3.532086053923738*^9, 3.532086054188938*^9}, {
   3.532086099616138*^9, 3.5320861000685377`*^9}, 3.5320861351373377`*^9, {
   3.532086170580538*^9, 3.532086170658538*^9}, {3.532086287723338*^9, 
   3.532086289501738*^9}, {3.532086330701338*^9, 3.532086357502138*^9}, {
   3.532086492958338*^9, 3.532086493207938*^9}, {3.5320865302087383`*^9, 
   3.5320865613463383`*^9}, {3.532086661264338*^9, 3.532086661451538*^9}, {
   3.532086705646338*^9, 3.532086705817938*^9}, 3.532086740278338*^9, 
   3.532086813660738*^9, {3.532086845453538*^9, 3.532086877589538*^9}, {
   3.5320869121279383`*^9, 3.532086912502338*^9}, {3.532086946806738*^9, 
   3.532086947181138*^9}, {3.532086986399538*^9, 3.5320869902995377`*^9}, {
   3.5320873071043377`*^9, 3.5320873072915382`*^9}, {3.5320873940587378`*^9, 
   3.532087396851138*^9}, 3.5320875040387383`*^9, 3.5320875571567383`*^9, 
   3.5320876608655376`*^9, 3.532087703859138*^9, {3.532087862629938*^9, 
   3.532087888900338*^9}, {3.532087920318738*^9, 3.532087940692338*^9}, {
   3.532087991922738*^9, 3.532088001360738*^9}, {3.532088440635138*^9, 
   3.532088443427538*^9}, {3.532088488807938*^9, 3.5320884901651382`*^9}, {
   3.532088557463538*^9, 3.532088569444338*^9}, {3.532088780106738*^9, 
   3.5320887846619377`*^9}, {3.532088851537138*^9, 3.532088859243538*^9}, {
   3.532088914327138*^9, 3.532088915013538*^9}, {3.532089086613538*^9, 
   3.532089118265938*^9}, {3.5320893946511383`*^9, 3.532089438440338*^9}, {
   3.5321494627007527`*^9, 3.5321494639643526`*^9}, {3.5321496742859526`*^9, 
   3.5321497099163527`*^9}, {3.5321499007823524`*^9, 
   3.5321499016403527`*^9}, {3.532149972448753*^9, 3.5321499837431526`*^9}, {
   3.532150738330753*^9, 3.532150742027953*^9}, {3.5321508114011526`*^9, 
   3.5321508197783527`*^9}, 3.5321509423631525`*^9, 3.532151190013153*^9, 
   3.5321515965647526`*^9, 3.532151973907153*^9, {3.532244783614336*^9, 
   3.532244784160336*^9}, 3.532244899023136*^9, {3.5322455466309357`*^9, 
   3.5322455470677357`*^9}, 3.532323255634951*^9, 3.532323526522951*^9, 
   3.5323236099205513`*^9, 3.5323247134333515`*^9, 3.532325135856151*^9, 
   3.532336929578125*^9, {3.532337006296875*^9, 3.53233700834375*^9}, 
   3.53233712128125*^9, {3.53233717396875*^9, 3.53233717425*^9}, 
   3.532337333734375*^9, 3.532337788953125*^9, 3.5323406890625*^9, 
   3.532341274421875*^9, {3.532341356234375*^9, 3.53234135634375*^9}, 
   3.53234453859375*^9, {3.532344615890625*^9, 3.532344616375*^9}, 
   3.532344855765625*^9, 3.53234498715625*^9, 3.532345095484375*^9, 
   3.53234634353125*^9, 3.54512921371875*^9, 3.54512968121875*^9, 
   3.545129848609375*^9, {3.545129913625*^9, 3.545129914*^9}, 
   3.545130259484375*^9, 3.545130440140625*^9, {3.54513056253125*^9, 
   3.545130562984375*^9}, 3.5451306680625*^9, 3.545130869296875*^9, 
   3.54513115415625*^9, 3.5451313645625*^9, 3.545132194046875*^9, 
   3.545132642171875*^9, {3.545132811140625*^9, 3.545132811640625*^9}, {
   3.545132963984375*^9, 3.545132964578125*^9}, 3.545133195359375*^9, 
   3.545133255625*^9, 3.545133384734375*^9, 3.545133482359375*^9, 
   3.545133560140625*^9, 3.5451338180625*^9, 3.545134198546875*^9, {
   3.545134322546875*^9, 3.545134323125*^9}, {3.54513453396875*^9, 
   3.5451345346875*^9}, {3.54513487678125*^9, 3.545134891671875*^9}, 
   3.545135035515625*^9, 3.545135389171875*^9, {3.545135473359375*^9, 
   3.545135475625*^9}, 3.545136616*^9, 3.545136668515625*^9, 
   3.54513677965625*^9, 3.545136852859375*^9, {3.545137108171875*^9, 
   3.54513710890625*^9}, 3.545137493453125*^9, 3.545137628359375*^9, 
   3.54513780190625*^9, {3.545137868875*^9, 3.545137870671875*^9}, 
   3.54513837096875*^9, 3.54513855175*^9, 3.545138644453125*^9, 
   3.545138892171875*^9, 3.54513902775*^9, {3.54513911390625*^9, 
   3.545139115171875*^9}, 3.545139227109375*^9, 3.5451392643125*^9, 
   3.545139520828125*^9, 3.545139740265625*^9, 3.545139925375*^9, 
   3.5451401370625*^9, 3.545149249375*^9, 3.545149599203125*^9, 
   3.545149668703125*^9, 3.545149815796875*^9, 3.545149920953125*^9, 
   3.545150022828125*^9, 3.545150141328125*^9, 3.545150216859375*^9, {
   3.545150763546875*^9, 3.545150765484375*^9}, {3.545150805328125*^9, 
   3.545150806140625*^9}, 3.54515089903125*^9, {3.545150954671875*^9, 
   3.54515095475*^9}, 3.545151025015625*^9, {3.545151070171875*^9, 
   3.5451511263125*^9}, {3.5451511651875*^9, 3.545151196734375*^9}, {
   3.545151302734375*^9, 3.545151303578125*^9}, 3.545151436828125*^9, {
   3.54515149609375*^9, 3.54515149734375*^9}, 3.54515157534375*^9, {
   3.545151805265625*^9, 3.545151813296875*^9}, {3.545151856359375*^9, 
   3.545151856546875*^9}, {3.5451519366875*^9, 3.5451519860625*^9}, {
   3.5451521400625*^9, 3.545152144671875*^9}, {3.545152246765625*^9, 
   3.545152248703125*^9}, {3.545152464390625*^9, 3.5451525135625*^9}, {
   3.545152656890625*^9, 3.545152657484375*^9}, {3.545152793578125*^9, 
   3.545152793703125*^9}, {3.54515288640625*^9, 3.5451528865*^9}, {
   3.545299978390625*^9, 3.54529998575*^9}, {3.54530004371875*^9, 
   3.545300044484375*^9}, {3.5453001406875*^9, 3.545300162609375*^9}, {
   3.5453001943125*^9, 3.545300247671875*^9}, {3.545300311109375*^9, 
   3.545300315578125*^9}, {3.54530035225*^9, 3.545300425390625*^9}, {
   3.545300462171875*^9, 3.545300462875*^9}, {3.5488468684375*^9, 
   3.5488468963125*^9}, 3.548847061890625*^9, 3.5488471054375*^9, {
   3.5488471861875*^9, 3.548847193234375*^9}, 3.549805657421875*^9, 
   3.54980573875*^9, 3.549806861875*^9, 3.549806936265625*^9, {
   3.549815485515625*^9, 3.549815492796875*^9}, {3.549815525921875*^9, 
   3.549815529546875*^9}, {3.549815561765625*^9, 3.549815592890625*^9}, {
   3.549815763171875*^9, 3.549815790046875*^9}, {3.5498158699375*^9, 
   3.54981589709375*^9}, {3.549817596796875*^9, 3.54981759828125*^9}, {
   3.549817742984375*^9, 3.54981778928125*^9}, 3.550575700125*^9, {
   3.550583462875*^9, 3.550583462984375*^9}, {3.562393243999369*^9, 
   3.5623932641655226`*^9}, {3.5623933064609413`*^9, 
   3.5623933104471693`*^9}, {3.562395433914625*^9, 3.5623954428861384`*^9}, {
   3.565088985474518*^9, 3.5650889880173225`*^9}, {3.565089111021934*^9, 
   3.5650891226907544`*^9}, {3.5667973335122547`*^9, 3.566797352372655*^9}, {
   3.5668069299166546`*^9, 3.566806938371855*^9}, {3.566807549489855*^9, 
   3.566807577289055*^9}, {3.566808306287055*^9, 3.5668083069578547`*^9}, {
   3.5668149691576*^9, 3.5668149697192*^9}, {3.570196452625*^9, 
   3.570196453921875*^9}, {3.570199458390625*^9, 3.570199459609375*^9}, {
   3.570203745390625*^9, 3.57020374565625*^9}, 3.5702109290625*^9, {
   3.570211316328125*^9, 3.570211317546875*^9}, 3.570211724796875*^9, {
   3.57021464121875*^9, 3.570214659515625*^9}, 3.5713968894514*^9, {
   3.5713969307134*^9, 3.5713969309318*^9}, {3.5713974130425997`*^9, 
   3.5713974133702*^9}, {3.5713981043602*^9, 3.5713981209118*^9}, {
   3.5714669080326805`*^9, 3.5714669085474806`*^9}, {3.571468731670081*^9, 
   3.5714687317636805`*^9}, {3.5714693536732807`*^9, 
   3.5714693546872807`*^9}, {3.571469930383481*^9, 3.5714699308358808`*^9}, {
   3.5714704631268806`*^9, 3.5714704645152807`*^9}, {3.5714709437160807`*^9, 
   3.5714709446676807`*^9}, {3.5714716293516808`*^9, 
   3.5714716316604805`*^9}, {3.5714717283648806`*^9, 3.571471728676881*^9}, {
   3.571471782325281*^9, 3.571471782886881*^9}, {3.5714718740064807`*^9, 
   3.5714718743964806`*^9}, {3.5714724754646807`*^9, 3.571472475948281*^9}, {
   3.571473396425081*^9, 3.571473396799481*^9}, {3.5729284870614915`*^9, 
   3.5729284873422914`*^9}, {3.5729296806368914`*^9, 
   3.5729296845836916`*^9}, {3.5729298719426913`*^9, 
   3.5729298724574914`*^9}, {3.5729303873884916`*^9, 
   3.5729303876848917`*^9}, {3.5729611164192*^9, 3.5729611178076*^9}, {
   3.5729612221247997`*^9, 3.5729612226084003`*^9}, {3.572963083075*^9, 
   3.5729630833714*^9}, {3.573045743890625*^9, 3.573045752984375*^9}, {
   3.5732946281875*^9, 3.573294632796875*^9}, {3.57329507965625*^9, 
   3.5732950798125*^9}, {3.5732958393125*^9, 3.573295839890625*^9}, {
   3.573296055609375*^9, 3.573296056515625*^9}, {3.57329617059375*^9, 
   3.57329617103125*^9}, {3.573296273265625*^9, 3.573296273734375*^9}, {
   3.57329805228125*^9, 3.573298052734375*^9}, {3.5732981673125*^9, 
   3.573298168078125*^9}, {3.573539284391242*^9, 3.573539285108842*^9}, {
   3.573539327837242*^9, 3.5735393291632423`*^9}, {3.573539867608842*^9, 
   3.573539868201642*^9}, {3.573540434940042*^9, 3.573540446952042*^9}, {
   3.573541671147242*^9, 3.573541671381242*^9}, {3.573544126417242*^9, 
   3.573544126978842*^9}, {3.573545093653842*^9, 3.573545093700642*^9}, {
   3.5735451794226418`*^9, 3.5735451795630417`*^9}, {3.573554214998042*^9, 
   3.573554221799642*^9}, {3.573554273544842*^9, 3.573554281500842*^9}, {
   3.573554330422442*^9, 3.5735543311400423`*^9}, {3.573554409858642*^9, 
   3.5735544103734417`*^9}, {3.5735544521730423`*^9, 3.573554452703442*^9}, {
   3.573554483513442*^9, 3.573554484075042*^9}, {3.573554786546442*^9, 
   3.573554787710442*^9}, {3.573554958048842*^9, 3.5735549585012417`*^9}, {
   3.5735558133984423`*^9, 3.573555814162842*^9}, {3.573555898997642*^9, 
   3.573555929808642*^9}, {3.573557611157042*^9, 3.573557611859042*^9}, {
   3.5919495991607018`*^9, 3.5919495995357094`*^9}, {3.5933428542310734`*^9, 
   3.5933428544341917`*^9}, {3.5933464048299084`*^9, 3.593346430564942*^9}, 
   3.593346697770253*^9, {3.5933469038327975`*^9, 3.5933469160666246`*^9}, {
   3.5933476965887613`*^9, 3.593347699973961*^9}, {3.5933480346583614`*^9, 
   3.5933480353135614`*^9}, {3.593410634661343*^9, 3.593410635191743*^9}, {
   3.593410721219143*^9, 3.593410721780743*^9}, {3.5934107829181433`*^9, 
   3.593410783401743*^9}, {3.5934111092701435`*^9, 3.5934112386253433`*^9}, {
   3.5934112881709433`*^9, 3.593411330056943*^9}, {3.593411361100943*^9, 
   3.5934113647513433`*^9}, {3.593411560080943*^9, 3.5934115605645432`*^9}, {
   3.5934115927251434`*^9, 3.593411640071143*^9}, 3.593411728289143*^9, {
   3.593411768053543*^9, 3.5934117690519433`*^9}, {3.5934118267875433`*^9, 
   3.5934118335891433`*^9}, 3.5934119731467433`*^9, {3.593412051209143*^9, 
   3.5934120728307433`*^9}, {3.593412130737943*^9, 3.5934121623591433`*^9}, {
   3.593412271094143*^9, 3.593412271530943*^9}, 3.5934123977349434`*^9, 
   3.5934187905310717`*^9, 3.5934188273279467`*^9, 3.5934190822810717`*^9, {
   3.5934191282966967`*^9, 3.5934191283435717`*^9}, {3.5934191854685717`*^9, 
   3.5934192096091967`*^9}, {3.5934192519216967`*^9, 3.5934192598123217`*^9}, 
   3.5934193168435717`*^9, {3.5934193737810717`*^9, 3.5934193990466967`*^9}, {
   3.5934221582641745`*^9, 3.5934221638421926`*^9}, {3.5934224133064656`*^9, 
   3.5934224154783125`*^9}, 3.5934229330220013`*^9, {3.5934231252251263`*^9, 
   3.5934231515220013`*^9}, {3.5934258340241866`*^9, 3.5934258369304366`*^9}, 
   3.5934262664745607`*^9, {3.5934263180845957`*^9, 3.5934263228815327`*^9}, {
   3.5934265568051715`*^9, 3.5934265591020465`*^9}, {3.5934267288364215`*^9, 
   3.5934267420395465`*^9}, {3.5934974536524515`*^9, 
   3.5934974633866396`*^9}, {3.5934975186046343`*^9, 
   3.5934975299014373`*^9}, {3.5934975938229027`*^9, 
   3.5934976409784255`*^9}, {3.593497714085929*^9, 3.593497714148427*^9}, {
   3.5934992235684977`*^9, 3.5934992242091184`*^9}, {3.5935009287947407`*^9, 
   3.593500929685371*^9}, {3.593501005716917*^9, 3.593501012357499*^9}, {
   3.5935046801879187`*^9, 3.5935046836566687`*^9}, {3.5935047665316687`*^9, 
   3.5935047722504187`*^9}, {3.5935048385582886`*^9, 3.59350483904262*^9}, 
   3.5935049312999783`*^9, {3.593505034072019*^9, 3.5935050384466267`*^9}, 
   3.5935050811927967`*^9, {3.5935051659553823`*^9, 3.5935051659866314`*^9}, {
   3.5935059332996435`*^9, 3.593505953830762*^9}, 3.5935060138303776`*^9, {
   3.593506059783209*^9, 3.593506092986121*^9}, 3.593513167038967*^9, {
   3.593513209663694*^9, 3.5935132101636906`*^9}, {3.593513247491577*^9, 
   3.5935132539290357`*^9}, {3.5935133041630893`*^9, 
   3.5935133544283924`*^9}, {3.593513414037386*^9, 3.593513429990409*^9}, {
   3.593513603254925*^9, 3.5935136237547936`*^9}, {3.5935136855356483`*^9, 
   3.5935137008011756`*^9}, 3.593513770238231*^9, {3.593513952612064*^9, 
   3.593513957627657*^9}, {3.593514102704853*^9, 3.59351410945481*^9}, 
   3.5935142529538918`*^9, {3.5935148300283237`*^9, 3.593514832934555*^9}, 
   3.593514881309245*^9, {3.593514957793131*^9, 3.5935149797929897`*^9}, {
   3.5935150392144847`*^9, 3.5935150817610874`*^9}, {3.5935151342920012`*^9, 
   3.5935151392919693`*^9}, {3.5935152106665125`*^9, 3.5935152113540077`*^9}, 
   3.5935170828420305`*^9, 3.5935173842776012`*^9, {3.5943143829861746`*^9, 
   3.594314440900834*^9}, {3.594314866506524*^9, 3.5943150032056847`*^9}, {
   3.5943151130440054`*^9, 3.594315114819191*^9}, {3.5943151449342933`*^9, 
   3.5943151478622484`*^9}, {3.594315225323265*^9, 3.5943154820213065`*^9}, {
   3.594315514398919*^9, 3.5943155225523624`*^9}, {3.5943155546688004`*^9, 
   3.594315556035713*^9}, {3.59431561558751*^9, 3.594315682848411*^9}, {
   3.5943157328998194`*^9, 3.5943157713294735`*^9}, {3.5943158145093656`*^9, 
   3.5943158160644035`*^9}, {3.594315852392655*^9, 3.594315900793961*^9}, {
   3.5943159660004883`*^9, 3.594315988730663*^9}, {3.5943161420520086`*^9, 
   3.594316228880967*^9}, {3.594316304333333*^9, 3.59431630868824*^9}, {
   3.594316348213623*^9, 3.5943163755218525`*^9}, {3.5943164393584642`*^9, 
   3.59431650059134*^9}, {3.594316552763166*^9, 3.59431658414011*^9}, {
   3.594316632587452*^9, 3.5943166340234103`*^9}, {3.594316671487417*^9, 
   3.594316757998165*^9}, {3.5943168374241843`*^9, 3.5943168818388305`*^9}, {
   3.5943169199082437`*^9, 3.594316954812543*^9}, {3.594317004031397*^9, 
   3.5943170245811143`*^9}, 3.5943170644977593`*^9, {3.594317111339027*^9, 
   3.5943171660532155`*^9}, {3.594317233647338*^9, 3.594317270929224*^9}, {
   3.5943173229479475`*^9, 3.5943173626972895`*^9}, {3.5943174216652517`*^9, 
   3.5943174454271126`*^9}, {3.5943175475352726`*^9, 3.594317564916875*^9}, {
   3.5943176255148497`*^9, 3.5943176385375414`*^9}, {3.5943177047747574`*^9, 
   3.5943177119055195`*^9}, {3.594317769916861*^9, 3.594317847517662*^9}, {
   3.5943179222325363`*^9, 3.5943179230250645`*^9}, {3.5943179674126935`*^9, 
   3.5943179778876877`*^9}, {3.5943181767134047`*^9, 3.59431819196859*^9}, {
   3.5943182271670856`*^9, 3.5943182892585325`*^9}, {3.5943183468739877`*^9, 
   3.5943183497419066`*^9}, {3.5943184198597136`*^9, 3.594318420494135*^9}, {
   3.5943184644734917`*^9, 3.5943184696719627`*^9}, {3.5943185378424683`*^9, 
   3.5943185379215193`*^9}, {3.59431862022412*^9, 3.5943186324402757`*^9}, {
   3.594318748366705*^9, 3.594318751299658*^9}, 3.594318824470501*^9, {
   3.5943188745529346`*^9, 3.5943188754295163`*^9}, {3.594318935419571*^9, 
   3.5943189385246353`*^9}, {3.594318970373639*^9, 3.5943190154487305`*^9}, {
   3.5943190495424914`*^9, 3.594319050237956*^9}, {3.594319081910095*^9, 
   3.594319244379547*^9}, {3.5943193315788*^9, 3.594319336690213*^9}, {
   3.5943194017656517`*^9, 3.5943194066899405`*^9}, {3.594319457403792*^9, 
   3.594319462682316*^9}, {3.594319504641324*^9, 3.594319509126319*^9}, {
   3.5943195543274927`*^9, 3.594319576745454*^9}, {3.5943197102778296`*^9, 
   3.5943197144706316`*^9}, {3.594319867177885*^9, 3.594319873054489*^9}, 
   3.59432037579447*^9, {3.594320464199481*^9, 3.5943204729823446`*^9}, {
   3.5943207216930327`*^9, 3.5943207228848257`*^9}, {3.5943208446721215`*^9, 
   3.5943208482465086`*^9}, {3.594320917374652*^9, 3.59432091823923*^9}, 
   3.5943212648135753`*^9, {3.5943213082485695`*^9, 3.594321334936386*^9}, {
   3.5943213674981213`*^9, 3.5943213681475525`*^9}, {3.5943215926113873`*^9, 
   3.594321593826198*^9}, 3.5943216310750647`*^9, {3.5943221783874826`*^9, 
   3.594322179141988*^9}, {3.594322612966573*^9, 3.5943226132347527`*^9}, {
   3.594322773074449*^9, 3.5943227732275524`*^9}, 3.594322833164561*^9, {
   3.594322882680617*^9, 3.594322883319042*^9}, 3.5943229183650117`*^9, {
   3.5943230006579447`*^9, 3.5943230012663517`*^9}, {3.594323372942453*^9, 
   3.5943233733757415`*^9}, {3.594377928943325*^9, 3.5943779326093254`*^9}, {
   3.5943779785201254`*^9, 3.594377981468525*^9}, {3.594378159465525*^9, 
   3.5943781599647255`*^9}, {3.5943785188271255`*^9, 
   3.5943785509007254`*^9}, {3.5943786119747252`*^9, 
   3.5943786249695253`*^9}, {3.5943786992577252`*^9, 3.594378699850525*^9}, {
   3.594379036139725*^9, 3.5943790361865253`*^9}, {3.594379203137725*^9, 
   3.5943792034029255`*^9}, {3.594379408030125*^9, 3.5943794086229253`*^9}, {
   3.5943794555321255`*^9, 3.5943794560469255`*^9}, {3.594379536528325*^9, 
   3.594379537542325*^9}, {3.5943802652365255`*^9, 3.5943802653769255`*^9}, 
   3.5943804366805253`*^9, {3.594381524607525*^9, 3.5943815249663253`*^9}, {
   3.594381598005525*^9, 3.5943815984891253`*^9}, {3.5943816757715254`*^9, 
   3.5943816772379255`*^9}, {3.594381809822325*^9, 3.594381811304325*^9}, {
   3.5943845277027254`*^9, 3.5943845284359255`*^9}, 3.5943846658095255`*^9, {
   3.5944394347965364`*^9, 3.5944394463093367`*^9}, {3.594441601833537*^9, 
   3.594441928216737*^9}, {3.594442014172737*^9, 3.594442014671937*^9}, {
   3.5944420619399366`*^9, 3.5944420624547367`*^9}, {3.594442262509137*^9, 
   3.594442291759137*^9}, {3.5944423784951367`*^9, 3.594442394422737*^9}, {
   3.594442470067137*^9, 3.5944424993795366`*^9}, {3.5944425348071365`*^9, 
   3.5944425422327366`*^9}, {3.594442588673937*^9, 3.5944425907019367`*^9}, {
   3.5944426268627367`*^9, 3.594442675909137*^9}, {3.5944427598683367`*^9, 
   3.594442774906737*^9}, {3.594442830676737*^9, 3.5944428471035366`*^9}, {
   3.594442893341937*^9, 3.5944429339019365`*^9}, {3.5944430827883368`*^9, 
   3.5944430851751366`*^9}, {3.594443168324537*^9, 3.594443242986137*^9}, {
   3.594443296712537*^9, 3.5944433061661367`*^9}, {3.594443400672537*^9, 
   3.594443472510537*^9}, {3.5944435148801365`*^9, 3.594443516767737*^9}, {
   3.594443561851737*^9, 3.594443565782937*^9}, {3.5944435974665365`*^9, 
   3.594443619462537*^9}, {3.594443680970337*^9, 3.5944437125291367`*^9}, {
   3.594443753495737*^9, 3.5944437578949366`*^9}, {3.594443796005737*^9, 
   3.594443797144537*^9}, {3.594443835411337*^9, 3.5944438727109365`*^9}, {
   3.594443921332937*^9, 3.5944439603485365`*^9}, {3.5944439946373367`*^9, 
   3.5944439987089367`*^9}, {3.594444051046937*^9, 3.594444053012537*^9}, {
   3.594444087816137*^9, 3.5944441035409365`*^9}, {3.594444150138137*^9, 
   3.5944441805425367`*^9}, {3.594444246327737*^9, 3.5944442889469366`*^9}, {
   3.594445203094937*^9, 3.594445211097737*^9}, {3.594445267975337*^9, 
   3.594445298223737*^9}, 3.5944453475695367`*^9, {3.594445898136337*^9, 
   3.594445900741537*^9}, {3.594445938789937*^9, 3.594445944031537*^9}, {
   3.594445979409337*^9, 3.594445979799337*^9}, {3.594446016280737*^9, 
   3.594446057745537*^9}, {3.5944461245915365`*^9, 3.5944461273683367`*^9}, 
   3.594446349942537*^9, {3.594446405462937*^9, 3.594446412482937*^9}, {
   3.5944464690641365`*^9, 3.594446472964137*^9}, {3.594446549568737*^9, 
   3.5944466182867365`*^9}, {3.594446675835137*^9, 3.594446677067537*^9}, {
   3.594446845954537*^9, 3.594446879837737*^9}, {3.594446934843337*^9, 
   3.5944469463093367`*^9}, {3.5944469814561367`*^9, 
   3.5944470171489367`*^9}, {3.5944470678957367`*^9, 3.594447120881937*^9}, {
   3.5944471695695367`*^9, 3.594447173781537*^9}, {3.594447216587937*^9, 
   3.594447222001137*^9}, {3.594447264901137*^9, 3.5944472972867365`*^9}, {
   3.5944473277847366`*^9, 3.594447413593337*^9}, {3.594447490674937*^9, 
   3.5944475598921366`*^9}, {3.594447623181337*^9, 3.594447693958537*^9}, {
   3.594447728716737*^9, 3.5944477605719366`*^9}, {3.5944484006791368`*^9, 
   3.594448458133937*^9}, {3.594448493639537*^9, 3.5944484950747366`*^9}, 
   3.5944486675171366`*^9, 3.594448742865137*^9, {3.594449021583737*^9, 
   3.594449049336137*^9}, {3.594449417577937*^9, 3.5944494184047365`*^9}, {
   3.594449457998537*^9, 3.594449459542937*^9}, {3.594449602144537*^9, 
   3.594449603813737*^9}, {3.594449664794137*^9, 3.594449665433737*^9}, {
   3.5944497514833364`*^9, 3.5944497523413367`*^9}, {3.594449811356137*^9, 
   3.5944498150065365`*^9}, {3.594449934610137*^9, 3.5944499349533367`*^9}, {
   3.594449967416937*^9, 3.594450024918537*^9}, {3.594450066679737*^9, 
   3.5944500718745365`*^9}, {3.594450114197337*^9, 3.5944501747565365`*^9}, {
   3.5944502113541365`*^9, 3.594450301725937*^9}, 3.594450402050537*^9, {
   3.5944506798739367`*^9, 3.594450705801137*^9}, 3.594450763678137*^9, {
   3.594451266072137*^9, 3.594451295774537*^9}, {3.594452482548537*^9, 
   3.5944524972593365`*^9}, {3.5944526554589367`*^9, 3.594452656192137*^9}, 
   3.5947237904206896`*^9, {3.5947331968981037`*^9, 3.594733197415454*^9}, 
   3.5947332805317745`*^9, {3.5947333260829477`*^9, 3.5947333267293787`*^9}, {
   3.5947333621039867`*^9, 3.594733364075307*^9}, {3.594734090417761*^9, 
   3.5947340912294283`*^9}, {3.594735406585331*^9, 3.5947354471293945`*^9}, {
   3.5947357050235443`*^9, 3.5947357680936456`*^9}, {3.663484679142099*^9, 
   3.6634846799971333`*^9}, {3.6634847945268583`*^9, 3.66348479482937*^9}, 
   3.663484893668418*^9, {3.66348494692766*^9, 3.663484948310215*^9}, {
   3.6634850151590595`*^9, 3.6634850151990604`*^9}, {3.6634852214188566`*^9, 
   3.663485221761367*^9}, 3.6634853864210663`*^9, {3.663485440006873*^9, 
   3.6634854406319103`*^9}, 3.663485581517474*^9, 3.663485849569541*^9, {
   3.6634860580416126`*^9, 3.6634860828184013`*^9}, {3.6634862522620573`*^9, 
   3.663486252494564*^9}, {3.663486294895776*^9, 3.663486296475808*^9}, 
   3.663486445660617*^9, 3.6634868639580717`*^9, 3.6634870565376997`*^9, {
   3.6634871093713923`*^9, 3.663487110316411*^9}, 3.6634873428284645`*^9, 
   3.663488565802554*^9, {3.663488670745028*^9, 3.663488671245038*^9}, {
   3.6634887505702744`*^9, 3.663488751402791*^9}, {3.6634887885816116`*^9, 
   3.6634887911966643`*^9}, {3.6634888403052096`*^9, 
   3.6634888587966366`*^9}, {3.663489063554844*^9, 3.6634890640273533`*^9}, {
   3.663489108458295*^9, 3.663489109315812*^9}, {3.663490669828927*^9, 
   3.6634906993656473`*^9}, 3.663934490148452*^9, {3.663935330158332*^9, 
   3.6639353385281687`*^9}, {3.663994803210081*^9, 3.663994814407779*^9}, {
   3.736420382510795*^9, 3.7364204115914583`*^9}},
 FontSize->10]
}, Open  ]],

Cell[CellGroupData[{

Cell["Actual low of motion for Omega", "Subsubsection",
 CellChangeTimes->{{3.505634306018392*^9, 3.505634310549671*^9}, {
  3.572694523249008*^9, 3.572694524139553*^9}, {3.572696116088958*^9, 
  3.572696116635728*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"ALM", " ", "coefficients"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"mALMlearn", "[", 
      RowBox[{"mMt_", ",", "mMt1_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"Inverse", "[", 
       RowBox[{"mI", "-", 
        RowBox[{"fM", ".", "mMt"}]}], "]"}], ".", 
      RowBox[{"(", 
       RowBox[{"aM", "+", 
        RowBox[{"dM", ".", "mMt1"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"gALMlearn", "[", "mMt_", "]"}], ":=", 
     RowBox[{
      RowBox[{"Inverse", "[", 
       RowBox[{"mI", "-", 
        RowBox[{"fM", ".", "mMt"}]}], "]"}], ".", "gM"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ggALMlearn", "[", "mMt_", "]"}], ":=", 
     RowBox[{
      RowBox[{"Inverse", "[", 
       RowBox[{"mI", "-", 
        RowBox[{"fM", ".", "mMt"}]}], "]"}], ".", "ggM"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"hALMlearn", "[", 
     RowBox[{"mMt_", ",", "hMt_", ",", "hMt1_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"Inverse", "[", 
      RowBox[{"mI", "-", 
       RowBox[{"fM", ".", "mMt"}]}], "]"}], ".", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"dM", ".", "hMt1"}], "+", 
       RowBox[{"fM", ".", "hMt"}], "+", "nM"}], ")"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"oALMlearn", "[", 
      RowBox[{"mM_", ",", "hM_"}], "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"oM", "=", 
         RowBox[{"Table", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "8", "}"}], ",", 
           RowBox[{"{", "9", "}"}]}], "]"}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"oM", "[", 
          RowBox[{"[", 
           RowBox[{"All", ",", "1"}], "]"}], "]"}], "=", "hM"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"oM", "[", 
          RowBox[{"[", 
           RowBox[{"All", ",", 
            RowBox[{"2", ";;", "9"}]}], "]"}], "]"}], "=", "mM"}], ";", 
        "\[IndentingNewLine]", "oM"}]}], "\[IndentingNewLine]", "]"}]}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Updating", " ", "beliefs"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"rAvar", "[", 
      RowBox[{"rAold_", ",", "xt1_"}], "]"}], ":=", 
     RowBox[{"rAold", "+", 
      RowBox[{"gamm", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Outer", "[", " ", 
          RowBox[{"Times", ",", "xt1", ",", "xt1"}], " ", "]"}], " ", "-", 
         " ", "rAold"}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"cAvar", "[", 
      RowBox[{"cAold_", ",", "rM_", ",", "yt_", ",", "xt1_"}], "]"}], ":=", 
     RowBox[{"cAold", "+", 
      RowBox[{"gamm", "*", 
       RowBox[{"Outer", "[", 
        RowBox[{"Times", ",", 
         RowBox[{"(", 
          RowBox[{"yt", "-", 
           RowBox[{"cAold", ".", "xt1"}]}], ")"}], ",", 
         RowBox[{"xt1", ".", 
          RowBox[{"Inverse", "[", " ", "rM", " ", "]"}]}]}], " ", "]"}]}]}]}],
     ";"}]}]}]], "Input",
 CellChangeTimes->{{3.7364195063376813`*^9, 3.7364195065976963`*^9}},
 FontSize->10]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Initalization of variance-covatiance matrix for adaptive learning\
\>", "Subsubsection",
 CellChangeTimes->{3.735908838282324*^9}],

Cell["\<\
Simulate the dynamics under RE and estimate a precision matrix for \
coefficients\
\>", "Text",
 CellChangeTimes->{{3.7358334458485527`*^9, 3.7358334476406546`*^9}, {
  3.7359089198279877`*^9, 3.7359089665726614`*^9}, {3.7359090099251413`*^9, 
  3.735909022682871*^9}},
 FontSize->10],

Cell[BoxData[{
 StyleBox[
  RowBox[{
   RowBox[{"tt", "=", "100000"}], ";"}],
  FontFamily->"Courier New",
  FontSize->10], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{"xREdynamics", "=", 
    RowBox[{"Table", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", "tt", "}"}], ",", 
      RowBox[{"{", "8", "}"}]}], "]"}]}], ";"}],
  FontFamily->"Courier New",
  FontSize->10], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{
    RowBox[{"xREdynamics", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "=", 
    RowBox[{"Log", "[", 
     RowBox[{"{", 
      RowBox[{
      "css", ",", "qss", ",", "lambdass", ",", "phiss", ",", "bss", ",", 
       "kss", ",", "theta", ",", "1"}], "}"}], "]"}]}], ";"}],
  FontFamily->"Courier New",
  FontSize->10], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{
    RowBox[{"vtt", "=", 
     RowBox[{"RandomReal", "[", 
      RowBox[{
       RowBox[{"NormalDistribution", "[", 
        RowBox[{"0", ",", 
         RowBox[{"StandardDeviation", "[", "innovOLS", "]"}]}], "]"}], ",", 
       RowBox[{"{", "tt", "}"}]}], "]"}]}], ";"}], " "}],
  FontFamily->"Courier New",
  FontSize->10], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{"wtt", "=", 
    RowBox[{"RandomReal", "[", 
     RowBox[{
      RowBox[{"NormalDistribution", "[", 
       RowBox[{"0", ",", "0.001"}], "]"}], ",", 
      RowBox[{"{", "tt", "}"}]}], "]"}]}], ";"}],
  FontFamily->"Courier New",
  FontSize->10], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{"stt", "=", 
    RowBox[{"RandomReal", "[", 
     RowBox[{
      RowBox[{"NormalDistribution", "[", 
       RowBox[{"0", ",", 
        RowBox[{"10", "^", 
         RowBox[{"-", "30"}]}]}], "]"}], ",", 
      RowBox[{"{", "tt", "}"}]}], "]"}]}], ";"}],
  FontFamily->"Courier New",
  FontSize->10], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{"ptt", "=", 
    RowBox[{"RandomReal", "[", 
     RowBox[{
      RowBox[{"NormalDistribution", "[", 
       RowBox[{"0", ",", 
        RowBox[{"10", "^", 
         RowBox[{"-", "30"}]}]}], "]"}], ",", 
      RowBox[{"{", "tt", "}"}]}], "]"}]}], ";"}],
  FontFamily->"Courier New",
  FontSize->10], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{"ktt", "=", 
    RowBox[{"RandomReal", "[", 
     RowBox[{
      RowBox[{"NormalDistribution", "[", 
       RowBox[{"0", ",", 
        RowBox[{"10", "^", 
         RowBox[{"-", "30"}]}]}], "]"}], ",", 
      RowBox[{"{", "tt", "}"}]}], "]"}]}], ";"}],
  FontFamily->"Courier New",
  FontSize->10], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{"mtt", "=", 
    RowBox[{"RandomReal", "[", 
     RowBox[{
      RowBox[{"NormalDistribution", "[", 
       RowBox[{"0", ",", 
        RowBox[{"10", "^", 
         RowBox[{"-", "30"}]}]}], "]"}], ",", 
      RowBox[{"{", "tt", "}"}]}], "]"}]}], ";"}],
  FontFamily->"Courier New",
  FontSize->10], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{"ntt", "=", 
    RowBox[{"RandomReal", "[", 
     RowBox[{
      RowBox[{"NormalDistribution", "[", 
       RowBox[{"0", ",", 
        RowBox[{"10", "^", 
         RowBox[{"-", "30"}]}]}], "]"}], ",", 
      RowBox[{"{", "tt", "}"}]}], "]"}]}], ";"}],
  FontFamily->"Courier New",
  FontSize->10], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{"ott", "=", 
    RowBox[{"RandomReal", "[", 
     RowBox[{
      RowBox[{"NormalDistribution", "[", 
       RowBox[{"0", ",", 
        RowBox[{"10", "^", 
         RowBox[{"-", "30"}]}]}], "]"}], ",", 
      RowBox[{"{", "tt", "}"}]}], "]"}]}], ";"}],
  FontFamily->"Courier New",
  FontSize->10], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{"ttt", "=", 
    RowBox[{"RandomReal", "[", 
     RowBox[{
      RowBox[{"NormalDistribution", "[", 
       RowBox[{"0", ",", 
        RowBox[{"10", "^", 
         RowBox[{"-", "30"}]}]}], "]"}], ",", 
      RowBox[{"{", "tt", "}"}]}], "]"}]}], ";"}],
  FontFamily->"Courier New",
  FontSize->10], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{"qtt", "=", 
    RowBox[{"RandomReal", "[", 
     RowBox[{
      RowBox[{"NormalDistribution", "[", 
       RowBox[{"0", ",", 
        RowBox[{"10", "^", 
         RowBox[{"-", "30"}]}]}], "]"}], ",", 
      RowBox[{"{", "tt", "}"}]}], "]"}]}], ";"}],
  FontFamily->"Courier New",
  FontSize->10], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "2"}], ",", 
      RowBox[{"i", "<", 
       RowBox[{"tt", "+", "1"}]}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"xREdynamics", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "=", 
        RowBox[{
         RowBox[{"mMRE", ".", 
          RowBox[{"xREdynamics", "[", 
           RowBox[{"[", 
            RowBox[{"i", "-", "1"}], "]"}], "]"}]}], "+", "hMRE", "+", 
         RowBox[{"gMRE", "*", 
          RowBox[{"vtt", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], " ", "+", 
         RowBox[{"ggMRE", "*", 
          RowBox[{"wtt", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "0", ",", "0", ",", "1", ",", "0", ",", "0", ",", "0", ",", "0", 
            ",", "0"}], "}"}], "*", 
          RowBox[{"stt", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "0", ",", "1", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
            ",", "0"}], "}"}], "*", 
          RowBox[{"ptt", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "1", ",", "0", 
            ",", "0"}], "}"}], "*", 
          RowBox[{"ktt", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
            ",", "1"}], "}"}], "*", 
          RowBox[{"mtt", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "0", ",", "0", ",", "0", ",", "1", ",", "0", ",", "0", ",", "0", 
            ",", "0"}], "}"}], "*", 
          RowBox[{"ntt", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "1", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
            ",", "0"}], "}"}], "*", 
          RowBox[{"ott", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "0", ",", "0", ",", "0", ",", "0", ",", "1", ",", "0", ",", "0", 
            ",", "0"}], "}"}], "*", 
          RowBox[{"ttt", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "0", ",", "0", ",", "0", ",", "0", ",", "1", ",", "1", ",", "0", 
            ",", "0"}], "}"}], "*", 
          RowBox[{"qtt", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}]}]}], ";"}]}], " ", 
     "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]"}],
  FontFamily->"Courier New",
  FontSize->10], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{"RR", "=", " ", 
    RowBox[{"Transpose", "[", "xREdynamics", "]"}]}], ";"}],
  FontFamily->"Courier New",
  FontSize->10], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{"QQ", "=", 
    RowBox[{
     RowBox[{"RR", ".", 
      RowBox[{"Transpose", "[", "RR", "]"}]}], "/", "tt"}]}], ";"}],
  FontFamily->"Courier New",
  FontSize->10], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{"TT", "=", 
    RowBox[{"Prepend", "[", 
     RowBox[{
      RowBox[{"Diagonal", "[", "QQ", "]"}], ",", "1"}], "]"}]}], ";"}],
  FontFamily->"Courier New",
  FontSize->10], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{"MM", "=", 
    RowBox[{"DiagonalMatrix", "[", "TT", "]"}]}], ";"}],
  FontFamily->"Courier New",
  FontSize->10], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{"Eigenvalues", "[", "MM", "]"}], ";"}],
  FontFamily->"Courier New",
  FontSize->10]}], "Input",
 CellChangeTimes->{{3.7364202853082356`*^9, 3.736420303532278*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Initialization of mean beliefs", "Subsubsection",
 CellChangeTimes->{{3.506692861375718*^9, 3.5066928842815285`*^9}, {
  3.7359089046631203`*^9, 3.7359089109794817`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Use", " ", "estimated", " ", "financial", " ", "shocks"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"tt", "=", " ", 
     RowBox[{"Length", "[", "innovCG", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"vtt", "=", "innovCG"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ytt", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "tt", "}"}], ",", 
       RowBox[{"{", "8", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"oMtt", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "tt", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", "*", "9"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"mMtt", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "tt", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", "*", "8"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"hMtt", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "tt", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", "*", "1"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ssCGtt", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "tt", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", "*", "1"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Initial", " ", "values"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"start", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ytt", "[", 
      RowBox[{"[", "start", "]"}], "]"}], "=", "initialALss"}], ";"}], " ", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Initial", " ", "beliefs", " ", "matrix"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"mM0", "=", "mMInitialAL"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"hM0", "=", "hMInitialAL"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rM0", "=", "MM"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ssCGtt", "[", 
      RowBox[{"[", "start", "]"}], "]"}], "=", 
     RowBox[{
      RowBox[{"Inverse", "[", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"IdentityMatrix", "[", "8", "]"}], " ", "-", " ", "mM0"}], 
        ")"}], "]"}], ".", "hM0"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gamm", "=", "gain"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rM1", "=", "rM0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"mM1", "=", "mM0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"mM2", "=", "mM0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"hM1", "=", "hM0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"hM2", "=", "hM0"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"oM0", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "8", "}"}], ",", 
       RowBox[{"{", "9", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"oM0", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "1"}], "]"}], "]"}], "=", "hM0"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"oM0", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", 
        RowBox[{"2", ";;", "9"}]}], "]"}], "]"}], "=", "mM0"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"oM1", "=", "oM0"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"oMtt", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "=", 
     RowBox[{"Flatten", "[", "oM0", "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"oMRE", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "8", "}"}], ",", 
       RowBox[{"{", "9", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"oMRE", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "1"}], "]"}], "]"}], "=", "hMRE"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"oMRE", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", 
        RowBox[{"2", ";;", "9"}]}], "]"}], "]"}], "=", "mMRE"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Computing", " ", "the", " ", "variance", " ", "of", " ", "estimates"}], 
    " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"Procedure", ":", " ", "use"}], " ", ";", "\[IndentingNewLine]", 
     "        ", 
     RowBox[{"ut", " ", "=", " ", 
      RowBox[{"yt", "-", 
       RowBox[{"cAold", ".", "xt1"}]}]}], ";", " ", "\[IndentingNewLine]", 
     "\t\t", 
     RowBox[{"Ut", " ", "=", " ", 
      RowBox[{"[", 
       RowBox[{"u1", ",", " ", "u2", ",", " ", "...", ",", " ", "ut"}], 
       "]"}]}], ";", "\[IndentingNewLine]", "\t\t", 
     RowBox[{"vzt", " ", "=", " ", 
      RowBox[{
       RowBox[{"[", 
        RowBox[{"1", ",", " ", 
         RowBox[{"yt", "'"}]}], "]"}], "'"}]}], ";", "        ", 
     RowBox[{"(", 
      RowBox[{"vector", " ", "z"}], ")"}], ";", " ", "\[IndentingNewLine]", 
     "\t\t", 
     RowBox[{"vZt", " ", "=", " ", 
      RowBox[{"[", 
       RowBox[{
       "z0", ",", " ", "z1", ",", " ", "z2", ",", "...", ",", " ", "zt"}], 
       "]"}]}], ";", "\[IndentingNewLine]", "        ", 
     RowBox[{"mGammat", " ", "=", " ", 
      RowBox[{
       RowBox[{"vZt", "*", 
        RowBox[{
         RowBox[{"vZt", "'"}], "/", "t"}]}], " ", "=", " ", 
       RowBox[{"mGammat1", " ", "+", " ", 
        RowBox[{"gain", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"vzt", "*", 
            RowBox[{"vzt", "'"}]}], " ", "-", " ", "mGammat1"}], 
          ")"}]}]}]}]}], ";", "\[IndentingNewLine]", "\t\t", 
     RowBox[{"mSigmaUt", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"UtUt", "'"}], "/", "t"}], " ", "=", " ", 
       RowBox[{"mSigmaUt1", " ", "+", " ", 
        RowBox[{"gain", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"ut", "*", 
            RowBox[{"ut", "'"}]}], " ", "-", " ", "mSigmaUt1"}], 
          ")"}]}]}]}]}], ";", "\[IndentingNewLine]", "\t\t", 
     RowBox[{"varMt", " ", "=", " ", 
      RowBox[{"t", " ", "*", " ", 
       RowBox[{
        RowBox[{"mGammat", "^", 
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}]}], " ", "\[CircleTimes]", " ", 
        "mSigmaUt"}]}]}]}], "\[IndentingNewLine]", "*)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", "variables", " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"uhattt", " ", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "tt", "}"}], ",", 
       RowBox[{"{", "8", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Sigmahattt", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "tt", "}"}], ",", 
       RowBox[{"{", "8", "}"}], ",", 
       RowBox[{"{", "8", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"vZtt", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "tt", "}"}], ",", 
       RowBox[{"{", "9", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"GammaTtt", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "tt", "}"}], ",", 
       RowBox[{"{", "8", "}"}], ",", 
       RowBox[{"{", "8", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"varoMtt", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "tt", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", "*", "9"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "matrices", " ", "to", " ", "record", " ", "variance", " ", "of", " ", 
     "estimates", " ", "and", " ", "temporary", " ", "stuff"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"oSumXXtt", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "tt", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", "*", "9"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"varoMtt", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "tt", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"8", "*", "9"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.7364204414191647`*^9, 3.7364204416761794`*^9}, {
  3.736420503914739*^9, 3.736420606682617*^9}, {3.7364207188570333`*^9, 
  3.7364207193220596`*^9}, {3.7364207523769503`*^9, 3.736420752666967*^9}, {
  3.7364219550917416`*^9, 3.736421994458994*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Recursions", "Subsubsection",
 CellChangeTimes->{{3.506692866516245*^9, 3.506692867891218*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", 
      RowBox[{"start", "+", "1"}]}], ",", 
     RowBox[{"i", "<", 
      RowBox[{"tt", "+", "1"}]}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"gamm", "=", "gain"}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"Updating", " ", "ALM"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"mALMt", "=", 
       RowBox[{"mALMlearn", "[", 
        RowBox[{"mM1", ",", "mM2"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"hALMt", "=", 
       RowBox[{"hALMlearn", "[", 
        RowBox[{"mM1", ",", "hM1", ",", "hM2"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"oALMt", "=", 
       RowBox[{"oALMlearn", "[", 
        RowBox[{"mALMt", ",", "hALMt"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"gALMt", "=", 
       RowBox[{"gALMlearn", "[", "mM1", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ggALMt", "=", 
       RowBox[{"ggALMlearn", "[", "mM1", "]"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"Exogenous", " ", "variables"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Solve", " ", "for", " ", "wtt", " ", "that", " ", "matches", " ", 
        RowBox[{"data", ":"}]}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"1", ":", " ", 
        RowBox[{"Set", " ", "unknown", " ", "as", " ", "xX"}]}], " ", "*)"}], 
      " ", "\[IndentingNewLine]", 
      RowBox[{"toSolve", "=", 
       RowBox[{"hALMt", "+", 
        RowBox[{"mALMt", ".", 
         RowBox[{"ytt", "[", 
          RowBox[{"[", 
           RowBox[{"i", "-", "1"}], "]"}], "]"}]}], "+", 
        RowBox[{"gALMt", "*", 
         RowBox[{"vtt", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], "+", 
        RowBox[{"ggALMt", "*", "xX"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"2", ":", " ", 
        RowBox[{
        "Solve", " ", "for", " ", "value", " ", "of", " ", "xX", " ", "that", 
         " ", "matches", " ", "price", " ", "in", " ", "that", " ", 
         "period"}]}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"solutionToxX", "=", 
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"toSolve", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "==", 
          RowBox[{"Exp", "[", 
           RowBox[{"p", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", "xX"}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "3.", " ", "Assign", " ", "that", " ", "value", " ", "as", " ", "a", 
        " ", "shock", " ", "to", " ", "land", " ", "price", " ", "and", " ", 
        "compute", " ", "eqbm"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"wtt", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "=", 
       RowBox[{"xX", " ", "/.", " ", 
        RowBox[{"solutionToxX", " ", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Use", " ", "this", " ", "value", " ", "in", " ", "computing", " ", 
        "actual", " ", "dynamics"}], " ", "*)"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"Endogenous", " ", "variables"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"ytt", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "=", 
       RowBox[{"hALMt", "+", 
        RowBox[{"mALMt", ".", 
         RowBox[{"ytt", "[", 
          RowBox[{"[", 
           RowBox[{"i", "-", "1"}], "]"}], "]"}]}], "+", 
        RowBox[{"gALMt", "*", 
         RowBox[{"vtt", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], "+", 
        RowBox[{"ggALMt", "*", 
         RowBox[{"wtt", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ztt", "=", 
       RowBox[{"Prepend", "[", 
        RowBox[{
         RowBox[{"ytt", "[", 
          RowBox[{"[", 
           RowBox[{"i", "-", "1"}], "]"}], "]"}], ",", "1"}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"Beliefs", " ", "updating"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"rM", "=", 
       RowBox[{"rAvar", "[", 
        RowBox[{"rM1", ",", "ztt"}], " ", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"oM", "=", 
       RowBox[{"cAvar", "[", 
        RowBox[{"oM1", ",", "rM", ",", 
         RowBox[{"ytt", "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", "ztt"}], " ", "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"Storing", " ", "results"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"oMtt", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "=", 
       RowBox[{"Flatten", "[", "oM", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"mM", "=", 
       RowBox[{"oM", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", 
          RowBox[{"2", ";;", "9"}]}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"hM", "=", 
       RowBox[{"oM", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "1"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"mMtt", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "=", 
       RowBox[{"Flatten", "[", "mM", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"hMtt", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "=", 
       RowBox[{"Flatten", "[", "hM", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"ssCGtt", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "=", 
       RowBox[{
        RowBox[{"Inverse", "[", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"IdentityMatrix", "[", "8", "]"}], " ", "-", " ", "mM"}], 
          ")"}], "]"}], ".", "hM"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"Updating", " ", "matrices"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"mM2", "=", "mM1"}], ";", "\[IndentingNewLine]", 
      RowBox[{"mM1", "=", "mM"}], ";", "\[IndentingNewLine]", 
      RowBox[{"hM2", "=", "hM1"}], ";", "\[IndentingNewLine]", 
      RowBox[{"hM1", "=", "hM"}], ";", "\[IndentingNewLine]", 
      RowBox[{"oM1", "=", "oM"}], ";", "\[IndentingNewLine]", 
      RowBox[{"rM1", "=", "rM"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xCGtt", " ", "=", " ", "ytt"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"zero", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "tt", "}"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7364208854055595`*^9, 3.7364208891327724`*^9}, {
  3.7364209317742114`*^9, 3.7364209597408113`*^9}, {3.736420990874592*^9, 
  3.736420998455025*^9}, {3.7364215785512047`*^9, 3.7364215790312324`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
5. Model-generated recession under RE\
\>", "Section",
 CellChangeTimes->{{3.735644902600684*^9, 3.735644957198807*^9}, {
   3.73583397608488*^9, 3.7358339786930294`*^9}, 3.735909114353114*^9, {
   3.736421620914628*^9, 3.736421635793479*^9}, 3.7364219233149242`*^9, {
   3.736422027407878*^9, 3.7364220287509546`*^9}}],

Cell[CellGroupData[{

Cell["Dynamics under RE", "Subsection",
 CellChangeTimes->{{3.736421658129757*^9, 3.7364216654251738`*^9}, {
  3.7364220451988955`*^9, 3.7364220466549788`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Use", " ", "estimated", " ", "financial", " ", "shocks"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"vtt", "=", "innovOLS"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"Computing", " ", "land"}], "-", 
     RowBox[{
     "price", " ", "shocks", " ", "and", " ", "endogenous", " ", "variables", 
      " ", "under", " ", "RE"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"xREtt", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "tt", "}"}], ",", 
       RowBox[{"{", "8", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"xREtt", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "=", 
     RowBox[{"Log", "[", 
      RowBox[{"{", 
       RowBox[{
       "css", ",", "qss", ",", "lambdass", ",", "phiss", ",", "bss", ",", 
        "kss", ",", "theta", ",", "1"}], "}"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "2"}], ",", 
      RowBox[{"i", "<", 
       RowBox[{"tt", "+", "1"}]}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Solve", " ", "for", " ", "wtt", " ", "that", " ", "matches", " ", 
        RowBox[{"data", ":"}]}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"1", ":", " ", 
        RowBox[{"Set", " ", "unknown", " ", "as", " ", "xX"}]}], " ", "*)"}], 
      " ", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"toSolve", "=", 
        RowBox[{
         RowBox[{"mMRE", ".", 
          RowBox[{"xREtt", "[", 
           RowBox[{"[", 
            RowBox[{"i", "-", "1"}], "]"}], "]"}]}], "+", "hMRE", "+", " ", 
         RowBox[{"gMRE", "*", 
          RowBox[{"vtt", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "+", 
         RowBox[{"ggMRE", "*", "xX"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"2", ":", " ", 
         RowBox[{
         "Solve", " ", "for", " ", "value", " ", "of", " ", "xX", " ", "that",
           " ", "matches", " ", "price", " ", "in", " ", "that", " ", 
          "period"}]}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"solutionToxX", "=", 
        RowBox[{"Solve", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"toSolve", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "==", 
           RowBox[{"Exp", "[", 
            RowBox[{"p", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", "xX"}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "3.", " ", "Assign", " ", "that", " ", "value", " ", "as", " ", "a", 
         " ", "shock", " ", "to", " ", "land", " ", "price", " ", "and", " ", 
         "compute", " ", "eqbm"}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"wtt", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "=", 
        RowBox[{"xX", " ", "/.", " ", 
         RowBox[{"solutionToxX", " ", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"xREtt", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "=", 
        RowBox[{
         RowBox[{"mMRE", ".", 
          RowBox[{"xREtt", "[", 
           RowBox[{"[", 
            RowBox[{"i", "-", "1"}], "]"}], "]"}]}], "+", "hMRE", "+", " ", 
         RowBox[{"gMRE", "*", 
          RowBox[{"vtt", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "+", 
         RowBox[{"ggMRE", "*", 
          RowBox[{"wtt", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}]}]}], ";"}]}], 
     "\[IndentingNewLine]", "]"}], ";"}]}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"tk", "=", "tt"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"outRE", " ", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"alpha", "+", 
       RowBox[{"alpha", "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "alpha", "-", "gamma"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"chi", "+", "gamma", "+", "alpha"}], ")"}]}]}]}], ")"}], 
     "*", 
     RowBox[{"xREtt", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"1", ";;", "tk"}], ",", "6"}], "]"}], "]"}]}], "+", 
    RowBox[{"Log", "[", "yss", "]"}], " ", "-", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"alpha", "+", 
       RowBox[{"alpha", "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "alpha", "-", "gamma"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"chi", "+", "gamma", "+", "alpha"}], ")"}]}]}]}], ")"}], 
     "*", 
     RowBox[{"Log", "[", "kss", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"priceRE", "=", 
   RowBox[{"xREtt", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{"1", ";;", "tk"}], ",", "2"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"thetaRE", "=", 
   RowBox[{
    RowBox[{"xREtt", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"1", ";;", "tk"}], ",", "7"}], "]"}], "]"}], "+", 
    RowBox[{"epsilon", "*", 
     RowBox[{"xREtt", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"1", ";;", "tk"}], ",", "2"}], "]"}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]"}], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["6. Figure 10", "Section",
 CellChangeTimes->{{3.7364220550714607`*^9, 3.736422056766557*^9}, {
  3.736426848541631*^9, 3.736426862877451*^9}, {3.7364276350796185`*^9, 
  3.736427638231799*^9}}],

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{"start", "=", "101"}], ";", " ", 
   RowBox[{"peak", "=", "132"}], ";", " ", 
   RowBox[{"trough", " ", "=", " ", "141"}], ";", " ", 
   RowBox[{"end", "=", "141"}], ";", " ", 
   RowBox[{"startyear", "=", "2000"}], ";", " ", 
   RowBox[{"quarter", "=", "1"}], ";"}],
  FontFamily->"Courier New",
  FontSize->10]], "Input",
 CellChangeTimes->{{3.7364222109433756`*^9, 3.736422212399459*^9}}],

Cell[CellGroupData[{

Cell["a. Figure 10", "Subsection",
 CellChangeTimes->{{3.7364222252781954`*^9, 3.736422244429291*^9}, {
  3.7364270201404457`*^9, 3.7364270213235135`*^9}, {3.7364276285202436`*^9, 
  3.736427628599248*^9}}],

Cell[BoxData[{
 RowBox[{
  StyleBox[
   RowBox[{
    RowBox[{"outCG07Q4", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"alpha", "+", 
        RowBox[{"alpha", "*", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "alpha", "-", "gamma"}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"chi", "+", "gamma", "+", "alpha"}], ")"}]}]}]}], ")"}], 
      "*", 
      RowBox[{"xCGtt", "[", 
       RowBox[{"[", 
        RowBox[{"peak", ",", "6"}], "]"}], "]"}]}]}], ";", " ", 
    RowBox[{"outRE07Q4", " ", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"alpha", "+", 
        RowBox[{"alpha", "*", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "alpha", "-", "gamma"}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"chi", "+", "gamma", "+", "alpha"}], ")"}]}]}]}], ")"}], 
      "*", 
      RowBox[{"xREtt", "[", 
       RowBox[{"[", 
        RowBox[{"peak", ",", "6"}], "]"}], "]"}]}]}], ";"}],
   FontFamily->"Courier New",
   FontSize->10], 
  StyleBox[" ",
   FontFamily->"Courier New",
   FontSize->10], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{
    RowBox[{"labCG07Q4", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"alpha", "/", 
        RowBox[{"(", 
         RowBox[{"chi", "+", "gamma", "+", "alpha"}], ")"}]}], ")"}], "*", 
      RowBox[{"xCGtt", "[", 
       RowBox[{"[", 
        RowBox[{"peak", ",", "6"}], "]"}], "]"}]}]}], ";"}], " "}],
  FontFamily->"Courier New",
  FontSize->10], "\[IndentingNewLine]", 
 RowBox[{
  StyleBox[
   RowBox[{
    RowBox[{"labRE07Q4", " ", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"alpha", "/", 
        RowBox[{"(", 
         RowBox[{"chi", "+", "gamma", "+", "alpha"}], ")"}]}], ")"}], "*", 
      RowBox[{"xREtt", "[", 
       RowBox[{"[", 
        RowBox[{"peak", ",", "6"}], "]"}], "]"}]}]}], ";"}],
   FontFamily->"Courier New",
   FontSize->10], 
  StyleBox[" ",
   FontFamily->"Courier New",
   FontSize->10], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{
    RowBox[{"consCG07Q4", "=", 
     RowBox[{"xCGtt", "[", 
      RowBox[{"[", 
       RowBox[{"peak", ",", "1"}], "]"}], "]"}]}], ";", " ", 
    RowBox[{"consRE07Q4", " ", "=", 
     RowBox[{"xREtt", "[", 
      RowBox[{"[", 
       RowBox[{"peak", ",", "1"}], "]"}], "]"}]}], ";"}], " "}],
  FontFamily->"Courier New",
  FontSize->10], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{
    RowBox[{"priceCG07Q4", " ", "=", 
     RowBox[{"xCGtt", "[", 
      RowBox[{"[", 
       RowBox[{"peak", ",", "2"}], "]"}], "]"}]}], ";", " ", 
    RowBox[{"priceRE07Q4", " ", "=", 
     RowBox[{"xREtt", "[", 
      RowBox[{"[", 
       RowBox[{"peak", ",", "2"}], "]"}], "]"}]}], ";"}], " "}],
  FontFamily->"Courier New",
  FontSize->10], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{"borrCG07Q4", "=", 
    RowBox[{"xCGtt", "[", 
     RowBox[{"[", 
      RowBox[{"peak", ",", "5"}], "]"}], "]"}]}], ";", " ", 
   RowBox[{"borrRE07Q4", " ", "=", 
    RowBox[{"xREtt", "[", 
     RowBox[{"[", 
      RowBox[{"peak", ",", "5"}], "]"}], "]"}]}], ";"}],
  FontFamily->"Courier New",
  FontSize->10], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{3.7364276896407394`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   StyleBox[
    RowBox[{"DateListPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"100", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"alpha", "+", 
              RowBox[{"alpha", "*", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "alpha", "-", "gamma"}], ")"}], "/", 
                RowBox[{"(", 
                 RowBox[{"chi", "+", "gamma", "+", "alpha"}], ")"}]}]}]}], 
             ")"}], "*", 
            RowBox[{"xCGtt", "[", 
             RowBox[{"[", 
              RowBox[{
               RowBox[{"start", ";;", "end"}], ",", "6"}], "]"}], "]"}]}], 
           " ", "-", "outCG07Q4"}], ")"}]}], ",", 
        RowBox[{"100", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"alpha", "+", 
              RowBox[{"alpha", "*", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "alpha", "-", "gamma"}], ")"}], "/", 
                RowBox[{"(", 
                 RowBox[{"chi", "+", "gamma", "+", "alpha"}], ")"}]}]}]}], 
             ")"}], "*", 
            RowBox[{"xREtt", "[", 
             RowBox[{"[", 
              RowBox[{
               RowBox[{"start", ";;", "end"}], ",", "6"}], "]"}], "]"}]}], 
           "-", "outRE07Q4"}], ")"}]}], ",", 
        RowBox[{"zero", "[", 
         RowBox[{"[", 
          RowBox[{"start", ";;", "end"}], "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"startyear", ",", "quarter", ",", "1"}], "}"}], ",", 
        "Automatic", ",", "\"\<Quarter\>\""}], "}"}], ",", 
      RowBox[{"Joined", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"True", ",", "False", ",", "True"}], "}"}]}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"Filling", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"1", "\[Rule]", 
         RowBox[{"{", "2", "}"}]}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Thick", ",", "Red"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"Thick", ",", "Blue"}], "}"}], ",", "Black"}], "}"}]}], ",", 
      RowBox[{"PlotLabel", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{
        "\"\<Output Response Over Time (% Deviations From 2007Q4)\>\"", ",", 
         "13"}], "]"}]}], " ", ",", 
      RowBox[{"LabelStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"FontSize", "\[Rule]", "13"}], "]"}]}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "Large"}]}], "]"}],
    FontFamily->"Courier New",
    FontSize->10], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.5730427185*^9, 3.573042760296875*^9}, {
   3.5730429791875*^9, 3.573042983375*^9}, {3.5730432280625*^9, 
   3.573043274625*^9}, {3.5730433145625*^9, 3.57304340446875*^9}, {
   3.573044337546875*^9, 3.573044357375*^9}, {3.573044584546875*^9, 
   3.573044633046875*^9}, {3.57304485915625*^9, 3.57304486446875*^9}, {
   3.573044924546875*^9, 3.57304492896875*^9}, {3.573045511109375*^9, 
   3.57304551175*^9}, {3.57304556675*^9, 3.573045612*^9}, {
   3.573045989328125*^9, 3.573046022421875*^9}, {3.573046560171875*^9, 
   3.573046617484375*^9}, {3.573047040109375*^9, 3.57304705003125*^9}, {
   3.57304712346875*^9, 3.57304714378125*^9}, {3.573047309234375*^9, 
   3.5730473378125*^9}, {3.573047391046875*^9, 3.573047399609375*^9}, {
   3.573048379640625*^9, 3.573048478421875*^9}, {3.573048607*^9, 
   3.5730486125*^9}, {3.573048696828125*^9, 3.573048696953125*^9}, {
   3.573049521703125*^9, 3.57304955990625*^9}, {3.573049603453125*^9, 
   3.573049641890625*^9}, {3.57305061178125*^9, 3.573050625703125*^9}, {
   3.573050831015625*^9, 3.5730508613125*^9}, {3.57305115325*^9, 
   3.5730512029375*^9}, {3.573051253546875*^9, 3.573051338265625*^9}, {
   3.57305137940625*^9, 3.57305141721875*^9}, {3.573051449921875*^9, 
   3.573051475484375*^9}, {3.5730515280625*^9, 3.573051619171875*^9}, {
   3.573054396390625*^9, 3.57305461121875*^9}, {3.573054650015625*^9, 
   3.57305465896875*^9}, {3.573054712890625*^9, 3.57305471628125*^9}, {
   3.573054781078125*^9, 3.573054862859375*^9}, {3.5730549875*^9, 
   3.57305500771875*^9}, {3.573055089859375*^9, 3.573055094015625*^9}, {
   3.5730552205*^9, 3.57305526740625*^9}, {3.573055534640625*^9, 
   3.5730555835*^9}, {3.57305565803125*^9, 3.57305569296875*^9}, {
   3.57305577571875*^9, 3.57305578634375*^9}, {3.57305585365625*^9, 
   3.573056097484375*^9}, {3.573056200015625*^9, 3.573056244859375*^9}, {
   3.5730585673125*^9, 3.573058569828125*^9}, {3.573058669*^9, 
   3.5730586856875*^9}, {3.573062921171875*^9, 3.5730629993125*^9}, {
   3.573116309046875*^9, 3.573116582078125*^9}, {3.5732090844437113`*^9, 
   3.573209217932911*^9}, {3.573209349784111*^9, 3.5732093535905113`*^9}, {
   3.573223606515625*^9, 3.573223606828125*^9}, {3.573224028296875*^9, 
   3.5732240964375*^9}, {3.573224283546875*^9, 3.573224284484375*^9}, {
   3.573234542015625*^9, 3.573234559578125*^9}, {3.573235697734375*^9, 
   3.573235716890625*^9}, {3.573235755265625*^9, 3.5732357946875*^9}, {
   3.573272596390625*^9, 3.573272604890625*^9}, {3.573289894890625*^9, 
   3.57328991234375*^9}, {3.5735391965164423`*^9, 3.573539229323242*^9}, {
   3.573539707942842*^9, 3.573539726959242*^9}, {3.5735397673008423`*^9, 
   3.573539769578442*^9}, {3.5735399716014423`*^9, 3.573539971648242*^9}, {
   3.573540049726242*^9, 3.5735400844050417`*^9}, {3.573540960489242*^9, 
   3.573540961456442*^9}, {3.5735409924380417`*^9, 3.5735410524668417`*^9}, {
   3.5735410935728416`*^9, 3.573541104804842*^9}, {3.5735411582660418`*^9, 
   3.573541227186842*^9}, {3.573541615548842*^9, 3.573541617701642*^9}, {
   3.573541724280842*^9, 3.573541727510042*^9}, {3.573541778413842*^9, 
   3.5735418571470423`*^9}, {3.5735419098594418`*^9, 3.573541944008842*^9}, {
   3.573542101537642*^9, 3.573542105437642*^9}, {3.573542242728242*^9, 
   3.573542245208642*^9}, {3.573542522924842*^9, 3.573542523112042*^9}, {
   3.573542780839642*^9, 3.573542820962842*^9}, {3.5735436186856422`*^9, 
   3.573543622538842*^9}, {3.573543955665242*^9, 3.573543957240842*^9}, {
   3.573544055281242*^9, 3.573544057590042*^9}, {3.5735457331632423`*^9, 
   3.5735457355656424`*^9}, {3.573545829533842*^9, 3.573545844556642*^9}, {
   3.573546203201642*^9, 3.573546219581642*^9}, {3.573556609950042*^9, 
   3.573556618608042*^9}, {3.573556989361642*^9, 3.573557145283642*^9}, {
   3.5735572200700417`*^9, 3.573557258602042*^9}, {3.573557302188442*^9, 
   3.573557308007242*^9}, 3.5735573412664423`*^9, {3.5735574099064417`*^9, 
   3.573557448454042*^9}, {3.5735579273514423`*^9, 3.573557957553042*^9}, {
   3.573558058890642*^9, 3.573558089872242*^9}, {3.5735581818654423`*^9, 
   3.573558182536242*^9}, {3.573558278975442*^9, 3.5735582833278418`*^9}, {
   3.573558457027842*^9, 3.573558543498642*^9}, {3.5735602491592417`*^9, 
   3.573560285304442*^9}, {3.573560375628442*^9, 3.573560416906042*^9}, {
   3.5735604507112417`*^9, 3.573560452037242*^9}, {3.573737688390625*^9, 
   3.5737377065*^9}, {3.573737893609375*^9, 3.573737896578125*^9}, {
   3.57373795665625*^9, 3.5737380334375*^9}, {3.573738395546875*^9, 
   3.57373843478125*^9}, {3.573738685890625*^9, 3.573738687921875*^9}, {
   3.573738770140625*^9, 3.57373877075*^9}, {3.5737395484375*^9, 
   3.573736099703125*^9}, {3.573736510578125*^9, 3.573736510875*^9}, {
   3.5737371225625*^9, 3.57373713990625*^9}, {3.5739592877970405`*^9, 
   3.5739593339574404`*^9}, {3.5739593914746404`*^9, 3.57395945392144*^9}, {
   3.5739594865098405`*^9, 3.5739595045122404`*^9}, {3.5739595928802404`*^9, 
   3.5739595947834406`*^9}, {3.57395962880704*^9, 3.5739596502414403`*^9}, {
   3.5739597600966406`*^9, 3.5739597622182407`*^9}, 3.5739597941232405`*^9, {
   3.57395986635124*^9, 3.5739599717604403`*^9}, {3.5739600193404408`*^9, 
   3.5739600508212404`*^9}, {3.5739600824892406`*^9, 
   3.5739601566994405`*^9}, {3.5739616964478407`*^9, 
   3.5739617128278403`*^9}, {3.5739617576310406`*^9, 3.5739617969118404`*^9}, 
   3.5739618481422405`*^9, {3.5739618837882404`*^9, 3.57396188943544*^9}, {
   3.57396196715464*^9, 3.5739619735350404`*^9}, {3.5739620530950403`*^9, 
   3.5739620533290405`*^9}, {3.5739621404550405`*^9, 3.5739621412818403`*^9}, 
   3.5739621800946407`*^9, {3.5786533579038*^9, 3.578653397559*^9}, {
   3.5786542647776003`*^9, 3.57865426523*^9}, {3.5786542988948*^9, 
   3.5786543023268003`*^9}, {3.5786543326376*^9, 3.5786543453828*^9}, {
   3.5786544706507998`*^9, 3.5786545014296*^9}, {3.5786547911345997`*^9, 
   3.5786548026006002`*^9}, {3.5786551025202*^9, 3.5786551113032*^9}, {
   3.5786556506692*^9, 3.5786556656764*^9}, {3.5786567131414003`*^9, 
   3.5786567246074*^9}, {3.5787179395101967`*^9, 3.578717971770997*^9}, {
   3.578718077258197*^9, 3.578718088334197*^9}, {3.578718162246997*^9, 
   3.578718165803797*^9}, {3.578718609358597*^9, 3.5787186113865967`*^9}, {
   3.578718677031397*^9, 3.5787186782481966`*^9}, {3.578718788898997*^9, 
   3.5787187914573965`*^9}, {3.578721068680597*^9, 3.578721069117397*^9}, {
   3.5787211201287966`*^9, 3.5787211204875965`*^9}, {3.578747403133397*^9, 
   3.578747403694997*^9}, {3.5789889042407994`*^9, 3.5789889326483994`*^9}, {
   3.578988977233199*^9, 3.5789889782315993`*^9}, {3.5789890139555993`*^9, 
   3.578989073781599*^9}, {3.5789894404127994`*^9, 3.578989458773999*^9}, {
   3.5789894906135993`*^9, 3.5789895383339996`*^9}, {3.578989571109599*^9, 
   3.5789895740423994`*^9}, 3.5789896057103996`*^9, {3.5790021010949993`*^9, 
   3.5790021013159995`*^9}, {3.5790023666119995`*^9, 
   3.5790025698919992`*^9}, {3.5790026856779995`*^9, 
   3.5790028212979994`*^9}, {3.5790029140429993`*^9, 3.579002916964999*^9}, {
   3.5790031707699995`*^9, 3.5790031757269993`*^9}, {3.5868504690076*^9, 
   3.5868504842644*^9}, {3.5868505506268*^9, 3.5868505517344*^9}, {
   3.5868507936904*^9, 3.5868507941272*^9}, {3.5868508305376*^9, 
   3.5868508331428003`*^9}, {3.586861617576*^9, 3.5868616474596*^9}, {
   3.5868616947588*^9, 3.5868617178468*^9}, {3.5868617718852*^9, 
   3.5868618017748003`*^9}, 3.5868618335832*^9, {3.5868618782771997`*^9, 
   3.5868618908352003`*^9}, {3.5868630180534*^9, 3.5868630319997997`*^9}, {
   3.5868637316976*^9, 3.58686374659*^9}, {3.5868638202074003`*^9, 
   3.5868638276798*^9}, {3.5868648538408003`*^9, 3.5868648671476*^9}, {
   3.586865546082*^9, 3.5868655512244*^9}, {3.5868664563714*^9, 
   3.5868664621278*^9}, {3.5908978300983877`*^9, 3.590897882810788*^9}, {
   3.590898024567988*^9, 3.590898123721588*^9}, {3.590898877961588*^9, 
   3.5908988973679876`*^9}, 3.5908996004543877`*^9, {3.5909028218985877`*^9, 
   3.590902839276988*^9}, {3.5915306518114023`*^9, 3.591530719173143*^9}, {
   3.5915326883824415`*^9, 3.5915326895492153`*^9}, {3.5915327534767423`*^9, 
   3.5915327796271095`*^9}, {3.5915329526289997`*^9, 
   3.5915329538057823`*^9}, {3.5915382275658865`*^9, 
   3.5915382285855627`*^9}, {3.591543986367614*^9, 3.5915440273619623`*^9}, {
   3.5915440693174486`*^9, 3.59154407001191*^9}, {3.5915444463411827`*^9, 
   3.59154447401256*^9}, 3.591950666779516*^9, {3.5919512254298277`*^9, 
   3.5919512259298215`*^9}, {3.5919517815021896`*^9, 3.591951804282419*^9}, {
   3.591952645926821*^9, 3.591952774048541*^9}, {3.5919528484685106`*^9, 
   3.5919528964672823`*^9}, {3.591952933044471*^9, 3.591952946325381*^9}, {
   3.5933432685214605`*^9, 3.5933433503657346`*^9}, {3.5933434259604*^9, 
   3.5933434263979087`*^9}, {3.5933435259779453`*^9, 3.5933435266810837`*^9}, 
   3.593343829749403*^9, {3.5934106663605433`*^9, 3.5934106840131435`*^9}, {
   3.593410875160943*^9, 3.593410949292143*^9}, {3.593410996388543*^9, 
   3.5934109994929433`*^9}, {3.5934114618925433`*^9, 
   3.5934114978037434`*^9}, {3.5934122106597433`*^9, 3.593412212750143*^9}, {
   3.5934133302777433`*^9, 3.5934133644105434`*^9}, {3.593414911575743*^9, 
   3.5934149550659432`*^9}, {3.5934150077401433`*^9, 
   3.5934150344785433`*^9}, {3.593415761507943*^9, 3.5934157652363434`*^9}, {
   3.593415866551343*^9, 3.593415869530943*^9}, {3.5934188661091967`*^9, 
   3.5934188662966967`*^9}, 3.5934190356091967`*^9, {3.593505904534202*^9, 
   3.593505905362322*^9}, {3.5935130495084686`*^9, 3.5935130564146748`*^9}, {
   3.593513092633193*^9, 3.59351314460161*^9}, {3.593513463052697*^9, 
   3.593513472943259*^9}, {3.5935135036305623`*^9, 3.593513553880241*^9}, {
   3.594313869188159*^9, 3.594313887321262*^9}, {3.5943144886136804`*^9, 
   3.5943144926423736`*^9}, {3.594314688147873*^9, 3.594314706132882*^9}, {
   3.5943147528120394`*^9, 3.594314770580963*^9}, {3.59431867468447*^9, 
   3.59431868753605*^9}, {3.5943201281311483`*^9, 3.5943201334366903`*^9}, {
   3.594320537727563*^9, 3.5943205437555866`*^9}, {3.5943206339324455`*^9, 
   3.5943206379861546`*^9}, {3.5943209919254136`*^9, 
   3.5943209957119436`*^9}, {3.594321187646062*^9, 3.594321191457608*^9}, {
   3.5943217931532507`*^9, 3.594321796451457*^9}, {3.5943218613607807`*^9, 
   3.594321864833098*^9}, {3.5943774515365252`*^9, 3.594377451676925*^9}, {
   3.594377610438125*^9, 3.5943776108125253`*^9}, {3.594378910715725*^9, 
   3.594378920996125*^9}, {3.594379789575925*^9, 3.594379801962325*^9}, {
   3.5943798728341255`*^9, 3.594379877295725*^9}, {3.594381401117925*^9, 
   3.594381410977125*^9}, {3.5943829126733255`*^9, 3.594382916261325*^9}, {
   3.594439156380537*^9, 3.5944392070627365`*^9}, {3.5944402580803366`*^9, 
   3.5944403314315367`*^9}, {3.594440439352337*^9, 3.594440493921137*^9}, {
   3.594440545947137*^9, 3.5944405464463367`*^9}, {3.5944405800487366`*^9, 
   3.594440580688337*^9}, {3.594441008455937*^9, 3.594441135862137*^9}, {
   3.5944411751429367`*^9, 3.594441180119337*^9}, {3.5944412914721365`*^9, 
   3.5944413280073366`*^9}, {3.594441444445137*^9, 3.594441447627537*^9}, {
   3.594448774517537*^9, 3.5944487748451366`*^9}, {3.594449540228137*^9, 
   3.594449540321737*^9}, {3.594449735150137*^9, 3.5944497387537365`*^9}, {
   3.594450449490137*^9, 3.594450455808137*^9}, {3.5944504990221367`*^9, 
   3.5944505026257367`*^9}, {3.5944514371271367`*^9, 3.594451463803137*^9}, {
   3.594451596091137*^9, 3.594451597136337*^9}, {3.594451632829137*^9, 
   3.594451643171937*^9}, {3.594451674153537*^9, 3.594451689691137*^9}, {
   3.5944517744147367`*^9, 3.5944518474539366`*^9}, {3.5944519718971367`*^9, 
   3.594451980024737*^9}, {3.5944522292981367`*^9, 3.594452233198137*^9}, {
   3.594453018964337*^9, 3.594453022864337*^9}, {3.594723152092534*^9, 
   3.594723163998483*^9}, {3.594723256840457*^9, 3.594723263453872*^9}, {
   3.5947235309614954`*^9, 3.59472357074205*^9}, {3.594723609190715*^9, 
   3.5947236129402204`*^9}, {3.59472364515272*^9, 3.5947236756550817`*^9}, {
   3.5961071737038736`*^9, 3.5961071903779974`*^9}, {3.5961072372392735`*^9, 
   3.5961074125942345`*^9}, {3.5961074480568914`*^9, 3.596107512735038*^9}, {
   3.596107549371478*^9, 3.5961075755309286`*^9}, 3.596107675368529*^9, {
   3.596107714075351*^9, 3.596107716541996*^9}, 3.5961077568188643`*^9, {
   3.5961078060266924`*^9, 3.5961078231671247`*^9}, {3.596107854192822*^9, 
   3.596107860399963*^9}, {3.596361793621315*^9, 3.5963620422245226`*^9}, {
   3.59636210521338*^9, 3.596362130054886*^9}, {3.5963621829240212`*^9, 
   3.596362196291904*^9}, {3.5963622322797527`*^9, 3.596362304072461*^9}, {
   3.59636234075984*^9, 3.5963624539790783`*^9}, {3.5963641289000187`*^9, 
   3.5963641522465334`*^9}, {3.663483638255076*^9, 3.6634836564648094`*^9}, {
   3.663484717001248*^9, 3.663484753058696*^9}, {3.6634855034842567`*^9, 
   3.6634855451522837`*^9}, {3.6639355144813657`*^9, 
   3.6639355563220425`*^9}, {3.663935659007708*^9, 3.663935741636611*^9}, {
   3.663935775949524*^9, 3.663935787397482*^9}, {3.6639358364524765`*^9, 
   3.663935837701029*^9}, {3.6639361582862263`*^9, 3.6639361954117155`*^9}, {
   3.6639364157182236`*^9, 3.663936423548538*^9}, {3.663937227567727*^9, 
   3.663937227817737*^9}, {3.6639372681323833`*^9, 3.663937268667405*^9}, {
   3.6639379993596163`*^9, 3.6639380279887676`*^9}, {3.6639430844803114`*^9, 
   3.6639430849903316`*^9}, {3.663943470752804*^9, 3.663943484657363*^9}, {
   3.6639449469008856`*^9, 3.663944947425907*^9}, {3.663944983388884*^9, 
   3.66394498604149*^9}, {3.663945296578824*^9, 3.6639452973978624`*^9}, 
   3.6639454260703154`*^9, {3.6639454845416794`*^9, 3.6639455188730893`*^9}, {
   3.663945549232332*^9, 3.663945552942481*^9}, {3.6639455867973647`*^9, 
   3.663945590832526*^9}, {3.6639458593111053`*^9, 3.663945862856247*^9}, {
   3.6639459065150366`*^9, 3.6639459525748844`*^9}, {3.669464209547323*^9, 
   3.6694642227503514`*^9}, {3.669464282817255*^9, 3.6694644362159047`*^9}, {
   3.669720018169963*^9, 3.669720069048873*^9}, {3.6697202176903753`*^9, 
   3.6697202481321163`*^9}, {3.669720288884447*^9, 3.6697203015201697`*^9}, {
   3.6697203360461445`*^9, 3.6697204042160435`*^9}, {3.669720499522495*^9, 
   3.669720549582358*^9}, {3.669720639427497*^9, 3.66972080521898*^9}, {
   3.6701339990615673`*^9, 3.6701339994329762`*^9}, {3.6701340734161654`*^9, 
   3.6701340821333528`*^9}, {3.6701341219330645`*^9, 
   3.6701341223744864`*^9}, {3.670134155953071*^9, 3.6701342077367954`*^9}, {
   3.6846610016295753`*^9, 3.684661028321723*^9}, {3.73642218898512*^9, 
   3.7364222063761144`*^9}, {3.736422268586673*^9, 3.736422295254198*^9}, {
   3.736423088210552*^9, 3.7364231100668025`*^9}, {3.736425562881096*^9, 
   3.736425598036106*^9}, 3.7364256307159758`*^9, {3.7364258682995644`*^9, 
   3.736425924325769*^9}, {3.736427819272154*^9, 3.7364278347300377`*^9}, {
   3.737175158681323*^9, 3.7371751589833403`*^9}},
 FontSize->12],

Cell[BoxData[
 GraphicsBox[{{}, GraphicsComplexBox[CompressedData["
1:eJzt1H1ME2ccwPEbLLxUWZhgtYtl1QxBkVGChL0l12duDCkThkLUzFkEFGXy
MhKVymhtDCHisLgZCZmjY7ypOBpl0zikZVCZGDaYTByIlhXWO6msEBEGZe6e
n7njiXH/7w8vacg3veb3u+OTZ/mO7MR0N4qi6rkP/stdimmdHR2pbDtf2+du
5jphqsyORNKqTEWZG27VQ4Md3ex5L+TKAmjDy0Y7omy0KuLGc7itMSY7Mn9Q
ml/hA22W/mxHzZ7uh+77QXcvG7SjJuX3Q+IsCrdvtMOO6tUtpbq5f0x4Xvas
HXV3Db++PmUWt/wdEYOmx4z91ZlzuBXrJAwqXulZssQdWvtxMIPkPq1t5S64
33wiikENP3nXxubO4DbsiWbQg+Jbn6m9pnAbdycxKGZjRodf/kPczuNpDMp5
cVWK+hNoeXMeg6oLl6LK7EmY94OOQc83BNYHrZuA/S6XMciQqDyvFY3j1tsM
DLJajvuIU5y4uxcaGdSUkJu6KRLaONTCzQvrDL1edx/2s3Zxv9fPeQ/4jOKm
RIMMUoRKDxWFjMC8CAeDjDEdUZm9Ntwyr1kGJUzu81ipvgv7eYpYpHK8tnyt
rBd3jlzCIrOlivp7ezvM2xLMImpVYOK1radgv1ejuPYfXV3vVwPvIzSa6/2J
8Zb3K2j8/0pO4nr+kmnTWKSIXHyqaagJfy/X5LFINll7RzVyDbeiUMfN/+ZG
7tsVV3Fr68q47/deDxrNgzZ3G1ikD/vz8xX+v+I21DSyyLC/7uThbT/CftUt
3LzSkwfdK3rg/Xd1sag4/81eY4IVnm/qNotyhl8Y7JyABo9xJbeiM1Y7aN7j
UVNqSPlSJ817bG8R5yxJ/ovmPaokWTXGo3A/eGwOvDPrjIUGjwvjQwdeSmNo
3uPavA3hyQ12mvdYLo6/cjH1Hs17VIe/8sVYBMwDjxmHNS5r9AjNezzwtYci
yNtK8x7LdzjOmTbcpHmP0wXJ+9aremne44Gi0zsrh+B+8OicGP10PLWP5j3q
0/N3KkWtNO9RO3hWY9lYR/MeVZu2dsychvcNHq35/p6lSRaa92i+ENBlmTlL
8x7leyXb+6s6BI/18dsCPkz5TfB4qSbyROO5u4JH2S7NiiP9twWP/r5TrMei
YcFjwS/jjCTRJniUN/8hG44bEDwG94UXuHb1CB59C5Up7V6tgkdtbpHrq+pO
waMztOag9FKb6b88GqzKNW98+7vgkaoactkuOwSPsVuoManugeDRcXX3l+kL
XIJHyWb5W3qNm4L3WL04bjq55BHNe9yj3ixnw6DB40fiY4saz8DvweMFI5ul
vUgpeI/EfuCRaPBI9OPzcf4Cj0SDR6LBI9HgkZyHPRINHokGj0SDR3Ie9kju
hz0SDR6JBo/kPOyRnIc9kvthj0SDR/L5sEdyHvZI7oc9Eg0eyXnYI9HgkdwP
eyQaPJLz4Hwk9oPzcf56fD7OX0/1SM4Dj8R+2CPR4JF8PuyRnIc9kvvB+Th/
gUdyHvbIR9SaM8vS7zEoQProu3fnbKYn+yn7P9nPztdn5+v/5nz9F7PavUg=

    "], {{{}, {}, {}, {}, {}, {}, {}, {}, 
      {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[{
         PolygonBox[{{126, 33, 34, 35, 36, 37, 38, 39, 40, 41, 82, 81, 80, 79,
           78, 77, 76, 75, 74, 127}}], 
         PolygonBox[{{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 
          17, 18, 19, 20, 21, 22, 23, 24, 125, 124, 65, 64, 63, 62, 61, 60, 
          59, 58, 57, 56, 55, 54, 53, 52, 51, 50, 49, 48, 47, 46, 45, 44, 43, 
          42}}]}]}, 
      {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[
        PolygonBox[{{124, 66, 67, 68, 69, 70, 71, 72, 73, 127, 126, 32, 31, 
         30, 29, 28, 27, 26, 25, 
         125}}]]}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, {}, {}, 
      {RGBColor[1, 0, 0], Thickness[Large], 
       LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
         19, 20, 21, 22, 23, 24, 125, 25, 26, 27, 28, 29, 30, 31, 32, 126, 33,
         34, 35, 36, 37, 38, 39, 40, 41}]}, {}, 
      {GrayLevel[0], 
       LineBox[{83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 
        98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 
        112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 
        123}]}}, {{}, {}, 
      {RGBColor[0, 0, 1], Thickness[Large], 
       PointBox[{128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 
        140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 
        154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 
        168}]}, {}, {}}}], {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  AxesOrigin->{3.1556736*^9, 0.},
  Frame->True,
  FrameLabel->{None, None},
  FrameTicks->{{Automatic, Automatic}, {{{3155673600, 
       FormBox["\"2000\"", TraditionalForm]}, {3218832000, 
       FormBox["\"2002\"", TraditionalForm]}, {3281904000, 
       FormBox["\"2004\"", TraditionalForm]}, {3345062400, 
       FormBox["\"2006\"", TraditionalForm]}, {3408134400, 
       FormBox["\"2008\"", TraditionalForm]}, {3471292800, 
       FormBox["\"2010\"", TraditionalForm]}, {3187296000, 
       FormBox["\"\"", TraditionalForm]}, {3250368000, 
       FormBox["\"\"", TraditionalForm]}, {3313526400, 
       FormBox["\"\"", TraditionalForm]}, {3376598400, 
       FormBox["\"\"", TraditionalForm]}, {3439756800, 
       FormBox["\"\"", TraditionalForm]}}, {{3155673600, 
       FormBox["\"\"", TraditionalForm]}, {3218832000, 
       FormBox["\"\"", TraditionalForm]}, {3281904000, 
       FormBox["\"\"", TraditionalForm]}, {3345062400, 
       FormBox["\"\"", TraditionalForm]}, {3408134400, 
       FormBox["\"\"", TraditionalForm]}, {3471292800, 
       FormBox["\"\"", TraditionalForm]}, {3187296000, 
       FormBox["\"\"", TraditionalForm]}, {3250368000, 
       FormBox["\"\"", TraditionalForm]}, {3313526400, 
       FormBox["\"\"", TraditionalForm]}, {3376598400, 
       FormBox["\"\"", TraditionalForm]}, {3439756800, 
       FormBox["\"\"", TraditionalForm]}}}},
  GridLines->{{{3155673600, 
      GrayLevel[0.8]}, {3218832000, 
      GrayLevel[0.8]}, {3281904000, 
      GrayLevel[0.8]}, {3345062400, 
      GrayLevel[0.8]}, {3408134400, 
      GrayLevel[0.8]}, {3471292800, 
      GrayLevel[0.8]}}, None},
  ImageSize->Large,
  LabelStyle->Directive[FontSize -> 13],
  Method->{},
  PlotLabel->FormBox[
    StyleBox[
    "\"Output Response Over Time (% Deviations From 2007Q4)\"", 13, 
     StripOnInput -> False], TraditionalForm],
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic},
  Ticks->None]], "Output",
 CellChangeTimes->{{3.596362280996128*^9, 3.5963623069193525`*^9}, {
   3.596362352887901*^9, 3.596362373689723*^9}, {3.596362415517522*^9, 
   3.59636245492771*^9}, 3.5963630891711836`*^9, 3.596363156837332*^9, 
   3.596363224092024*^9, 3.5963642009739137`*^9, 3.596367830697854*^9, 
   3.663483732938013*^9, 3.6634839464844847`*^9, 3.6634840136164455`*^9, 
   3.663484060922023*^9, 3.663484144086848*^9, 3.663484240133937*^9, 
   3.663484407088063*^9, 3.663484476618656*^9, 3.6634845173754416`*^9, 
   3.6634846273922815`*^9, 3.6634846933932543`*^9, 3.6634848074549294`*^9, 
   3.6634849073705373`*^9, 3.6634849617988057`*^9, 3.6634850296070285`*^9, 
   3.66348523527188*^9, 3.6634853991493845`*^9, 3.6634854534332175`*^9, 
   3.663485508934585*^9, 3.6634855944798174`*^9, 3.663485667881772*^9, 
   3.663485755207117*^9, 3.663485820746852*^9, 3.663485853549201*^9, 
   3.6634858888072*^9, 3.663485957671583*^9, 3.6634860247495656`*^9, {
   3.6634860610242023`*^9, 3.663486086310011*^9}, 3.6634862561146727`*^9, 
   3.663486300015879*^9, 3.663486355500619*^9, 3.663486394914536*^9, 
   3.663486449050685*^9, {3.6634865160871925`*^9, 3.6634865654310017`*^9}, 
   3.6634866218772745`*^9, 3.663486685294196*^9, 3.663486805331333*^9, 
   3.663486875451369*^9, 3.6634870036410804`*^9, 3.6634870833578153`*^9, 
   3.6634871219197187`*^9, 3.663487354707286*^9, 3.663488282789917*^9, 
   3.663488318472097*^9, 3.6634883677651815`*^9, 3.6634884165167804`*^9, 
   3.663488454389535*^9, 3.6634885028401146`*^9, 3.6634886309986844`*^9, 
   3.6634886828603306`*^9, 3.663488755268391*^9, 3.6634887952767487`*^9, {
   3.663488843645277*^9, 3.663488866971321*^9}, 3.6634890679624324`*^9, 
   3.663489187768258*^9, 3.6634892958423257`*^9, 3.6634893555976515`*^9, 
   3.6634900260082417`*^9, 3.663490076586825*^9, 3.6634901573289824`*^9, 
   3.663490252104816*^9, 3.6634906085508623`*^9, 3.663490639995681*^9, 
   3.6634906754866533`*^9, 3.663490715517406*^9, 3.663569869258157*^9, 
   3.663569924668874*^9, 3.6635700231760178`*^9, 3.663570084641415*^9, 
   3.6635701398397193`*^9, 3.663570180027242*^9, 3.663570289043664*^9, 
   3.6635704993920975`*^9, 3.663570573388312*^9, 3.663570629058608*^9, 
   3.663570667769005*^9, 3.663570740997093*^9, 3.663570995107113*^9, 
   3.663571166378634*^9, 3.6635720698456554`*^9, 3.6635723269054885`*^9, 
   3.663590149360917*^9, 3.663590234734711*^9, 3.663590322646716*^9, 
   3.663590383698021*^9, 3.6635904831801553`*^9, 3.6635905598118153`*^9, 
   3.66359116288815*^9, 3.663591609897353*^9, 3.6635916441861343`*^9, 
   3.663591791317257*^9, 3.6635919324482093`*^9, 3.66359197698924*^9, 
   3.6635925114101205`*^9, 3.663592624527517*^9, 3.663592842659052*^9, 
   3.66359296070755*^9, 3.663593054189581*^9, {3.663593123280085*^9, 
   3.6635931374474716`*^9}, 3.6635932296754823`*^9, 3.663593338287814*^9, 
   3.663593381903807*^9, 3.6635934640865555`*^9, 3.6635935832610655`*^9, 
   3.663593941037224*^9, 3.663594021186808*^9, 3.663594109806877*^9, 
   3.663594145853939*^9, 3.663594232748909*^9, 3.663594372687913*^9, 
   3.663594643788419*^9, 3.663594696928458*^9, 3.66359475518579*^9, 
   3.6635948688132896`*^9, 3.6635949915943127`*^9, 3.663928184599144*^9, 
   3.663933082784305*^9, 3.663933710962593*^9, 3.6639339493832293`*^9, 
   3.6639345115611596`*^9, 3.6639352136989837`*^9, 3.6639352868530364`*^9, 
   3.6639353790328293`*^9, 3.6639354702605543`*^9, 3.6639355570120707`*^9, {
   3.663935673161786*^9, 3.663935701076436*^9}, 3.6639357435891895`*^9, 
   3.663935789787577*^9, 3.6639358897081738`*^9, 3.663935993611933*^9, 
   3.6639360322145476`*^9, 3.663936119119622*^9, 3.6639362003219156`*^9, 
   3.663936237727991*^9, 3.663936357637866*^9, 3.6639369197075586`*^9, 
   3.6639370481623173`*^9, 3.663937119573271*^9, 3.663937178658227*^9, 
   3.663937229030286*^9, 3.6639372697224474`*^9, 3.663937309149584*^9, 
   3.6639374564550667`*^9, 3.6639378535715265`*^9, 3.6639379119319425`*^9, 
   3.6639379553258095`*^9, {3.663938029088812*^9, 3.6639380575540237`*^9}, 
   3.663938103993971*^9, 3.663938230277522*^9, 3.6639382989995017`*^9, 
   3.663938348632622*^9, 3.6639383912821665`*^9, 3.663938427590107*^9, 
   3.6639385302347755`*^9, 3.663938630589958*^9, 3.663938747687711*^9, 
   3.663938793083169*^9, 3.663938858679208*^9, 3.6639390704140186`*^9, 
   3.663939130502493*^9, 3.6639392162140074`*^9, 3.6639393373745403`*^9, 
   3.6639393689268675`*^9, 3.6639394361526394`*^9, 3.663939491929473*^9, 
   3.6639395581287184`*^9, 3.6639396051351905`*^9, 3.663939636536072*^9, 
   3.6639396667628894`*^9, 3.66393973514572*^9, 3.6639397882564473`*^9, 
   3.6639398238029623`*^9, 3.6639398879121933`*^9, 3.663939930606105*^9, 
   3.663939982851321*^9, 3.6639400541337605`*^9, 3.66394014855464*^9, 
   3.663940206447567*^9, 3.663940247348332*^9, 3.6639402927622356`*^9, 
   3.663940351449171*^9, 3.6639404353561373`*^9, 3.6639405232097664`*^9, {
   3.663940621509299*^9, 3.663940649736006*^9}, 3.663940720353952*^9, 
   3.6639407544469*^9, 3.6639407890923414`*^9, 3.6639408648505597`*^9, 
   3.663940918768301*^9, {3.6639409511471944`*^9, 3.66394097801886*^9}, 
   3.6639410140058646`*^9, 3.6639410716497374`*^9, 3.66394112118778*^9, 
   3.663941159774929*^9, 3.6639412135341463`*^9, 3.6639412571834693`*^9, 
   3.663941324676281*^9, 3.6639413780439963`*^9, 3.663941833084263*^9, 
   3.6639418803347273`*^9, {3.663942270383334*^9, 3.663942297166567*^9}, {
   3.66394234427816*^9, 3.663942370771837*^9}, 3.6639424010085754`*^9, 
   3.6639426361013136`*^9, 3.6639427481097994`*^9, 3.6639430248838854`*^9, 
   3.663943085590356*^9, 3.663943376074979*^9, 3.6639434859974165`*^9, 
   3.6639437442628303`*^9, 3.6639438262422657`*^9, 3.663943973803405*^9, 
   3.6639440698224435`*^9, 3.663944142638011*^9, 3.663944207599722*^9, 
   3.6639446625455832`*^9, 3.663944720470481*^9, 3.6639447750537863`*^9, 
   3.6639448417740393`*^9, 3.6639448824672585`*^9, 3.663944948045932*^9, 
   3.6639449879515667`*^9, {3.6639452981103907`*^9, 3.6639453211294565`*^9}, 
   3.6639453906108294`*^9, 3.663945426825345*^9, 3.66394548655426*^9, 
   3.663945520355649*^9, 3.663945561799837*^9, 3.663945592150079*^9, 
   3.663945624881941*^9, 3.6639457041342115`*^9, 3.663945786388138*^9, 
   3.663945868953991*^9, 3.6639459531584077`*^9, 3.663994872634403*^9, 
   3.663995139436865*^9, 3.663995282066491*^9, 3.6639953318134785`*^9, 
   3.6639954054329004`*^9, 3.6639954496075387`*^9, 3.6639955249108915`*^9, {
   3.663995557559814*^9, 3.6639955811113896`*^9}, 3.663995622498348*^9, 
   3.6639956768474884`*^9, 3.6639957295773954`*^9, 3.6639978404913883`*^9, 
   3.663997895927596*^9, 3.66399845433539*^9, 3.6639986444650326`*^9, 
   3.6639987377243614`*^9, 3.664001126625965*^9, 3.664001313738989*^9, 
   3.6640014013795357`*^9, 3.6640016035969515`*^9, 3.6640016501017866`*^9, 
   3.66400169092927*^9, 3.6640024520985317`*^9, 3.664002584108607*^9, 
   3.664002707630083*^9, 3.664002796646349*^9, 3.664003358563898*^9, 
   3.6640043430057917`*^9, 3.664004412359011*^9, 3.66400447061972*^9, 
   3.6640045304313717`*^9, 3.6640056368531713`*^9, 3.6640058348596225`*^9, 
   3.6640075383137927`*^9, 3.6640076045498133`*^9, {3.664007729561447*^9, 
   3.6640077567591257`*^9}, 3.664007789949175*^9, 3.664007821735157*^9, 
   3.6640078849810123`*^9, {3.664007915158881*^9, 3.6640079416945376`*^9}, {
   3.6640079767564745`*^9, 3.6640080063463483`*^9}, {3.6640080499456725`*^9, 
   3.6640080786966143`*^9}, 3.66400836724426*^9, 3.6640084421736665`*^9, {
   3.664008546223013*^9, 3.6640085817318463`*^9}, 3.6640086148515635`*^9, 
   3.664088792966473*^9, 3.6640888959258122`*^9, 3.6640890052783785`*^9, 
   3.6640894646689568`*^9, 3.6640896686889133`*^9, 3.6640897001390543`*^9, 
   3.66408977838011*^9, {3.6640898432250395`*^9, 3.66408987130455*^9}, 
   3.6640899253884153`*^9, 3.6640900718466463`*^9, 3.664091616282437*^9, 
   3.6640916765856442`*^9, 3.6640917170777473`*^9, 3.6640917803909693`*^9, 
   3.664091819158964*^9, 3.6640920354759226`*^9, 3.6640921761551304`*^9, 
   3.664092415481303*^9, 3.6640924787406235`*^9, 3.6640925334485188`*^9, 
   3.664092593631632*^9, 3.664092679362569*^9, 3.664092732486829*^9, {
   3.664092762698406*^9, 3.6640927808803744`*^9}, 3.66409320964187*^9, 
   3.6640932532856827`*^9, 3.6640933630188103`*^9, 3.6640935190921087`*^9, 
   3.664098937910981*^9, 3.664099103937376*^9, 3.6640993748541756`*^9, 
   3.664099580832324*^9, 3.664099754016818*^9, 3.664099952475327*^9, 
   3.664100138380327*^9, 3.664100263041438*^9, 3.6641005841147857`*^9, 
   3.664100797787779*^9, 3.664100844991579*^9, 3.664100922629357*^9, 
   3.6641014271183023`*^9, 3.664101548225133*^9, 3.664101929843404*^9, 
   3.664102069525651*^9, 3.6641026213420725`*^9, 3.664110934762556*^9, 
   3.6641120976893654`*^9, 3.6641764266107745`*^9, 3.6693695573775835`*^9, 
   3.669370525836623*^9, 3.6693706415411863`*^9, 3.6693708610692863`*^9, 
   3.669375666593078*^9, 3.6693757155446606`*^9, 3.669375811033287*^9, 
   3.6693761155558696`*^9, 3.6693765598808594`*^9, 3.6693767898341017`*^9, 
   3.669377264407379*^9, 3.669464466889186*^9, 3.669465551891777*^9, 
   3.6694656067540665`*^9, 3.6694658361123295`*^9, 3.669720190637828*^9, 
   3.669720470817853*^9, 3.6697205675963883`*^9, {3.6697206523572364`*^9, 
   3.669720671260318*^9}, 3.6697207310687385`*^9, 3.669720807005082*^9, 
   3.6701351207114573`*^9, 3.676630989924796*^9, 3.676789827793831*^9, 
   3.676882190270832*^9, 3.6768877787408314`*^9, 3.681540909257305*^9, 
   3.681621979678943*^9, 3.6816397963371735`*^9, 3.6840380318844366`*^9, 
   3.6846610577390785`*^9, 3.684673441691176*^9, 3.6846735503653917`*^9, 
   3.6846736873522267`*^9, 3.684673774580216*^9, 3.684673872639825*^9, 
   3.700559442492158*^9, 3.7005595557546363`*^9, 3.736414624838475*^9, 
   3.7364150027590914`*^9, 3.7364261925821123`*^9, 3.7364262924358234`*^9, 
   3.7364265368488035`*^9, 3.7364269753028817`*^9, 3.7364277792978673`*^9, 
   3.7364278359131055`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"CG Loss in output from peak to trough = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "0.5553250453192549`"}]}],
  SequenceForm[
  "CG Loss in output from peak to trough = ", -0.5553250453192549],
  Editable->False]], "Print",
 CellChangeTimes->{3.669720671460329*^9, 3.669720731298752*^9, 
  3.6697208072090936`*^9, 3.670135121119481*^9, 3.6766309901538095`*^9, 
  3.6767898280408454`*^9, 3.6768821905258465`*^9, 3.676887778964844*^9, 
  3.681540909432315*^9, 3.6816219798359437`*^9, 3.681639796524577*^9, 
  3.684038032129451*^9, 3.684661057950091*^9, 3.684673441882187*^9, 
  3.6846735505804043`*^9, 3.684673687591241*^9, 3.6846737748082294`*^9, 
  3.6846738728458366`*^9, 3.700559442782174*^9, 3.7005595560266514`*^9, 
  3.736414625168494*^9, 3.7364150028710976`*^9, 3.7364261926051135`*^9, 
  3.7364262924648256`*^9, 3.736426536876805*^9, 3.736426975323883*^9, 
  3.736427779328869*^9, 3.736427835923106*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"RE Loss in output from peak to trough = \"\>", 
   "\[InvisibleSpace]", "2.2436566847613415`"}],
  SequenceForm[
  "RE Loss in output from peak to trough = ", 2.2436566847613415`],
  Editable->False]], "Print",
 CellChangeTimes->{3.669720671460329*^9, 3.669720731298752*^9, 
  3.6697208072090936`*^9, 3.670135121119481*^9, 3.6766309901538095`*^9, 
  3.6767898280408454`*^9, 3.6768821905258465`*^9, 3.676887778964844*^9, 
  3.681540909432315*^9, 3.6816219798359437`*^9, 3.681639796524577*^9, 
  3.684038032129451*^9, 3.684661057950091*^9, 3.684673441882187*^9, 
  3.6846735505804043`*^9, 3.684673687591241*^9, 3.6846737748082294`*^9, 
  3.6846738728458366`*^9, 3.700559442782174*^9, 3.7005595560266514`*^9, 
  3.736414625168494*^9, 3.7364150028710976`*^9, 3.7364261926051135`*^9, 
  3.7364262924648256`*^9, 3.736426536876805*^9, 3.736426975323883*^9, 
  3.736427779328869*^9, 3.736427835924106*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{927, 957},
WindowMargins->{{6, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
Magnification->1.2000000476837158`,
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (January 25, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 183, 2, 201, "Title"],
Cell[765, 26, 244, 3, 66, "Subtitle"],
Cell[1012, 31, 5445, 96, 677, "Text"],
Cell[CellGroupData[{
Cell[6482, 131, 177, 2, 103, "Section"],
Cell[6662, 135, 750, 15, 126, "Text"],
Cell[7415, 152, 941, 14, 36, "Input"],
Cell[8359, 168, 84, 2, 36, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8480, 175, 94, 1, 103, "Section"],
Cell[8577, 178, 1427, 25, 250, "Text"],
Cell[CellGroupData[{
Cell[10029, 207, 159, 2, 69, "Subsection"],
Cell[CellGroupData[{
Cell[10213, 213, 4767, 89, 714, "Input"],
Cell[14983, 304, 5660, 104, 390, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[20692, 414, 211, 3, 69, "Subsection"],
Cell[20906, 419, 21863, 372, 618, "Input"],
Cell[CellGroupData[{
Cell[42794, 795, 154, 2, 56, "Subsubsection"],
Cell[CellGroupData[{
Cell[42973, 801, 820, 21, 114, "Input"],
Cell[43796, 824, 5648, 104, 390, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[49505, 935, 244, 5, 69, "Subsection"],
Cell[49752, 942, 220, 5, 37, "Text"],
Cell[CellGroupData[{
Cell[49997, 951, 2257, 61, 282, "Input"],
Cell[52257, 1014, 53466, 769, 390, "Output"],
Cell[105726, 1785, 53541, 771, 382, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[159328, 2563, 132, 1, 66, "Section"],
Cell[159463, 2566, 3984, 123, 435, "Input"],
Cell[CellGroupData[{
Cell[163472, 2693, 161, 2, 58, "Subsection"],
Cell[163636, 2697, 39201, 599, 395, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[202874, 3301, 122, 1, 58, "Subsection"],
Cell[202999, 3304, 8926, 213, 455, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[211962, 3522, 144, 3, 58, "Subsection"],
Cell[CellGroupData[{
Cell[212131, 3529, 3788, 88, 295, "Input"],
Cell[215922, 3619, 46206, 645, 24, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[262189, 4271, 108, 1, 103, "Section"],
Cell[CellGroupData[{
Cell[262322, 4276, 160, 4, 58, "Subsection"],
Cell[262485, 4282, 71929, 1049, 355, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[334451, 5336, 186, 2, 69, "Subsection"],
Cell[334640, 5340, 7759, 191, 426, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[342436, 5536, 205, 4, 69, "Subsection"],
Cell[342644, 5542, 16183, 402, 762, "Input"],
Cell[358830, 5946, 8848, 282, 1098, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[367715, 6233, 245, 4, 69, "Subsection"],
Cell[367963, 6239, 144, 2, 37, "Text"],
Cell[368110, 6243, 2215, 49, 114, "Input"],
Cell[CellGroupData[{
Cell[370350, 6296, 14579, 264, 618, "Input"],
Cell[CellGroupData[{
Cell[384954, 6564, 119, 1, 31, "Print"],
Cell[385076, 6567, 1805, 40, 178, "Print"],
Cell[386884, 6609, 137, 2, 31, "Print"],
Cell[387024, 6613, 231, 5, 31, "Print"]
}, Open  ]],
Cell[387270, 6621, 420, 9, 36, "Output"],
Cell[CellGroupData[{
Cell[387715, 6634, 119, 1, 26, "Print"],
Cell[387837, 6637, 1015, 32, 149, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[388901, 6675, 2603, 74, 244, "Input"],
Cell[391507, 6751, 11768, 163, 156, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[403336, 6921, 339, 6, 153, "Section"],
Cell[CellGroupData[{
Cell[403700, 6931, 150, 3, 32, "Subsubsection"],
Cell[403853, 6936, 44012, 613, 34, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[447902, 7554, 219, 3, 47, "Subsubsection"],
Cell[448124, 7559, 3329, 99, 295, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[451490, 7663, 140, 3, 56, "Subsubsection"],
Cell[451633, 7668, 294, 7, 37, "Text"],
Cell[451930, 7677, 8290, 261, 734, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[460257, 7943, 176, 2, 47, "Subsubsection"],
Cell[460436, 7947, 9143, 259, 1440, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[469616, 8211, 101, 1, 47, "Subsubsection"],
Cell[469720, 8214, 7130, 174, 1095, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[476899, 8394, 329, 6, 103, "Section"],
Cell[CellGroupData[{
Cell[477253, 8404, 160, 2, 58, "Subsection"],
Cell[477416, 8408, 3785, 98, 382, "Input"],
Cell[481204, 8508, 1583, 51, 175, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[482836, 8565, 199, 3, 103, "Section"],
Cell[483038, 8570, 438, 11, 34, "Input"],
Cell[CellGroupData[{
Cell[483501, 8585, 206, 3, 58, "Subsection"],
Cell[483710, 8590, 3279, 106, 244, "Input"],
Cell[CellGroupData[{
Cell[487014, 8700, 17828, 284, 235, "Input"],
Cell[504845, 8986, 15177, 237, 494, "Output"],
Cell[CellGroupData[{
Cell[520047, 9227, 965, 17, 26, "Print"],
Cell[521015, 9246, 946, 16, 26, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
